@@ -4,35 +4,30 @@
 #include "gtest/gtest.h"
 #include "mozilla/BasePrincipal.h"
 
-using mozilla::PrincipalOriginAttributes;
+using mozilla::OriginAttributes;
 
-static void
-TestSuffix(const PrincipalOriginAttributes& attrs)
-{
+static void TestSuffix(const OriginAttributes& attrs) {
   nsAutoCString suffix;
   attrs.CreateSuffix(suffix);
 
-  PrincipalOriginAttributes attrsFromSuffix;
+  OriginAttributes attrsFromSuffix;
   bool success = attrsFromSuffix.PopulateFromSuffix(suffix);
   EXPECT_TRUE(success);
 
   EXPECT_EQ(attrs, attrsFromSuffix);
 }
 
-TEST(PrincipalOriginAttributes, Suffix_default)
-{
-  PrincipalOriginAttributes attrs;
+TEST(OriginAttributes, Suffix_default) {
+  OriginAttributes attrs;
   TestSuffix(attrs);
 }
 
-TEST(PrincipalOriginAttributes, Suffix_appId_inIsolatedMozBrowser)
-{
-  PrincipalOriginAttributes attrs(1, true);
+TEST(OriginAttributes, Suffix_appId_inIsolatedMozBrowser) {
+  OriginAttributes attrs(1, true);
   TestSuffix(attrs);
 }
 
-TEST(PrincipalOriginAttributes, Suffix_maxAppId_inIsolatedMozBrowser)
-{
-  PrincipalOriginAttributes attrs(4294967295, true);
+TEST(OriginAttributes, Suffix_maxAppId_inIsolatedMozBrowser) {
+  OriginAttributes attrs(4294967295, true);
   TestSuffix(attrs);
 }
