@@ -1,7 +1,7 @@
 var urifixup = Cc["@mozilla.org/docshell/urifixup;1"].
                getService(Ci.nsIURIFixup);
 
-Components.utils.import("resource://gre/modules/Services.jsm");
+ChromeUtils.import("resource://gre/modules/Services.jsm");
 
 var prefList = ["browser.fixup.typo.scheme", "keyword.enabled",
                 "browser.fixup.domainwhitelist.whitelisted"];
@@ -14,14 +14,19 @@ const kSearchEngineURL = "http://www.example.org/?search={searchTerms}";
 Services.search.addEngineWithDetails(kSearchEngineID, "", "", "", "get",
                                      kSearchEngineURL);
 
+Services.io.getProtocolHandler("resource")
+        .QueryInterface(Ci.nsIResProtocolHandler)
+        .setSubstitution("search-plugins",
+                         Services.io.newURI("chrome://mozapps/locale/searchplugins/"));
+
 var oldDefaultEngine = Services.search.defaultEngine;
 Services.search.defaultEngine = Services.search.getEngineByName(kSearchEngineID);
 
 var selectedName = Services.search.defaultEngine.name;
-do_check_eq(selectedName, kSearchEngineID);
+Assert.equal(selectedName, kSearchEngineID);
 
 const kForceHostLookup = "browser.fixup.dns_first_for_single_words";
-do_register_cleanup(function() {
+registerCleanupFunction(function() {
   if (oldDefaultEngine) {
     Services.search.defaultEngine = oldDefaultEngine;
   }
@@ -182,12 +187,10 @@ var testcases = [ {
   }, {
     input: "[::1]:8000",
     fixedURI: "http://[::1]:8000/",
-    alternateURI: "http://[::1]:8000/",
     protocolChange: true,
   }, {
     input: "[::1]:8000/",
     fixedURI: "http://[::1]:8000/",
-    alternateURI: "http://[::1]:8000/",
     protocolChange: true,
   }, {
     input: "[[::1]]/",
@@ -200,11 +203,13 @@ var testcases = [ {
     protocolChange: true,
   }, {
     input: "[64:ff9b::8.8.8.8]",
-    fixedURI: "http://[64:ff9b::8.8.8.8]/",
+    fixedURI: "http://[64:ff9b::808:808]/",
+    alternateURI: "http://[64:ff9b::808:808]/",
     protocolChange: true
   }, {
     input: "[64:ff9b::8.8.8.8]/~moz",
-    fixedURI: "http://[64:ff9b::8.8.8.8]/~moz",
+    fixedURI: "http://[64:ff9b::808:808]/~moz",
+    alternateURI: "http://[64:ff9b::808:808]/~moz",
     protocolChange: true
   }, {
     input: "[::1][::1]",
@@ -213,7 +218,6 @@ var testcases = [ {
   }, {
     input: "[::1][100",
     fixedURI: null,
-    alternateURI: null,
     keywordLookup: true,
     protocolChange: true
   }, {
@@ -338,8 +342,8 @@ var testcases = [ {
     inWhitelist: true,
   }, {
     input: "café.local",
-    fixedURI: "http://café.local/",
-    alternateURI: "http://www.café.local/",
+    fixedURI: "http://xn--caf-dma.local/",
+    alternateURI: "http://www.xn--caf-dma.local/",
     protocolChange: true
   }, {
     input: "47.6182,-122.830",
@@ -426,8 +430,6 @@ var testcases = [ {
     protocolChange: true,
   }, {
     input: "?'.com",
-    fixedURI: "http:///?%27.com",
-    alternateURI: "http://www..com/?%27.com",
     keywordLookup: true,
     protocolChange: true,
   }, {
@@ -436,14 +438,10 @@ var testcases = [ {
     protocolChange: true
   }, {
     input: "?mozilla",
-    fixedURI: "http:///?mozilla",
-    alternateURI: "http://www..com/?mozilla",
     keywordLookup: true,
     protocolChange: true,
   }, {
     input: "??mozilla",
-    fixedURI: "http:///??mozilla",
-    alternateURI: "http://www..com/??mozilla",
     keywordLookup: true,
     protocolChange: true,
   }, {
@@ -475,7 +473,37 @@ var testcases = [ {
     keywordLookup: true,
     protocolChange: true,
     affectedByDNSForSingleHosts: true,
-  }];
+  }, {
+    input: "localhost",
+    fixedURI: "http://localhost/",
+    keywordLookup: true,
+    protocolChange: true,
+    affectedByDNSForSingleHosts: true,
+  }, {
+    input: "localhost:8080",
+    fixedURI: "http://localhost:8080/",
+    protocolChange: true,
+  }, {
+    input: "plonk:8080",
+    fixedURI: "http://plonk:8080/",
+    protocolChange: true,
+  }, {
+    input: "\u10E0\u10D4\u10D2\u10D8\u10E1\u10E2\u10E0\u10D0\u10EA\u10D8\u10D0.\u10D2\u10D4",
+    fixedURI: "http://xn--lodaehvb5cdik4g.xn--node/",
+    alternateURI: "http://www.xn--lodaehvb5cdik4g.xn--node/",
+    protocolChange: true,
+  },
+  {
+    input: " \t mozilla.org/\t \t ",
+    fixedURI: "http://mozilla.org/",
+    alternateURI: "http://www.mozilla.org/",
+    protocolChange: true,
+  },
+  {
+    input: " moz\ti\tlla.org ",
+    keywordLookup: true,
+  },
+];
 
 if (Services.appinfo.OS.toLowerCase().startsWith("win")) {
   testcases.push({
@@ -510,14 +538,14 @@ function sanitize(input) {
 var gSingleWordHostLookup = false;
 function run_test() {
   // Only keywordlookup things should be affected by requiring a DNS lookup for single-word hosts:
-  do_print("Check only keyword lookup testcases should be affected by requiring DNS for single hosts");
+  info("Check only keyword lookup testcases should be affected by requiring DNS for single hosts");
   let affectedTests = testcases.filter(t => !t.keywordLookup && t.affectedByDNSForSingleHosts);
   if (affectedTests.length) {
     for (let testcase of affectedTests) {
-      do_print("Affected: " + testcase.input);
+      info("Affected: " + testcase.input);
     }
   }
-  do_check_eq(affectedTests.length, 0);
+  Assert.equal(affectedTests.length, 0);
   do_single_test_run();
   gSingleWordHostLookup = true;
   do_single_test_run();
@@ -547,74 +575,77 @@ function do_single_test_run() {
     expectKeywordLookup = expectKeywordLookup && (!affectedByDNSForSingleHosts || !gSingleWordHostLookup);
 
     for (let flags of flagInputs) {
-      let info;
+      let URIInfo;
       let fixupURIOnly = null;
       try {
         fixupURIOnly = urifixup.createFixupURI(testInput, flags);
       } catch (ex) {
-        do_print("Caught exception: " + ex);
-        do_check_eq(expectedFixedURI, null);
+        info("Caught exception: " + ex);
+        Assert.equal(expectedFixedURI, null);
       }
 
       try {
-        info = urifixup.getFixupURIInfo(testInput, flags);
+        URIInfo = urifixup.getFixupURIInfo(testInput, flags);
       } catch (ex) {
         // Both APIs should return an error in the same cases.
-        do_print("Caught exception: " + ex);
-        do_check_eq(expectedFixedURI, null);
-        do_check_eq(fixupURIOnly, null);
+        info("Caught exception: " + ex);
+        Assert.equal(expectedFixedURI, null);
+        Assert.equal(fixupURIOnly, null);
         continue;
       }
 
-      do_print("Checking \"" + testInput + "\" with flags " + flags +
-               " (host lookup for single words: " + (gSingleWordHostLookup ? "yes" : "no") + ")");
+      info("Checking \"" + testInput + "\" with flags " + flags +
+           " (host lookup for single words: " + (gSingleWordHostLookup ? "yes" : "no") + ")");
 
       // Both APIs should then also be using the same spec.
-      do_check_eq(!!fixupURIOnly, !!info.preferredURI);
-      if (fixupURIOnly)
-        do_check_eq(fixupURIOnly.spec, info.preferredURI.spec);
+      Assert.equal(!!fixupURIOnly, !!URIInfo.preferredURI);
+      if (fixupURIOnly) {
+        Assert.equal(fixupURIOnly.spec, URIInfo.preferredURI.spec, "Fixed and preferred URI should match");
+      }
 
       let isFileURL = expectedFixedURI && expectedFixedURI.startsWith("file");
 
       // Check the fixedURI:
       let makeAlternativeURI = flags & urifixup.FIXUP_FLAGS_MAKE_ALTERNATE_URI;
       if (makeAlternativeURI && alternativeURI != null) {
-        do_check_eq(info.fixedURI.spec, alternativeURI);
+        Assert.equal(URIInfo.fixedURI.spec, alternativeURI, "should have gotten alternate URI");
       } else {
-        do_check_eq(info.fixedURI && info.fixedURI.spec, expectedFixedURI);
+        Assert.equal(URIInfo.fixedURI && URIInfo.fixedURI.spec, expectedFixedURI, "should get correct fixed URI");
       }
 
       // Check booleans on input:
       let couldDoKeywordLookup = flags & urifixup.FIXUP_FLAG_ALLOW_KEYWORD_LOOKUP;
-      do_check_eq(!!info.keywordProviderName, couldDoKeywordLookup && expectKeywordLookup);
-      do_check_eq(info.fixupChangedProtocol, expectProtocolChange);
-      do_check_eq(info.fixupCreatedAlternateURI, makeAlternativeURI && alternativeURI != null);
+      Assert.equal(!!URIInfo.keywordProviderName, couldDoKeywordLookup && expectKeywordLookup, "keyword lookup as expected");
+      Assert.equal(URIInfo.fixupChangedProtocol, expectProtocolChange, "protocol change as expected");
+      Assert.equal(URIInfo.fixupCreatedAlternateURI, makeAlternativeURI && alternativeURI != null, "alternative URI as expected");
 
       // Check the preferred URI
       if (couldDoKeywordLookup) {
         if (expectKeywordLookup) {
           if (!inWhitelist) {
             let urlparamInput = encodeURIComponent(sanitize(testInput)).replace(/%20/g, "+");
-            // If the input starts with `?`, then info.preferredURI.spec will omit it
+            // If the input starts with `?`, then URIInfo.preferredURI.spec will omit it
             // In order to test this behaviour, remove `?` only if it is the first character
             if (urlparamInput.startsWith("%3F")) {
               urlparamInput = urlparamInput.replace("%3F", "");
             }
             let searchURL = kSearchEngineURL.replace("{searchTerms}", urlparamInput);
-            let spec = info.preferredURI.spec.replace(/%27/g, "'");
-            do_check_eq(spec, searchURL);
+            let spec = URIInfo.preferredURI.spec.replace(/%27/g, "'");
+            Assert.equal(spec, searchURL, "should get correct search URI");
           } else {
-            do_check_eq(info.preferredURI, null);
+            Assert.equal(URIInfo.preferredURI, null, "not expecting a preferred URI");
           }
         } else {
-          do_check_eq(info.preferredURI.spec, info.fixedURI.spec);
+          Assert.equal(URIInfo.preferredURI.spec, URIInfo.fixedURI.spec, "fixed URI should match");
         }
       } else {
         // In these cases, we should never be doing a keyword lookup and
         // the fixed URI should be preferred:
-        do_check_eq(info.preferredURI.spec, info.fixedURI.spec);
+        let prefURI = URIInfo.preferredURI && URIInfo.preferredURI.spec;
+        let fixedURI = URIInfo.fixedURI && URIInfo.fixedURI.spec;
+        Assert.equal(prefURI, fixedURI, "fixed URI should be same as expected");
       }
-      do_check_eq(sanitize(testInput), info.originalInput);
+      Assert.equal(sanitize(testInput), URIInfo.originalInput, "should mirror original input");
     }
   }
 }
