@@ -295,34 +295,23 @@ qcms_bool qcms_profile_is_bogus(qcms_profile *profile)
        bY = s15Fixed16Number_to_float(profile->blueColorant.Y);
        bZ = s15Fixed16Number_to_float(profile->blueColorant.Z);
 
-       // Check if any of the XYZ values are negative (see mozilla bug 498245)
-       // CIEXYZ tristimulus values cannot be negative according to the spec.
-       negative =
-	       (rX < 0) || (rY < 0) || (rZ < 0) ||
-	       (gX < 0) || (gY < 0) || (gZ < 0) ||
-	       (bX < 0) || (bY < 0) || (bZ < 0);
-
-       if (negative)
-	       return true;
-
-
        // Sum the values; they should add up to something close to white
        sum[0] = rX + gX + bX;
        sum[1] = rY + gY + bY;
        sum[2] = rZ + gZ + bZ;
 
        // Build our target vector (see mozilla bug 460629)
-       target[0] = 0.96420;
-       target[1] = 1.00000;
-       target[2] = 0.82491;
+       target[0] = 0.96420f;
+       target[1] = 1.00000f;
+       target[2] = 0.82491f;
 
        // Our tolerance vector - Recommended by Chris Murphy based on
        // conversion from the LAB space criterion of no more than 3 in any one
        // channel. This is similar to, but slightly more tolerant than Adobe's
        // criterion.
-       tolerance[0] = 0.02;
-       tolerance[1] = 0.02;
-       tolerance[2] = 0.04;
+       tolerance[0] = 0.02f;
+       tolerance[1] = 0.02f;
+       tolerance[2] = 0.04f;
 
        // Compare with our tolerance
        for (i = 0; i < 3; ++i) {
@@ -331,6 +320,28 @@ qcms_bool qcms_profile_is_bogus(qcms_profile *profile)
                return true;
        }
 
+#ifndef __APPLE__
+       // Check if any of the XYZ values are negative (see mozilla bug 498245)
+       // CIEXYZ tristimulus values cannot be negative according to the spec.
+
+       negative =
+	       (rX < 0) || (rY < 0) || (rZ < 0) ||
+	       (gX < 0) || (gY < 0) || (gZ < 0) ||
+	       (bX < 0) || (bY < 0) || (bZ < 0);
+
+#else
+       // Chromatic adaption to D50 can result in negative XYZ, but the white
+       // point D50 tolerance test has passed. Accept negative values herein.
+       // See https://bugzilla.mozilla.org/show_bug.cgi?id=498245#c18 onwards
+       // for discussion about whether profile XYZ can or cannot be negative,
+       // per the spec. Also the https://bugzil.la/450923 user report.
+
+       // FIXME: allow this relaxation on all ports?
+       negative = false;
+#endif
+       if (negative)
+	       return true; // bogus
+
        // All Good
        return false;
 }
@@ -547,7 +558,7 @@ static struct lutmABType *read_tag_lutmABType(struct mem_source *src, struct tag
 	}
 
 	num_in_channels = read_u8(src, offset + 8);
-	num_out_channels = read_u8(src, offset + 8);
+	num_out_channels = read_u8(src, offset + 9);
 	if (num_in_channels > MAX_CHANNELS || num_out_channels > MAX_CHANNELS)
 		return NULL;
 
@@ -605,12 +616,14 @@ static struct lutmABType *read_tag_lutmABType(struct mem_source *src, struct tag
 	memset(lut, 0, sizeof(struct lutmABType));
 	lut->clut_table   = &lut->clut_table_data[0];
 
-	for (i = 0; i < num_in_channels; i++) {
-		lut->num_grid_points[i] = read_u8(src, clut_offset + i);
-		if (lut->num_grid_points[i] == 0) {
-			invalid_source(src, "bad grid_points");
+        if (clut_offset) {
+		for (i = 0; i < num_in_channels; i++) {
+			lut->num_grid_points[i] = read_u8(src, clut_offset + i);
+			if (lut->num_grid_points[i] == 0) {
+				invalid_source(src, "bad grid_points");
+			}
 		}
-	}
+        }
 
 	// Reverse the processing of transformation elements for mBA type.
 	lut->reversed = (type == LUT_MBA_TYPE);
@@ -713,6 +726,11 @@ static struct lutType *read_tag_lutType(struct mem_source *src, struct tag_index
 		return NULL;
 	}
 
+	if (clut_size <= 0) {
+		invalid_source(src, "CLUT must not be empty.");
+		return NULL;
+	}
+
 	if (in_chan != 3 || out_chan != 3) {
 		invalid_source(src, "CLUT only supports RGB");
 		return NULL;
@@ -744,7 +762,7 @@ static struct lutType *read_tag_lutType(struct mem_source *src, struct tag_index
 	lut->e21 = read_s15Fixed16Number(src, offset+40);
 	lut->e22 = read_s15Fixed16Number(src, offset+44);
 
-	for (i = 0; i < lut->num_input_table_entries * in_chan; i++) {
+	for (i = 0; i < (uint32_t)(lut->num_input_table_entries * in_chan); i++) {
 		if (type == LUT8_TYPE) {
 			lut->input_table[i] = uInt8Number_to_float(read_uInt8Number(src, offset + 52 + i * entry_size));
 		} else {
@@ -766,7 +784,7 @@ static struct lutType *read_tag_lutType(struct mem_source *src, struct tag_index
 	}
 
 	output_offset = clut_offset + clut_size * out_chan * entry_size;
-	for (i = 0; i < lut->num_output_table_entries * out_chan; i++) {
+	for (i = 0; i < (uint32_t)(lut->num_output_table_entries * out_chan); i++) {
 		if (type == LUT8_TYPE) {
 			lut->output_table[i] = uInt8Number_to_float(read_uInt8Number(src, output_offset + i*entry_size));
 		} else {
@@ -1303,7 +1321,7 @@ void qcms_data_from_unicode_path(const wchar_t *path, void **mem, size_t *size)
 #define ICC_PROFILE_HEADER_LENGTH 128
 void qcms_data_create_rgb_with_gamma(qcms_CIE_xyY white_point, qcms_CIE_xyYTRIPLE primaries, float gamma, void **mem, size_t *size)
 {
-	uint32_t length, offset, index, xyz_count, trc_count;
+	uint32_t length, index, xyz_count, trc_count;
 	size_t tag_table_offset, tag_data_offset;
 	void *data;
 	struct matrix colorants;
