@@ -8,6 +8,21 @@
 
 #include "Layers.h"
 #include "nsTArray.h"
+#include "mozilla/layers/ISurfaceAllocator.h"
+
+namespace mozilla {
+namespace layers {
+
+class TestSurfaceAllocator final : public ISurfaceAllocator {
+ public:
+  TestSurfaceAllocator() {}
+  ~TestSurfaceAllocator() override {}
+
+  bool IsSameProcess() const override { return true; }
+};
+
+}  // namespace layers
+}  // namespace mozilla
 
 /* Create layer tree from a simple layer tree description syntax.
  * Each index is either the first letter of the layer type or
@@ -25,12 +40,9 @@
  *      t   t
  */
 already_AddRefed<mozilla::layers::Layer> CreateLayerTree(
-    const char* aLayerTreeDescription,
-    nsIntRegion* aVisibleRegions,
-    const gfx3DMatrix* aTransforms,
-    nsRefPtr<mozilla::layers::LayerManager>& aLayerManager,
-    nsTArray<nsRefPtr<mozilla::layers::Layer> >& aLayersOut);
-
+    const char* aLayerTreeDescription, nsIntRegion* aVisibleRegions,
+    const mozilla::gfx::Matrix4x4* aTransforms,
+    RefPtr<mozilla::layers::LayerManager>& aLayerManager,
+    nsTArray<RefPtr<mozilla::layers::Layer> >& aLayersOut);
 
 #endif
-
