@@ -11,7 +11,7 @@
 #include "nsIServiceManager.h"
 #include "nsIInterfaceRequestor.h"
 #include "nsIInterfaceRequestorUtils.h"
-#include "nsXPIDLString.h"
+#include "nsString.h"
 #include "nsReadableUtils.h"
 #include "nsMimeTypes.h"
 #include "nsMemory.h"
@@ -28,11 +28,7 @@
 #include "nsProxyRelease.h"
 #include "nsContentSecurityManager.h"
 #include "nsContentUtils.h"
-
-#ifdef _WIN32_WINNT
-#undef _WIN32_WINNT
-#endif
-#define _WIN32_WINNT 0x0600
+#include "nsNetUtil.h"
 
 // we need windows.h to read out registry information...
 #include <windows.h>
@@ -61,34 +57,24 @@ struct ICONENTRY {
 };
 
 // Match stock icons with names
-static SHSTOCKICONID
-GetStockIconIDForName(const nsACString& aStockName)
-{
-  return aStockName.EqualsLiteral("uac-shield") ? SIID_SHIELD :
-                                                  SIID_INVALID;
+static SHSTOCKICONID GetStockIconIDForName(const nsACString& aStockName) {
+  return aStockName.EqualsLiteral("uac-shield") ? SIID_SHIELD : SIID_INVALID;
 }
 
 // nsIconChannel methods
-nsIconChannel::nsIconChannel()
-{
-}
+nsIconChannel::nsIconChannel() {}
 
-nsIconChannel::~nsIconChannel()
-{
+nsIconChannel::~nsIconChannel() {
   if (mLoadInfo) {
-    NS_ReleaseOnMainThread(mLoadInfo.forget());
+    NS_ReleaseOnMainThreadSystemGroup("nsIconChannel::mLoadInfo",
+                                      mLoadInfo.forget());
   }
 }
 
-NS_IMPL_ISUPPORTS(nsIconChannel,
-                  nsIChannel,
-                  nsIRequest,
-                  nsIRequestObserver,
+NS_IMPL_ISUPPORTS(nsIconChannel, nsIChannel, nsIRequest, nsIRequestObserver,
                   nsIStreamListener)
 
-nsresult
-nsIconChannel::Init(nsIURI* uri)
-{
+nsresult nsIconChannel::Init(nsIURI* uri) {
   NS_ASSERTION(uri, "no uri");
   mUrl = uri;
   mOriginalURI = uri;
@@ -101,116 +87,94 @@ nsIconChannel::Init(nsIURI* uri)
 // nsIRequest methods:
 
 NS_IMETHODIMP
-nsIconChannel::GetName(nsACString& result)
-{
-  return mUrl->GetSpec(result);
-}
+nsIconChannel::GetName(nsACString& result) { return mUrl->GetSpec(result); }
 
 NS_IMETHODIMP
-nsIconChannel::IsPending(bool* result)
-{
-  return mPump->IsPending(result);
-}
+nsIconChannel::IsPending(bool* result) { return mPump->IsPending(result); }
 
 NS_IMETHODIMP
-nsIconChannel::GetStatus(nsresult* status)
-{
-  return mPump->GetStatus(status);
-}
+nsIconChannel::GetStatus(nsresult* status) { return mPump->GetStatus(status); }
 
 NS_IMETHODIMP
-nsIconChannel::Cancel(nsresult status)
-{
-  return mPump->Cancel(status);
-}
+nsIconChannel::Cancel(nsresult status) { return mPump->Cancel(status); }
 
 NS_IMETHODIMP
-nsIconChannel::Suspend(void)
-{
-  return mPump->Suspend();
-}
+nsIconChannel::Suspend(void) { return mPump->Suspend(); }
 
 NS_IMETHODIMP
-nsIconChannel::Resume(void)
-{
-  return mPump->Resume();
-}
+nsIconChannel::Resume(void) { return mPump->Resume(); }
 NS_IMETHODIMP
-nsIconChannel::GetLoadGroup(nsILoadGroup** aLoadGroup)
-{
+nsIconChannel::GetLoadGroup(nsILoadGroup** aLoadGroup) {
   *aLoadGroup = mLoadGroup;
   NS_IF_ADDREF(*aLoadGroup);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetLoadGroup(nsILoadGroup* aLoadGroup)
-{
+nsIconChannel::SetLoadGroup(nsILoadGroup* aLoadGroup) {
   mLoadGroup = aLoadGroup;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::GetLoadFlags(uint32_t* aLoadAttributes)
-{
+nsIconChannel::GetLoadFlags(uint32_t* aLoadAttributes) {
   return mPump->GetLoadFlags(aLoadAttributes);
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetLoadFlags(uint32_t aLoadAttributes)
-{
+nsIconChannel::SetLoadFlags(uint32_t aLoadAttributes) {
   return mPump->SetLoadFlags(aLoadAttributes);
 }
 
+NS_IMETHODIMP
+nsIconChannel::GetIsDocument(bool* aIsDocument) {
+  return NS_GetIsDocumentChannel(this, aIsDocument);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // nsIChannel methods:
 
 NS_IMETHODIMP
-nsIconChannel::GetOriginalURI(nsIURI** aURI)
-{
+nsIconChannel::GetOriginalURI(nsIURI** aURI) {
   *aURI = mOriginalURI;
   NS_ADDREF(*aURI);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetOriginalURI(nsIURI* aURI)
-{
+nsIconChannel::SetOriginalURI(nsIURI* aURI) {
   NS_ENSURE_ARG_POINTER(aURI);
   mOriginalURI = aURI;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::GetURI(nsIURI** aURI)
-{
+nsIconChannel::GetURI(nsIURI** aURI) {
   *aURI = mUrl;
   NS_IF_ADDREF(*aURI);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::Open(nsIInputStream** _retval)
-{
+nsIconChannel::Open(nsIInputStream** _retval) {
   return MakeInputStream(_retval, false);
 }
 
 NS_IMETHODIMP
-nsIconChannel::Open2(nsIInputStream** aStream)
-{
+nsIconChannel::Open2(nsIInputStream** aStream) {
   nsCOMPtr<nsIStreamListener> listener;
-  nsresult rv = nsContentSecurityManager::doContentSecurityCheck(this, listener);
+  nsresult rv =
+      nsContentSecurityManager::doContentSecurityCheck(this, listener);
   NS_ENSURE_SUCCESS(rv, rv);
   return Open(aStream);
 }
 
-nsresult
-nsIconChannel::ExtractIconInfoFromUrl(nsIFile** aLocalFile,
-                        uint32_t* aDesiredImageSize, nsCString& aContentType,
-                        nsCString& aFileExtension)
-{
+nsresult nsIconChannel::ExtractIconInfoFromUrl(nsIFile** aLocalFile,
+                                               uint32_t* aDesiredImageSize,
+                                               nsCString& aContentType,
+                                               nsCString& aFileExtension) {
   nsresult rv = NS_OK;
-  nsCOMPtr<nsIMozIconURI> iconURI (do_QueryInterface(mUrl, &rv));
+  nsCOMPtr<nsIMozIconURI> iconURI(do_QueryInterface(mUrl, &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
   iconURI->GetImageSize(aDesiredImageSize);
@@ -232,25 +196,28 @@ nsIconChannel::ExtractIconInfoFromUrl(nsIFile** aLocalFile,
 }
 
 NS_IMETHODIMP
-nsIconChannel::AsyncOpen(nsIStreamListener* aListener,
-                                       nsISupports* ctxt)
-{
-  MOZ_ASSERT(!mLoadInfo ||
-             mLoadInfo->GetSecurityMode() == 0 ||
-             mLoadInfo->GetInitialSecurityCheckDone() ||
-             (mLoadInfo->GetSecurityMode() == nsILoadInfo::SEC_ALLOW_CROSS_ORIGIN_DATA_IS_NULL &&
-              nsContentUtils::IsSystemPrincipal(mLoadInfo->LoadingPrincipal())),
-             "security flags in loadInfo but asyncOpen2() not called");
+nsIconChannel::AsyncOpen(nsIStreamListener* aListener, nsISupports* ctxt) {
+  MOZ_ASSERT(
+      !mLoadInfo || mLoadInfo->GetSecurityMode() == 0 ||
+          mLoadInfo->GetInitialSecurityCheckDone() ||
+          (mLoadInfo->GetSecurityMode() ==
+               nsILoadInfo::SEC_ALLOW_CROSS_ORIGIN_DATA_IS_NULL &&
+           nsContentUtils::IsSystemPrincipal(mLoadInfo->LoadingPrincipal())),
+      "security flags in loadInfo but asyncOpen2() not called");
 
   nsCOMPtr<nsIInputStream> inStream;
   nsresult rv = MakeInputStream(getter_AddRefs(inStream), true);
   if (NS_FAILED(rv)) {
+    mCallbacks = nullptr;
     return rv;
   }
 
   // Init our streampump
-  rv = mPump->Init(inStream, int64_t(-1), int64_t(-1), 0, 0, false);
+  nsCOMPtr<nsIEventTarget> target = nsContentUtils::GetEventTargetByLoadInfo(
+      mLoadInfo, mozilla::TaskCategory::Other);
+  rv = mPump->Init(inStream, 0, 0, false, target);
   if (NS_FAILED(rv)) {
+    mCallbacks = nullptr;
     return rv;
   }
 
@@ -262,23 +229,27 @@ nsIconChannel::AsyncOpen(nsIStreamListener* aListener,
     if (mLoadGroup) {
       mLoadGroup->AddRequest(this, nullptr);
     }
+  } else {
+    mCallbacks = nullptr;
   }
+
   return rv;
 }
 
 NS_IMETHODIMP
-nsIconChannel::AsyncOpen2(nsIStreamListener* aListener)
-{
+nsIconChannel::AsyncOpen2(nsIStreamListener* aListener) {
   nsCOMPtr<nsIStreamListener> listener = aListener;
-  nsresult rv = nsContentSecurityManager::doContentSecurityCheck(this, listener);
-  NS_ENSURE_SUCCESS(rv, rv);
+  nsresult rv =
+      nsContentSecurityManager::doContentSecurityCheck(this, listener);
+  if (NS_FAILED(rv)) {
+    mCallbacks = nullptr;
+    return rv;
+  }
   return AsyncOpen(listener, nullptr);
 }
 
-static DWORD
-GetSpecialFolderIcon(nsIFile* aFile, int aFolder,
-                                  SHFILEINFOW* aSFI, UINT aInfoFlags)
-{
+static DWORD GetSpecialFolderIcon(nsIFile* aFile, int aFolder,
+                                  SHFILEINFOW* aSFI, UINT aInfoFlags) {
   DWORD shellResult = 0;
 
   if (!aFile) {
@@ -301,8 +272,7 @@ GetSpecialFolderIcon(nsIFile* aFile, int aFolder,
 
     if (!wcsicmp(fileNativePath, specialNativePath)) {
       aInfoFlags |= (SHGFI_PIDL | SHGFI_SYSICONINDEX);
-      shellResult = ::SHGetFileInfoW((LPCWSTR)(LPCITEMIDLIST)idList, 0,
-                                      aSFI,
+      shellResult = ::SHGetFileInfoW((LPCWSTR)(LPCITEMIDLIST)idList, 0, aSFI,
                                      sizeof(*aSFI), aInfoFlags);
     }
   }
@@ -310,28 +280,22 @@ GetSpecialFolderIcon(nsIFile* aFile, int aFolder,
   return shellResult;
 }
 
-static UINT
-GetSizeInfoFlag(uint32_t aDesiredImageSize)
-{
-  return
-    (UINT) (aDesiredImageSize > 16 ? SHGFI_SHELLICONSIZE : SHGFI_SMALLICON);
+static UINT GetSizeInfoFlag(uint32_t aDesiredImageSize) {
+  return (UINT)(aDesiredImageSize > 16 ? SHGFI_SHELLICONSIZE : SHGFI_SMALLICON);
 }
 
-nsresult
-nsIconChannel::GetHIconFromFile(HICON* hIcon)
-{
-  nsXPIDLCString contentType;
+nsresult nsIconChannel::GetHIconFromFile(HICON* hIcon) {
+  nsCString contentType;
   nsCString fileExt;
-  nsCOMPtr<nsIFile> localFile; // file we want an icon for
+  nsCOMPtr<nsIFile> localFile;  // file we want an icon for
   uint32_t desiredImageSize;
   nsresult rv = ExtractIconInfoFromUrl(getter_AddRefs(localFile),
-                                       &desiredImageSize, contentType,
-                                       fileExt);
+                                       &desiredImageSize, contentType, fileExt);
   NS_ENSURE_SUCCESS(rv, rv);
 
   // if the file exists, we are going to use it's real attributes...
   // otherwise we only want to use it for it's extension...
-  SHFILEINFOW      sfi;
+  SHFILEINFOW sfi;
   UINT infoFlags = SHGFI_ICON;
 
   bool fileExists = false;
@@ -344,7 +308,7 @@ nsIconChannel::GetHIconFromFile(HICON* hIcon)
 
     localFile->GetPath(filePath);
     if (filePath.Length() < 2 || filePath[1] != ':') {
-      return NS_ERROR_MALFORMED_URI; // UNC
+      return NS_ERROR_MALFORMED_URI;  // UNC
     }
 
     if (filePath.Last() == ':') {
@@ -352,13 +316,13 @@ nsIconChannel::GetHIconFromFile(HICON* hIcon)
     } else {
       localFile->Exists(&fileExists);
       if (!fileExists) {
-       localFile->GetLeafName(filePath);
+        localFile->GetLeafName(filePath);
       }
     }
   }
 
   if (!fileExists) {
-   infoFlags |= SHGFI_USEFILEATTRIBUTES;
+    infoFlags |= SHGFI_USEFILEATTRIBUTES;
   }
 
   infoFlags |= GetSizeInfoFlag(desiredImageSize);
@@ -366,8 +330,8 @@ nsIconChannel::GetHIconFromFile(HICON* hIcon)
   // if we have a content type... then use it! but for existing files,
   // we want to show their real icon.
   if (!fileExists && !contentType.IsEmpty()) {
-    nsCOMPtr<nsIMIMEService> mimeService
-      (do_GetService(NS_MIMESERVICE_CONTRACTID, &rv));
+    nsCOMPtr<nsIMIMEService> mimeService(
+        do_GetService(NS_MIMESERVICE_CONTRACTID, &rv));
     NS_ENSURE_SUCCESS(rv, rv);
 
     nsAutoCString defFileExt;
@@ -375,17 +339,16 @@ nsIconChannel::GetHIconFromFile(HICON* hIcon)
     // If the mime service does not know about this mime type, we show
     // the generic icon.
     // In any case, we need to insert a '.' before the extension.
-    filePath = NS_LITERAL_STRING(".") +
-               NS_ConvertUTF8toUTF16(defFileExt);
+    filePath = NS_LITERAL_STRING(".") + NS_ConvertUTF8toUTF16(defFileExt);
   }
 
   // Is this the "Desktop" folder?
-  DWORD shellResult = GetSpecialFolderIcon(localFile, CSIDL_DESKTOP,
-                                           &sfi, infoFlags);
+  DWORD shellResult =
+      GetSpecialFolderIcon(localFile, CSIDL_DESKTOP, &sfi, infoFlags);
   if (!shellResult) {
     // Is this the "My Documents" folder?
-    shellResult = GetSpecialFolderIcon(localFile, CSIDL_PERSONAL,
-                                       &sfi, infoFlags);
+    shellResult =
+        GetSpecialFolderIcon(localFile, CSIDL_PERSONAL, &sfi, infoFlags);
   }
 
   // There are other "Special Folders" and Namespace entities that we
@@ -396,9 +359,8 @@ nsIconChannel::GetHIconFromFile(HICON* hIcon)
 
   // Not a special folder, or something else failed above.
   if (!shellResult) {
-    shellResult = ::SHGetFileInfoW(filePath.get(),
-                                   FILE_ATTRIBUTE_ARCHIVE,
-                                   &sfi, sizeof(sfi), infoFlags);
+    shellResult = ::SHGetFileInfoW(filePath.get(), FILE_ATTRIBUTE_ARCHIVE, &sfi,
+                                   sizeof(sfi), infoFlags);
   }
 
   if (shellResult && sfi.hIcon) {
@@ -410,94 +372,74 @@ nsIconChannel::GetHIconFromFile(HICON* hIcon)
   return rv;
 }
 
-nsresult
-nsIconChannel::GetStockHIcon(nsIMozIconURI* aIconURI,
-                                      HICON* hIcon)
-{
+nsresult nsIconChannel::GetStockHIcon(nsIMozIconURI* aIconURI, HICON* hIcon) {
   nsresult rv = NS_OK;
 
-  // We can only do this on Vista or above
-  HMODULE hShellDLL = ::LoadLibraryW(L"shell32.dll");
-  decltype(SHGetStockIconInfo)* pSHGetStockIconInfo =
-    (decltype(SHGetStockIconInfo)*) ::GetProcAddress(hShellDLL,
-                                                    "SHGetStockIconInfo");
+  uint32_t desiredImageSize;
+  aIconURI->GetImageSize(&desiredImageSize);
+  nsAutoCString stockIcon;
+  aIconURI->GetStockIcon(stockIcon);
 
-  if (pSHGetStockIconInfo) {
-    uint32_t desiredImageSize;
-    aIconURI->GetImageSize(&desiredImageSize);
-    nsAutoCString stockIcon;
-    aIconURI->GetStockIcon(stockIcon);
-
-    SHSTOCKICONID stockIconID = GetStockIconIDForName(stockIcon);
-    if (stockIconID == SIID_INVALID) {
-      return NS_ERROR_NOT_AVAILABLE;
-    }
-
-    UINT infoFlags = SHGSI_ICON;
-    infoFlags |= GetSizeInfoFlag(desiredImageSize);
-
-    SHSTOCKICONINFO sii = {0};
-    sii.cbSize = sizeof(sii);
-    HRESULT hr = pSHGetStockIconInfo(stockIconID, infoFlags, &sii);
-
-    if (SUCCEEDED(hr)) {
-      *hIcon = sii.hIcon;
-    } else {
-      rv = NS_ERROR_FAILURE;
-    }
-  } else {
-    rv = NS_ERROR_NOT_AVAILABLE;
+  SHSTOCKICONID stockIconID = GetStockIconIDForName(stockIcon);
+  if (stockIconID == SIID_INVALID) {
+    return NS_ERROR_NOT_AVAILABLE;
   }
 
-  if (hShellDLL) {
-    ::FreeLibrary(hShellDLL);
+  UINT infoFlags = SHGSI_ICON;
+  infoFlags |= GetSizeInfoFlag(desiredImageSize);
+
+  SHSTOCKICONINFO sii = {0};
+  sii.cbSize = sizeof(sii);
+  HRESULT hr = SHGetStockIconInfo(stockIconID, infoFlags, &sii);
+
+  if (SUCCEEDED(hr)) {
+    *hIcon = sii.hIcon;
+  } else {
+    rv = NS_ERROR_FAILURE;
   }
 
   return rv;
 }
 
 // Given a BITMAPINFOHEADER, returns the size of the color table.
-static int
-GetColorTableSize(BITMAPINFOHEADER* aHeader)
-{
+static int GetColorTableSize(BITMAPINFOHEADER* aHeader) {
   int colorTableSize = -1;
 
   // http://msdn.microsoft.com/en-us/library/dd183376%28v=VS.85%29.aspx
   switch (aHeader->biBitCount) {
-  case 0:
-    colorTableSize = 0;
-    break;
-  case 1:
-    colorTableSize = 2 * sizeof(RGBQUAD);
-    break;
-  case 4:
-  case 8: {
-    // The maximum possible size for the color table is 2**bpp, so check for
-    // that and fail if we're not in those bounds
-    unsigned int maxEntries = 1 << (aHeader->biBitCount);
-    if (aHeader->biClrUsed > 0 && aHeader->biClrUsed <= maxEntries) {
-      colorTableSize = aHeader->biClrUsed * sizeof(RGBQUAD);
-    } else if (aHeader->biClrUsed == 0) {
-      colorTableSize = maxEntries * sizeof(RGBQUAD);
+    case 0:
+      colorTableSize = 0;
+      break;
+    case 1:
+      colorTableSize = 2 * sizeof(RGBQUAD);
+      break;
+    case 4:
+    case 8: {
+      // The maximum possible size for the color table is 2**bpp, so check for
+      // that and fail if we're not in those bounds
+      unsigned int maxEntries = 1 << (aHeader->biBitCount);
+      if (aHeader->biClrUsed > 0 && aHeader->biClrUsed <= maxEntries) {
+        colorTableSize = aHeader->biClrUsed * sizeof(RGBQUAD);
+      } else if (aHeader->biClrUsed == 0) {
+        colorTableSize = maxEntries * sizeof(RGBQUAD);
+      }
+      break;
     }
-    break;
-  }
-  case 16:
-  case 32:
-    // If we have BI_BITFIELDS compression, we would normally need 3 DWORDS for
-    // the bitfields mask which would be stored in the color table; However,
-    // we instead force the bitmap to request data of type BI_RGB so the color
-    // table should be of size 0.
-    // Setting aHeader->biCompression = BI_RGB forces the later call to
-    // GetDIBits to return to us BI_RGB data.
-    if (aHeader->biCompression == BI_BITFIELDS) {
-      aHeader->biCompression = BI_RGB;
-    }
-    colorTableSize = 0;
-    break;
-  case 24:
-    colorTableSize = 0;
-    break;
+    case 16:
+    case 32:
+      // If we have BI_BITFIELDS compression, we would normally need 3 DWORDS
+      // for the bitfields mask which would be stored in the color table;
+      // However, we instead force the bitmap to request data of type BI_RGB so
+      // the color table should be of size 0. Setting aHeader->biCompression =
+      // BI_RGB forces the later call to GetDIBits to return to us BI_RGB data.
+      if (aHeader->biCompression == BI_BITFIELDS) {
+        aHeader->biCompression = BI_RGB;
+      }
+      colorTableSize = 0;
+      break;
+    case 24:
+      colorTableSize = 0;
+      break;
   }
 
   if (colorTableSize < 0) {
@@ -509,12 +451,10 @@ GetColorTableSize(BITMAPINFOHEADER* aHeader)
 
 // Given a header and a size, creates a freshly allocated BITMAPINFO structure.
 // It is the caller's responsibility to null-check and delete the structure.
-static BITMAPINFO*
-CreateBitmapInfo(BITMAPINFOHEADER* aHeader, size_t aColorTableSize)
-{
-  BITMAPINFO* bmi = (BITMAPINFO*) ::operator new(sizeof(BITMAPINFOHEADER) +
-                                                 aColorTableSize,
-                                                 mozilla::fallible);
+static BITMAPINFO* CreateBitmapInfo(BITMAPINFOHEADER* aHeader,
+                                    size_t aColorTableSize) {
+  BITMAPINFO* bmi = (BITMAPINFO*)::operator new(
+      sizeof(BITMAPINFOHEADER) + aColorTableSize, mozilla::fallible);
   if (bmi) {
     memcpy(bmi, aHeader, sizeof(BITMAPINFOHEADER));
     memset(bmi->bmiColors, 0, aColorTableSize);
@@ -522,9 +462,8 @@ CreateBitmapInfo(BITMAPINFOHEADER* aHeader, size_t aColorTableSize)
   return bmi;
 }
 
-nsresult
-nsIconChannel::MakeInputStream(nsIInputStream** _retval, bool aNonBlocking)
-{
+nsresult nsIconChannel::MakeInputStream(nsIInputStream** _retval,
+                                        bool aNonBlocking) {
   // Check whether the icon requested's a file icon or a stock icon
   nsresult rv = NS_ERROR_NOT_AVAILABLE;
 
@@ -550,28 +489,25 @@ nsIconChannel::MakeInputStream(nsIInputStream** _retval, bool aNonBlocking)
     ICONINFO iconInfo;
     if (GetIconInfo(hIcon, &iconInfo)) {
       // we got the bitmaps, first find out their size
-      HDC hDC = CreateCompatibleDC(nullptr); // get a device context for
-                                             // the screen.
-      BITMAPINFOHEADER maskHeader  = {sizeof(BITMAPINFOHEADER)};
+      HDC hDC = CreateCompatibleDC(nullptr);  // get a device context for
+                                              // the screen.
+      BITMAPINFOHEADER maskHeader = {sizeof(BITMAPINFOHEADER)};
       BITMAPINFOHEADER colorHeader = {sizeof(BITMAPINFOHEADER)};
       int colorTableSize, maskTableSize;
-      if (GetDIBits(hDC, iconInfo.hbmMask,  0, 0, nullptr,
-                    (BITMAPINFO*)&maskHeader,  DIB_RGB_COLORS) &&
+      if (GetDIBits(hDC, iconInfo.hbmMask, 0, 0, nullptr,
+                    (BITMAPINFO*)&maskHeader, DIB_RGB_COLORS) &&
           GetDIBits(hDC, iconInfo.hbmColor, 0, 0, nullptr,
                     (BITMAPINFO*)&colorHeader, DIB_RGB_COLORS) &&
           maskHeader.biHeight == colorHeader.biHeight &&
-          maskHeader.biWidth  == colorHeader.biWidth  &&
-          colorHeader.biBitCount > 8 &&
-          colorHeader.biSizeImage > 0 &&
+          maskHeader.biWidth == colorHeader.biWidth &&
+          colorHeader.biBitCount > 8 && colorHeader.biSizeImage > 0 &&
           colorHeader.biWidth >= 0 && colorHeader.biWidth <= 255 &&
           colorHeader.biHeight >= 0 && colorHeader.biHeight <= 255 &&
-          maskHeader.biSizeImage > 0  &&
+          maskHeader.biSizeImage > 0 &&
           (colorTableSize = GetColorTableSize(&colorHeader)) >= 0 &&
-          (maskTableSize  = GetColorTableSize(&maskHeader))  >= 0) {
-        uint32_t iconSize = sizeof(ICONFILEHEADER) +
-                            sizeof(ICONENTRY) +
-                            sizeof(BITMAPINFOHEADER) +
-                            colorHeader.biSizeImage +
+          (maskTableSize = GetColorTableSize(&maskHeader)) >= 0) {
+        uint32_t iconSize = sizeof(ICONFILEHEADER) + sizeof(ICONENTRY) +
+                            sizeof(BITMAPINFOHEADER) + colorHeader.biSizeImage +
                             maskHeader.biSizeImage;
 
         UniquePtr<char[]> buffer = MakeUnique<char[]>(iconSize);
@@ -619,24 +555,24 @@ nsIconChannel::MakeInputStream(nsIInputStream** _retval, bool aNonBlocking)
           // followed by the XOR bitmap data (colorHeader)
           // (you'd expect the color table to come here, but it apparently
           // doesn't)
-          BITMAPINFO* colorInfo = CreateBitmapInfo(&colorHeader,
-                                                   colorTableSize);
-          if (colorInfo && GetDIBits(hDC, iconInfo.hbmColor, 0,
-                                     colorHeader.biHeight, whereTo, colorInfo,
-                                     DIB_RGB_COLORS)) {
+          BITMAPINFO* colorInfo =
+              CreateBitmapInfo(&colorHeader, colorTableSize);
+          if (colorInfo &&
+              GetDIBits(hDC, iconInfo.hbmColor, 0, colorHeader.biHeight,
+                        whereTo, colorInfo, DIB_RGB_COLORS)) {
             whereTo += colorHeader.biSizeImage;
 
             // and finally the AND bitmap data (maskHeader)
             BITMAPINFO* maskInfo = CreateBitmapInfo(&maskHeader, maskTableSize);
-            if (maskInfo && GetDIBits(hDC, iconInfo.hbmMask, 0,
-                                      maskHeader.biHeight, whereTo, maskInfo,
-                                      DIB_RGB_COLORS)) {
+            if (maskInfo &&
+                GetDIBits(hDC, iconInfo.hbmMask, 0, maskHeader.biHeight,
+                          whereTo, maskInfo, DIB_RGB_COLORS)) {
               // Now, create a pipe and stuff our data into it
               nsCOMPtr<nsIInputStream> inStream;
               nsCOMPtr<nsIOutputStream> outStream;
               rv = NS_NewPipe(getter_AddRefs(inStream),
-                              getter_AddRefs(outStream),
-                              iconSize, iconSize, aNonBlocking);
+                              getter_AddRefs(outStream), iconSize, iconSize,
+                              aNonBlocking);
               if (NS_SUCCEEDED(rv)) {
                 uint32_t written;
                 rv = outStream->Write(buffer.get(), iconSize, &written);
@@ -645,19 +581,19 @@ nsIconChannel::MakeInputStream(nsIInputStream** _retval, bool aNonBlocking)
                 }
               }
 
-            } // if we got bitmap bits
+            }  // if we got bitmap bits
             delete maskInfo;
-          } // if we got mask bits
+          }  // if we got mask bits
           delete colorInfo;
-        } // if we allocated the buffer
-      } // if we got mask size
+        }  // if we allocated the buffer
+      }    // if we got mask size
 
       DeleteDC(hDC);
       DeleteObject(iconInfo.hbmColor);
       DeleteObject(iconInfo.hbmMask);
-    } // if we got icon info
+    }  // if we got icon info
     DestroyIcon(hIcon);
-  } // if we got an hIcon
+  }  // if we got an hIcon
 
   // If we didn't make a stream, then fail.
   if (!*_retval && NS_SUCCEEDED(rv)) {
@@ -667,138 +603,119 @@ nsIconChannel::MakeInputStream(nsIInputStream** _retval, bool aNonBlocking)
 }
 
 NS_IMETHODIMP
-nsIconChannel::GetContentType(nsACString& aContentType)
-{
+nsIconChannel::GetContentType(nsACString& aContentType) {
   aContentType.AssignLiteral(IMAGE_ICO);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetContentType(const nsACString& aContentType)
-{
+nsIconChannel::SetContentType(const nsACString& aContentType) {
   // It doesn't make sense to set the content-type on this type
   // of channel...
   return NS_ERROR_FAILURE;
 }
 
-NS_IMETHODIMP nsIconChannel::GetContentCharset(nsACString& aContentCharset)
-{
+NS_IMETHODIMP nsIconChannel::GetContentCharset(nsACString& aContentCharset) {
   aContentCharset.Truncate();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetContentCharset(const nsACString& aContentCharset)
-{
+nsIconChannel::SetContentCharset(const nsACString& aContentCharset) {
   // It doesn't make sense to set the content-charset on this type
   // of channel...
   return NS_ERROR_FAILURE;
 }
 
 NS_IMETHODIMP
-nsIconChannel::GetContentDisposition(uint32_t* aContentDisposition)
-{
+nsIconChannel::GetContentDisposition(uint32_t* aContentDisposition) {
   return NS_ERROR_NOT_AVAILABLE;
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetContentDisposition(uint32_t aContentDisposition)
-{
+nsIconChannel::SetContentDisposition(uint32_t aContentDisposition) {
   return NS_ERROR_NOT_AVAILABLE;
 }
 
 NS_IMETHODIMP
-nsIconChannel::
-  GetContentDispositionFilename(nsAString& aContentDispositionFilename)
-{
+nsIconChannel::GetContentDispositionFilename(
+    nsAString& aContentDispositionFilename) {
   return NS_ERROR_NOT_AVAILABLE;
 }
 
 NS_IMETHODIMP
-nsIconChannel::
-  SetContentDispositionFilename(const nsAString& aContentDispositionFilename)
-{
+nsIconChannel::SetContentDispositionFilename(
+    const nsAString& aContentDispositionFilename) {
   return NS_ERROR_NOT_AVAILABLE;
 }
 
 NS_IMETHODIMP
-nsIconChannel::
-  GetContentDispositionHeader(nsACString& aContentDispositionHeader)
-{
+nsIconChannel::GetContentDispositionHeader(
+    nsACString& aContentDispositionHeader) {
   return NS_ERROR_NOT_AVAILABLE;
 }
 
 NS_IMETHODIMP
-nsIconChannel::GetContentLength(int64_t* aContentLength)
-{
+nsIconChannel::GetContentLength(int64_t* aContentLength) {
   *aContentLength = 0;
   return NS_ERROR_FAILURE;
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetContentLength(int64_t aContentLength)
-{
+nsIconChannel::SetContentLength(int64_t aContentLength) {
   NS_NOTREACHED("nsIconChannel::SetContentLength");
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
-nsIconChannel::GetOwner(nsISupports** aOwner)
-{
+nsIconChannel::GetOwner(nsISupports** aOwner) {
   *aOwner = mOwner.get();
   NS_IF_ADDREF(*aOwner);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetOwner(nsISupports* aOwner)
-{
+nsIconChannel::SetOwner(nsISupports* aOwner) {
   mOwner = aOwner;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::GetLoadInfo(nsILoadInfo** aLoadInfo)
-{
+nsIconChannel::GetLoadInfo(nsILoadInfo** aLoadInfo) {
   NS_IF_ADDREF(*aLoadInfo = mLoadInfo);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::SetLoadInfo(nsILoadInfo* aLoadInfo)
-{
+nsIconChannel::SetLoadInfo(nsILoadInfo* aLoadInfo) {
   mLoadInfo = aLoadInfo;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::
-  GetNotificationCallbacks(nsIInterfaceRequestor** aNotificationCallbacks)
-{
+nsIconChannel::GetNotificationCallbacks(
+    nsIInterfaceRequestor** aNotificationCallbacks) {
   *aNotificationCallbacks = mCallbacks.get();
   NS_IF_ADDREF(*aNotificationCallbacks);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::
-  SetNotificationCallbacks(nsIInterfaceRequestor* aNotificationCallbacks)
-{
+nsIconChannel::SetNotificationCallbacks(
+    nsIInterfaceRequestor* aNotificationCallbacks) {
   mCallbacks = aNotificationCallbacks;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIconChannel::GetSecurityInfo(nsISupports** aSecurityInfo)
-{
+nsIconChannel::GetSecurityInfo(nsISupports** aSecurityInfo) {
   *aSecurityInfo = nullptr;
   return NS_OK;
 }
 
 // nsIRequestObserver methods
 NS_IMETHODIMP nsIconChannel::OnStartRequest(nsIRequest* aRequest,
-                                            nsISupports* aContext)
-{
+                                            nsISupports* aContext) {
   if (mListener) {
     return mListener->OnStartRequest(this, aContext);
   }
@@ -806,10 +723,8 @@ NS_IMETHODIMP nsIconChannel::OnStartRequest(nsIRequest* aRequest,
 }
 
 NS_IMETHODIMP
-nsIconChannel::OnStopRequest(nsIRequest* aRequest,
-                             nsISupports* aContext,
-                             nsresult aStatus)
-{
+nsIconChannel::OnStopRequest(nsIRequest* aRequest, nsISupports* aContext,
+                             nsresult aStatus) {
   if (mListener) {
     mListener->OnStopRequest(this, aContext, aStatus);
     mListener = nullptr;
@@ -828,12 +743,9 @@ nsIconChannel::OnStopRequest(nsIRequest* aRequest,
 
 // nsIStreamListener methods
 NS_IMETHODIMP
-nsIconChannel::OnDataAvailable(nsIRequest* aRequest,
-                               nsISupports* aContext,
-                               nsIInputStream* aStream,
-                               uint64_t aOffset,
-                               uint32_t aCount)
-{
+nsIconChannel::OnDataAvailable(nsIRequest* aRequest, nsISupports* aContext,
+                               nsIInputStream* aStream, uint64_t aOffset,
+                               uint32_t aCount) {
   if (mListener) {
     return mListener->OnDataAvailable(this, aContext, aStream, aOffset, aCount);
   }
