@@ -7,10 +7,10 @@
 #include "mozilla/EndianUtils.h"
 #include "mozilla/UniquePtrExtensions.h"
 #include "nsBMPEncoder.h"
-#include "prprf.h"
 #include "nsString.h"
 #include "nsStreamUtils.h"
 #include "nsTArray.h"
+#include "mozilla/CheckedInt.h"
 
 using namespace mozilla;
 using namespace mozilla::image;
@@ -19,19 +19,17 @@ using namespace mozilla::image::bmp;
 NS_IMPL_ISUPPORTS(nsBMPEncoder, imgIEncoder, nsIInputStream,
                   nsIAsyncInputStream)
 
-nsBMPEncoder::nsBMPEncoder() : mImageBufferStart(nullptr),
-                               mImageBufferCurr(0),
-                               mImageBufferSize(0),
-                               mImageBufferReadPoint(0),
-                               mFinished(false),
-                               mCallback(nullptr),
-                               mCallbackTarget(nullptr),
-                               mNotifyThreshold(0)
-{
-}
+nsBMPEncoder::nsBMPEncoder()
+    : mImageBufferStart(nullptr),
+      mImageBufferCurr(0),
+      mImageBufferSize(0),
+      mImageBufferReadPoint(0),
+      mFinished(false),
+      mCallback(nullptr),
+      mCallbackTarget(nullptr),
+      mNotifyThreshold(0) {}
 
-nsBMPEncoder::~nsBMPEncoder()
-{
+nsBMPEncoder::~nsBMPEncoder() {
   if (mImageBufferStart) {
     free(mImageBufferStart);
     mImageBufferStart = nullptr;
@@ -45,28 +43,28 @@ nsBMPEncoder::~nsBMPEncoder()
 // bpp specifies the bits per pixel to use where bpp_value can be 24 or 32
 NS_IMETHODIMP
 nsBMPEncoder::InitFromData(const uint8_t* aData,
-                           uint32_t aLength, // (unused, req'd by JS)
-                           uint32_t aWidth,
-                           uint32_t aHeight,
-                           uint32_t aStride,
+                           uint32_t aLength,  // (unused, req'd by JS)
+                           uint32_t aWidth, uint32_t aHeight, uint32_t aStride,
                            uint32_t aInputFormat,
-                           const nsAString& aOutputOptions)
-{
+                           const nsAString& aOutputOptions) {
   // validate input format
-  if (aInputFormat != INPUT_FORMAT_RGB &&
-      aInputFormat != INPUT_FORMAT_RGBA &&
+  if (aInputFormat != INPUT_FORMAT_RGB && aInputFormat != INPUT_FORMAT_RGBA &&
       aInputFormat != INPUT_FORMAT_HOSTARGB) {
     return NS_ERROR_INVALID_ARG;
   }
 
+  CheckedInt32 check = CheckedInt32(aWidth) * 4;
+  if (MOZ_UNLIKELY(!check.isValid())) {
+    return NS_ERROR_INVALID_ARG;
+  }
+
   // Stride is the padded width of each row, so it better be longer
-  if ((aInputFormat == INPUT_FORMAT_RGB &&
-       aStride < aWidth * 3) ||
+  if ((aInputFormat == INPUT_FORMAT_RGB && aStride < aWidth * 3) ||
       ((aInputFormat == INPUT_FORMAT_RGBA ||
         aInputFormat == INPUT_FORMAT_HOSTARGB) &&
        aStride < aWidth * 4)) {
-      NS_WARNING("Invalid stride for InitFromData");
-      return NS_ERROR_INVALID_ARG;
+    NS_WARNING("Invalid stride for InitFromData");
+    return NS_ERROR_INVALID_ARG;
   }
 
   nsresult rv;
@@ -75,8 +73,8 @@ nsBMPEncoder::InitFromData(const uint8_t* aData,
     return rv;
   }
 
-  rv = AddImageFrame(aData, aLength, aWidth, aHeight, aStride,
-                     aInputFormat, aOutputOptions);
+  rv = AddImageFrame(aData, aLength, aWidth, aHeight, aStride, aInputFormat,
+                     aOutputOptions);
   if (NS_FAILED(rv)) {
     return rv;
   }
@@ -87,19 +85,13 @@ nsBMPEncoder::InitFromData(const uint8_t* aData,
 
 // Just a helper method to make it explicit in calculations that we are dealing
 // with bytes and not bits
-static inline uint32_t
-BytesPerPixel(uint32_t aBPP)
-{
-  return aBPP / 8;
-}
+static inline uint16_t BytesPerPixel(uint16_t aBPP) { return aBPP / 8; }
 
 // Calculates the number of padding bytes that are needed per row of image data
-static inline uint32_t
-PaddingBytes(uint32_t aBPP, uint32_t aWidth)
-{
+static inline uint32_t PaddingBytes(uint16_t aBPP, uint32_t aWidth) {
   uint32_t rowSize = aWidth * BytesPerPixel(aBPP);
   uint8_t paddingSize = 0;
-  if(rowSize % 4) {
+  if (rowSize % 4) {
     paddingSize = (4 - (rowSize % 4));
   }
   return paddingSize;
@@ -107,33 +99,37 @@ PaddingBytes(uint32_t aBPP, uint32_t aWidth)
 
 // See ::InitFromData for other info.
 NS_IMETHODIMP
-nsBMPEncoder::StartImageEncode(uint32_t aWidth,
-                               uint32_t aHeight,
+nsBMPEncoder::StartImageEncode(uint32_t aWidth, uint32_t aHeight,
                                uint32_t aInputFormat,
-                               const nsAString& aOutputOptions)
-{
+                               const nsAString& aOutputOptions) {
   // can't initialize more than once
   if (mImageBufferStart || mImageBufferCurr) {
     return NS_ERROR_ALREADY_INITIALIZED;
   }
 
   // validate input format
-  if (aInputFormat != INPUT_FORMAT_RGB &&
-      aInputFormat != INPUT_FORMAT_RGBA &&
+  if (aInputFormat != INPUT_FORMAT_RGB && aInputFormat != INPUT_FORMAT_RGBA &&
       aInputFormat != INPUT_FORMAT_HOSTARGB) {
     return NS_ERROR_INVALID_ARG;
   }
 
   // parse and check any provided output options
   Version version;
-  uint32_t bpp;
+  uint16_t bpp;
   nsresult rv = ParseOptions(aOutputOptions, version, bpp);
   if (NS_FAILED(rv)) {
     return rv;
   }
+  MOZ_ASSERT(bpp <= 32);
 
-  InitFileHeader(version, bpp, aWidth, aHeight);
-  InitInfoHeader(version, bpp, aWidth, aHeight);
+  rv = InitFileHeader(version, bpp, aWidth, aHeight);
+  if (NS_FAILED(rv)) {
+    return rv;
+  }
+  rv = InitInfoHeader(version, bpp, aWidth, aHeight);
+  if (NS_FAILED(rv)) {
+    return rv;
+  }
 
   mImageBufferSize = mBMPFileHeader.filesize;
   mImageBufferStart = static_cast<uint8_t*>(malloc(mImageBufferSize));
@@ -151,8 +147,7 @@ nsBMPEncoder::StartImageEncode(uint32_t aWidth,
 // Returns the number of bytes in the image buffer used.
 // For a BMP file, this is all bytes in the buffer.
 NS_IMETHODIMP
-nsBMPEncoder::GetImageBufferUsed(uint32_t* aOutputSize)
-{
+nsBMPEncoder::GetImageBufferUsed(uint32_t* aOutputSize) {
   NS_ENSURE_ARG_POINTER(aOutputSize);
   *aOutputSize = mImageBufferSize;
   return NS_OK;
@@ -160,8 +155,7 @@ nsBMPEncoder::GetImageBufferUsed(uint32_t* aOutputSize)
 
 // Returns a pointer to the start of the image buffer
 NS_IMETHODIMP
-nsBMPEncoder::GetImageBuffer(char** aOutputBuffer)
-{
+nsBMPEncoder::GetImageBuffer(char** aOutputBuffer) {
   NS_ENSURE_ARG_POINTER(aOutputBuffer);
   *aOutputBuffer = reinterpret_cast<char*>(mImageBufferStart);
   return NS_OK;
@@ -169,38 +163,48 @@ nsBMPEncoder::GetImageBuffer(char** aOutputBuffer)
 
 NS_IMETHODIMP
 nsBMPEncoder::AddImageFrame(const uint8_t* aData,
-                            uint32_t aLength, // (unused, req'd by JS)
-                            uint32_t aWidth,
-                            uint32_t aHeight,
-                            uint32_t aStride,
+                            uint32_t aLength,  // (unused, req'd by JS)
+                            uint32_t aWidth, uint32_t aHeight, uint32_t aStride,
                             uint32_t aInputFormat,
-                            const nsAString& aFrameOptions)
-{
+                            const nsAString& aFrameOptions) {
   // must be initialized
   if (!mImageBufferStart || !mImageBufferCurr) {
     return NS_ERROR_NOT_INITIALIZED;
   }
 
   // validate input format
-  if (aInputFormat != INPUT_FORMAT_RGB &&
-      aInputFormat != INPUT_FORMAT_RGBA &&
+  if (aInputFormat != INPUT_FORMAT_RGB && aInputFormat != INPUT_FORMAT_RGBA &&
       aInputFormat != INPUT_FORMAT_HOSTARGB) {
     return NS_ERROR_INVALID_ARG;
   }
 
-  auto row = MakeUniqueFallible<uint8_t[]>(mBMPInfoHeader.width *
-                                           BytesPerPixel(mBMPInfoHeader.bpp));
+  if (mBMPInfoHeader.width < 0) {
+    return NS_ERROR_ILLEGAL_VALUE;
+  }
+
+  CheckedUint32 size = CheckedUint32(mBMPInfoHeader.width) *
+                       CheckedUint32(BytesPerPixel(mBMPInfoHeader.bpp));
+  if (MOZ_UNLIKELY(!size.isValid())) {
+    return NS_ERROR_FAILURE;
+  }
+
+  auto row = MakeUniqueFallible<uint8_t[]>(size.value());
   if (!row) {
     return NS_ERROR_OUT_OF_MEMORY;
   }
 
+  CheckedUint32 check = CheckedUint32(mBMPInfoHeader.height) * aStride;
+  if (MOZ_UNLIKELY(!check.isValid())) {
+    return NS_ERROR_FAILURE;
+  }
+
   // write each row: if we add more input formats, we may want to
   // generalize the conversions
   if (aInputFormat == INPUT_FORMAT_HOSTARGB) {
     // BMP requires RGBA with post-multiplied alpha, so we need to convert
-    for (int32_t y = mBMPInfoHeader.height - 1; y >= 0 ; y --) {
+    for (int32_t y = mBMPInfoHeader.height - 1; y >= 0; y--) {
       ConvertHostARGBRow(&aData[y * aStride], row, mBMPInfoHeader.width);
-      if(mBMPInfoHeader.bpp == 24) {
+      if (mBMPInfoHeader.bpp == 24) {
         EncodeImageDataRow24(row.get());
       } else {
         EncodeImageDataRow32(row.get());
@@ -232,10 +236,8 @@ nsBMPEncoder::AddImageFrame(const uint8_t* aData,
   return NS_OK;
 }
 
-
 NS_IMETHODIMP
-nsBMPEncoder::EndImageEncode()
-{
+nsBMPEncoder::EndImageEncode() {
   // must be initialized
   if (!mImageBufferStart || !mImageBufferCurr) {
     return NS_ERROR_NOT_INITIALIZED;
@@ -252,13 +254,10 @@ nsBMPEncoder::EndImageEncode()
   return NS_OK;
 }
 
-
 // Parses the encoder options and sets the bits per pixel to use
 // See InitFromData for a description of the parse options
-nsresult
-nsBMPEncoder::ParseOptions(const nsAString& aOptions, Version& aVersionOut,
-                           uint32_t& aBppOut)
-{
+nsresult nsBMPEncoder::ParseOptions(const nsAString& aOptions,
+                                    Version& aVersionOut, uint16_t& aBppOut) {
   aVersionOut = VERSION_3;
   aBppOut = 24;
 
@@ -272,7 +271,6 @@ nsBMPEncoder::ParseOptions(const nsAString& aOptions, Version& aVersionOut,
 
   // For each name/value pair in the set
   for (uint32_t i = 0; i < nameValuePairs.Length(); ++i) {
-
     // Split the name value pair [0] = name, [1] = value
     nsTArray<nsCString> nameValuePair;
     if (!ParseString(nameValuePairs[i], '=', nameValuePair)) {
@@ -311,8 +309,7 @@ nsBMPEncoder::ParseOptions(const nsAString& aOptions, Version& aVersionOut,
 }
 
 NS_IMETHODIMP
-nsBMPEncoder::Close()
-{
+nsBMPEncoder::Close() {
   if (mImageBufferStart) {
     free(mImageBufferStart);
     mImageBufferStart = nullptr;
@@ -326,8 +323,7 @@ nsBMPEncoder::Close()
 
 // Obtains the available bytes to read
 NS_IMETHODIMP
-nsBMPEncoder::Available(uint64_t* _retval)
-{
+nsBMPEncoder::Available(uint64_t* _retval) {
   if (!mImageBufferStart || !mImageBufferCurr) {
     return NS_BASE_STREAM_CLOSED;
   }
@@ -338,16 +334,14 @@ nsBMPEncoder::Available(uint64_t* _retval)
 
 // [noscript] Reads bytes which are available
 NS_IMETHODIMP
-nsBMPEncoder::Read(char* aBuf, uint32_t aCount, uint32_t* _retval)
-{
+nsBMPEncoder::Read(char* aBuf, uint32_t aCount, uint32_t* _retval) {
   return ReadSegments(NS_CopySegmentToBuffer, aBuf, aCount, _retval);
 }
 
 // [noscript] Reads segments
 NS_IMETHODIMP
 nsBMPEncoder::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
-                           uint32_t aCount, uint32_t* _retval)
-{
+                           uint32_t aCount, uint32_t* _retval) {
   uint32_t maxCount = GetCurrentImageBufferOffset() - mImageBufferReadPoint;
   if (maxCount == 0) {
     *_retval = 0;
@@ -357,10 +351,10 @@ nsBMPEncoder::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
   if (aCount > maxCount) {
     aCount = maxCount;
   }
-  nsresult rv = aWriter(this, aClosure,
-                        reinterpret_cast<const char*>(mImageBufferStart +
-                                                      mImageBufferReadPoint),
-                        0, aCount, _retval);
+  nsresult rv = aWriter(
+      this, aClosure,
+      reinterpret_cast<const char*>(mImageBufferStart + mImageBufferReadPoint),
+      0, aCount, _retval);
   if (NS_SUCCEEDED(rv)) {
     NS_ASSERTION(*_retval <= aCount, "bad write count");
     mImageBufferReadPoint += *_retval;
@@ -370,18 +364,14 @@ nsBMPEncoder::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
 }
 
 NS_IMETHODIMP
-nsBMPEncoder::IsNonBlocking(bool* _retval)
-{
+nsBMPEncoder::IsNonBlocking(bool* _retval) {
   *_retval = true;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsBMPEncoder::AsyncWait(nsIInputStreamCallback* aCallback,
-                        uint32_t aFlags,
-                        uint32_t aRequestedCount,
-                        nsIEventTarget* aTarget)
-{
+nsBMPEncoder::AsyncWait(nsIInputStreamCallback* aCallback, uint32_t aFlags,
+                        uint32_t aRequestedCount, nsIEventTarget* aTarget) {
   if (aFlags != 0) {
     return NS_ERROR_NOT_IMPLEMENTED;
   }
@@ -394,7 +384,7 @@ nsBMPEncoder::AsyncWait(nsIInputStreamCallback* aCallback,
   // 0 means "any number of bytes except 0"
   mNotifyThreshold = aRequestedCount;
   if (!aRequestedCount) {
-    mNotifyThreshold = 1024; // We don't want to notify incessantly
+    mNotifyThreshold = 1024;  // We don't want to notify incessantly
   }
 
   // We set the callback absolutely last, because NotifyListener uses it to
@@ -410,22 +400,17 @@ nsBMPEncoder::AsyncWait(nsIInputStreamCallback* aCallback,
 }
 
 NS_IMETHODIMP
-nsBMPEncoder::CloseWithStatus(nsresult aStatus)
-{
-  return Close();
-}
+nsBMPEncoder::CloseWithStatus(nsresult aStatus) { return Close(); }
 
 // nsBMPEncoder::ConvertHostARGBRow
 //
 //    Our colors are stored with premultiplied alphas, but we need
 //    an output with no alpha in machine-independent byte order.
 //
-void
-nsBMPEncoder::ConvertHostARGBRow(const uint8_t* aSrc,
-                                 const UniquePtr<uint8_t[]>& aDest,
-                                 uint32_t aPixelWidth)
-{
-  int bytes = BytesPerPixel(mBMPInfoHeader.bpp);
+void nsBMPEncoder::ConvertHostARGBRow(const uint8_t* aSrc,
+                                      const UniquePtr<uint8_t[]>& aDest,
+                                      uint32_t aPixelWidth) {
+  uint16_t bytes = BytesPerPixel(mBMPInfoHeader.bpp);
 
   if (mBMPInfoHeader.bpp == 32) {
     for (uint32_t x = 0; x < aPixelWidth; x++) {
@@ -433,8 +418,8 @@ nsBMPEncoder::ConvertHostARGBRow(const uint8_t* aSrc,
       uint8_t* pixelOut = &aDest[x * bytes];
 
       pixelOut[0] = (pixelIn & 0x00ff0000) >> 16;
-      pixelOut[1] = (pixelIn & 0x0000ff00) >>  8;
-      pixelOut[2] = (pixelIn & 0x000000ff) >>  0;
+      pixelOut[1] = (pixelIn & 0x0000ff00) >> 8;
+      pixelOut[2] = (pixelIn & 0x000000ff) >> 0;
       pixelOut[3] = (pixelIn & 0xff000000) >> 24;
     }
   } else {
@@ -443,21 +428,20 @@ nsBMPEncoder::ConvertHostARGBRow(const uint8_t* aSrc,
       uint8_t* pixelOut = &aDest[x * bytes];
 
       pixelOut[0] = (pixelIn & 0xff0000) >> 16;
-      pixelOut[1] = (pixelIn & 0x00ff00) >>  8;
-      pixelOut[2] = (pixelIn & 0x0000ff) >>  0;
+      pixelOut[1] = (pixelIn & 0x00ff00) >> 8;
+      pixelOut[2] = (pixelIn & 0x0000ff) >> 0;
     }
   }
 }
 
-void
-nsBMPEncoder::NotifyListener()
-{
-  if (mCallback &&
-      (GetCurrentImageBufferOffset() - mImageBufferReadPoint >=
-       mNotifyThreshold || mFinished)) {
+void nsBMPEncoder::NotifyListener() {
+  if (mCallback && (GetCurrentImageBufferOffset() - mImageBufferReadPoint >=
+                        mNotifyThreshold ||
+                    mFinished)) {
     nsCOMPtr<nsIInputStreamCallback> callback;
     if (mCallbackTarget) {
-      callback = NS_NewInputStreamReadyEvent(mCallback, mCallbackTarget);
+      callback = NS_NewInputStreamReadyEvent("nsBMPEncoder::NotifyListener",
+                                             mCallback, mCallbackTarget);
     } else {
       callback = mCallback;
     }
@@ -474,17 +458,15 @@ nsBMPEncoder::NotifyListener()
 }
 
 // Initializes the BMP file header mBMPFileHeader to the passed in values
-void
-nsBMPEncoder::InitFileHeader(Version aVersion, uint32_t aBPP, uint32_t aWidth,
-                             uint32_t aHeight)
-{
+nsresult nsBMPEncoder::InitFileHeader(Version aVersion, uint16_t aBPP,
+                                      uint32_t aWidth, uint32_t aHeight) {
   memset(&mBMPFileHeader, 0, sizeof(mBMPFileHeader));
   mBMPFileHeader.signature[0] = 'B';
   mBMPFileHeader.signature[1] = 'M';
 
   if (aVersion == VERSION_3) {
     mBMPFileHeader.dataoffset = FILE_HEADER_LENGTH + InfoHeaderLength::WIN_V3;
-  } else { // aVersion == 5
+  } else {  // aVersion == 5
     mBMPFileHeader.dataoffset = FILE_HEADER_LENGTH + InfoHeaderLength::WIN_V5;
   }
 
@@ -492,24 +474,35 @@ nsBMPEncoder::InitFileHeader(Version aVersion, uint32_t aBPP, uint32_t aWidth,
   if (aBPP <= 8) {
     uint32_t numColors = 1 << aBPP;
     mBMPFileHeader.dataoffset += 4 * numColors;
-    mBMPFileHeader.filesize = mBMPFileHeader.dataoffset + aWidth * aHeight;
+    CheckedUint32 filesize = CheckedUint32(mBMPFileHeader.dataoffset) +
+                             CheckedUint32(aWidth) * aHeight;
+    if (MOZ_UNLIKELY(!filesize.isValid())) {
+      return NS_ERROR_INVALID_ARG;
+    }
+    mBMPFileHeader.filesize = filesize.value();
   } else {
-    mBMPFileHeader.filesize = mBMPFileHeader.dataoffset +
-      (aWidth * BytesPerPixel(aBPP) + PaddingBytes(aBPP, aWidth)) * aHeight;
+    CheckedUint32 filesize = CheckedUint32(mBMPFileHeader.dataoffset) +
+                             (CheckedUint32(aWidth) * BytesPerPixel(aBPP) +
+                              PaddingBytes(aBPP, aWidth)) *
+                                 aHeight;
+    if (MOZ_UNLIKELY(!filesize.isValid())) {
+      return NS_ERROR_INVALID_ARG;
+    }
+    mBMPFileHeader.filesize = filesize.value();
   }
 
   mBMPFileHeader.reserved = 0;
+
+  return NS_OK;
 }
 
-#define ENCODE(pImageBufferCurr, value) \
-    memcpy(*pImageBufferCurr, &value, sizeof value); \
-    *pImageBufferCurr += sizeof value;
+#define ENCODE(pImageBufferCurr, value)            \
+  memcpy(*pImageBufferCurr, &value, sizeof value); \
+  *pImageBufferCurr += sizeof value;
 
 // Initializes the bitmap info header mBMPInfoHeader to the passed in values
-void
-nsBMPEncoder::InitInfoHeader(Version aVersion, uint32_t aBPP, uint32_t aWidth,
-                             uint32_t aHeight)
-{
+nsresult nsBMPEncoder::InitInfoHeader(Version aVersion, uint16_t aBPP,
+                                      uint32_t aWidth, uint32_t aHeight) {
   memset(&mBMPInfoHeader, 0, sizeof(mBMPInfoHeader));
   if (aVersion == VERSION_3) {
     mBMPInfoHeader.bihsize = InfoHeaderLength::WIN_V3;
@@ -517,50 +510,72 @@ nsBMPEncoder::InitInfoHeader(Version aVersion, uint32_t aBPP, uint32_t aWidth,
     MOZ_ASSERT(aVersion == VERSION_5);
     mBMPInfoHeader.bihsize = InfoHeaderLength::WIN_V5;
   }
-  mBMPInfoHeader.width = aWidth;
-  mBMPInfoHeader.height = aHeight;
+
+  CheckedInt32 width(aWidth);
+  CheckedInt32 height(aHeight);
+  if (MOZ_UNLIKELY(!width.isValid() || !height.isValid())) {
+    return NS_ERROR_INVALID_ARG;
+  }
+  mBMPInfoHeader.width = width.value();
+  mBMPInfoHeader.height = height.value();
+
   mBMPInfoHeader.planes = 1;
   mBMPInfoHeader.bpp = aBPP;
   mBMPInfoHeader.compression = 0;
   mBMPInfoHeader.colors = 0;
   mBMPInfoHeader.important_colors = 0;
+
+  CheckedUint32 check = CheckedUint32(aWidth) * BytesPerPixel(aBPP);
+  if (MOZ_UNLIKELY(!check.isValid())) {
+    return NS_ERROR_INVALID_ARG;
+  }
+
   if (aBPP <= 8) {
-    mBMPInfoHeader.image_size = aWidth * aHeight;
+    CheckedUint32 imagesize = CheckedUint32(aWidth) * aHeight;
+    if (MOZ_UNLIKELY(!imagesize.isValid())) {
+      return NS_ERROR_INVALID_ARG;
+    }
+    mBMPInfoHeader.image_size = imagesize.value();
   } else {
-    mBMPInfoHeader.image_size =
-      (aWidth * BytesPerPixel(aBPP) + PaddingBytes(aBPP, aWidth)) * aHeight;
+    CheckedUint32 imagesize = (CheckedUint32(aWidth) * BytesPerPixel(aBPP) +
+                               PaddingBytes(aBPP, aWidth)) *
+                              CheckedUint32(aHeight);
+    if (MOZ_UNLIKELY(!imagesize.isValid())) {
+      return NS_ERROR_INVALID_ARG;
+    }
+    mBMPInfoHeader.image_size = imagesize.value();
   }
   mBMPInfoHeader.xppm = 0;
   mBMPInfoHeader.yppm = 0;
   if (aVersion >= VERSION_5) {
-      mBMPInfoHeader.red_mask   = 0x000000FF;
-      mBMPInfoHeader.green_mask = 0x0000FF00;
-      mBMPInfoHeader.blue_mask  = 0x00FF0000;
-      mBMPInfoHeader.alpha_mask = 0xFF000000;
-      mBMPInfoHeader.color_space = V5InfoHeader::COLOR_SPACE_LCS_SRGB;
-      mBMPInfoHeader.white_point.r.x = 0;
-      mBMPInfoHeader.white_point.r.y = 0;
-      mBMPInfoHeader.white_point.r.z = 0;
-      mBMPInfoHeader.white_point.g.x = 0;
-      mBMPInfoHeader.white_point.g.y = 0;
-      mBMPInfoHeader.white_point.g.z = 0;
-      mBMPInfoHeader.white_point.b.x = 0;
-      mBMPInfoHeader.white_point.b.y = 0;
-      mBMPInfoHeader.white_point.b.z = 0;
-      mBMPInfoHeader.gamma_red = 0;
-      mBMPInfoHeader.gamma_green = 0;
-      mBMPInfoHeader.gamma_blue = 0;
-      mBMPInfoHeader.intent = 0;
-      mBMPInfoHeader.profile_offset = 0;
-      mBMPInfoHeader.profile_size = 0;
-      mBMPInfoHeader.reserved = 0;
+    mBMPInfoHeader.red_mask = 0x000000FF;
+    mBMPInfoHeader.green_mask = 0x0000FF00;
+    mBMPInfoHeader.blue_mask = 0x00FF0000;
+    mBMPInfoHeader.alpha_mask = 0xFF000000;
+    mBMPInfoHeader.color_space = V5InfoHeader::COLOR_SPACE_LCS_SRGB;
+    mBMPInfoHeader.white_point.r.x = 0;
+    mBMPInfoHeader.white_point.r.y = 0;
+    mBMPInfoHeader.white_point.r.z = 0;
+    mBMPInfoHeader.white_point.g.x = 0;
+    mBMPInfoHeader.white_point.g.y = 0;
+    mBMPInfoHeader.white_point.g.z = 0;
+    mBMPInfoHeader.white_point.b.x = 0;
+    mBMPInfoHeader.white_point.b.y = 0;
+    mBMPInfoHeader.white_point.b.z = 0;
+    mBMPInfoHeader.gamma_red = 0;
+    mBMPInfoHeader.gamma_green = 0;
+    mBMPInfoHeader.gamma_blue = 0;
+    mBMPInfoHeader.intent = 0;
+    mBMPInfoHeader.profile_offset = 0;
+    mBMPInfoHeader.profile_size = 0;
+    mBMPInfoHeader.reserved = 0;
   }
+
+  return NS_OK;
 }
 
 // Encodes the BMP file header mBMPFileHeader
-void
-nsBMPEncoder::EncodeFileHeader()
-{
+void nsBMPEncoder::EncodeFileHeader() {
   FileHeader littleEndianBFH = mBMPFileHeader;
   NativeEndian::swapToLittleEndianInPlace(&littleEndianBFH.filesize, 1);
   NativeEndian::swapToLittleEndianInPlace(&littleEndianBFH.reserved, 1);
@@ -573,9 +588,7 @@ nsBMPEncoder::EncodeFileHeader()
 }
 
 // Encodes the BMP infor header mBMPInfoHeader
-void
-nsBMPEncoder::EncodeInfoHeader()
-{
+void nsBMPEncoder::EncodeInfoHeader() {
   V5InfoHeader littleEndianmBIH = mBMPInfoHeader;
   NativeEndian::swapToLittleEndianInPlace(&littleEndianmBIH.bihsize, 1);
   NativeEndian::swapToLittleEndianInPlace(&littleEndianmBIH.width, 1);
@@ -648,20 +661,17 @@ nsBMPEncoder::EncodeInfoHeader()
 }
 
 // Sets a pixel in the image buffer that doesn't have alpha data
-static inline void
-SetPixel24(uint8_t*& imageBufferCurr, uint8_t aRed, uint8_t aGreen,
-  uint8_t aBlue)
-{
+static inline void SetPixel24(uint8_t*& imageBufferCurr, uint8_t aRed,
+                              uint8_t aGreen, uint8_t aBlue) {
   *imageBufferCurr = aBlue;
   *(imageBufferCurr + 1) = aGreen;
   *(imageBufferCurr + 2) = aRed;
 }
 
 // Sets a pixel in the image buffer with alpha data
-static inline void
-SetPixel32(uint8_t*& imageBufferCurr, uint8_t aRed, uint8_t aGreen,
-           uint8_t aBlue, uint8_t aAlpha = 0xFF)
-{
+static inline void SetPixel32(uint8_t*& imageBufferCurr, uint8_t aRed,
+                              uint8_t aGreen, uint8_t aBlue,
+                              uint8_t aAlpha = 0xFF) {
   *imageBufferCurr = aBlue;
   *(imageBufferCurr + 1) = aGreen;
   *(imageBufferCurr + 2) = aRed;
@@ -669,34 +679,30 @@ SetPixel32(uint8_t*& imageBufferCurr, uint8_t aRed, uint8_t aGreen,
 }
 
 // Encodes a row of image data which does not have alpha data
-void
-nsBMPEncoder::EncodeImageDataRow24(const uint8_t* aData)
-{
+void nsBMPEncoder::EncodeImageDataRow24(const uint8_t* aData) {
   for (int32_t x = 0; x < mBMPInfoHeader.width; x++) {
     uint32_t pos = x * BytesPerPixel(mBMPInfoHeader.bpp);
     SetPixel24(mImageBufferCurr, aData[pos], aData[pos + 1], aData[pos + 2]);
     mImageBufferCurr += BytesPerPixel(mBMPInfoHeader.bpp);
   }
 
-  for (uint32_t x = 0; x < PaddingBytes(mBMPInfoHeader.bpp,
-                                        mBMPInfoHeader.width); x++) {
+  for (uint32_t x = 0;
+       x < PaddingBytes(mBMPInfoHeader.bpp, mBMPInfoHeader.width); x++) {
     *mImageBufferCurr++ = 0;
   }
 }
 
 // Encodes a row of image data which does have alpha data
-void
-nsBMPEncoder::EncodeImageDataRow32(const uint8_t* aData)
-{
+void nsBMPEncoder::EncodeImageDataRow32(const uint8_t* aData) {
   for (int32_t x = 0; x < mBMPInfoHeader.width; x++) {
     uint32_t pos = x * BytesPerPixel(mBMPInfoHeader.bpp);
-    SetPixel32(mImageBufferCurr, aData[pos], aData[pos + 1],
-               aData[pos + 2], aData[pos + 3]);
+    SetPixel32(mImageBufferCurr, aData[pos], aData[pos + 1], aData[pos + 2],
+               aData[pos + 3]);
     mImageBufferCurr += 4;
   }
 
-  for (uint32_t x = 0; x < PaddingBytes(mBMPInfoHeader.bpp,
-                                        mBMPInfoHeader.width); x++) {
+  for (uint32_t x = 0;
+       x < PaddingBytes(mBMPInfoHeader.bpp, mBMPInfoHeader.width); x++) {
     *mImageBufferCurr++ = 0;
   }
 }
