@@ -24,27 +24,23 @@ struct encoder_error_mgr {
 };
 
 nsJPEGEncoder::nsJPEGEncoder()
-   : mFinished(false),
-     mImageBuffer(nullptr),
-     mImageBufferSize(0),
-     mImageBufferUsed(0),
-     mImageBufferReadPoint(0),
-     mCallback(nullptr),
-     mCallbackTarget(nullptr),
-     mNotifyThreshold(0),
-     mReentrantMonitor("nsJPEGEncoder.mReentrantMonitor")
-{
-}
+    : mFinished(false),
+      mImageBuffer(nullptr),
+      mImageBufferSize(0),
+      mImageBufferUsed(0),
+      mImageBufferReadPoint(0),
+      mCallback(nullptr),
+      mCallbackTarget(nullptr),
+      mNotifyThreshold(0),
+      mReentrantMonitor("nsJPEGEncoder.mReentrantMonitor") {}
 
-nsJPEGEncoder::~nsJPEGEncoder()
-{
+nsJPEGEncoder::~nsJPEGEncoder() {
   if (mImageBuffer) {
     free(mImageBuffer);
     mImageBuffer = nullptr;
   }
 }
 
-
 // nsJPEGEncoder::InitFromData
 //
 //    One output option is supported: "quality=X" where X is an integer in the
@@ -54,25 +50,20 @@ nsJPEGEncoder::~nsJPEGEncoder()
 
 NS_IMETHODIMP
 nsJPEGEncoder::InitFromData(const uint8_t* aData,
-                            uint32_t aLength, // (unused, req'd by JS)
-                            uint32_t aWidth,
-                            uint32_t aHeight,
-                            uint32_t aStride,
+                            uint32_t aLength,  // (unused, req'd by JS)
+                            uint32_t aWidth, uint32_t aHeight, uint32_t aStride,
                             uint32_t aInputFormat,
-                            const nsAString& aOutputOptions)
-{
+                            const nsAString& aOutputOptions) {
   NS_ENSURE_ARG(aData);
 
   // validate input format
-  if (aInputFormat != INPUT_FORMAT_RGB &&
-      aInputFormat != INPUT_FORMAT_RGBA &&
+  if (aInputFormat != INPUT_FORMAT_RGB && aInputFormat != INPUT_FORMAT_RGBA &&
       aInputFormat != INPUT_FORMAT_HOSTARGB)
     return NS_ERROR_INVALID_ARG;
 
   // Stride is the padded width of each row, so it better be longer (I'm afraid
   // people will not understand what stride means, so check it well)
-  if ((aInputFormat == INPUT_FORMAT_RGB &&
-       aStride < aWidth * 3) ||
+  if ((aInputFormat == INPUT_FORMAT_RGB && aStride < aWidth * 3) ||
       ((aInputFormat == INPUT_FORMAT_RGBA ||
         aInputFormat == INPUT_FORMAT_HOSTARGB) &&
        aStride < aWidth * 4)) {
@@ -90,26 +81,26 @@ nsJPEGEncoder::InitFromData(const uint8_t* aData,
   if (aOutputOptions.Length() > 0) {
     // have options string
     const nsString qualityPrefix(NS_LITERAL_STRING("quality="));
-    if (aOutputOptions.Length() > qualityPrefix.Length()  &&
+    if (aOutputOptions.Length() > qualityPrefix.Length() &&
         StringBeginsWith(aOutputOptions, qualityPrefix)) {
       // have quality string
-      nsCString value =
-        NS_ConvertUTF16toUTF8(Substring(aOutputOptions,
-                                        qualityPrefix.Length()));
+      nsCString value = NS_ConvertUTF16toUTF8(
+          Substring(aOutputOptions, qualityPrefix.Length()));
       int newquality = -1;
       if (PR_sscanf(value.get(), "%d", &newquality) == 1) {
         if (newquality >= 0 && newquality <= 100) {
           quality = newquality;
         } else {
-          NS_WARNING("Quality value out of range, should be 0-100,"
-                     " using default");
+          NS_WARNING(
+              "Quality value out of range, should be 0-100,"
+              " using default");
         }
       } else {
-        NS_WARNING("Quality value invalid, should be integer 0-100,"
-                   " using default");
+        NS_WARNING(
+            "Quality value invalid, should be integer 0-100,"
+            " using default");
       }
-    }
-    else {
+    } else {
       return NS_ERROR_INVALID_ARG;
     }
   }
@@ -136,12 +127,12 @@ nsJPEGEncoder::InitFromData(const uint8_t* aData,
   cinfo.data_precision = 8;
 
   jpeg_set_defaults(&cinfo);
-  jpeg_set_quality(&cinfo, quality, 1); // quality here is 0-100
+  jpeg_set_quality(&cinfo, quality, 1);  // quality here is 0-100
   if (quality >= 90) {
     int i;
-    for (i=0; i < MAX_COMPONENTS; i++) {
-      cinfo.comp_info[i].h_samp_factor=1;
-      cinfo.comp_info[i].v_samp_factor=1;
+    for (i = 0; i < MAX_COMPONENTS; i++) {
+      cinfo.comp_info[i].h_samp_factor = 1;
+      cinfo.comp_info[i].v_samp_factor = 1;
     }
   }
 
@@ -191,20 +182,16 @@ nsJPEGEncoder::InitFromData(const uint8_t* aData,
   return NS_OK;
 }
 
-
 NS_IMETHODIMP
-nsJPEGEncoder::StartImageEncode(uint32_t aWidth,
-                                uint32_t aHeight,
+nsJPEGEncoder::StartImageEncode(uint32_t aWidth, uint32_t aHeight,
                                 uint32_t aInputFormat,
-                                const nsAString& aOutputOptions)
-{
+                                const nsAString& aOutputOptions) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 // Returns the number of bytes in the image buffer used.
 NS_IMETHODIMP
-nsJPEGEncoder::GetImageBufferUsed(uint32_t* aOutputSize)
-{
+nsJPEGEncoder::GetImageBufferUsed(uint32_t* aOutputSize) {
   NS_ENSURE_ARG_POINTER(aOutputSize);
   *aOutputSize = mImageBufferUsed;
   return NS_OK;
@@ -212,35 +199,25 @@ nsJPEGEncoder::GetImageBufferUsed(uint32_t* aOutputSize)
 
 // Returns a pointer to the start of the image buffer
 NS_IMETHODIMP
-nsJPEGEncoder::GetImageBuffer(char** aOutputBuffer)
-{
+nsJPEGEncoder::GetImageBuffer(char** aOutputBuffer) {
   NS_ENSURE_ARG_POINTER(aOutputBuffer);
   *aOutputBuffer = reinterpret_cast<char*>(mImageBuffer);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsJPEGEncoder::AddImageFrame(const uint8_t* aData,
-                             uint32_t aLength,
-                             uint32_t aWidth,
-                             uint32_t aHeight,
-                             uint32_t aStride,
-                             uint32_t aFrameFormat,
-                             const nsAString& aFrameOptions)
-{
+nsJPEGEncoder::AddImageFrame(const uint8_t* aData, uint32_t aLength,
+                             uint32_t aWidth, uint32_t aHeight,
+                             uint32_t aStride, uint32_t aFrameFormat,
+                             const nsAString& aFrameOptions) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
-nsJPEGEncoder::EndImageEncode()
-{
-  return NS_ERROR_NOT_IMPLEMENTED;
-}
-
+nsJPEGEncoder::EndImageEncode() { return NS_ERROR_NOT_IMPLEMENTED; }
 
 NS_IMETHODIMP
-nsJPEGEncoder::Close()
-{
+nsJPEGEncoder::Close() {
   if (mImageBuffer != nullptr) {
     free(mImageBuffer);
     mImageBuffer = nullptr;
@@ -252,8 +229,7 @@ nsJPEGEncoder::Close()
 }
 
 NS_IMETHODIMP
-nsJPEGEncoder::Available(uint64_t* _retval)
-{
+nsJPEGEncoder::Available(uint64_t* _retval) {
   if (!mImageBuffer) {
     return NS_BASE_STREAM_CLOSED;
   }
@@ -263,15 +239,13 @@ nsJPEGEncoder::Available(uint64_t* _retval)
 }
 
 NS_IMETHODIMP
-nsJPEGEncoder::Read(char* aBuf, uint32_t aCount, uint32_t* _retval)
-{
+nsJPEGEncoder::Read(char* aBuf, uint32_t aCount, uint32_t* _retval) {
   return ReadSegments(NS_CopySegmentToBuffer, aBuf, aCount, _retval);
 }
 
 NS_IMETHODIMP
-nsJPEGEncoder::ReadSegments(nsWriteSegmentFun aWriter,
-                            void* aClosure, uint32_t aCount, uint32_t* _retval)
-{
+nsJPEGEncoder::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
+                            uint32_t aCount, uint32_t* _retval) {
   // Avoid another thread reallocing the buffer underneath us
   ReentrantMonitorAutoEnter autoEnter(mReentrantMonitor);
 
@@ -284,10 +258,10 @@ nsJPEGEncoder::ReadSegments(nsWriteSegmentFun aWriter,
   if (aCount > maxCount) {
     aCount = maxCount;
   }
-  nsresult rv = aWriter(this, aClosure,
-                        reinterpret_cast<const char*>
-                          (mImageBuffer+mImageBufferReadPoint),
-                        0, aCount, _retval);
+  nsresult rv = aWriter(
+      this, aClosure,
+      reinterpret_cast<const char*>(mImageBuffer + mImageBufferReadPoint), 0,
+      aCount, _retval);
   if (NS_SUCCEEDED(rv)) {
     NS_ASSERTION(*_retval <= aCount, "bad write count");
     mImageBufferReadPoint += *_retval;
@@ -298,17 +272,14 @@ nsJPEGEncoder::ReadSegments(nsWriteSegmentFun aWriter,
 }
 
 NS_IMETHODIMP
-nsJPEGEncoder::IsNonBlocking(bool* _retval)
-{
+nsJPEGEncoder::IsNonBlocking(bool* _retval) {
   *_retval = true;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsJPEGEncoder::AsyncWait(nsIInputStreamCallback* aCallback,
-                         uint32_t aFlags, uint32_t aRequestedCount,
-                         nsIEventTarget* aTarget)
-{
+nsJPEGEncoder::AsyncWait(nsIInputStreamCallback* aCallback, uint32_t aFlags,
+                         uint32_t aRequestedCount, nsIEventTarget* aTarget) {
   if (aFlags != 0) {
     return NS_ERROR_NOT_IMPLEMENTED;
   }
@@ -321,8 +292,8 @@ nsJPEGEncoder::AsyncWait(nsIInputStreamCallback* aCallback,
   // 0 means "any number of bytes except 0"
   mNotifyThreshold = aRequestedCount;
   if (!aRequestedCount) {
-    mNotifyThreshold = 1024; // 1 KB seems good.  We don't want to
-                             // notify incessantly
+    mNotifyThreshold = 1024;  // 1 KB seems good.  We don't want to
+                              // notify incessantly
   }
 
   // We set the callback absolutely last, because NotifyListener uses it to
@@ -338,12 +309,7 @@ nsJPEGEncoder::AsyncWait(nsIInputStreamCallback* aCallback,
 }
 
 NS_IMETHODIMP
-nsJPEGEncoder::CloseWithStatus(nsresult aStatus)
-{
-  return Close();
-}
-
-
+nsJPEGEncoder::CloseWithStatus(nsresult aStatus) { return Close(); }
 
 // nsJPEGEncoder::ConvertHostARGBRow
 //
@@ -351,17 +317,15 @@ nsJPEGEncoder::CloseWithStatus(nsresult aStatus)
 //    an output with no alpha in machine-independent byte order.
 //
 //    See gfx/cairo/cairo/src/cairo-png.c
-void
-nsJPEGEncoder::ConvertHostARGBRow(const uint8_t* aSrc, uint8_t* aDest,
-                                  uint32_t aPixelWidth)
-{
+void nsJPEGEncoder::ConvertHostARGBRow(const uint8_t* aSrc, uint8_t* aDest,
+                                       uint32_t aPixelWidth) {
   for (uint32_t x = 0; x < aPixelWidth; x++) {
     const uint32_t& pixelIn = ((const uint32_t*)(aSrc))[x];
     uint8_t* pixelOut = &aDest[x * 3];
 
     pixelOut[0] = (pixelIn & 0xff0000) >> 16;
-    pixelOut[1] = (pixelIn & 0x00ff00) >>  8;
-    pixelOut[2] = (pixelIn & 0x0000ff) >>  0;
+    pixelOut[1] = (pixelIn & 0x00ff00) >> 8;
+    pixelOut[2] = (pixelIn & 0x0000ff) >> 0;
   }
 }
 
@@ -370,10 +334,8 @@ nsJPEGEncoder::ConvertHostARGBRow(const uint8_t* aSrc, uint8_t* aDest,
  *
  * Input is RGBA, output is RGB, so we should alpha-premultiply.
  */
-void
-nsJPEGEncoder::ConvertRGBARow(const uint8_t* aSrc, uint8_t* aDest,
-                              uint32_t aPixelWidth)
-{
+void nsJPEGEncoder::ConvertRGBARow(const uint8_t* aSrc, uint8_t* aDest,
+                                   uint32_t aPixelWidth) {
   for (uint32_t x = 0; x < aPixelWidth; x++) {
     const uint8_t* pixelIn = &aSrc[x * 4];
     uint8_t* pixelOut = &aDest[x * 3];
@@ -391,9 +353,8 @@ nsJPEGEncoder::ConvertRGBARow(const uint8_t* aSrc, uint8_t* aDest,
 //    any data is actually written. It must initialize next_output_byte and
 //    free_in_buffer. free_in_buffer must be initialized to a positive value.
 
-void // static
-nsJPEGEncoder::initDestination(jpeg_compress_struct* cinfo)
-{
+void  // static
+nsJPEGEncoder::initDestination(jpeg_compress_struct* cinfo) {
   nsJPEGEncoder* that = static_cast<nsJPEGEncoder*>(cinfo->client_data);
   NS_ASSERTION(!that->mImageBuffer, "Image buffer already initialized");
 
@@ -405,7 +366,6 @@ nsJPEGEncoder::initDestination(jpeg_compress_struct* cinfo)
   cinfo->dest->free_in_buffer = that->mImageBufferSize;
 }
 
-
 // nsJPEGEncoder::emptyOutputBuffer
 //
 //    This is called whenever the buffer has filled (free_in_buffer reaches
@@ -417,9 +377,8 @@ nsJPEGEncoder::initDestination(jpeg_compress_struct* cinfo)
 //    TRUE is returned.  A FALSE return should only be used when I/O suspension
 //    is desired (this operating mode is discussed in the next section).
 
-boolean // static
-nsJPEGEncoder::emptyOutputBuffer(jpeg_compress_struct* cinfo)
-{
+boolean  // static
+nsJPEGEncoder::emptyOutputBuffer(jpeg_compress_struct* cinfo) {
   nsJPEGEncoder* that = static_cast<nsJPEGEncoder*>(cinfo->client_data);
   NS_ASSERTION(that->mImageBuffer, "No buffer to empty!");
 
@@ -432,8 +391,8 @@ nsJPEGEncoder::emptyOutputBuffer(jpeg_compress_struct* cinfo)
   // expand buffer, just double size each time
   that->mImageBufferSize *= 2;
 
-  uint8_t* newBuf = (uint8_t*)realloc(that->mImageBuffer,
-                                      that->mImageBufferSize);
+  uint8_t* newBuf =
+      (uint8_t*)realloc(that->mImageBuffer, that->mImageBufferSize);
   if (!newBuf) {
     // can't resize, just zero (this will keep us from writing more)
     free(that->mImageBuffer);
@@ -454,7 +413,6 @@ nsJPEGEncoder::emptyOutputBuffer(jpeg_compress_struct* cinfo)
   return 1;
 }
 
-
 // nsJPEGEncoder::termDestination
 //
 //    Terminate destination --- called by jpeg_finish_compress() after all data
@@ -462,9 +420,8 @@ nsJPEGEncoder::emptyOutputBuffer(jpeg_compress_struct* cinfo)
 //    remaining in the buffer.  Use either next_output_byte or free_in_buffer
 //    to determine how much data is in the buffer.
 
-void // static
-nsJPEGEncoder::termDestination(jpeg_compress_struct* cinfo)
-{
+void  // static
+nsJPEGEncoder::termDestination(jpeg_compress_struct* cinfo) {
   nsJPEGEncoder* that = static_cast<nsJPEGEncoder*>(cinfo->client_data);
   if (!that->mImageBuffer) {
     return;
@@ -475,17 +432,15 @@ nsJPEGEncoder::termDestination(jpeg_compress_struct* cinfo)
   that->NotifyListener();
 }
 
-
 // nsJPEGEncoder::errorExit
 //
 //    Override the standard error method in the IJG JPEG decoder code. This
 //    was mostly copied from nsJPEGDecoder.cpp
 
-void // static
-nsJPEGEncoder::errorExit(jpeg_common_struct* cinfo)
-{
+void  // static
+nsJPEGEncoder::errorExit(jpeg_common_struct* cinfo) {
   nsresult error_code;
-  encoder_error_mgr* err = (encoder_error_mgr*) cinfo->err;
+  encoder_error_mgr* err = (encoder_error_mgr*)cinfo->err;
 
   // Convert error to a browser error code
   switch (cinfo->err->msg_code) {
@@ -501,9 +456,7 @@ nsJPEGEncoder::errorExit(jpeg_common_struct* cinfo)
   longjmp(err->setjmp_buffer, static_cast<int>(error_code));
 }
 
-void
-nsJPEGEncoder::NotifyListener()
-{
+void nsJPEGEncoder::NotifyListener() {
   // We might call this function on multiple threads (any threads that call
   // AsyncWait and any that do encoding) so we lock to avoid notifying the
   // listener twice about the same data (which generally leads to a truncated
@@ -515,7 +468,8 @@ nsJPEGEncoder::NotifyListener()
        mFinished)) {
     nsCOMPtr<nsIInputStreamCallback> callback;
     if (mCallbackTarget) {
-      callback = NS_NewInputStreamReadyEvent(mCallback, mCallbackTarget);
+      callback = NS_NewInputStreamReadyEvent("nsJPEGEncoder::NotifyListener",
+                                             mCallback, mCallbackTarget);
     } else {
       callback = mCallback;
     }
