@@ -35,31 +35,28 @@ class imgMemoryReporter;
 namespace mozilla {
 namespace image {
 class ImageURL;
-} // namespace image
-} // namespace mozilla
+}  // namespace image
+}  // namespace mozilla
+
+class imgCacheEntry {
+ public:
+  static uint32_t SecondsFromPRTime(PRTime prTime);
 
-class imgCacheEntry
-{
-public:
   imgCacheEntry(imgLoader* loader, imgRequest* request,
                 bool aForcePrincipalCheck);
   ~imgCacheEntry();
 
-  nsrefcnt AddRef()
-  {
+  nsrefcnt AddRef() {
     NS_PRECONDITION(int32_t(mRefCnt) >= 0, "illegal refcnt");
-    MOZ_ASSERT(_mOwningThread.GetThread() == PR_GetCurrentThread(),
-      "imgCacheEntry addref isn't thread-safe!");
+    NS_ASSERT_OWNINGTHREAD(imgCacheEntry);
     ++mRefCnt;
     NS_LOG_ADDREF(this, mRefCnt, "imgCacheEntry", sizeof(*this));
     return mRefCnt;
   }
 
-  nsrefcnt Release()
-  {
+  nsrefcnt Release() {
     NS_PRECONDITION(0 != mRefCnt, "dup release");
-    MOZ_ASSERT(_mOwningThread.GetThread() == PR_GetCurrentThread(),
-      "imgCacheEntry release isn't thread-safe!");
+    NS_ASSERT_OWNINGTHREAD(imgCacheEntry);
     --mRefCnt;
     NS_LOG_RELEASE(this, mRefCnt, "imgCacheEntry");
     if (mRefCnt == 0) {
@@ -70,100 +67,62 @@ public:
     return mRefCnt;
   }
 
-  uint32_t GetDataSize() const
-  {
-    return mDataSize;
-  }
-  void SetDataSize(uint32_t aDataSize)
-  {
+  uint32_t GetDataSize() const { return mDataSize; }
+  void SetDataSize(uint32_t aDataSize) {
     int32_t oldsize = mDataSize;
     mDataSize = aDataSize;
     UpdateCache(mDataSize - oldsize);
   }
 
-  int32_t GetTouchedTime() const
-  {
-    return mTouchedTime;
-  }
-  void SetTouchedTime(int32_t time)
-  {
+  int32_t GetTouchedTime() const { return mTouchedTime; }
+  void SetTouchedTime(int32_t time) {
     mTouchedTime = time;
     Touch(/* updateTime = */ false);
   }
 
-  uint32_t GetLoadTime() const
-  {
-    return mLoadTime;
-  }
+  uint32_t GetLoadTime() const { return mLoadTime; }
 
   void UpdateLoadTime();
 
-  int32_t GetExpiryTime() const
-  {
-    return mExpiryTime;
-  }
-  void SetExpiryTime(int32_t aExpiryTime)
-  {
+  int32_t GetExpiryTime() const { return mExpiryTime; }
+  void SetExpiryTime(int32_t aExpiryTime) {
     mExpiryTime = aExpiryTime;
     Touch();
   }
 
-  bool GetMustValidate() const
-  {
-    return mMustValidate;
-  }
-  void SetMustValidate(bool aValidate)
-  {
+  bool GetMustValidate() const { return mMustValidate; }
+  void SetMustValidate(bool aValidate) {
     mMustValidate = aValidate;
     Touch();
   }
 
-  already_AddRefed<imgRequest> GetRequest() const
-  {
+  already_AddRefed<imgRequest> GetRequest() const {
     RefPtr<imgRequest> req = mRequest;
     return req.forget();
   }
 
-  bool Evicted() const
-  {
-    return mEvicted;
-  }
+  bool Evicted() const { return mEvicted; }
 
-  nsExpirationState* GetExpirationState()
-  {
-    return &mExpirationState;
-  }
+  nsExpirationState* GetExpirationState() { return &mExpirationState; }
 
-  bool HasNoProxies() const
-  {
-    return mHasNoProxies;
-  }
+  bool HasNoProxies() const { return mHasNoProxies; }
 
-  bool ForcePrincipalCheck() const
-  {
-    return mForcePrincipalCheck;
-  }
+  bool ForcePrincipalCheck() const { return mForcePrincipalCheck; }
 
-  imgLoader* Loader() const
-  {
-    return mLoader;
-  }
+  imgLoader* Loader() const { return mLoader; }
 
-private: // methods
+ private:  // methods
   friend class imgLoader;
   friend class imgCacheQueue;
   void Touch(bool updateTime = true);
   void UpdateCache(int32_t diff = 0);
-  void SetEvicted(bool evict)
-  {
-    mEvicted = evict;
-  }
+  void SetEvicted(bool evict) { mEvicted = evict; }
   void SetHasNoProxies(bool hasNoProxies);
 
   // Private, unimplemented copy constructor.
   imgCacheEntry(const imgCacheEntry&);
 
-private: // data
+ private:  // data
   nsAutoRefCnt mRefCnt;
   NS_DECL_OWNINGTHREAD
 
@@ -182,17 +141,15 @@ private: // data
 
 #include <vector>
 
-#define NS_IMGLOADER_CID \
-{ /* c1354898-e3fe-4602-88a7-c4520c21cb4e */         \
-     0xc1354898,                                     \
-     0xe3fe,                                         \
-     0x4602,                                         \
-    {0x88, 0xa7, 0xc4, 0x52, 0x0c, 0x21, 0xcb, 0x4e} \
-}
+#define NS_IMGLOADER_CID                             \
+  { /* c1354898-e3fe-4602-88a7-c4520c21cb4e */       \
+    0xc1354898, 0xe3fe, 0x4602, {                    \
+      0x88, 0xa7, 0xc4, 0x52, 0x0c, 0x21, 0xcb, 0x4e \
+    }                                                \
+  }
 
-class imgCacheQueue
-{
-public:
+class imgCacheQueue {
+ public:
   imgCacheQueue();
   void Remove(imgCacheEntry*);
   void Push(imgCacheEntry*);
@@ -203,7 +160,8 @@ public:
   uint32_t GetSize() const;
   void UpdateSize(int32_t diff);
   uint32_t GetNumElements() const;
-  typedef std::vector<RefPtr<imgCacheEntry> > queueContainer;
+  bool Contains(imgCacheEntry* aEntry) const;
+  typedef nsTArray<RefPtr<imgCacheEntry>> queueContainer;
   typedef queueContainer::iterator iterator;
   typedef queueContainer::const_iterator const_iterator;
 
@@ -212,7 +170,7 @@ public:
   iterator end();
   const_iterator end() const;
 
-private:
+ private:
   queueContainer mQueue;
   bool mDirty;
   uint32_t mSize;
@@ -227,15 +185,14 @@ class imgLoader final : public imgILoader,
                         public nsIContentSniffer,
                         public imgICache,
                         public nsSupportsWeakReference,
-                        public nsIObserver
-{
+                        public nsIObserver {
   virtual ~imgLoader();
 
-public:
+ public:
   typedef mozilla::image::ImageCacheKey ImageCacheKey;
   typedef mozilla::image::ImageURL ImageURL;
-  typedef nsRefPtrHashtable<nsGenericHashKey<ImageCacheKey>,
-                            imgCacheEntry> imgCacheTable;
+  typedef nsRefPtrHashtable<nsGenericHashKey<ImageCacheKey>, imgCacheEntry>
+      imgCacheTable;
   typedef nsTHashtable<nsPtrHashKey<imgRequest>> imgSet;
   typedef mozilla::net::ReferrerPolicy ReferrerPolicy;
   typedef mozilla::Mutex Mutex;
@@ -246,49 +203,61 @@ public:
   NS_DECL_IMGICACHE
   NS_DECL_NSIOBSERVER
 
-  static imgLoader* Singleton();
-  static imgLoader* PBSingleton();
+  /**
+   * Get the normal image loader instance that is used by gecko code, creating
+   * it if necessary.
+   */
+  static imgLoader* NormalLoader();
 
+  /**
+   * Get the Private Browsing image loader instance that is used by gecko code,
+   * creating it if necessary.
+   */
+  static imgLoader* PrivateBrowsingLoader();
+
+  /**
+   * Gecko code should use NormalLoader() or PrivateBrowsingLoader() to get the
+   * appropriate image loader.
+   *
+   * This constructor is public because the XPCOM module code that creates
+   * instances of "@mozilla.org/image/loader;1" / "@mozilla.org/image/cache;1"
+   * for nsIComponentManager.createInstance()/nsIServiceManager.getService()
+   * calls (now only made by add-ons) needs access to it.
+   *
+   * XXX We would like to get rid of the nsIServiceManager.getService (and
+   * nsIComponentManager.createInstance) method of creating imgLoader objects,
+   * but there are add-ons that are still using it.  These add-ons don't
+   * actually do anything useful with the loaders that they create since nobody
+   * who creates an imgLoader using this method actually QIs to imgILoader and
+   * loads images.  They all just QI to imgICache and either call clearCache()
+   * or findEntryProperties().  Since they're doing this on an imgLoader that
+   * has never loaded images, these calls are useless.  It seems likely that
+   * the code that is doing this is just legacy code left over from a time when
+   * there was only one imgLoader instance for the entire process.  (Nowadays
+   * the correct method to get an imgILoader/imgICache is to call
+   * imgITools::getImgCacheForDocument/imgITools::getImgLoaderForDocument.)
+   * All the same, even though what these add-ons are doing is a no-op,
+   * removing the nsIServiceManager.getService method of creating/getting an
+   * imgLoader objects would cause an exception in these add-ons that could
+   * break things.
+   */
   imgLoader();
-
   nsresult Init();
 
-  static imgLoader* Create()
-  {
-      // Unfortunately, we rely on XPCOM module init happening
-      // before imgLoader creation. For now, it's easier
-      // to just call CallCreateInstance() which will init
-      // the image module instead of calling new imgLoader
-      // directly.
-      imgILoader* loader;
-      CallCreateInstance("@mozilla.org/image/loader;1", &loader);
-      // There's only one imgLoader implementation so we
-      // can safely cast to it.
-      return static_cast<imgLoader*>(loader);
-  }
+  MOZ_MUST_USE nsresult
+  LoadImage(nsIURI* aURI, nsIURI* aInitialDocumentURI, nsIURI* aReferrerURI,
+            ReferrerPolicy aReferrerPolicy, nsIPrincipal* aLoadingPrincipal,
+            uint64_t aRequestContextID, nsILoadGroup* aLoadGroup,
+            imgINotificationObserver* aObserver, nsINode* aContext,
+            nsIDocument* aLoadingDocument, nsLoadFlags aLoadFlags,
+            nsISupports* aCacheKey, nsContentPolicyType aContentPolicyType,
+            const nsAString& initiatorType, bool aUseUrgentStartForChannel,
+            imgRequestProxy** _retval);
 
-  static already_AddRefed<imgLoader>
-  GetInstance();
-
-  nsresult LoadImage(nsIURI* aURI,
-                     nsIURI* aInitialDocumentURI,
-                     nsIURI* aReferrerURI,
-                     ReferrerPolicy aReferrerPolicy,
-                     nsIPrincipal* aLoadingPrincipal,
-                     nsILoadGroup* aLoadGroup,
-                     imgINotificationObserver* aObserver,
-                     nsISupports* aCX,
-                     nsLoadFlags aLoadFlags,
-                     nsISupports* aCacheKey,
-                     nsContentPolicyType aContentPolicyType,
-                     const nsAString& initiatorType,
-                     imgRequestProxy** _retval);
-
-  nsresult LoadImageWithChannel(nsIChannel* channel,
-                                imgINotificationObserver* aObserver,
-                                nsISupports* aCX,
-                                nsIStreamListener** listener,
-                                imgRequestProxy** _retval);
+  MOZ_MUST_USE nsresult
+  LoadImageWithChannel(nsIChannel* channel, imgINotificationObserver* aObserver,
+                       nsISupports* aCX, nsIStreamListener** listener,
+                       imgRequestProxy** _retval);
 
   static nsresult GetMimeTypeFromContent(const char* aContents,
                                          uint32_t aLength,
@@ -306,13 +275,13 @@ public:
    * @param aMimeType The MIME type to evaluate.
    * @param aAcceptedMimeTypes Which kinds of MIME types to treat as images.
    */
-  static NS_EXPORT_(bool)
-  SupportImageWithMimeType(const char* aMimeType,
-                           AcceptedMimeTypes aAccept =
-                             AcceptedMimeTypes::IMAGES);
+  static bool SupportImageWithMimeType(
+      const char* aMimeType,
+      AcceptedMimeTypes aAccept = AcceptedMimeTypes::IMAGES);
 
-  static void GlobalInit(); // for use by the factory
-  static void Shutdown(); // for use by the factory
+  static void GlobalInit();  // for use by the factory
+  static void Shutdown();    // for use by the factory
+  static void ShutdownMemoryReporter();
 
   nsresult ClearChromeImageCache();
   nsresult ClearImageCache();
@@ -321,7 +290,13 @@ public:
   nsresult InitCache();
 
   bool RemoveFromCache(const ImageCacheKey& aKey);
-  bool RemoveFromCache(imgCacheEntry* entry);
+
+  // Enumeration describing if a given entry is in the cache queue or not.
+  // There are some cases we know the entry is definitely not in the queue.
+  enum class QueueState { MaybeExists, AlreadyRemoved };
+
+  bool RemoveFromCache(imgCacheEntry* entry,
+                       QueueState aQueueState = QueueState::MaybeExists);
 
   bool PutIntoCache(const ImageCacheKey& aKey, imgCacheEntry* aEntry);
 
@@ -332,8 +307,7 @@ public:
   // entry |one|.
   // This mixes units in the worst way, but provides reasonable results.
   inline static bool CompareCacheEntries(const RefPtr<imgCacheEntry>& one,
-                                         const RefPtr<imgCacheEntry>& two)
-  {
+                                         const RefPtr<imgCacheEntry>& two) {
     if (!one) {
       return false;
     }
@@ -370,34 +344,29 @@ public:
   bool SetHasNoProxies(imgRequest* aRequest, imgCacheEntry* aEntry);
   bool SetHasProxies(imgRequest* aRequest);
 
-private: // methods
+ private:  // methods
+  static already_AddRefed<imgLoader> CreateImageLoader();
 
   bool ValidateEntry(imgCacheEntry* aEntry, nsIURI* aKey,
                      nsIURI* aInitialDocumentURI, nsIURI* aReferrerURI,
-                     ReferrerPolicy aReferrerPolicy,
-                     nsILoadGroup* aLoadGroup,
+                     ReferrerPolicy aReferrerPolicy, nsILoadGroup* aLoadGroup,
                      imgINotificationObserver* aObserver, nsISupports* aCX,
-                     nsLoadFlags aLoadFlags,
+                     nsIDocument* aLoadingDocument, nsLoadFlags aLoadFlags,
                      nsContentPolicyType aContentPolicyType,
-                     bool aCanMakeNewChannel,
-                     imgRequestProxy** aProxyRequest,
-                     nsIPrincipal* aLoadingPrincipal,
-                     int32_t aCORSMode);
+                     bool aCanMakeNewChannel, imgRequestProxy** aProxyRequest,
+                     nsIPrincipal* aLoadingPrincipal, int32_t aCORSMode);
 
-  bool ValidateRequestWithNewChannel(imgRequest* request, nsIURI* aURI,
-                                     nsIURI* aInitialDocumentURI,
-                                     nsIURI* aReferrerURI,
-                                     ReferrerPolicy aReferrerPolicy,
-                                     nsILoadGroup* aLoadGroup,
-                                     imgINotificationObserver* aObserver,
-                                     nsISupports* aCX, nsLoadFlags aLoadFlags,
-                                     nsContentPolicyType aContentPolicyType,
-                                     imgRequestProxy** aProxyRequest,
-                                     nsIPrincipal* aLoadingPrincipal,
-                                     int32_t aCORSMode);
+  bool ValidateRequestWithNewChannel(
+      imgRequest* request, nsIURI* aURI, nsIURI* aInitialDocumentURI,
+      nsIURI* aReferrerURI, ReferrerPolicy aReferrerPolicy,
+      nsILoadGroup* aLoadGroup, imgINotificationObserver* aObserver,
+      nsISupports* aCX, nsIDocument* aLoadingDocument, nsLoadFlags aLoadFlags,
+      nsContentPolicyType aContentPolicyType, imgRequestProxy** aProxyRequest,
+      nsIPrincipal* aLoadingPrincipal, int32_t aCORSMode);
 
   nsresult CreateNewProxyForRequest(imgRequest* aRequest,
                                     nsILoadGroup* aLoadGroup,
+                                    nsIDocument* aLoadingDocument,
                                     imgINotificationObserver* aObserver,
                                     nsLoadFlags aLoadFlags,
                                     imgRequestProxy** _retval);
@@ -414,7 +383,7 @@ private: // methods
   void CacheEntriesChanged(bool aForChrome, int32_t aSizeDiff = 0);
   void CheckCacheLimits(imgCacheTable& cache, imgCacheQueue& queue);
 
-private: // data
+ private:  // data
   friend class imgCacheEntry;
   friend class imgMemoryReporter;
 
@@ -444,8 +413,6 @@ private: // data
   bool mRespectPrivacy;
 };
 
-
-
 /**
  * proxy stream listener class used to handle multipart/x-mixed-replace
  */
@@ -454,10 +421,9 @@ private: // data
 #include "nsIStreamListener.h"
 #include "nsIThreadRetargetableStreamListener.h"
 
-class ProxyListener : public nsIStreamListener
-                    , public nsIThreadRetargetableStreamListener
-{
-public:
+class ProxyListener : public nsIStreamListener,
+                      public nsIThreadRetargetableStreamListener {
+ public:
   explicit ProxyListener(nsIStreamListener* dest);
 
   /* additional members */
@@ -466,7 +432,7 @@ public:
   NS_DECL_NSITHREADRETARGETABLESTREAMLISTENER
   NS_DECL_NSIREQUESTOBSERVER
 
-private:
+ private:
   virtual ~ProxyListener();
 
   nsCOMPtr<nsIStreamListener> mDestListener;
@@ -478,27 +444,24 @@ private:
  * nsIInterfaceRequestor and gives out itself for nsIProgressEventSink calls,
  * and forwards everything else to the channel's notification callbacks.
  */
-class nsProgressNotificationProxy final
-  : public nsIProgressEventSink
-  , public nsIChannelEventSink
-  , public nsIInterfaceRequestor
-{
-  public:
-    nsProgressNotificationProxy(nsIChannel* channel,
-                                imgIRequest* proxy)
-        : mImageRequest(proxy) {
-      channel->GetNotificationCallbacks(getter_AddRefs(mOriginalCallbacks));
-    }
+class nsProgressNotificationProxy final : public nsIProgressEventSink,
+                                          public nsIChannelEventSink,
+                                          public nsIInterfaceRequestor {
+ public:
+  nsProgressNotificationProxy(nsIChannel* channel, imgIRequest* proxy)
+      : mImageRequest(proxy) {
+    channel->GetNotificationCallbacks(getter_AddRefs(mOriginalCallbacks));
+  }
 
-    NS_DECL_ISUPPORTS
-    NS_DECL_NSIPROGRESSEVENTSINK
-    NS_DECL_NSICHANNELEVENTSINK
-    NS_DECL_NSIINTERFACEREQUESTOR
-  private:
-    ~nsProgressNotificationProxy() { }
+  NS_DECL_ISUPPORTS
+  NS_DECL_NSIPROGRESSEVENTSINK
+  NS_DECL_NSICHANNELEVENTSINK
+  NS_DECL_NSIINTERFACEREQUESTOR
+ private:
+  ~nsProgressNotificationProxy() {}
 
-    nsCOMPtr<nsIInterfaceRequestor> mOriginalCallbacks;
-    nsCOMPtr<nsIRequest> mImageRequest;
+  nsCOMPtr<nsIInterfaceRequestor> mOriginalCallbacks;
+  nsCOMPtr<nsIRequest> mImageRequest;
 };
 
 /**
@@ -511,16 +474,16 @@ class imgCacheValidator : public nsIStreamListener,
                           public nsIThreadRetargetableStreamListener,
                           public nsIChannelEventSink,
                           public nsIInterfaceRequestor,
-                          public nsIAsyncVerifyRedirectCallback
-{
-public:
+                          public nsIAsyncVerifyRedirectCallback {
+ public:
   imgCacheValidator(nsProgressNotificationProxy* progress, imgLoader* loader,
                     imgRequest* aRequest, nsISupports* aContext,
                     bool forcePrincipalCheckForCacheEntry);
 
   void AddProxy(imgRequestProxy* aProxy);
+  void RemoveProxy(imgRequestProxy* aProxy);
 
-  NS_DECL_ISUPPORTS
+  NS_DECL_THREADSAFE_ISUPPORTS
   NS_DECL_NSITHREADRETARGETABLESTREAMLISTENER
   NS_DECL_NSISTREAMLISTENER
   NS_DECL_NSIREQUESTOBSERVER
@@ -528,7 +491,8 @@ public:
   NS_DECL_NSIINTERFACEREQUESTOR
   NS_DECL_NSIASYNCVERIFYREDIRECTCALLBACK
 
-private:
+ private:
+  void UpdateProxies(bool aCancelRequest, bool aSyncNotify);
   virtual ~imgCacheValidator();
 
   nsCOMPtr<nsIStreamListener> mDestListener;
@@ -537,7 +501,7 @@ private:
   nsCOMPtr<nsIChannel> mRedirectChannel;
 
   RefPtr<imgRequest> mRequest;
-  nsCOMArray<imgIRequest> mProxies;
+  AutoTArray<RefPtr<imgRequestProxy>, 4> mProxies;
 
   RefPtr<imgRequest> mNewRequest;
   RefPtr<imgCacheEntry> mNewEntry;
@@ -549,4 +513,4 @@ private:
   bool mHadInsecureRedirect;
 };
 
-#endif // mozilla_image_imgLoader_h
+#endif  // mozilla_image_imgLoader_h
