@@ -113,71 +113,6 @@ CheckPalettedIterativeWrite(Decoder* aDecoder,
   });
 }
 
-TEST(ImageSurfaceSink, NullSurfaceSink)
-{
-  // Create the NullSurfaceSink.
-  NullSurfaceSink sink;
-  nsresult rv = sink.Configure(NullSurfaceConfig { });
-  ASSERT_TRUE(NS_SUCCEEDED(rv));
-  EXPECT_TRUE(!sink.IsValidPalettedPipe());
-
-  // Ensure that we can't write anything.
-  bool gotCalled = false;
-  auto result = sink.WritePixels<uint32_t>([&]() {
-    gotCalled = true;
-    return AsVariant(BGRAColor::Green().AsPixel());
-  });
-  EXPECT_FALSE(gotCalled);
-  EXPECT_EQ(WriteState::FINISHED, result);
-  EXPECT_TRUE(sink.IsSurfaceFinished());
-  Maybe<SurfaceInvalidRect> invalidRect = sink.TakeInvalidRect();
-  EXPECT_TRUE(invalidRect.isNothing());
-
-  uint32_t source = BGRAColor::Red().AsPixel();
-  result = sink.WriteBuffer(&source);
-  EXPECT_EQ(WriteState::FINISHED, result);
-  EXPECT_TRUE(sink.IsSurfaceFinished());
-  invalidRect = sink.TakeInvalidRect();
-  EXPECT_TRUE(invalidRect.isNothing());
-
-  result = sink.WriteBuffer(&source, 0, 1);
-  EXPECT_EQ(WriteState::FINISHED, result);
-  EXPECT_TRUE(sink.IsSurfaceFinished());
-  invalidRect = sink.TakeInvalidRect();
-  EXPECT_TRUE(invalidRect.isNothing());
-
-  result = sink.WriteEmptyRow();
-  EXPECT_EQ(WriteState::FINISHED, result);
-  EXPECT_TRUE(sink.IsSurfaceFinished());
-  invalidRect = sink.TakeInvalidRect();
-  EXPECT_TRUE(invalidRect.isNothing());
-
-  result = sink.WriteUnsafeComputedRow<uint32_t>([&](uint32_t* aRow,
-                                                     uint32_t aLength) {
-    gotCalled = true;
-    for (uint32_t col = 0; col < aLength; ++col, ++aRow) {
-      *aRow = BGRAColor::Red().AsPixel();
-    }
-  });
-  EXPECT_FALSE(gotCalled);
-  EXPECT_EQ(WriteState::FINISHED, result);
-  EXPECT_TRUE(sink.IsSurfaceFinished());
-  invalidRect = sink.TakeInvalidRect();
-  EXPECT_TRUE(invalidRect.isNothing());
-
-  // Attempt to advance to the next row and make sure nothing changes.
-  sink.AdvanceRow();
-  EXPECT_TRUE(sink.IsSurfaceFinished());
-  invalidRect = sink.TakeInvalidRect();
-  EXPECT_TRUE(invalidRect.isNothing());
-
-  // Attempt to advance to the next pass and make sure nothing changes.
-  sink.ResetToFirstRow();
-  EXPECT_TRUE(sink.IsSurfaceFinished());
-  invalidRect = sink.TakeInvalidRect();
-  EXPECT_TRUE(invalidRect.isNothing());
-}
-
 TEST(ImageSurfaceSink, SurfaceSinkInitialization)
 {
   WithSurfaceSink<Orient::NORMAL>([](Decoder* aDecoder, SurfaceSink* aSink) {
