@@ -91,7 +91,8 @@ static int mar_consume_index(MarFile *mar, char **buf, const char *buf_end) {
   name = *buf;
   /* find namelen; must take care not to read beyond buf_end */
   while (**buf) {
-    if (*buf == buf_end)
+    /* buf_end points one byte past the end of buf's allocation */
+    if (*buf == (buf_end - 1))
       return -1;
     ++(*buf);
   }
@@ -113,6 +114,7 @@ static int mar_read_index(MarFile *mar) {
   uint32_t offset_to_index, size_of_index;
 
   /* verify MAR ID */
+  fseek(mar->fp, 0, SEEK_SET);
   if (fread(id, MAR_ID_SIZE, 1, mar->fp) != 1)
     return -1;
   if (memcmp(id, MAR_ID, MAR_ID_SIZE) != 0)
@@ -159,11 +161,8 @@ static MarFile *mar_fpopen(FILE *fp)
   }
 
   mar->fp = fp;
+  mar->item_table_is_valid = 0;
   memset(mar->item_table, 0, sizeof(mar->item_table));
-  if (mar_read_index(mar)) {
-    mar_close(mar);
-    return NULL;
-  }
 
   return mar;
 }
@@ -337,7 +336,7 @@ int get_mar_file_info_fp(FILE *fp,
     }
   }
 
-  if (ftell(fp) == offsetToContent) {
+  if ((int64_t)ftell(fp) == (int64_t)offsetToContent) {
     *hasAdditionalBlocks = 0;
   } else {
     if (numAdditionalBlocks) {
@@ -405,10 +404,12 @@ mar_read_product_info_block(MarFile *mar,
   /* The buffer size is 97 bytes because the MAR channel name < 64 bytes, and 
      product version < 32 bytes + 3 NULL terminator bytes. */
   char buf[97] = { '\0' };
-  int ret = get_mar_file_info_fp(mar->fp, NULL, NULL,
-                                 &hasAdditionalBlocks, 
-                                 &offsetAdditionalBlocks, 
-                                 &numAdditionalBlocks);
+  if (get_mar_file_info_fp(mar->fp, NULL, NULL,
+                           &hasAdditionalBlocks,
+                           &offsetAdditionalBlocks,
+                           &numAdditionalBlocks) != 0) {
+    return -1;
+  }
   for (i = 0; i < numAdditionalBlocks; ++i) {
     /* Read the additional block size */
     if (fread(&additionalBlockSize, 
@@ -460,7 +461,6 @@ mar_read_product_info_block(MarFile *mar,
       /* Extract the version from the buffer */
       len = strlen(location);
       infoBlock->productVersion = location;
-      location += len + 1;
       if (len >= 32) {
         infoBlock->MARChannelID = NULL;
         infoBlock->productVersion = NULL;
@@ -487,6 +487,14 @@ const MarItem *mar_find_item(MarFile *mar, const char *name) {
   uint32_t hash;
   const MarItem *item;
 
+  if (!mar->item_table_is_valid) {
+    if (mar_read_index(mar)) {
+      return NULL;
+    } else {
+      mar->item_table_is_valid = 1;
+    }
+  }
+
   hash = mar_hash_name(name);
 
   item = mar->item_table[hash];
@@ -500,6 +508,14 @@ int mar_enum_items(MarFile *mar, MarItemCallback callback, void *closure) {
   MarItem *item;
   int i;
 
+  if (!mar->item_table_is_valid) {
+    if (mar_read_index(mar)) {
+      return -1;
+    } else {
+      mar->item_table_is_valid = 1;
+    }
+  }
+
   for (i = 0; i < TABLESIZE; ++i) {
     item = mar->item_table[i];
     while (item) {
@@ -513,7 +529,7 @@ int mar_enum_items(MarFile *mar, MarItemCallback callback, void *closure) {
   return 0;
 }
 
-int mar_read(MarFile *mar, const MarItem *item, int offset, char *buf,
+int mar_read(MarFile *mar, const MarItem *item, int offset, uint8_t *buf,
              int bufsize) {
   int nr;
 
