@@ -156,15 +156,44 @@ CryptoMac_VerifySignature(CryptoX_SignatureHandle* aInputData,
                                 signatureData,
                                 &error);
   if (!verifier || error) {
+    if (error) {
+      CFRelease(error);
+    }
     CFRelease(signatureData);
     return CryptoX_Error;
   }
 
+  SecTransformSetAttributePtr(verifier,
+                              kSecDigestTypeAttribute,
+                              kSecDigestSHA2,
+                              &error);
+  if (error) {
+    CFRelease(error);
+    CFRelease(signatureData);
+    CFRelease(verifier);
+    return CryptoX_Error;
+  }
+
+  int digestLength = 384;
+  CFNumberRef dLen = CFNumberCreate(kCFAllocatorDefault, kCFNumberIntType, &digestLength);
+  SecTransformSetAttributePtr(verifier,
+                              kSecDigestLengthAttribute,
+                              dLen,
+                              &error);
+  CFRelease(dLen);
+  if (error) {
+    CFRelease(error);
+    CFRelease(signatureData);
+    CFRelease(verifier);
+    return CryptoX_Error;
+  }
+
   SecTransformSetAttributePtr(verifier,
                               kSecTransformInputAttributeName,
                               (CFDataRef)*aInputData,
                               &error);
   if (error) {
+    CFRelease(error);
     CFRelease(signatureData);
     CFRelease(verifier);
     return CryptoX_Error;
@@ -173,6 +202,7 @@ CryptoMac_VerifySignature(CryptoX_SignatureHandle* aInputData,
   CryptoX_Result result = CryptoX_Error;
   CFTypeRef rv = SecTransformExecutePtr(verifier, &error);
   if (error) {
+    CFRelease(error);
     CFRelease(signatureData);
     CFRelease(verifier);
     return CryptoX_Error;
