@@ -11,29 +11,22 @@
 #include "nsISupports.h"
 #include "nsCOMPtr.h"
 
-// This class is no longer useful.
-class nsIHTMLContentSink;
-
 #ifdef _MSC_VER
-#pragma warning( disable : 4275 )
+#pragma warning(disable : 4275)
 #endif
 
-class CNavDTD : public nsIDTD
-{
+class CNavDTD : public nsIDTD {
 #ifdef _MSC_VER
-#pragma warning( default : 4275 )
+#pragma warning(default : 4275)
 #endif
 
-    virtual ~CNavDTD();
+  virtual ~CNavDTD();
 
-public:
-    CNavDTD();
+ public:
+  CNavDTD();
 
-    NS_DECL_ISUPPORTS
-    NS_DECL_NSIDTD
+  NS_DECL_ISUPPORTS
+  NS_DECL_NSIDTD
 };
 
 #endif
-
-
-
