@@ -10,6 +10,7 @@ from collections import Iterable
 
 import argparse
 import codecs
+import errno
 import imp
 import logging
 import os
@@ -20,15 +21,15 @@ import uuid
 from .base import (
     CommandContext,
     MachError,
+    MissingFileError,
     NoCommandError,
     UnknownCommandError,
     UnrecognizedArgumentError,
+    FailedCommandError,
 )
 
 from .decorators import (
-    CommandArgument,
     CommandProvider,
-    Command,
 )
 
 from .config import ConfigSettings
@@ -37,7 +38,6 @@ from .logging import LoggingManager
 from .registrar import Registrar
 
 
-
 MACH_ERROR = r'''
 The error occurred in mach itself. This is likely a bug in mach itself or a
 fundamental problem with a loaded module.
@@ -102,6 +102,7 @@ to implement a mach command. Please fix the error, or uninstall the module from
 your system.
 '''.lstrip()
 
+
 class ArgumentParser(argparse.ArgumentParser):
     """Custom implementation argument parser to make things look pretty."""
 
@@ -185,6 +186,9 @@ class Mach(object):
         require_conditions -- If True, commands that do not have any condition
             functions applied will be skipped. Defaults to False.
 
+        settings_paths -- A list of files or directories in which to search
+            for settings files to load.
+
     """
 
     USAGE = """%(prog)s [global arguments] command [command arguments]
@@ -211,6 +215,10 @@ To see more help for a specific command, run:
         self.log_manager = LoggingManager()
         self.logger = logging.getLogger(__name__)
         self.settings = ConfigSettings()
+        self.settings_paths = []
+
+        if 'MACHRC' in os.environ:
+            self.settings_paths.append(os.environ['MACHRC'])
 
         self.log_manager.register_structured_logger(self.logger)
         self.global_arguments = []
@@ -255,7 +263,13 @@ To see more help for a specific command, run:
 
             module_name = 'mach.commands.%s' % uuid.uuid1().get_hex()
 
-        imp.load_source(module_name, path)
+        try:
+            imp.load_source(module_name, path)
+        except IOError as e:
+            if e.errno != errno.ENOENT:
+                raise
+
+            raise MissingFileError('%s does not exist' % path)
 
     def load_commands_from_entry_point(self, group='mach.providers'):
         """Scan installed packages for mach command provider entry points. An
@@ -323,6 +337,8 @@ To see more help for a specific command, run:
         sys.stdout = stdout
         sys.stderr = stderr
 
+        orig_env = dict(os.environ)
+
         try:
             if stdin.encoding is None:
                 sys.stdin = codecs.getreader('utf-8')(stdin)
@@ -333,12 +349,19 @@ To see more help for a specific command, run:
             if stderr.encoding is None:
                 sys.stderr = codecs.getwriter('utf-8')(stderr)
 
+            # Allow invoked processes (which may not have a handle on the
+            # original stdout file descriptor) to know if the original stdout
+            # is a TTY. This provides a mechanism to allow said processes to
+            # enable emitting code codes, for example.
+            if os.isatty(orig_stdout.fileno()):
+                os.environ[b'MACH_STDOUT_ISATTY'] = b'1'
+
             return self._run(argv)
         except KeyboardInterrupt:
             print('mach interrupted by signal or user action. Stopping.')
             return 1
 
-        except Exception as e:
+        except Exception:
             # _run swallows exceptions in invoked handlers and converts them to
             # a proper exit code. So, the only scenario where we should get an
             # exception here is if _run itself raises. If _run raises, that's a
@@ -355,14 +378,23 @@ To see more help for a specific command, run:
             return 1
 
         finally:
+            os.environ.clear()
+            os.environ.update(orig_env)
+
             sys.stdin = orig_stdin
             sys.stdout = orig_stdout
             sys.stderr = orig_stderr
 
     def _run(self, argv):
+        # Load settings as early as possible so things in dispatcher.py
+        # can use them.
+        for provider in Registrar.settings_providers:
+            self.settings.register_provider(provider)
+        self.load_settings(self.settings_paths)
+
         context = CommandContext(cwd=self.cwd,
-            settings=self.settings, log_manager=self.log_manager,
-            commands=Registrar)
+                                 settings=self.settings, log_manager=self.log_manager,
+                                 commands=Registrar)
 
         if self.populate_context_handler:
             self.populate_context_handler(context)
@@ -384,12 +416,14 @@ To see more help for a specific command, run:
             print(NO_COMMAND_ERROR)
             return 1
         except UnknownCommandError as e:
-            suggestion_message = SUGGESTED_COMMANDS_MESSAGE % (e.verb, ', '.join(e.suggested_commands)) if e.suggested_commands else ''
-            print(UNKNOWN_COMMAND_ERROR % (e.verb, e.command, suggestion_message))
+            suggestion_message = SUGGESTED_COMMANDS_MESSAGE % (
+                e.verb, ', '.join(e.suggested_commands)) if e.suggested_commands else ''
+            print(UNKNOWN_COMMAND_ERROR %
+                  (e.verb, e.command, suggestion_message))
             return 1
         except UnrecognizedArgumentError as e:
             print(UNRECOGNIZED_ARGUMENT_ERROR % (e.command,
-                ' '.join(e.arguments)))
+                                                 ' '.join(e.arguments)))
             return 1
 
         # Add JSON logging to a file if requested.
@@ -410,9 +444,13 @@ To see more help for a specific command, run:
         # Always enable terminal logging. The log manager figures out if we are
         # actually in a TTY or are a pipe and does the right thing.
         self.log_manager.add_terminal_logging(level=log_level,
-            write_interval=args.log_interval, write_times=write_times)
+                                              write_interval=args.log_interval,
+                                              write_times=write_times)
 
-        self.load_settings(args)
+        if args.settings_file:
+            # Argument parsing has already happened, so settings that apply
+            # to command line handling (e.g alias, defaults) will be ignored.
+            self.load_settings(args.settings_file)
 
         if not hasattr(args, 'mach_handler'):
             raise MachError('ArgumentParser result missing mach handler info.')
@@ -421,9 +459,13 @@ To see more help for a specific command, run:
 
         try:
             return Registrar._run_command_handler(handler, context=context,
-                debug_command=args.debug_command, **vars(args.command_args))
+                                                  debug_command=args.debug_command,
+                                                  **vars(args.command_args))
         except KeyboardInterrupt as ki:
             raise ki
+        except FailedCommandError as e:
+            print(e.message)
+            return e.exit_code
         except Exception as e:
             exc_type, exc_value, exc_tb = sys.exc_info()
 
@@ -439,7 +481,7 @@ To see more help for a specific command, run:
             if not len(stack):
                 print(COMMAND_ERROR)
                 self._print_exception(sys.stdout, exc_type, exc_value,
-                    traceback.extract_tb(exc_tb))
+                                      traceback.extract_tb(exc_tb))
                 return 1
 
             # Split the frames into those from the module containing the
@@ -473,7 +515,7 @@ To see more help for a specific command, run:
     def log(self, level, action, params, format_str):
         """Helper method to record a structured log event."""
         self.logger.log(level, format_str,
-            extra={'action': action, 'params': params})
+                        extra={'action': action, 'params': params})
 
     def _print_error_header(self, argv, fh):
         fh.write('Error running mach:\n\n')
@@ -492,77 +534,71 @@ To see more help for a specific command, run:
         for l in traceback.format_list(stack):
             fh.write(l)
 
-    def load_settings(self, args):
-        """Determine which settings files apply and load them.
+    def load_settings(self, paths):
+        """Load the specified settings files.
 
-        Currently, we only support loading settings from a single file.
-        Ideally, we support loading from multiple files. This is supported by
-        the ConfigSettings API. However, that API currently doesn't track where
-        individual values come from, so if we load from multiple sources then
-        save, we effectively do a full copy. We don't want this. Until
-        ConfigSettings does the right thing, we shouldn't expose multi-file
-        loading.
+        If a directory is specified, the following basenames will be
+        searched for in this order:
 
-        We look for a settings file in the following locations. The first one
-        found wins:
-
-          1) Command line argument
-          2) Environment variable
-          3) Default path
+            machrc, .machrc
         """
-        # Settings are disabled until integration with command providers is
-        # worked out.
-        self.settings = None
-        return False
+        if isinstance(paths, basestring):
+            paths = [paths]
 
-        for provider in Registrar.settings_providers:
-            provider.register_settings()
-            self.settings.register_provider(provider)
+        valid_names = ('machrc', '.machrc')
 
-        p = os.path.join(self.cwd, 'mach.ini')
+        def find_in_dir(base):
+            if os.path.isfile(base):
+                return base
 
-        if args.settings_file:
-            p = args.settings_file
-        elif 'MACH_SETTINGS_FILE' in os.environ:
-            p = os.environ['MACH_SETTINGS_FILE']
+            for name in valid_names:
+                path = os.path.join(base, name)
+                if os.path.isfile(path):
+                    return path
 
-        self.settings.load_file(p)
+        files = map(find_in_dir, self.settings_paths)
+        files = filter(bool, files)
 
-        return os.path.exists(p)
+        self.settings.load_files(files)
 
     def get_argument_parser(self, context):
         """Returns an argument parser for the command-line interface."""
 
         parser = ArgumentParser(add_help=False,
-            usage='%(prog)s [global arguments] command [command arguments]')
+                                usage='%(prog)s [global arguments] '
+                                'command [command arguments]')
 
         # Order is important here as it dictates the order the auto-generated
         # help messages are printed.
         global_group = parser.add_argument_group('Global Arguments')
 
-        #global_group.add_argument('--settings', dest='settings_file',
-        #    metavar='FILENAME', help='Path to settings file.')
-
         global_group.add_argument('-v', '--verbose', dest='verbose',
-            action='store_true', default=False,
-            help='Print verbose output.')
+                                  action='store_true', default=False,
+                                  help='Print verbose output.')
         global_group.add_argument('-l', '--log-file', dest='logfile',
-            metavar='FILENAME', type=argparse.FileType('ab'),
-            help='Filename to write log data to.')
+                                  metavar='FILENAME', type=argparse.FileType('ab'),
+                                  help='Filename to write log data to.')
         global_group.add_argument('--log-interval', dest='log_interval',
-            action='store_true', default=False,
-            help='Prefix log line with interval from last message rather '
-                'than relative time. Note that this is NOT execution time '
-                'if there are parallel operations.')
+                                  action='store_true', default=False,
+                                  help='Prefix log line with interval from last message rather '
+                                  'than relative time. Note that this is NOT execution time '
+                                  'if there are parallel operations.')
+        suppress_log_by_default = False
+        if 'INSIDE_EMACS' in os.environ:
+            suppress_log_by_default = True
         global_group.add_argument('--log-no-times', dest='log_no_times',
-            action='store_true', default=False,
-            help='Do not prefix log lines with times. By default, mach will '
-                'prefix each output line with the time since command start.')
+                                  action='store_true', default=suppress_log_by_default,
+                                  help='Do not prefix log lines with times. By default, '
+                                  'mach will prefix each output line with the time since '
+                                  'command start.')
         global_group.add_argument('-h', '--help', dest='help',
-            action='store_true', default=False,
-            help='Show this help message.')
+                                  action='store_true', default=False,
+                                  help='Show this help message.')
         global_group.add_argument('--debug-command', action='store_true',
-            help='Start a Python debugger when command is dispatched.')
+                                  help='Start a Python debugger when command is dispatched.')
+        global_group.add_argument('--settings', dest='settings_file',
+                                  metavar='FILENAME', default=None,
+                                  help='Path to settings file.')
 
         for args, kwargs in self.global_arguments:
             global_group.add_argument(*args, **kwargs)
@@ -570,6 +606,6 @@ To see more help for a specific command, run:
         # We need to be last because CommandAction swallows all remaining
         # arguments and argparse parses arguments in the order they were added.
         parser.add_argument('command', action=CommandAction,
-            registrar=Registrar, context=context)
+                            registrar=Registrar, context=context)
 
         return parser
