@@ -2,10 +2,10 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-import os
-import sys
+from __future__ import absolute_import, print_function
 
 from mozboot.base import BaseBootstrapper
+from mozboot.linux_common import StyloInstall
 
 
 MERCURIAL_INSTALL_PROMPT = '''
@@ -28,13 +28,14 @@ Choice:
 '''.strip()
 
 
-class DebianBootstrapper(BaseBootstrapper):
+class DebianBootstrapper(StyloInstall, BaseBootstrapper):
     # These are common packages for all Debian-derived distros (such as
     # Ubuntu).
     COMMON_PACKAGES = [
         'autoconf2.13',
         'build-essential',
         'ccache',
+        'nodejs',
         'python-dev',
         'python-pip',
         'python-setuptools',
@@ -46,6 +47,12 @@ class DebianBootstrapper(BaseBootstrapper):
     # Subclasses can add packages to this variable to have them installed.
     DISTRO_PACKAGES = []
 
+    # Ubuntu and Debian don't often differ, but they do for npm.
+    DEBIAN_PACKAGES = [
+        # Comment the npm package until Debian bring it back
+        # 'npm'
+    ]
+
     # These are common packages for building IceCat for Desktop
     # (browser) for all Debian-derived distros (such as Ubuntu).
     BROWSER_COMMON_PACKAGES = [
@@ -54,18 +61,14 @@ class DebianBootstrapper(BaseBootstrapper):
         'libdbus-1-dev',
         'libdbus-glib-1-dev',
         'libgconf2-dev',
-        'libgstreamer0.10-dev',
-        'libgstreamer-plugins-base0.10-dev',
-        'libgtk2.0-dev',
         'libgtk-3-dev',
-        'libiw-dev',
-        'libnotify-dev',
+        'libgtk2.0-dev',
         'libpulse-dev',
+        'libx11-xcb-dev',
         'libxt-dev',
-        'mesa-common-dev',
         'python-dbus',
-        'yasm',
         'xvfb',
+        'yasm',
     ]
 
     # Subclasses can add packages to this variable to have them installed.
@@ -74,42 +77,52 @@ class DebianBootstrapper(BaseBootstrapper):
     # These are common packages for building IceCat for Android
     # (mobile/android) for all Debian-derived distros (such as Ubuntu).
     MOBILE_ANDROID_COMMON_PACKAGES = [
-        'zlib1g-dev',  # mobile/android requires system zlib.
-        'openjdk-7-jdk',
-        'ant',
+        'default-jdk',
         'wget',  # For downloading the Android SDK and NDK.
         'libncurses5:i386',  # See comments about i386 below.
         'libstdc++6:i386',
-        'zlib1g:i386',
     ]
 
     # Subclasses can add packages to this variable to have them installed.
     MOBILE_ANDROID_DISTRO_PACKAGES = []
 
-    def __init__(self, version, dist_id, **kwargs):
+    def __init__(self, distro, version, dist_id, **kwargs):
         BaseBootstrapper.__init__(self, **kwargs)
 
+        self.distro = distro
         self.version = version
         self.dist_id = dist_id
 
         self.packages = self.COMMON_PACKAGES + self.DISTRO_PACKAGES
+        if self.distro == 'Debian' or self.distro == 'debian':
+            self.packages += self.DEBIAN_PACKAGES
         self.browser_packages = self.BROWSER_COMMON_PACKAGES + self.BROWSER_DISTRO_PACKAGES
-        self.mobile_android_packages = self.MOBILE_ANDROID_COMMON_PACKAGES + self.MOBILE_ANDROID_DISTRO_PACKAGES
-
+        self.mobile_android_packages = self.MOBILE_ANDROID_COMMON_PACKAGES + \
+            self.MOBILE_ANDROID_DISTRO_PACKAGES
 
     def install_system_packages(self):
         self.apt_install(*self.packages)
 
     def install_browser_packages(self):
-        self.apt_install(*self.browser_packages)
+        self.ensure_browser_packages()
+
+    def install_browser_artifact_mode_packages(self):
+        self.ensure_browser_packages(artifact_mode=True)
 
     def install_mobile_android_packages(self):
-        import android
+        self.ensure_mobile_android_packages()
 
+    def install_mobile_android_artifact_mode_packages(self):
+        self.ensure_mobile_android_packages(artifact_mode=True)
+
+    def ensure_browser_packages(self, artifact_mode=False):
+        # TODO: Figure out what not to install for artifact mode
+        self.apt_install(*self.browser_packages)
+
+    def ensure_mobile_android_packages(self, artifact_mode=False):
         # Multi-part process:
         # 1. System packages.
-        # 2. Android SDK and NDK.
-        # 3. Android packages.
+        # 2. Android SDK. Android NDK only if we are not in artifact mode. Android packages.
 
         # 1. This is hard to believe, but the Android SDK binaries are 32-bit
         # and that conflicts with 64-bit Debian and Ubuntu installations out of
@@ -121,28 +134,17 @@ class DebianBootstrapper(BaseBootstrapper):
         self.apt_update()
         self.apt_install(*self.mobile_android_packages)
 
-        # 2. The user may have an external Android SDK (in which case we save
-        # them a lengthy download), or they may have already completed the
-        # download. We unpack to ~/.mozbuild/{android-sdk-linux, android-ndk-r10e}.
-        mozbuild_path = os.environ.get('MOZBUILD_STATE_PATH', os.path.expanduser(os.path.join('~', '.mozbuild')))
-        self.sdk_path = os.environ.get('ANDROID_SDK_HOME', os.path.join(mozbuild_path, 'android-sdk-linux'))
-        self.ndk_path = os.environ.get('ANDROID_NDK_HOME', os.path.join(mozbuild_path, 'android-ndk-r10e'))
-        self.sdk_url = 'https://dl.google.com/android/android-sdk_r24.0.1-linux.tgz'
-        self.ndk_url = android.android_ndk_url('linux')
+        # 2. Android pieces.
+        from mozboot import android
+        android.ensure_android('linux', artifact_mode=artifact_mode,
+                               no_interactive=self.no_interactive)
 
-        android.ensure_android_sdk_and_ndk(path=mozbuild_path,
-                                           sdk_path=self.sdk_path, sdk_url=self.sdk_url,
-                                           ndk_path=self.ndk_path, ndk_url=self.ndk_url)
+    def suggest_mobile_android_mozconfig(self, artifact_mode=False):
+        from mozboot import android
+        android.suggest_mozconfig('linux', artifact_mode=artifact_mode)
 
-        # 3. We expect the |android| tool to at
-        # ~/.mozbuild/android-sdk-linux/tools/android.
-        android_tool = os.path.join(self.sdk_path, 'tools', 'android')
-        android.ensure_android_packages(android_tool=android_tool)
-
-    def suggest_mobile_android_mozconfig(self):
-        import android
-        android.suggest_mozconfig(sdk_path=self.sdk_path,
-                                  ndk_path=self.ndk_path)
+    def suggest_mobile_android_artifact_mode_mozconfig(self):
+        self.suggest_mobile_android_mozconfig(artifact_mode=True)
 
     def _update_package_manager(self):
         self.apt_update()
