@@ -2,7 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 
-from __future__ import print_function, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 import os
 import re
@@ -20,15 +20,18 @@ from mozboot.base import BaseBootstrapper
 
 HOMEBREW_BOOTSTRAP = 'https://raw.githubusercontent.com/Homebrew/install/master/install'
 XCODE_APP_STORE = 'macappstore://itunes.apple.com/app/id497799835?mt=12'
-XCODE_LEGACY = 'https://developer.apple.com/downloads/download.action?path=Developer_Tools/xcode_3.2.6_and_ios_sdk_4.3__final/xcode_3.2.6_and_ios_sdk_4.3.dmg'
-HOMEBREW_AUTOCONF213 = 'https://raw.github.com/Homebrew/homebrew-versions/master/autoconf213.rb'
+XCODE_LEGACY = ('https://developer.apple.com/downloads/download.action?path=Developer_Tools/'
+                'xcode_3.2.6_and_ios_sdk_4.3__final/xcode_3.2.6_and_ios_sdk_4.3.dmg')
 
-MACPORTS_URL = {'9': 'https://distfiles.macports.org/MacPorts/MacPorts-2.2.1-10.9-Mavericks.pkg',
-                '8': 'https://distfiles.macports.org/MacPorts/MacPorts-2.1.3-10.8-MountainLion.pkg',
-                '7': 'https://distfiles.macports.org/MacPorts/MacPorts-2.1.3-10.7-Lion.pkg',
-                '6': 'https://distfiles.macports.org/MacPorts/MacPorts-2.1.3-10.6-SnowLeopard.pkg', }
-
-MACPORTS_CLANG_PACKAGE = 'clang-3.3'
+MACPORTS_URL = {
+    '13': 'https://distfiles.macports.org/MacPorts/MacPorts-2.4.2-10.13-HighSierra.pkg',
+    '12': 'https://distfiles.macports.org/MacPorts/MacPorts-2.4.2-10.12-Sierra.pkg',
+    '11': 'https://distfiles.macports.org/MacPorts/MacPorts-2.4.2-10.11-ElCapitan.pkg',
+    '10': 'https://distfiles.macports.org/MacPorts/MacPorts-2.4.2-10.10-Yosemite.pkg',
+    '9': 'https://distfiles.macports.org/MacPorts/MacPorts-2.4.2-10.9-Mavericks.pkg',
+    '8': 'https://distfiles.macports.org/MacPorts/MacPorts-2.4.2-10.8-MountainLion.pkg',
+    '7': 'https://distfiles.macports.org/MacPorts/MacPorts-2.4.2-10.7-Lion.pkg',
+    '6': 'https://distfiles.macports.org/MacPorts/MacPorts-2.4.2-10.6-SnowLeopard.pkg', }
 
 RE_CLANG_VERSION = re.compile('Apple (?:clang|LLVM) version (\d+\.\d+)')
 
@@ -142,7 +145,11 @@ shell's init script (e.g. ~/.bash_profile) to export a PATH
 environment variable containing the location of your package
 manager binary. e.g.
 
+Homebrew:
     export PATH=/usr/local/bin:$PATH
+
+MacPorts:
+    export PATH=/opt/local/bin:$PATH
 '''
 
 BAD_PATH_ORDER = '''
@@ -188,12 +195,23 @@ class OSXBootstrapper(BaseBootstrapper):
     def install_browser_packages(self):
         getattr(self, 'ensure_%s_browser_packages' % self.package_manager)()
 
+    def install_browser_artifact_mode_packages(self):
+        getattr(self, 'ensure_%s_browser_packages' % self.package_manager)(artifact_mode=True)
+
     def install_mobile_android_packages(self):
         getattr(self, 'ensure_%s_mobile_android_packages' % self.package_manager)()
 
+    def install_mobile_android_artifact_mode_packages(self):
+        getattr(self, 'ensure_%s_mobile_android_packages' %
+                self.package_manager)(artifact_mode=True)
+
     def suggest_mobile_android_mozconfig(self):
         getattr(self, 'suggest_%s_mobile_android_mozconfig' % self.package_manager)()
 
+    def suggest_mobile_android_artifact_mode_mozconfig(self):
+        getattr(self, 'suggest_%s_mobile_android_mozconfig' %
+                self.package_manager)(artifact_mode=True)
+
     def ensure_xcode(self):
         if self.os_version < StrictVersion('10.7'):
             if not os.path.exists('/Developer/Applications/Xcode.app'):
@@ -271,17 +289,23 @@ class OSXBootstrapper(BaseBootstrapper):
         print('Once the install has finished, please relaunch this script.')
         sys.exit(1)
 
-    def _ensure_homebrew_packages(self, packages, extra_brew_args=[]):
-        self.brew = self.which('brew')
+    def _ensure_homebrew_found(self):
+        if not hasattr(self, 'brew'):
+            self.brew = self.which('brew')
+        # Earlier code that checks for valid package managers ensures
+        # which('brew') is found.
         assert self.brew is not None
+
+    def _ensure_homebrew_packages(self, packages, extra_brew_args=[]):
+        self._ensure_homebrew_found()
         cmd = [self.brew] + extra_brew_args
 
         installed = self.check_output(cmd + ['list']).split()
 
         printed = False
 
-        for name, package in packages:
-            if name in installed:
+        for package in packages:
+            if package in installed:
                 continue
 
             if not printed:
@@ -293,86 +317,73 @@ class OSXBootstrapper(BaseBootstrapper):
         return printed
 
     def _ensure_homebrew_casks(self, casks):
+        self._ensure_homebrew_found()
+
+        # Ensure that we can access old versions of packages.  This is
+        # idempotent, so no need to avoid repeat invocation.
+        self.check_output([self.brew, 'tap', 'caskroom/versions'])
+
         # Change |brew install cask| into |brew cask install cask|.
         return self._ensure_homebrew_packages(casks, extra_brew_args=['cask'])
 
     def ensure_homebrew_system_packages(self):
+        # We need to install Python because Mercurial requires the
+        # Python development headers which are missing from OS X (at
+        # least on 10.8) and because the build system wants a version
+        # newer than what Apple ships.
         packages = [
-            # We need to install Python because Mercurial requires the Python
-            # development headers which are missing from OS X (at least on
-            # 10.8) and because the build system wants a version newer than
-            # what Apple ships.
-            ('python', 'python'),
-            ('mercurial', 'mercurial'),
-            ('git', 'git'),
-            ('autoconf213', HOMEBREW_AUTOCONF213),
-            ('gnu-tar', 'gnu-tar'),
-            ('watchman', 'watchman',)
+            'autoconf@2.13',
+            'git',
+            'gnu-tar',
+            'llvm',
+            'mercurial',
+            'node',
+            'python',
+            'python3',
+            'terminal-notifier',
+            'watchman',
         ]
         self._ensure_homebrew_packages(packages)
 
-    def ensure_homebrew_browser_packages(self):
+    def ensure_homebrew_browser_packages(self, artifact_mode=False):
+        # TODO: Figure out what not to install for artifact mode
         packages = [
-            ('yasm', 'yasm'),
+            'yasm',
         ]
         self._ensure_homebrew_packages(packages)
 
-        installed = self.check_output([self.brew, 'list']).split()
-        if self.os_version < StrictVersion('10.7') and b'llvm' not in installed:
-            print(PACKAGE_MANAGER_OLD_CLANG % ('Homebrew',))
-
-            subprocess.check_call([self.brew, '-v', 'install', 'llvm',
-                                   '--with-clang', '--all-targets'])
-
-    def ensure_homebrew_mobile_android_packages(self):
+    def ensure_homebrew_mobile_android_packages(self, artifact_mode=False):
         # Multi-part process:
         # 1. System packages.
-        # 2. Android SDK and NDK.
-        # 3. Android packages.
-
-        import android
+        # 2. Android SDK. Android NDK only if we are not in artifact mode. Android packages.
 
         # 1. System packages.
         packages = [
-            ('ant', 'ant'),
-            ('brew-cask', 'caskroom/cask/brew-cask'),  # For installing Java later.
-            ('wget', 'wget'),
+            'wget',
         ]
         self._ensure_homebrew_packages(packages)
 
         casks = [
-            ('java', 'java'),
+            'java8',
         ]
         installed = self._ensure_homebrew_casks(casks)
         if installed:
             print(JAVA_LICENSE_NOTICE)  # We accepted a license agreement for the user.
 
-        # 2. The user may have an external Android SDK (in which case we save
-        # them a lengthy download), or they may have already completed the
-        # download. We unpack to ~/.mozbuild/{android-sdk-linux, android-ndk-r10e}.
-        mozbuild_path = os.environ.get('MOZBUILD_STATE_PATH', os.path.expanduser(os.path.join('~', '.mozbuild')))
-        self.sdk_path = os.environ.get('ANDROID_SDK_HOME', os.path.join(mozbuild_path, 'android-sdk-macosx'))
-        self.ndk_path = os.environ.get('ANDROID_NDK_HOME', os.path.join(mozbuild_path, 'android-ndk-r10e'))
-        self.sdk_url = 'https://dl.google.com/android/android-sdk_r24.0.1-macosx.zip'
         is_64bits = sys.maxsize > 2**32
-        if is_64bits:
-            self.ndk_url = android.android_ndk_url('darwin')
-        else:
+        if not is_64bits:
             raise Exception('You need a 64-bit version of Mac OS X to build IceCat for Android.')
 
-        android.ensure_android_sdk_and_ndk(path=mozbuild_path,
-                                           sdk_path=self.sdk_path, sdk_url=self.sdk_url,
-                                           ndk_path=self.ndk_path, ndk_url=self.ndk_url)
+        # 2. Android pieces.
+        from mozboot import android
+        android.ensure_android('macosx', artifact_mode=artifact_mode,
+                               no_interactive=self.no_interactive)
 
-        # 3. We expect the |android| tool to at
-        # ~/.mozbuild/android-sdk-macosx/tools/android.
-        android_tool = os.path.join(self.sdk_path, 'tools', 'android')
-        android.ensure_android_packages(android_tool=android_tool)
-
-    def suggest_homebrew_mobile_android_mozconfig(self):
-        import android
-        android.suggest_mozconfig(sdk_path=self.sdk_path,
-                                  ndk_path=self.ndk_path)
+    def suggest_homebrew_mobile_android_mozconfig(self, artifact_mode=False):
+        from mozboot import android
+        # Path to java and javac from the caskroom/versions/java8 cask.
+        android.suggest_mozconfig('macosx', artifact_mode=artifact_mode,
+                                  java_bin_path='/Library/Java/Home/bin')
 
     def _ensure_macports_packages(self, packages):
         self.port = self.which('port')
@@ -388,35 +399,57 @@ class OSXBootstrapper(BaseBootstrapper):
     def ensure_macports_system_packages(self):
         packages = [
             'python27',
+            'python36',
+            'py27-gnureadline',
             'mercurial',
             'autoconf213',
             'gnutar',
             'watchman',
+            'nodejs8'
         ]
 
         self._ensure_macports_packages(packages)
         self.run_as_root([self.port, 'select', '--set', 'python', 'python27'])
 
-    def ensure_macports_browser_packages(self):
-        packages = ['yasm']
+    def ensure_macports_browser_packages(self, artifact_mode=False):
+        # TODO: Figure out what not to install for artifact mode
+        packages = [
+            'yasm',
+            'llvm-4.0',
+            'clang-4.0',
+        ]
 
         self._ensure_macports_packages(packages)
 
-        installed = set(self.check_output([self.port, 'installed']).split())
-        if self.os_version < StrictVersion('10.7') and MACPORTS_CLANG_PACKAGE not in installed:
-            print(PACKAGE_MANAGER_OLD_CLANG % ('MacPorts',))
-            self.run_as_root([self.port, '-v', 'install', MACPORTS_CLANG_PACKAGE])
-            self.run_as_root([self.port, 'select', '--set', 'clang', 'mp-' + MACPORTS_CLANG_PACKAGE])
+    def ensure_macports_mobile_android_packages(self, artifact_mode=False):
+        # Multi-part process:
+        # 1. System packages.
+        # 2. Android SDK. Android NDK only if we are not in artifact mode. Android packages.
 
-    def ensure_macports_mobile_android_packages(self):
-        raise NotImplementedError("We don't yet support bootstrapping IceCat for Android with Macports. " +
-                                  "We don't know of a package that installs the Java 7 JDK. " +
-                                  "See https://bugzilla.mozilla.org/show_bug.cgi?id=1114382.")
+        # 1. System packages.
+        packages = [
+            'wget',
+        ]
+        self._ensure_macports_packages(packages)
 
-    def suggest_macports_mobile_android_mozconfig(self):
-        raise NotImplementedError("We don't yet support bootstrapping IceCat for Android with Macports. " +
-                                  "We don't know of a package that installs the Java 7 JDK." +
-                                  "See https://bugzilla.mozilla.org/show_bug.cgi?id=1114382.")
+        # Verify the presence of java and javac.
+        if not self.which('java') or not self.which('javac'):
+            raise Exception('You need to have Java version 1.7 or later installed. '
+                            'Please visit http://www.java.com/en/download/mac_download.jsp '
+                            'to get the latest version.')
+
+        is_64bits = sys.maxsize > 2**32
+        if not is_64bits:
+            raise Exception('You need a 64-bit version of Mac OS X to build IceCat for Android.')
+
+        # 2. Android pieces.
+        from mozboot import android
+        android.ensure_android('macosx', artifact_mode=artifact_mode,
+                               no_interactive=self.no_interactive)
+
+    def suggest_macports_mobile_android_mozconfig(self, artifact_mode=False):
+        from mozboot import android
+        android.suggest_mozconfig('macosx', artifact_mode=artifact_mode)
 
     def ensure_package_manager(self):
         '''
@@ -469,6 +502,10 @@ class OSXBootstrapper(BaseBootstrapper):
 
         return active_name.lower()
 
+    def ensure_stylo_packages(self, state_dir, checkout_root):
+        # We installed these via homebrew earlier.
+        pass
+
     def install_homebrew(self):
         print(PACKAGE_MANAGER_INSTALL % ('Homebrew', 'Homebrew', 'Homebrew', 'brew'))
         bootstrap = urlopen(url=HOMEBREW_BOOTSTRAP, timeout=20).read()
