@@ -1,4 +1,4 @@
-# -*- Mode: python; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 40 -*-
+# -*- Mode: python; indent-tabs-mode: nil; tab-width: 40 -*-
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -8,9 +8,9 @@ Script to generate the browsersearch.json file for IceCatMobile.
 
 This script follows these steps:
 
-1. Read the region.properties file in all the given source directories (see
-srcdir option). Merge all properties into a single dict accounting for the
-priority of source directories.
+1. Read all the given region.properties files (see inputs and --fallback
+options). Merge all properties into a single dict accounting for the priority
+of inputs.
 
 2. Read the default search plugin from 'browser.search.defaultenginename'.
 
@@ -38,6 +38,7 @@ from __future__ import (
 
 import argparse
 import codecs
+import errno
 import json
 import sys
 import os
@@ -51,39 +52,52 @@ from mozbuild.util import (
 import mozpack.path as mozpath
 
 
-def merge_properties(filename, srcdirs):
-    """Merges properties from the given file in the given source directories."""
+def merge_properties(paths):
+    """Merges properties from the given paths."""
     properties = DotProperties()
-    for srcdir in srcdirs:
-        path = mozpath.join(srcdir, filename)
+    for path in paths:
         try:
             properties.update(path)
-        except IOError:
-            # Ignore non-existing files
-            continue
+        except IOError as e:
+            if e.errno != errno.ENOENT:
+                raise e
     return properties
 
 
-def main(args):
+def main(output, *args, **kwargs):
     parser = argparse.ArgumentParser()
     parser.add_argument('--verbose', '-v', default=False, action='store_true',
                         help='be verbose')
     parser.add_argument('--silent', '-s', default=False, action='store_true',
                         help='be silent')
-    parser.add_argument('--srcdir', metavar='SRCDIR',
-                        action='append', required=True,
-                        help='directories to read inputs from, in order of priority')
-    parser.add_argument('output', metavar='OUTPUT',
-                        help='output')
+    parser.add_argument('inputs', metavar='INPUT', nargs='*',
+                        help='inputs, in order of priority')
+    # This awkward "extra input" is an expedient work-around for an issue with
+    # the build system.  It allows to specify the in-tree unlocalized version
+    # of a resource where a regular input will always be the localized version.
+    parser.add_argument('--fallback',
+                        required=True,
+                        help='fallback input')
     opts = parser.parse_args(args)
 
-    # Use reversed order so that the first srcdir has higher priority to override keys.
-    properties = merge_properties('region.properties', reversed(opts.srcdir))
+    # Ensure the fallback is valid.
+    if not os.path.isfile(opts.fallback):
+        print('Fallback path {fallback} is not a file!'.format(fallback=opts.fallback))
+        return 1
+
+    # Use reversed order so that the first input has higher priority to override keys.
+    sources = [opts.fallback] + list(reversed(opts.inputs))
+    properties = merge_properties(sources)
 
     # Default, not region-specific.
     default = properties.get('browser.search.defaultenginename')
     engines = properties.get_list('browser.search.order')
 
+    # We must define at least one engine -- that's what the fallback is for.
+    if not engines:
+        print('No engines defined: searched in {}!'.format(sources))
+        return 1
+
     writer = codecs.getwriter('utf-8')(sys.stdout)
     if opts.verbose:
         print('Read {len} engines: {engines}'.format(len=len(engines), engines=engines), file=writer)
@@ -112,20 +126,13 @@ def main(args):
             'engines': region_engines,
         }
 
-    # FileAvoidWrite creates its parent directories.
-    output = os.path.abspath(opts.output)
-    fh = FileAvoidWrite(output)
-    json.dump(browsersearch, fh)
-    existed, updated = fh.close()
+    json.dump(browsersearch, output)
+    existed, updated = output.close()  # It's safe to close a FileAvoidWrite multiple times.
 
     if not opts.silent:
         if updated:
-            print('{output} updated'.format(output=output))
+            print('{output} updated'.format(output=os.path.abspath(output.name)))
         else:
-            print('{output} already up-to-date'.format(output=output))
+            print('{output} already up-to-date'.format(output=os.path.abspath(output.name)))
 
-    return 0
-
-
-if __name__ == '__main__':
-    sys.exit(main(sys.argv[1:]))
+    return set([opts.fallback])
