@@ -2,16 +2,21 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-import random
+from __future__ import absolute_import
+
 import errno
-import types
+import random
 import os
+import shutil
+import subprocess
+import types
 import xml.etree.ElementTree as ET
 from .common import CommonBackend
 
 from ..frontend.data import (
     Defines,
 )
+from mozbuild.base import ExecutionSummary
 
 # TODO Have ./mach eclipse generate the workspace and index it:
 # /Users/bgirard/mozilla/eclipse/eclipse/eclipse/eclipse -application org.eclipse.cdt.managedbuilder.core.headlessbuild -data $PWD/workspace -importAll $PWD/eclipse
@@ -22,42 +27,60 @@ class CppEclipseBackend(CommonBackend):
     """Backend that generates Cpp Eclipse project files.
     """
 
+    def __init__(self, environment):
+        if os.name == 'nt':
+            raise Exception('Eclipse is not supported on Windows. '
+                            'Consider using Visual Studio instead.')
+        super(CppEclipseBackend, self).__init__(environment)
+
     def _init(self):
         CommonBackend._init(self)
 
         self._paths_to_defines = {}
-        self._workspace_dir = os.path.join(self.environment.topobjdir, 'eclipse_workspace')
-        self._project_dir = os.path.join(self._workspace_dir, 'gecko')
+        self._project_name = 'Gecko'
+        self._workspace_dir = self._get_workspace_path()
+        self._project_dir = os.path.join(self._workspace_dir, self._project_name)
+        self._overwriting_workspace = os.path.isdir(self._workspace_dir)
 
         self._macbundle = self.environment.substs['MOZ_MACBUNDLE_NAME']
         self._appname = self.environment.substs['MOZ_APP_NAME']
         self._bin_suffix = self.environment.substs['BIN_SUFFIX']
         self._cxx = self.environment.substs['CXX']
         # Note: We need the C Pre Processor (CPP) flags, not the CXX flags
-        self._cppflags = self.environment.substs['CPPFLAGS']
+        self._cppflags = self.environment.substs.get('CPPFLAGS', '')
 
-        def detailed(summary):
-            return ('\n' + \
-                   'Generated Cpp Eclipse workspace in "%s".\n' + \
-                   'OPTIONAL: Setup & index the project using: eclipse -application org.eclipse.cdt.managedbuilder.core.headlessbuild -data %s -importAll %s\n' + \
-                   'NOTE: This will take about 10 minutes.\n\n' \
-                   'Run with: eclipse -data %s\n' \
-                   'Import the project using File > Import > General > Existing Project into workspace') \
-                   % (self._workspace_dir, self._workspace_dir, self._project_dir, self._workspace_dir)
+    def summary(self):
+        return ExecutionSummary(
+            'CppEclipse backend executed in {execution_time:.2f}s\n'
+            'Generated Cpp Eclipse workspace in "{workspace:s}".\n'
+            'If missing, import the project using File > Import > General > Existing Project into workspace\n'
+            '\n'
+            'Run with: eclipse -data {workspace:s}\n',
+            execution_time=self._execution_time,
+            workspace=self._workspace_dir)
 
-        self.summary.backend_detailed_summary = types.MethodType(detailed,
-            self.summary)
+    def _get_workspace_path(self):
+        return CppEclipseBackend.get_workspace_path(self.environment.topsrcdir, self.environment.topobjdir)
+
+    @staticmethod
+    def get_workspace_path(topsrcdir, topobjdir):
+        # Eclipse doesn't support having the workspace inside the srcdir.
+        # Since most people have their objdir inside their srcdir it's easier
+        # and more consistent to just put the workspace along side the srcdir
+        srcdir_parent = os.path.dirname(topsrcdir)
+        workspace_dirname = "eclipse_" + os.path.basename(topobjdir)
+        return os.path.join(srcdir_parent, workspace_dirname)
 
     def consume_object(self, obj):
-        obj.ack()
-
-        reldir = getattr(obj, 'relativedir', None)
+        reldir = getattr(obj, 'relsrcdir', None)
 
         # Note that unlike VS, Eclipse' indexer seem to crawl the headers and
         # isn't picky about the local includes.
         if isinstance(obj, Defines):
             self._paths_to_defines.setdefault(reldir, {}).update(obj.defines)
 
+        return True
+
     def consume_finished(self):
         settings_dir = os.path.join(self._project_dir, '.settings')
         launch_dir = os.path.join(self._project_dir, 'RunConfigurations')
@@ -91,16 +114,91 @@ class CppEclipseBackend(CommonBackend):
 
         self._write_launch_files(launch_dir)
 
-        # This will show up as an 'unmanged' formatter. This can be named by generating
-        # another file.
-        formatter_prefs_path = os.path.join(settings_dir, 'org.eclipse.cdt.core.prefs')
-        with open(formatter_prefs_path, 'wb') as fh:
-            fh.write(FORMATTER_SETTINGS);
+        core_resources_prefs_path = os.path.join(workspace_settings_dir, 'org.eclipse.core.resources.prefs')
+        with open(core_resources_prefs_path, 'wb') as fh:
+            fh.write(STATIC_CORE_RESOURCES_PREFS);
+
+        core_runtime_prefs_path = os.path.join(workspace_settings_dir, 'org.eclipse.core.runtime.prefs')
+        with open(core_runtime_prefs_path, 'wb') as fh:
+            fh.write(STATIC_CORE_RUNTIME_PREFS);
+
+        ui_prefs_path = os.path.join(workspace_settings_dir, 'org.eclipse.ui.prefs')
+        with open(ui_prefs_path, 'wb') as fh:
+            fh.write(STATIC_UI_PREFS);
+
+        cdt_ui_prefs_path = os.path.join(workspace_settings_dir, 'org.eclipse.cdt.ui.prefs')
+        cdt_ui_prefs = STATIC_CDT_UI_PREFS
+        # Here we generate the code formatter that will show up in the UI with
+        # the name "Mozilla".  The formatter is stored as a single line of XML
+        # in the org.eclipse.cdt.ui.formatterprofiles pref.
+        cdt_ui_prefs += """org.eclipse.cdt.ui.formatterprofiles=<?xml version\="1.0" encoding\="UTF-8" standalone\="no"?>\\n<profiles version\="1">\\n<profile kind\="CodeFormatterProfile" name\="Mozilla" version\="1">\\n"""
+        XML_PREF_TEMPLATE = """<setting id\="@PREF_NAME@" value\="@PREF_VAL@"/>\\n"""
+        for line in FORMATTER_SETTINGS.splitlines():
+            [pref, val] = line.split("=")
+            cdt_ui_prefs += XML_PREF_TEMPLATE.replace("@PREF_NAME@", pref).replace("@PREF_VAL@", val)
+        cdt_ui_prefs += "</profile>\\n</profiles>\\n"
+        with open(cdt_ui_prefs_path, 'wb') as fh:
+            fh.write(cdt_ui_prefs);
+
+        cdt_core_prefs_path = os.path.join(workspace_settings_dir, 'org.eclipse.cdt.core.prefs')
+        with open(cdt_core_prefs_path, 'wb') as fh:
+            cdt_core_prefs = STATIC_CDT_CORE_PREFS
+            # When we generated the code formatter called "Mozilla" above, we
+            # also set it to be the active formatter.  When a formatter is set
+            # as the active formatter all its prefs are set in this prefs file,
+            # so we need add those now:
+            cdt_core_prefs += FORMATTER_SETTINGS
+            fh.write(cdt_core_prefs);
 
         editor_prefs_path = os.path.join(workspace_settings_dir, "org.eclipse.ui.editors.prefs");
         with open(editor_prefs_path, 'wb') as fh:
             fh.write(EDITOR_SETTINGS);
 
+        # Now import the project into the workspace
+        self._import_project()
+
+    def _import_project(self):
+        # If the workspace already exists then don't import the project again because
+        # eclipse doesn't handle this properly
+        if self._overwriting_workspace:
+            return
+
+        # We disable the indexer otherwise we're forced to index
+        # the whole codebase when importing the project. Indexing the project can take 20 minutes.
+        self._write_noindex()
+
+        try:
+            process = subprocess.check_call(
+                             ["eclipse", "-application", "-nosplash",
+                              "org.eclipse.cdt.managedbuilder.core.headlessbuild",
+                              "-data", self._workspace_dir, "-importAll", self._project_dir])
+        except OSError as e:
+            # Remove the workspace directory so we re-generate it and
+            # try to import again when the backend is invoked again.
+            shutil.rmtree(self._workspace_dir)
+
+            if e.errno == errno.ENOENT:
+                raise Exception("Failed to launch eclipse to import project. "
+                                "Ensure 'eclipse' is in your PATH and try again")
+            else:
+                raise
+        finally:
+            self._remove_noindex()
+
+    def _write_noindex(self):
+        noindex_path = os.path.join(self._project_dir, '.settings/org.eclipse.cdt.core.prefs')
+        with open(noindex_path, 'wb') as fh:
+            fh.write(NOINDEX_TEMPLATE);
+
+    def _remove_noindex(self):
+        noindex_path = os.path.join(self._project_dir, '.settings/org.eclipse.cdt.core.prefs')
+        # This may fail if the entire tree has been removed; that's fine.
+        try:
+            os.remove(noindex_path)
+        except OSError as e:
+            if e.errno != errno.ENOENT:
+                raise
+
     def _define_entry(self, name, value):
         define = ET.Element('entry')
         define.set('kind', 'macro')
@@ -116,7 +214,6 @@ class CppEclipseBackend(CommonBackend):
         settings = settings.replace('@IPDL_INCLUDE_PATH@', os.path.join(self.environment.topobjdir, 'ipc/ipdl/_ipdlheaders'))
         settings = settings.replace('@PREINCLUDE_FILE_PATH@', os.path.join(self.environment.topobjdir, 'dist/include/mozilla-config.h'))
         settings = settings.replace('@DEFINE_MOZILLA_INTERNAL_API@', self._define_entry('MOZILLA_INTERNAL_API', '1'))
-        settings = settings.replace('@DEFINE_MDCPUCFG@', self._define_entry('MDCPUCFG', self.environment.substs['TARGET_NSPR_MDCPUCFG']))
         settings = settings.replace("@COMPILER_FLAGS@", self._cxx + " " + self._cppflags);
 
         fh.write(settings)
@@ -132,33 +229,22 @@ class CppEclipseBackend(CommonBackend):
 
         exe_path = os.path.join(exe_path, self._appname + self._bin_suffix)
 
-        if self.environment.substs['MOZ_WIDGET_TOOLKIT'] != 'gonk':
-            main_gecko_launch = os.path.join(launch_dir, 'gecko.launch')
-            with open(main_gecko_launch, 'wb') as fh:
-                launch = GECKO_LAUNCH_CONFIG_TEMPLATE
-                launch = launch.replace('@LAUNCH_PROGRAM@', exe_path)
-                launch = launch.replace('@LAUNCH_ARGS@', '-P -no-remote')
-                fh.write(launch)
-
-        if self.environment.substs['MOZ_WIDGET_TOOLKIT'] == 'gonk':
-            b2g_flash = os.path.join(launch_dir, 'b2g-flash.launch')
-            with open(b2g_flash, 'wb') as fh:
-                # We assume that the srcdir is inside the b2g tree.
-                # If that's not the case the user can always adjust the path
-                # from the eclipse IDE.
-                fastxul_path = os.path.join(self.environment.topsrcdir, '..', 'scripts', 'fastxul.sh')
-                launch = B2GFLASH_LAUNCH_CONFIG_TEMPLATE
-                launch = launch.replace('@LAUNCH_PROGRAM@', fastxul_path)
-                launch = launch.replace('@OBJDIR@', self.environment.topobjdir)
-                fh.write(launch)
+        main_gecko_launch = os.path.join(launch_dir, 'gecko.launch')
+        with open(main_gecko_launch, 'wb') as fh:
+            launch = GECKO_LAUNCH_CONFIG_TEMPLATE
+            launch = launch.replace('@LAUNCH_PROGRAM@', exe_path)
+            launch = launch.replace('@LAUNCH_ARGS@', '-P -no-remote')
+            fh.write(launch)
 
         #TODO Add more launch configs (and delegate calls to mach)
 
     def _write_project(self, fh):
         project = PROJECT_TEMPLATE;
 
-        project = project.replace('@PROJECT_NAME@', 'Gecko')
+        project = project.replace('@PROJECT_NAME@', self._project_name)
         project = project.replace('@PROJECT_TOPSRCDIR@', self.environment.topsrcdir)
+        project = project.replace('@GENERATED_IPDL_FILES@', os.path.join(self.environment.topobjdir, "ipc", "ipdl"))
+        project = project.replace('@GENERATED_WEBIDL_FILES@', os.path.join(self.environment.topobjdir, "dom", "bindings"))
         fh.write(project)
 
     def _write_cproject(self, fh):
@@ -215,6 +301,16 @@ PROJECT_TEMPLATE = """<?xml version="1.0" encoding="UTF-8"?>
                         <type>2</type>
                         <location>@PROJECT_TOPSRCDIR@</location>
                 </link>
+                <link>
+                        <name>generated-ipdl</name>
+                        <type>2</type>
+                        <location>@GENERATED_IPDL_FILES@</location>
+                </link>
+                <link>
+                        <name>generated-webidl</name>
+                        <type>2</type>
+                        <location>@GENERATED_WEBIDL_FILES@</location>
+                </link>
         </linkedResources>
         <filteredResources>
                 <filter>
@@ -287,7 +383,7 @@ CPROJECT_TEMPLATE_HEADER = """<?xml version="1.0" encoding="UTF-8" standalone="n
                                 <configuration artifactName="${ProjName}" buildProperties="" description="" id="0.1674256904" name="Default" parent="org.eclipse.cdt.build.core.prefbase.cfg">
                                         <folderInfo id="0.1674256904." name="/" resourcePath="">
                                                 <toolChain id="cdt.managedbuild.toolchain.gnu.cross.exe.debug.1276586933" name="Cross GCC" superClass="cdt.managedbuild.toolchain.gnu.cross.exe.debug">
-                                                        <targetPlatform archList="all" binaryParser="org.eclipse.cdt.core.ELF" id="cdt.managedbuild.targetPlatform.gnu.cross.710759961" isAbstract="false" osList="all" superClass="cdt.managedbuild.targetPlatform.gnu.cross"/>
+                                                        <targetPlatform archList="all" binaryParser="" id="cdt.managedbuild.targetPlatform.gnu.cross.710759961" isAbstract="false" osList="all" superClass="cdt.managedbuild.targetPlatform.gnu.cross"/>
 							<builder arguments="--log-no-times build" buildPath="@PROJECT_TOPSRCDIR@" command="@MACH_COMMAND@" enableCleanBuild="false" incrementalBuildTarget="binaries" id="org.eclipse.cdt.build.core.settings.default.builder.1437267827" keepEnvironmentInBuildfile="false" name="Gnu Make Builder" superClass="org.eclipse.cdt.build.core.settings.default.builder"/>
                                                 </toolChain>
                                         </folderInfo>
@@ -376,7 +472,6 @@ LANGUAGE_SETTINGS_TEMPLATE = """<?xml version="1.0" encoding="UTF-8" standalone=
                                                   MOZILLA_EXTERNAL_API code will suffer.
                                                 -->
                                                 @DEFINE_MOZILLA_INTERNAL_API@
-                                                @DEFINE_MDCPUCFG@
                                         </resource>
                                 </language>
                         </provider>
@@ -478,8 +573,25 @@ tabWidth=2
 undoHistorySize=200
 """
 
-FORMATTER_SETTINGS = """eclipse.preferences.version=1
-org.eclipse.cdt.core.formatter.alignment_for_arguments_in_method_invocation=16
+
+STATIC_CORE_RESOURCES_PREFS="""eclipse.preferences.version=1
+refresh.enabled=true
+"""
+
+STATIC_CORE_RUNTIME_PREFS="""eclipse.preferences.version=1
+content-types/org.eclipse.cdt.core.cxxSource/file-extensions=mm
+content-types/org.eclipse.core.runtime.xml/file-extensions=xul
+content-types/org.eclipse.wst.jsdt.core.jsSource/file-extensions=jsm
+"""
+
+STATIC_UI_PREFS="""eclipse.preferences.version=1
+showIntro=false
+"""
+
+STATIC_CDT_CORE_PREFS="""eclipse.preferences.version=1
+"""
+
+FORMATTER_SETTINGS = """org.eclipse.cdt.core.formatter.alignment_for_arguments_in_method_invocation=16
 org.eclipse.cdt.core.formatter.alignment_for_assignment=16
 org.eclipse.cdt.core.formatter.alignment_for_base_clause_in_type_declaration=80
 org.eclipse.cdt.core.formatter.alignment_for_binary_expression=16
@@ -642,3 +754,19 @@ org.eclipse.cdt.core.formatter.tabulation.char=space
 org.eclipse.cdt.core.formatter.tabulation.size=2
 org.eclipse.cdt.core.formatter.use_tabs_only_for_leading_indentations=false
 """
+
+STATIC_CDT_UI_PREFS="""eclipse.preferences.version=1
+buildConsoleLines=10000
+Console.limitConsoleOutput=false
+ensureNewlineAtEOF=false
+formatter_profile=_Mozilla
+formatter_settings_version=1
+org.eclipse.cdt.ui.formatterprofiles.version=1
+removeTrailingWhitespace=true
+removeTrailingWhitespaceEditedLines=true
+scalability.numberOfLines=15000
+"""
+
+NOINDEX_TEMPLATE = """eclipse.preferences.version=1
+indexer/indexerId=org.eclipse.cdt.core.nullIndexer
+"""
