@@ -287,24 +287,6 @@ class TestMozconfigLoader(unittest.TestCase):
             self.assertEqual(result['configure_args'], [
                 '--foo=%s' % loader.topsrcdir])
 
-    def test_read_ac_app_options(self):
-        with NamedTemporaryFile(mode='w') as mozconfig:
-            mozconfig.write('ac_add_options --foo=@TOPSRCDIR@\n')
-            mozconfig.write('ac_add_app_options app1 --bar=@TOPSRCDIR@\n')
-            mozconfig.write('ac_add_app_options app2 --bar=x\n')
-            mozconfig.flush()
-
-            loader = self.get_loader()
-            result = loader.read_mozconfig(mozconfig.name, moz_build_app='app1')
-            self.assertEqual(result['configure_args'], [
-                '--foo=%s' % loader.topsrcdir,
-                '--bar=%s' % loader.topsrcdir])
-
-            result = loader.read_mozconfig(mozconfig.name, moz_build_app='app2')
-            self.assertEqual(result['configure_args'], [
-                '--foo=%s' % loader.topsrcdir,
-                '--bar=x'])
-
     def test_read_capture_mk_options(self):
         """Ensures mk_add_options calls are captured."""
         with NamedTemporaryFile(mode='w') as mozconfig:
@@ -319,10 +301,6 @@ class TestMozconfigLoader(unittest.TestCase):
             self.assertEqual(result['make_flags'], ['-j8', '-s'])
             self.assertEqual(result['make_extra'], ['FOO=BAR BAZ', 'BIZ=1'])
 
-            vars = result['vars']['added']
-            for var in ('MOZ_OBJDIR', 'MOZ_MAKE_FLAGS', 'FOO', 'BIZ'):
-                self.assertEqual(vars.get('%s_IS_SET' % var), '1')
-
     def test_read_empty_mozconfig_objdir_environ(self):
         os.environ[b'MOZ_OBJDIR'] = b'obj-icecat'
         with NamedTemporaryFile(mode='w') as mozconfig:
@@ -379,22 +357,25 @@ class TestMozconfigLoader(unittest.TestCase):
 
     def test_read_modify_variables(self):
         """Variables modified by mozconfig are detected."""
-        os.environ[b'CC'] = b'/usr/bin/gcc'
+        old_path = os.path.realpath(b'/usr/bin/gcc')
+        new_path = os.path.realpath(b'/usr/local/bin/clang')
+        os.environ[b'CC'] = old_path
 
         with NamedTemporaryFile(mode='w') as mozconfig:
-            mozconfig.write('CC=/usr/local/bin/clang\n')
+            mozconfig.write('CC="%s"\n' % new_path)
             mozconfig.flush()
 
             result = self.get_loader().read_mozconfig(mozconfig.name)
 
             self.assertEqual(result['vars']['modified'], {})
             self.assertEqual(result['env']['modified'], {
-                'CC': ('/usr/bin/gcc', '/usr/local/bin/clang')
+                'CC': (old_path, new_path)
             })
 
     def test_read_unmodified_variables(self):
         """Variables modified by mozconfig are detected."""
-        os.environ[b'CC'] = b'/usr/bin/gcc'
+        cc_path = os.path.realpath(b'/usr/bin/gcc')
+        os.environ[b'CC'] = cc_path
 
         with NamedTemporaryFile(mode='w') as mozconfig:
             mozconfig.flush()
@@ -403,12 +384,13 @@ class TestMozconfigLoader(unittest.TestCase):
 
             self.assertEqual(result['vars']['unmodified'], {})
             self.assertEqual(result['env']['unmodified'], {
-                'CC': '/usr/bin/gcc'
+                'CC': cc_path
             })
 
     def test_read_removed_variables(self):
         """Variables unset by the mozconfig are detected."""
-        os.environ[b'CC'] = b'/usr/bin/clang'
+        cc_path = os.path.realpath(b'/usr/bin/clang')
+        os.environ[b'CC'] = cc_path
 
         with NamedTemporaryFile(mode='w') as mozconfig:
             mozconfig.write('unset CC\n')
@@ -418,7 +400,7 @@ class TestMozconfigLoader(unittest.TestCase):
 
             self.assertEqual(result['vars']['removed'], {})
             self.assertEqual(result['env']['removed'], {
-                'CC': '/usr/bin/clang'})
+                'CC': cc_path})
 
     def test_read_multiline_variables(self):
         """Ensure multi-line variables are captured properly."""
