@@ -34,14 +34,17 @@
 #include "seccomon.h"
 
 namespace mozilla {
-class NeckoOriginAttributes;
+class OriginAttributes;
 }
 
-namespace mozilla { namespace pkix {
+namespace mozilla {
+namespace pkix {
 struct CertID;
-} } // namespace mozilla::pkix
+}
+}  // namespace mozilla
 
-namespace mozilla { namespace psm {
+namespace mozilla {
+namespace psm {
 
 // make SHA384Buffer be of type "array of uint8_t of length SHA384_LENGTH"
 typedef uint8_t SHA384Buffer[SHA384_LENGTH];
@@ -52,9 +55,8 @@ typedef uint8_t SHA384Buffer[SHA384_LENGTH];
 // issuer public key, much like in an encoded OCSP response itself). A maximum
 // of 1024 distinct entries can be stored.
 // OCSPCache is thread-safe.
-class OCSPCache
-{
-public:
+class OCSPCache {
+ public:
   OCSPCache();
   ~OCSPCache();
 
@@ -66,7 +68,7 @@ public:
   // We currently only use the first party domain portion of the attributes, and
   // it is non-empty only when "privacy.firstParty.isolate" is enabled.
   bool Get(const mozilla::pkix::CertID& aCertID,
-           const NeckoOriginAttributes& aOriginAttributes,
+           const OriginAttributes& aOriginAttributes,
            /*out*/ mozilla::pkix::Result& aResult,
            /*out*/ mozilla::pkix::Time& aValidThrough);
 
@@ -83,7 +85,7 @@ public:
   // We currently only use the first party domain portion of the attributes, and
   // it is non-empty only when "privacy.firstParty.isolate" is enabled.
   mozilla::pkix::Result Put(const mozilla::pkix::CertID& aCertID,
-                            const NeckoOriginAttributes& aOriginAttributes,
+                            const OriginAttributes& aOriginAttributes,
                             mozilla::pkix::Result aResult,
                             mozilla::pkix::Time aThisUpdate,
                             mozilla::pkix::Time aValidThrough);
@@ -91,20 +93,16 @@ public:
   // Removes everything from the cache.
   void Clear();
 
-private:
-  class Entry
-  {
-  public:
-    Entry(mozilla::pkix::Result aResult,
-          mozilla::pkix::Time aThisUpdate,
+ private:
+  class Entry {
+   public:
+    Entry(mozilla::pkix::Result aResult, mozilla::pkix::Time aThisUpdate,
           mozilla::pkix::Time aValidThrough)
-      : mResult(aResult)
-      , mThisUpdate(aThisUpdate)
-      , mValidThrough(aValidThrough)
-    {
-    }
+        : mResult(aResult),
+          mThisUpdate(aThisUpdate),
+          mValidThrough(aValidThrough) {}
     mozilla::pkix::Result Init(const mozilla::pkix::CertID& aCertID,
-                               const NeckoOriginAttributes& aOriginAttributes);
+                               const OriginAttributes& aOriginAttributes);
 
     mozilla::pkix::Result mResult;
     mozilla::pkix::Time mThisUpdate;
@@ -118,9 +116,8 @@ private:
   };
 
   bool FindInternal(const mozilla::pkix::CertID& aCertID,
-                    const NeckoOriginAttributes& aOriginAttributes,
-                    /*out*/ size_t& index,
-                    const MutexAutoLock& aProofOfLock);
+                    const OriginAttributes& aOriginAttributes,
+                    /*out*/ size_t& index, const MutexAutoLock& aProofOfLock);
   void MakeMostRecentlyUsed(size_t aIndex, const MutexAutoLock& aProofOfLock);
 
   Mutex mMutex;
@@ -133,6 +130,7 @@ private:
   Vector<Entry*, 256> mEntries;
 };
 
-} } // namespace mozilla::psm
+}  // namespace psm
+}  // namespace mozilla
 
-#endif // mozilla_psm_OCSPCache_h
+#endif  // mozilla_psm_OCSPCache_h
