@@ -6,12 +6,12 @@
 
 #include "TransportSecurityInfo.h"
 
+#include "DateTimeFormat.h"
 #include "PSMRunnable.h"
 #include "mozilla/Casting.h"
 #include "nsComponentManagerUtils.h"
 #include "nsIArray.h"
 #include "nsICertOverrideService.h"
-#include "nsIDateTimeFormat.h"
 #include "nsIObjectInputStream.h"
 #include "nsIObjectOutputStream.h"
 #include "nsIWebProgressListener.h"
@@ -25,99 +25,53 @@
 #include "pkix/pkixtypes.h"
 #include "secerr.h"
 
-//#define DEBUG_SSL_VERBOSE //Enable this define to get minimal 
-                            //reports when doing SSL read/write
+//#define DEBUG_SSL_VERBOSE //Enable this define to get minimal
+// reports when doing SSL read/write
 
 //#define DUMP_BUFFER  //Enable this define along with
-                       //DEBUG_SSL_VERBOSE to dump SSL
-                       //read/write buffer to a log.
-                       //Uses PR_LOG except on Mac where
-                       //we always write out to our own
-                       //file.
+// DEBUG_SSL_VERBOSE to dump SSL
+// read/write buffer to a log.
+// Uses PR_LOG except on Mac where
+// we always write out to our own
+// file.
 
-namespace mozilla { namespace psm {
+namespace mozilla {
+namespace psm {
 
 TransportSecurityInfo::TransportSecurityInfo()
-  : mMutex("TransportSecurityInfo::mMutex"),
-    mSecurityState(nsIWebProgressListener::STATE_IS_INSECURE),
-    mSubRequestsBrokenSecurity(0),
-    mSubRequestsNoSecurity(0),
-    mErrorCode(0),
-    mErrorMessageType(PlainErrorMessage),
-    mPort(0)
-{
+    : mMutex("TransportSecurityInfo::mMutex"),
+      mSecurityState(nsIWebProgressListener::STATE_IS_INSECURE),
+      mSubRequestsBrokenSecurity(0),
+      mSubRequestsNoSecurity(0),
+      mErrorCode(0),
+      mErrorMessageType(SSLErrorMessageType::Plain),
+      mPort(0) {}
+
+NS_IMPL_ISUPPORTS(TransportSecurityInfo, nsITransportSecurityInfo,
+                  nsIInterfaceRequestor, nsISSLStatusProvider,
+                  nsIAssociatedContentSecurity, nsISerializable, nsIClassInfo)
+
+void TransportSecurityInfo::SetHostName(const char* host) {
+  mHostName.Assign(host);
 }
 
-TransportSecurityInfo::~TransportSecurityInfo()
-{
-  nsNSSShutDownPreventionLock locker;
-  if (isAlreadyShutDown())
-    return;
+void TransportSecurityInfo::SetPort(int32_t aPort) { mPort = aPort; }
 
-  shutdown(ShutdownCalledFrom::Object);
-}
-
-void
-TransportSecurityInfo::virtualDestroyNSSReference()
-{
-}
-
-NS_IMPL_ISUPPORTS(TransportSecurityInfo,
-                  nsITransportSecurityInfo,
-                  nsIInterfaceRequestor,
-                  nsISSLStatusProvider,
-                  nsIAssociatedContentSecurity,
-                  nsISerializable,
-                  nsIClassInfo)
-
-nsresult
-TransportSecurityInfo::SetHostName(const char* host)
-{
-  mHostName.Adopt(host ? NS_strdup(host) : 0);
-  return NS_OK;
-}
-
-nsresult
-TransportSecurityInfo::GetHostName(char **host)
-{
-  *host = (mHostName) ? NS_strdup(mHostName) : nullptr;
-  return NS_OK;
-}
-
-nsresult
-TransportSecurityInfo::SetPort(int32_t aPort)
-{
-  mPort = aPort;
-  return NS_OK;
-}
-
-nsresult
-TransportSecurityInfo::GetPort(int32_t *aPort)
-{
-  *aPort = mPort;
-  return NS_OK;
-}
-
-nsresult
-TransportSecurityInfo::SetOriginAttributes(
-  const NeckoOriginAttributes& aOriginAttributes)
-{
+void TransportSecurityInfo::SetOriginAttributes(
+    const OriginAttributes& aOriginAttributes) {
   mOriginAttributes = aOriginAttributes;
-  return NS_OK;
 }
 
-PRErrorCode
-TransportSecurityInfo::GetErrorCode() const
-{
+NS_IMETHODIMP
+TransportSecurityInfo::GetErrorCode(int32_t* state) {
   MutexAutoLock lock(mMutex);
 
-  return mErrorCode;
+  *state = mErrorCode;
+  return NS_OK;
 }
 
-void
-TransportSecurityInfo::SetCanceled(PRErrorCode errorCode,
-                                   SSLErrorMessageType errorMessageType)
-{
+void TransportSecurityInfo::SetCanceled(PRErrorCode errorCode,
+                                        SSLErrorMessageType errorMessageType) {
   MutexAutoLock lock(mMutex);
 
   mErrorCode = errorCode;
@@ -126,60 +80,48 @@ TransportSecurityInfo::SetCanceled(PRErrorCode errorCode,
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetSecurityState(uint32_t* state)
-{
+TransportSecurityInfo::GetSecurityState(uint32_t* state) {
   *state = mSecurityState;
   return NS_OK;
 }
 
-nsresult
-TransportSecurityInfo::SetSecurityState(uint32_t aState)
-{
+void TransportSecurityInfo::SetSecurityState(uint32_t aState) {
   mSecurityState = aState;
-  return NS_OK;
 }
 
 NS_IMETHODIMP
 TransportSecurityInfo::GetCountSubRequestsBrokenSecurity(
-  int32_t *aSubRequestsBrokenSecurity)
-{
+    int32_t* aSubRequestsBrokenSecurity) {
   *aSubRequestsBrokenSecurity = mSubRequestsBrokenSecurity;
   return NS_OK;
 }
 
 NS_IMETHODIMP
 TransportSecurityInfo::SetCountSubRequestsBrokenSecurity(
-  int32_t aSubRequestsBrokenSecurity)
-{
+    int32_t aSubRequestsBrokenSecurity) {
   mSubRequestsBrokenSecurity = aSubRequestsBrokenSecurity;
   return NS_OK;
 }
 
 NS_IMETHODIMP
 TransportSecurityInfo::GetCountSubRequestsNoSecurity(
-  int32_t *aSubRequestsNoSecurity)
-{
+    int32_t* aSubRequestsNoSecurity) {
   *aSubRequestsNoSecurity = mSubRequestsNoSecurity;
   return NS_OK;
 }
 
 NS_IMETHODIMP
 TransportSecurityInfo::SetCountSubRequestsNoSecurity(
-  int32_t aSubRequestsNoSecurity)
-{
+    int32_t aSubRequestsNoSecurity) {
   mSubRequestsNoSecurity = aSubRequestsNoSecurity;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::Flush()
-{
-  return NS_OK;
-}
+TransportSecurityInfo::Flush() { return NS_OK; }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetErrorMessage(char16_t** aText)
-{
+TransportSecurityInfo::GetErrorMessage(char16_t** aText) {
   NS_ENSURE_ARG_POINTER(aText);
   *aText = nullptr;
 
@@ -191,9 +133,8 @@ TransportSecurityInfo::GetErrorMessage(char16_t** aText)
   MutexAutoLock lock(mMutex);
 
   if (mErrorMessageCached.IsEmpty()) {
-    nsresult rv = formatErrorMessage(lock, 
-                                     mErrorCode, mErrorMessageType,
-                                     true, true, mErrorMessageCached);
+    nsresult rv = formatErrorMessage(lock, mErrorCode, mErrorMessageType, true,
+                                     true, mErrorMessageCached);
     NS_ENSURE_SUCCESS(rv, rv);
   }
 
@@ -201,44 +142,34 @@ TransportSecurityInfo::GetErrorMessage(char16_t** aText)
   return *aText ? NS_OK : NS_ERROR_OUT_OF_MEMORY;
 }
 
-void
-TransportSecurityInfo::GetErrorLogMessage(PRErrorCode errorCode,
-                                          SSLErrorMessageType errorMessageType,
-                                          nsString &result)
-{
+void TransportSecurityInfo::GetErrorLogMessage(
+    PRErrorCode errorCode, SSLErrorMessageType errorMessageType,
+    nsString& result) {
   if (!NS_IsMainThread()) {
     NS_ERROR("nsNSSSocketInfo::GetErrorLogMessage called off the main thread");
     return;
   }
 
   MutexAutoLock lock(mMutex);
-  (void) formatErrorMessage(lock, errorCode, errorMessageType,
-                            false, false, result);
+  (void)formatErrorMessage(lock, errorCode, errorMessageType, false, false,
+                           result);
 }
 
-static nsresult
-formatPlainErrorMessage(nsXPIDLCString const & host, int32_t port,
-                        PRErrorCode err, 
-                        bool suppressPort443,
-                        nsString &returnedMessage);
+static nsresult formatPlainErrorMessage(const nsCString& host, int32_t port,
+                                        PRErrorCode err, bool suppressPort443,
+                                        /*out*/ nsString& returnedMessage);
 
-static nsresult
-formatOverridableCertErrorMessage(nsISSLStatus & sslStatus,
-                                  PRErrorCode errorCodeToReport, 
-                                  const nsXPIDLCString & host, int32_t port,
-                                  bool suppressPort443,
-                                  bool wantsHtml,
-                                  nsString & returnedMessage);
+static nsresult formatOverridableCertErrorMessage(
+    nsISSLStatus& sslStatus, PRErrorCode errorCodeToReport,
+    const nsCString& host, int32_t port, bool suppressPort443, bool wantsHtml,
+    /*out*/ nsString& returnedMessage);
 
 // XXX: uses nsNSSComponent string bundles off the main thread when called by
 //      nsNSSSocketInfo::Write().
-nsresult
-TransportSecurityInfo::formatErrorMessage(MutexAutoLock const & proofOfLock, 
-                                          PRErrorCode errorCode,
-                                          SSLErrorMessageType errorMessageType,
-                                          bool wantsHtml, bool suppressPort443, 
-                                          nsString &result)
-{
+nsresult TransportSecurityInfo::formatErrorMessage(
+    const MutexAutoLock& /*proofOfLock*/, PRErrorCode errorCode,
+    SSLErrorMessageType errorMessageType, bool wantsHtml, bool suppressPort443,
+    /*out*/ nsString& result) {
   result.Truncate();
   if (errorCode == 0) {
     return NS_OK;
@@ -249,22 +180,17 @@ TransportSecurityInfo::formatErrorMessage(MutexAutoLock const & proofOfLock,
   }
 
   nsresult rv;
-  NS_ConvertASCIItoUTF16 hostNameU(mHostName);
-  NS_ASSERTION(errorMessageType != OverridableCertErrorMessage || 
-                (mSSLStatus && mSSLStatus->HasServerCert() &&
-                 mSSLStatus->mHaveCertErrorBits),
-                "GetErrorLogMessage called for cert error without cert");
-  if (errorMessageType == OverridableCertErrorMessage && 
-      mSSLStatus && mSSLStatus->HasServerCert()) {
-    rv = formatOverridableCertErrorMessage(*mSSLStatus, errorCode,
-                                           mHostName, mPort,
-                                           suppressPort443,
-                                           wantsHtml,
+  MOZ_ASSERT(errorMessageType != SSLErrorMessageType::OverridableCert ||
+                 (mSSLStatus && mSSLStatus->HasServerCert() &&
+                  mSSLStatus->mHaveCertErrorBits),
+             "formatErrorMessage() called for cert error without cert");
+  if (errorMessageType == SSLErrorMessageType::OverridableCert && mSSLStatus &&
+      mSSLStatus->HasServerCert()) {
+    rv = formatOverridableCertErrorMessage(*mSSLStatus, errorCode, mHostName,
+                                           mPort, suppressPort443, wantsHtml,
                                            result);
   } else {
-    rv = formatPlainErrorMessage(mHostName, mPort, 
-                                 errorCode,
-                                 suppressPort443,
+    rv = formatPlainErrorMessage(mHostName, mPort, errorCode, suppressPort443,
                                  result);
   }
 
@@ -276,15 +202,7 @@ TransportSecurityInfo::formatErrorMessage(MutexAutoLock const & proofOfLock,
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetErrorCode(int32_t* state)
-{
-  *state = GetErrorCode();
-  return NS_OK;
-}
-
-NS_IMETHODIMP
-TransportSecurityInfo::GetInterface(const nsIID & uuid, void * *result)
-{
+TransportSecurityInfo::GetInterface(const nsIID& uuid, void** result) {
   if (!NS_IsMainThread()) {
     NS_ERROR("nsNSSSocketInfo::GetInterface called off the main thread");
     return NS_ERROR_NOT_SAME_THREAD;
@@ -304,13 +222,16 @@ TransportSecurityInfo::GetInterface(const nsIID & uuid, void * *result)
 // of the previous value. This is so when older versions attempt to
 // read a newer serialized TransportSecurityInfo, they will actually
 // fail and return NS_ERROR_FAILURE instead of silently failing.
-#define TRANSPORTSECURITYINFOMAGIC { 0xa9863a23, 0x1faa, 0x4169, \
-  { 0xb0, 0xd2, 0x81, 0x29, 0xec, 0x7c, 0xb1, 0xde } }
+#define TRANSPORTSECURITYINFOMAGIC                   \
+  {                                                  \
+    0xa9863a23, 0x1faa, 0x4169, {                    \
+      0xb0, 0xd2, 0x81, 0x29, 0xec, 0x7c, 0xb1, 0xde \
+    }                                                \
+  }
 static NS_DEFINE_CID(kTransportSecurityInfoMagic, TRANSPORTSECURITYINFOMAGIC);
 
 NS_IMETHODIMP
-TransportSecurityInfo::Write(nsIObjectOutputStream* stream)
-{
+TransportSecurityInfo::Write(nsIObjectOutputStream* stream) {
   nsresult rv = stream->WriteID(kTransportSecurityInfoMagic);
   if (NS_FAILED(rv)) {
     return rv;
@@ -336,8 +257,8 @@ TransportSecurityInfo::Write(nsIObjectOutputStream* stream)
   }
   if (mErrorMessageCached.IsEmpty()) {
     // XXX: uses nsNSSComponent string bundles off the main thread
-    rv = formatErrorMessage(lock, mErrorCode, mErrorMessageType,
-                            true, true, mErrorMessageCached);
+    rv = formatErrorMessage(lock, mErrorCode, mErrorMessageType, true, true,
+                            mErrorMessageCached);
     if (NS_FAILED(rv)) {
       return rv;
     }
@@ -351,18 +272,14 @@ TransportSecurityInfo::Write(nsIObjectOutputStream* stream)
   // mSSLStatus will be non-null. However, for connections with non-overridable
   // errors, it will be null.
   nsCOMPtr<nsISerializable> serializable(mSSLStatus);
-  rv = NS_WriteOptionalCompoundObject(stream,
-                                      serializable,
-                                      NS_GET_IID(nsISSLStatus),
-                                      true);
+  rv = NS_WriteOptionalCompoundObject(stream, serializable,
+                                      NS_GET_IID(nsISSLStatus), true);
   if (NS_FAILED(rv)) {
     return rv;
   }
 
-  rv = NS_WriteOptionalCompoundObject(stream,
-                                      mFailedCertChain,
-                                      NS_GET_IID(nsIX509CertList),
-                                      true);
+  rv = NS_WriteOptionalCompoundObject(stream, mFailedCertChain,
+                                      NS_GET_IID(nsIX509CertList), true);
   if (NS_FAILED(rv)) {
     return rv;
   }
@@ -371,8 +288,7 @@ TransportSecurityInfo::Write(nsIObjectOutputStream* stream)
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::Read(nsIObjectInputStream* stream)
-{
+TransportSecurityInfo::Read(nsIObjectInputStream* stream) {
   nsID id;
   nsresult rv = stream->ReadID(&id);
   if (NS_FAILED(rv)) {
@@ -429,10 +345,16 @@ TransportSecurityInfo::Read(nsIObjectInputStream* stream)
   if (NS_FAILED(rv)) {
     return rv;
   }
-  mSSLStatus = BitwiseCast<nsSSLStatus*, nsISupports*>(supports.get());
+  nsCOMPtr<nsISSLStatus> castGuard(do_QueryInterface(supports));
+  if (castGuard) {
+    mSSLStatus = BitwiseCast<nsSSLStatus*, nsISSLStatus*>(castGuard.get());
+  } else {
+    mSSLStatus = nullptr;
+  }
 
   nsCOMPtr<nsISupports> failedCertChainSupports;
-  rv = NS_ReadOptionalObject(stream, true, getter_AddRefs(failedCertChainSupports));
+  rv = NS_ReadOptionalObject(stream, true,
+                             getter_AddRefs(failedCertChainSupports));
   if (NS_FAILED(rv)) {
     return rv;
   }
@@ -442,46 +364,39 @@ TransportSecurityInfo::Read(nsIObjectInputStream* stream)
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetInterfaces(uint32_t *count, nsIID * **array)
-{
+TransportSecurityInfo::GetInterfaces(uint32_t* count, nsIID*** array) {
   *count = 0;
   *array = nullptr;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetScriptableHelper(nsIXPCScriptable **_retval)
-{
+TransportSecurityInfo::GetScriptableHelper(nsIXPCScriptable** _retval) {
   *_retval = nullptr;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetContractID(char * *aContractID)
-{
-  *aContractID = nullptr;
+TransportSecurityInfo::GetContractID(nsACString& aContractID) {
+  aContractID.SetIsVoid(true);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetClassDescription(char * *aClassDescription)
-{
-  *aClassDescription = nullptr;
+TransportSecurityInfo::GetClassDescription(nsACString& aClassDescription) {
+  aClassDescription.SetIsVoid(true);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetClassID(nsCID * *aClassID)
-{
-  *aClassID = (nsCID*) moz_xmalloc(sizeof(nsCID));
-  if (!*aClassID)
-    return NS_ERROR_OUT_OF_MEMORY;
+TransportSecurityInfo::GetClassID(nsCID** aClassID) {
+  *aClassID = (nsCID*)moz_xmalloc(sizeof(nsCID));
+  if (!*aClassID) return NS_ERROR_OUT_OF_MEMORY;
   return GetClassIDNoAlloc(*aClassID);
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetFlags(uint32_t *aFlags)
-{
+TransportSecurityInfo::GetFlags(uint32_t* aFlags) {
   *aFlags = 0;
   return NS_OK;
 }
@@ -489,15 +404,12 @@ TransportSecurityInfo::GetFlags(uint32_t *aFlags)
 static NS_DEFINE_CID(kNSSSocketInfoCID, TRANSPORTSECURITYINFO_CID);
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetClassIDNoAlloc(nsCID *aClassIDNoAlloc)
-{
+TransportSecurityInfo::GetClassIDNoAlloc(nsCID* aClassIDNoAlloc) {
   *aClassIDNoAlloc = kNSSSocketInfoCID;
   return NS_OK;
 }
 
-nsresult
-TransportSecurityInfo::GetSSLStatus(nsISSLStatus** _result)
-{
+nsresult TransportSecurityInfo::GetSSLStatus(nsISSLStatus** _result) {
   NS_ENSURE_ARG_POINTER(_result);
 
   *_result = mSSLStatus;
@@ -506,12 +418,8 @@ TransportSecurityInfo::GetSSLStatus(nsISSLStatus** _result)
   return NS_OK;
 }
 
-nsresult
-TransportSecurityInfo::SetSSLStatus(nsSSLStatus *aSSLStatus)
-{
+void TransportSecurityInfo::SetSSLStatus(nsSSLStatus* aSSLStatus) {
   mSSLStatus = aSSLStatus;
-
-  return NS_OK;
 }
 
 /* Formats an error message for non-certificate-related SSL errors
@@ -519,24 +427,18 @@ TransportSecurityInfo::SetSSLStatus(nsSSLStatus *aSSLStatus)
  * PlainErrormMessage). Use formatOverridableCertErrorMessage
  * for overridable cert errors.
  */
-static nsresult
-formatPlainErrorMessage(const nsXPIDLCString &host, int32_t port,
-                        PRErrorCode err, 
-                        bool suppressPort443,
-                        nsString &returnedMessage)
-{
+static nsresult formatPlainErrorMessage(const nsCString& host, int32_t port,
+                                        PRErrorCode err, bool suppressPort443,
+                                        /*out*/ nsString& returnedMessage) {
   static NS_DEFINE_CID(kNSSComponentCID, NS_NSSCOMPONENT_CID);
 
-  const char16_t *params[1];
+  const char16_t* params[1];
   nsresult rv;
 
   nsCOMPtr<nsINSSComponent> component = do_GetService(kNSSComponentCID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  if (host.Length())
-  {
-    nsString hostWithPort;
-
+  if (host.Length()) {
     // For now, hide port when it's 443 and we're reporting the error.
     // In the future a better mechanism should be used
     // to make a decision about showing the port number, possibly by requiring
@@ -544,7 +446,7 @@ formatPlainErrorMessage(const nsXPIDLCString &host, int32_t port,
     // The motivation is that GNU browser would like to hide the port number
     // in error pages in the common case.
 
-    hostWithPort.AssignASCII(host);
+    NS_ConvertASCIItoUTF16 hostWithPort(host);
     if (!suppressPort443 || port != 443) {
       hostWithPort.Append(':');
       hostWithPort.AppendInt(port);
@@ -552,11 +454,9 @@ formatPlainErrorMessage(const nsXPIDLCString &host, int32_t port,
     params[0] = hostWithPort.get();
 
     nsString formattedString;
-    rv = component->PIPBundleFormatStringFromName("SSLConnectionErrorPrefix", 
-                                                  params, 1, 
-                                                  formattedString);
-    if (NS_SUCCEEDED(rv))
-    {
+    rv = component->PIPBundleFormatStringFromName("SSLConnectionErrorPrefix",
+                                                  params, 1, formattedString);
+    if (NS_SUCCEEDED(rv)) {
       returnedMessage.Append(formattedString);
       returnedMessage.AppendLiteral("\n\n");
     }
@@ -564,19 +464,15 @@ formatPlainErrorMessage(const nsXPIDLCString &host, int32_t port,
 
   nsString explanation;
   rv = nsNSSErrors::getErrorMessageFromCode(err, component, explanation);
-  if (NS_SUCCEEDED(rv))
-    returnedMessage.Append(explanation);
+  if (NS_SUCCEEDED(rv)) returnedMessage.Append(explanation);
 
   return NS_OK;
 }
 
-static void
-AppendErrorTextUntrusted(PRErrorCode errTrust,
-                         const nsString &host,
-                         nsIX509Cert* ix509,
-                         nsINSSComponent *component,
-                         nsString &returnedMessage)
-{
+static void AppendErrorTextUntrusted(PRErrorCode errTrust, const nsString& host,
+                                     nsIX509Cert* ix509,
+                                     nsINSSComponent* component,
+                                     nsString& returnedMessage) {
   const char* errorID = nullptr;
   const char* errorID2 = nullptr;
   const char* errorID3 = nullptr;
@@ -611,14 +507,15 @@ AppendErrorTextUntrusted(PRErrorCode errTrust,
     }
   }
 
-  const char* errorIDs[] = { errorID, errorID2, errorID3 };
+  const char* errorIDs[] = {errorID, errorID2, errorID3};
   for (size_t i = 0; i < ArrayLength(errorIDs); i++) {
     if (!errorIDs[i]) {
       break;
     }
 
     nsString formattedString;
-    nsresult rv = component->GetPIPNSSBundleString(errorIDs[i], formattedString);
+    nsresult rv =
+        component->GetPIPNSSBundleString(errorIDs[i], formattedString);
     if (NS_SUCCEEDED(rv)) {
       returnedMessage.Append(formattedString);
       returnedMessage.Append('\n');
@@ -630,9 +527,8 @@ AppendErrorTextUntrusted(PRErrorCode errTrust,
 // subject alternative name extension of the certificate.
 // Returns zero if the extension is not present, could not be decoded, or if it
 // does not contain any dNSName or iPAddress entries.
-static uint32_t
-GetSubjectAltNames(CERTCertificate* nssCert, nsString& allNames)
-{
+static uint32_t GetSubjectAltNames(CERTCertificate* nssCert,
+                                   nsString& allNames) {
   allNames.Truncate();
 
   ScopedAutoSECItem altNameExtension;
@@ -645,8 +541,8 @@ GetSubjectAltNames(CERTCertificate* nssCert, nsString& allNames)
   if (!arena) {
     return 0;
   }
-  CERTGeneralName* sanNameList(CERT_DecodeAltNameExtension(arena.get(),
-                                                           &altNameExtension));
+  CERTGeneralName* sanNameList(
+      CERT_DecodeAltNameExtension(arena.get(), &altNameExtension));
   if (!sanNameList) {
     return 0;
   }
@@ -656,72 +552,71 @@ GetSubjectAltNames(CERTCertificate* nssCert, nsString& allNames)
   do {
     nsAutoString name;
     switch (current->type) {
-      case certDNSName:
-        {
-          nsDependentCSubstring nameFromCert(BitwiseCast<char*, unsigned char*>(
-                                               current->name.other.data),
-                                             current->name.other.len);
-          // dNSName fields are defined as type IA5String and thus should
-          // be limited to ASCII characters.
-          if (IsASCII(nameFromCert)) {
-            name.Assign(NS_ConvertASCIItoUTF16(nameFromCert));
-            if (!allNames.IsEmpty()) {
-              allNames.AppendLiteral(", ");
-            }
-            ++nameCount;
-            allNames.Append(name);
+      case certDNSName: {
+        nsDependentCSubstring nameFromCert(
+            BitwiseCast<char*, unsigned char*>(current->name.other.data),
+            current->name.other.len);
+        // dNSName fields are defined as type IA5String and thus should
+        // be limited to ASCII characters.
+        if (IsASCII(nameFromCert)) {
+          name.Assign(NS_ConvertASCIItoUTF16(nameFromCert));
+          if (!allNames.IsEmpty()) {
+            allNames.AppendLiteral(", ");
           }
+          ++nameCount;
+          allNames.Append(name);
+        }
+      } break;
+
+      case certIPAddress: {
+        char buf[INET6_ADDRSTRLEN];
+        PRNetAddr addr;
+        if (current->name.other.len == 4) {
+          addr.inet.family = PR_AF_INET;
+          memcpy(&addr.inet.ip, current->name.other.data,
+                 current->name.other.len);
+          PR_NetAddrToString(&addr, buf, sizeof(buf));
+          name.AssignASCII(buf);
+        } else if (current->name.other.len == 16) {
+          addr.ipv6.family = PR_AF_INET6;
+          memcpy(&addr.ipv6.ip, current->name.other.data,
+                 current->name.other.len);
+          PR_NetAddrToString(&addr, buf, sizeof(buf));
+          name.AssignASCII(buf);
+        } else {
+          /* invalid IP address */
+        }
+        if (!name.IsEmpty()) {
+          if (!allNames.IsEmpty()) {
+            allNames.AppendLiteral(", ");
+          }
+          ++nameCount;
+          allNames.Append(name);
         }
         break;
+      }
 
-      case certIPAddress:
-        {
-          char buf[INET6_ADDRSTRLEN];
-          PRNetAddr addr;
-          if (current->name.other.len == 4) {
-            addr.inet.family = PR_AF_INET;
-            memcpy(&addr.inet.ip, current->name.other.data, current->name.other.len);
-            PR_NetAddrToString(&addr, buf, sizeof(buf));
-            name.AssignASCII(buf);
-          } else if (current->name.other.len == 16) {
-            addr.ipv6.family = PR_AF_INET6;
-            memcpy(&addr.ipv6.ip, current->name.other.data, current->name.other.len);
-            PR_NetAddrToString(&addr, buf, sizeof(buf));
-            name.AssignASCII(buf);
-          } else {
-            /* invalid IP address */
-          }
-          if (!name.IsEmpty()) {
-            if (!allNames.IsEmpty()) {
-              allNames.AppendLiteral(", ");
-            }
-            ++nameCount;
-            allNames.Append(name);
-          }
-          break;
-        }
-
-      default: // all other types of names are ignored
+      default:  // all other types of names are ignored
         break;
     }
     current = CERT_GetNextGeneralName(current);
-  } while (current != sanNameList); // double linked
+  } while (current != sanNameList);  // double linked
 
   return nameCount;
 }
 
-static nsresult
-AppendErrorTextMismatch(const nsString& host, nsIX509Cert* ix509,
-                        nsINSSComponent* component, bool wantsHtml,
-                        nsString& returnedMessage)
-{
+static nsresult AppendErrorTextMismatch(const nsString& host,
+                                        nsIX509Cert* ix509,
+                                        nsINSSComponent* component,
+                                        bool wantsHtml,
+                                        nsString& returnedMessage) {
   // Prepare a default "not valid for <hostname>" string in case anything
   // goes wrong (or in case the certificate is not valid for any hostnames).
   nsAutoString notValidForHostnameString;
   const char16_t* params[1];
   params[0] = host.get();
   nsresult rv = component->PIPBundleFormatStringFromName(
-    "certErrorMismatch", params, 1, notValidForHostnameString);
+      "certErrorMismatch", params, 1, notValidForHostnameString);
   if (NS_FAILED(rv)) {
     return rv;
   }
@@ -750,8 +645,8 @@ AppendErrorTextMismatch(const nsString& host, nsIX509Cert* ix509,
   } else if (nameCount == 1) {
     params[0] = allNames.get();
 
-    const char* stringID = wantsHtml ? "certErrorMismatchSingle2"
-                                     : "certErrorMismatchSinglePlain";
+    const char* stringID =
+        wantsHtml ? "certErrorMismatchSingle2" : "certErrorMismatchSinglePlain";
     nsAutoString formattedString;
     rv = component->PIPBundleFormatStringFromName(stringID, params, 1,
                                                   formattedString);
@@ -765,12 +660,9 @@ AppendErrorTextMismatch(const nsString& host, nsIX509Cert* ix509,
   return NS_OK;
 }
 
-static void
-GetDateBoundary(nsIX509Cert* ix509,
-                nsString &formattedDate,
-                nsString &nowDate,
-                bool &trueExpired_falseNotYetValid)
-{
+static void GetDateBoundary(nsIX509Cert* ix509, nsString& formattedDate,
+                            nsString& nowDate,
+                            bool& trueExpired_falseNotYetValid) {
   trueExpired_falseNotYetValid = true;
   formattedDate.Truncate();
 
@@ -779,16 +671,13 @@ GetDateBoundary(nsIX509Cert* ix509,
   nsresult rv;
 
   rv = ix509->GetValidity(getter_AddRefs(validity));
-  if (NS_FAILED(rv))
-    return;
+  if (NS_FAILED(rv)) return;
 
   rv = validity->GetNotAfter(&notAfter);
-  if (NS_FAILED(rv))
-    return;
+  if (NS_FAILED(rv)) return;
 
   rv = validity->GetNotBefore(&notBefore);
-  if (NS_FAILED(rv))
-    return;
+  if (NS_FAILED(rv)) return;
 
   PRTime now = PR_Now();
   if (now > notAfter) {
@@ -798,71 +687,56 @@ GetDateBoundary(nsIX509Cert* ix509,
     trueExpired_falseNotYetValid = false;
   }
 
-  nsCOMPtr<nsIDateTimeFormat> dateTimeFormat = nsIDateTimeFormat::Create();
-  if (!dateTimeFormat) {
-    return;
-  }
-
-  dateTimeFormat->FormatPRTime(nullptr, kDateFormatLong, kTimeFormatNoSeconds,
-                               timeToUse, formattedDate);
-  dateTimeFormat->FormatPRTime(nullptr, kDateFormatLong, kTimeFormatNoSeconds,
-                               now, nowDate);
+  DateTimeFormat::FormatPRTime(kDateFormatLong, kTimeFormatNoSeconds, timeToUse,
+                               formattedDate);
+  DateTimeFormat::FormatPRTime(kDateFormatLong, kTimeFormatNoSeconds, now,
+                               nowDate);
 }
 
-static void
-AppendErrorTextTime(nsIX509Cert* ix509,
-                    nsINSSComponent *component,
-                    nsString &returnedMessage)
-{
+static void AppendErrorTextTime(nsIX509Cert* ix509, nsINSSComponent* component,
+                                nsString& returnedMessage) {
   nsAutoString formattedDate, nowDate;
   bool trueExpired_falseNotYetValid;
   GetDateBoundary(ix509, formattedDate, nowDate, trueExpired_falseNotYetValid);
 
-  const char16_t *params[2];
-  params[0] = formattedDate.get(); // might be empty, if helper function had a problem 
+  const char16_t* params[2];
+  params[0] =
+      formattedDate.get();  // might be empty, if helper function had a problem
   params[1] = nowDate.get();
 
-  const char *key = trueExpired_falseNotYetValid ? 
-                    "certErrorExpiredNow" : "certErrorNotYetValidNow";
+  const char* key = trueExpired_falseNotYetValid ? "certErrorExpiredNow"
+                                                 : "certErrorNotYetValidNow";
   nsresult rv;
   nsString formattedString;
   rv = component->PIPBundleFormatStringFromName(
-           key,
-           params, 
-           ArrayLength(params),
-           formattedString);
-  if (NS_SUCCEEDED(rv))
-  {
+      key, params, ArrayLength(params), formattedString);
+  if (NS_SUCCEEDED(rv)) {
     returnedMessage.Append(formattedString);
     returnedMessage.Append('\n');
   }
 }
 
-static void
-AppendErrorTextCode(PRErrorCode errorCodeToReport,
-                    nsINSSComponent *component,
-                    nsString &returnedMessage)
-{
-  const char *codeName = nsNSSErrors::getDefaultErrorStringName(errorCodeToReport);
-  if (codeName)
-  {
+static void AppendErrorTextCode(PRErrorCode errorCodeToReport,
+                                nsINSSComponent* component,
+                                nsString& returnedMessage) {
+  const char* codeName =
+      nsNSSErrors::getDefaultErrorStringName(errorCodeToReport);
+  if (codeName) {
     nsCString error_id(codeName);
     NS_ConvertASCIItoUTF16 idU(error_id);
 
-    const char16_t *params[1];
+    const char16_t* params[1];
     params[0] = idU.get();
 
     nsString formattedString;
     nsresult rv;
     rv = component->PIPBundleFormatStringFromName("certErrorCodePrefix2",
-                                                  params, 1, 
-                                                  formattedString);
+                                                  params, 1, formattedString);
     if (NS_SUCCEEDED(rv)) {
       returnedMessage.Append('\n');
       returnedMessage.Append(formattedString);
       returnedMessage.Append('\n');
-    }
-    else {
+    } else {
       returnedMessage.AppendLiteral(" (");
       returnedMessage.Append(idU);
       returnedMessage.Append(')');
@@ -874,20 +748,16 @@ AppendErrorTextCode(PRErrorCode errorCodeToReport,
  * OverridableCertErrorMessage). Use formatPlainErrorMessage to format
  * non-overridable cert errors and non-cert-related errors.
  */
-static nsresult
-formatOverridableCertErrorMessage(nsISSLStatus & sslStatus,
-                                  PRErrorCode errorCodeToReport, 
-                                  const nsXPIDLCString & host, int32_t port,
-                                  bool suppressPort443,
-                                  bool wantsHtml,
-                                  nsString & returnedMessage)
-{
+static nsresult formatOverridableCertErrorMessage(
+    nsISSLStatus& sslStatus, PRErrorCode errorCodeToReport,
+    const nsCString& host, int32_t port, bool suppressPort443, bool wantsHtml,
+    /*out*/ nsString& returnedMessage) {
   static NS_DEFINE_CID(kNSSComponentCID, NS_NSSCOMPONENT_CID);
 
-  const char16_t *params[1];
+  const char16_t* params[1];
   nsresult rv;
-  nsAutoString hostWithPort;
-  nsAutoString hostWithoutPort;
+  NS_ConvertASCIItoUTF16 hostWithPort(host);
+  NS_ConvertASCIItoUTF16 hostWithoutPort(host);
 
   // For now, hide port when it's 443 and we're reporting the error.
   // In the future a better mechanism should be used
@@ -895,12 +765,9 @@ formatOverridableCertErrorMessage(nsISSLStatus & sslStatus,
   // the context object to implement a specific interface.
   // The motivation is that GNU browser would like to hide the port number
   // in error pages in the common case.
-  
-  hostWithoutPort.AppendASCII(host);
   if (suppressPort443 && port == 443) {
     params[0] = hostWithoutPort.get();
   } else {
-    hostWithPort.AppendASCII(host);
     hostWithPort.Append(':');
     hostWithPort.AppendInt(port);
     params[0] = hostWithPort.get();
@@ -924,7 +791,7 @@ formatOverridableCertErrorMessage(nsISSLStatus & sslStatus,
   rv = sslStatus.GetIsUntrusted(&isUntrusted);
   NS_ENSURE_SUCCESS(rv, rv);
   if (isUntrusted) {
-    AppendErrorTextUntrusted(errorCodeToReport, hostWithoutPort, ix509, 
+    AppendErrorTextUntrusted(errorCodeToReport, hostWithoutPort, ix509,
                              component, returnedMessage);
   }
 
@@ -951,55 +818,39 @@ formatOverridableCertErrorMessage(nsISSLStatus & sslStatus,
 
 // RememberCertErrorsTable
 
-/*static*/ RememberCertErrorsTable*
-RememberCertErrorsTable::sInstance = nullptr;
+/*static*/ RememberCertErrorsTable* RememberCertErrorsTable::sInstance =
+    nullptr;
 
 RememberCertErrorsTable::RememberCertErrorsTable()
-  : mErrorHosts()
-  , mMutex("RememberCertErrorsTable::mMutex")
-{
-}
+    : mErrorHosts(), mMutex("RememberCertErrorsTable::mMutex") {}
 
-static nsresult
-GetHostPortKey(TransportSecurityInfo* infoObject, nsAutoCString &result)
-{
-  nsresult rv;
+static nsresult GetHostPortKey(TransportSecurityInfo* infoObject,
+                               /*out*/ nsCString& result) {
+  MOZ_ASSERT(infoObject);
+  NS_ENSURE_ARG(infoObject);
 
   result.Truncate();
 
-  nsXPIDLCString hostName;
-  rv = infoObject->GetHostName(getter_Copies(hostName));
-  NS_ENSURE_SUCCESS(rv, rv);
-
-  int32_t port;
-  rv = infoObject->GetPort(&port);
-  NS_ENSURE_SUCCESS(rv, rv);
-
-  result.Assign(hostName);
+  result.Assign(infoObject->GetHostName());
   result.Append(':');
-  result.AppendInt(port);
+  result.AppendInt(infoObject->GetPort());
 
   return NS_OK;
 }
 
-void
-RememberCertErrorsTable::RememberCertHasError(TransportSecurityInfo* infoObject,
-                                              nsSSLStatus* status,
-                                              SECStatus certVerificationResult)
-{
+void RememberCertErrorsTable::RememberCertHasError(
+    TransportSecurityInfo* infoObject, nsSSLStatus* status,
+    SECStatus certVerificationResult) {
   nsresult rv;
 
   nsAutoCString hostPortKey;
   rv = GetHostPortKey(infoObject, hostPortKey);
-  if (NS_FAILED(rv))
-    return;
+  if (NS_FAILED(rv)) return;
 
   if (certVerificationResult != SECSuccess) {
-    NS_ASSERTION(status,
-        "Must have nsSSLStatus object when remembering flags");
+    MOZ_ASSERT(status, "Must have nsSSLStatus object when remembering flags");
 
-    if (!status)
-      return;
+    if (!status) return;
 
     CertStateBits bits;
     bits.mIsDomainMismatch = status->mIsDomainMismatch;
@@ -1008,17 +859,14 @@ RememberCertErrorsTable::RememberCertHasError(TransportSecurityInfo* infoObject,
 
     MutexAutoLock lock(mMutex);
     mErrorHosts.Put(hostPortKey, bits);
-  }
-  else {
+  } else {
     MutexAutoLock lock(mMutex);
     mErrorHosts.Remove(hostPortKey);
   }
 }
 
-void
-RememberCertErrorsTable::LookupCertErrorBits(TransportSecurityInfo* infoObject,
-                                             nsSSLStatus* status)
-{
+void RememberCertErrorsTable::LookupCertErrorBits(
+    TransportSecurityInfo* infoObject, nsSSLStatus* status) {
   // Get remembered error bits from our cache, because of SSL session caching
   // the NSS library potentially hasn't notified us for this socket.
   if (status->mHaveCertErrorBits)
@@ -1029,8 +877,7 @@ RememberCertErrorsTable::LookupCertErrorBits(TransportSecurityInfo* infoObject,
 
   nsAutoCString hostPortKey;
   rv = GetHostPortKey(infoObject, hostPortKey);
-  if (NS_FAILED(rv))
-    return;
+  if (NS_FAILED(rv)) return;
 
   CertStateBits bits;
   {
@@ -1047,10 +894,8 @@ RememberCertErrorsTable::LookupCertErrorBits(TransportSecurityInfo* infoObject,
   status->mIsUntrusted = bits.mIsUntrusted;
 }
 
-void
-TransportSecurityInfo::SetStatusErrorBits(nsNSSCertificate* cert,
-                                          uint32_t collected_errors)
-{
+void TransportSecurityInfo::SetStatusErrorBits(nsNSSCertificate* cert,
+                                               uint32_t collected_errors) {
   MutexAutoLock lock(mMutex);
 
   if (!mSSLStatus) {
@@ -1058,24 +903,23 @@ TransportSecurityInfo::SetStatusErrorBits(nsNSSCertificate* cert,
   }
 
   mSSLStatus->SetServerCert(cert, EVStatus::NotEV);
+  mSSLStatus->SetFailedCertChain(mFailedCertChain);
 
   mSSLStatus->mHaveCertErrorBits = true;
-  mSSLStatus->mIsDomainMismatch = 
-    collected_errors & nsICertOverrideService::ERROR_MISMATCH;
-  mSSLStatus->mIsNotValidAtThisTime = 
-    collected_errors & nsICertOverrideService::ERROR_TIME;
-  mSSLStatus->mIsUntrusted = 
-    collected_errors & nsICertOverrideService::ERROR_UNTRUSTED;
+  mSSLStatus->mIsDomainMismatch =
+      collected_errors & nsICertOverrideService::ERROR_MISMATCH;
+  mSSLStatus->mIsNotValidAtThisTime =
+      collected_errors & nsICertOverrideService::ERROR_TIME;
+  mSSLStatus->mIsUntrusted =
+      collected_errors & nsICertOverrideService::ERROR_UNTRUSTED;
 
-  RememberCertErrorsTable::GetInstance().RememberCertHasError(this,
-                                                              mSSLStatus,
+  RememberCertErrorsTable::GetInstance().RememberCertHasError(this, mSSLStatus,
                                                               SECFailure);
 }
 
 NS_IMETHODIMP
-TransportSecurityInfo::GetFailedCertChain(nsIX509CertList** _result)
-{
-  NS_ASSERTION(_result, "non-NULL destination required");
+TransportSecurityInfo::GetFailedCertChain(nsIX509CertList** _result) {
+  MOZ_ASSERT(_result);
 
   *_result = mFailedCertChain;
   NS_IF_ADDREF(*_result);
@@ -1083,18 +927,13 @@ TransportSecurityInfo::GetFailedCertChain(nsIX509CertList** _result)
   return NS_OK;
 }
 
-nsresult
-TransportSecurityInfo::SetFailedCertChain(UniqueCERTCertList certList)
-{
-  nsNSSShutDownPreventionLock lock;
-  if (isAlreadyShutDown()) {
-    return NS_ERROR_NOT_AVAILABLE;
-  }
-
+nsresult TransportSecurityInfo::SetFailedCertChain(
+    UniqueCERTCertList certList) {
   // nsNSSCertList takes ownership of certList
-  mFailedCertChain = new nsNSSCertList(Move(certList), lock);
+  mFailedCertChain = new nsNSSCertList(Move(certList));
 
   return NS_OK;
 }
 
-} } // namespace mozilla::psm
+}  // namespace psm
+}  // namespace mozilla
