@@ -30,7 +30,8 @@
 #include "pkix/Result.h"
 #include "stdint.h"
 
-namespace mozilla { namespace pkix {
+namespace mozilla {
+namespace pkix {
 
 class Reader;
 
@@ -49,9 +50,8 @@ class Reader;
 //
 // Note that in the example, GoodExample has the same performance
 // characteristics as WorseExample, but with much better safety guarantees.
-class Input final
-{
-public:
+class Input final {
+ public:
   typedef uint16_t size_type;
 
   // This constructor is useful for inputs that are statically known to be of a
@@ -66,26 +66,17 @@ public:
   //   Input expected;
   //   Result rv = expected.Init(EXPECTED_BYTES, sizeof EXPECTED_BYTES);
   template <size_type N>
-  explicit Input(const uint8_t (&data)[N])
-    : data(data)
-    , len(N)
-  {
-  }
+  explicit Input(const uint8_t (&data)[N]) : data(data), len(N) {}
 
   // Construct a valid, empty, Init-able Input.
-  Input()
-    : data(nullptr)
-    , len(0u)
-  {
-  }
+  Input() : data(nullptr), len(0u) {}
 
   // This is intentionally not explicit in order to allow value semantics.
   Input(const Input&) = default;
 
   // Initialize the input. data must be non-null and len must be less than
   // 65536. Init may not be called more than once.
-  Result Init(const uint8_t* data, size_t len)
-  {
+  Result Init(const uint8_t* data, size_t len) {
     if (this->data) {
       // already initialized
       return Result::FATAL_ERROR_INVALID_ARGS;
@@ -107,10 +98,7 @@ public:
   // This is basically operator=, but it wasn't given that name because
   // normally callers do not check the result of operator=, and normally
   // operator= can be used multiple times.
-  Result Init(Input other)
-  {
-    return Init(other.data, other.len);
-  }
+  Result Init(Input other) { return Init(other.data, other.len); }
 
   // Returns the length of the input.
   //
@@ -122,18 +110,17 @@ public:
   // don't want to declare in this header file.
   const uint8_t* UnsafeGetData() const { return data; }
 
-private:
+ private:
   const uint8_t* data;
   size_t len;
 
-  void operator=(const Input&) = delete; // Use Init instead.
+  void operator=(const Input&) = delete;  // Use Init instead.
 };
 
-inline bool
-InputsAreEqual(const Input& a, const Input& b)
-{
+inline bool InputsAreEqual(const Input& a, const Input& b) {
   return a.GetLength() == b.GetLength() &&
-         std::equal(a.UnsafeGetData(), a.UnsafeGetData() + a.GetLength(), b.UnsafeGetData());
+         std::equal(a.UnsafeGetData(), a.UnsafeGetData() + a.GetLength(),
+                    b.UnsafeGetData());
 }
 
 // An Reader is a cursor/iterator through the contents of an Input, designed to
@@ -144,23 +131,15 @@ InputsAreEqual(const Input& a, const Input& b)
 //
 // In general, Reader allows for one byte of lookahead and no backtracking.
 // However, the Match* functions internally may have more lookahead.
-class Reader final
-{
-public:
-  Reader()
-    : input(nullptr)
-    , end(nullptr)
-  {
-  }
+class Reader final {
+ public:
+  Reader() : input(nullptr), end(nullptr) {}
 
   explicit Reader(Input input)
-    : input(input.UnsafeGetData())
-    , end(input.UnsafeGetData() + input.GetLength())
-  {
-  }
+      : input(input.UnsafeGetData()),
+        end(input.UnsafeGetData() + input.GetLength()) {}
 
-  Result Init(Input input)
-  {
+  Result Init(Input input) {
     if (this->input) {
       return Result::FATAL_ERROR_INVALID_ARGS;
     }
@@ -169,13 +148,11 @@ public:
     return Success;
   }
 
-  bool Peek(uint8_t expectedByte) const
-  {
+  bool Peek(uint8_t expectedByte) const {
     return input < end && *input == expectedByte;
   }
 
-  Result Read(uint8_t& out)
-  {
+  Result Read(uint8_t& out) {
     Result rv = EnsureLength(1);
     if (rv != Success) {
       return rv;
@@ -184,8 +161,7 @@ public:
     return Success;
   }
 
-  Result Read(uint16_t& out)
-  {
+  Result Read(uint16_t& out) {
     Result rv = EnsureLength(2);
     if (rv != Success) {
       return rv;
@@ -197,8 +173,7 @@ public:
   }
 
   template <Input::size_type N>
-  bool MatchRest(const uint8_t (&toMatch)[N])
-  {
+  bool MatchRest(const uint8_t (&toMatch)[N]) {
     // Normally we use EnsureLength which compares (input + len < end), but
     // here we want to be sure that there is nothing following the matched
     // bytes
@@ -212,8 +187,7 @@ public:
     return true;
   }
 
-  bool MatchRest(Input toMatch)
-  {
+  bool MatchRest(Input toMatch) {
     // Normally we use EnsureLength which compares (input + len < end), but
     // here we want to be sure that there is nothing following the matched
     // bytes
@@ -228,8 +202,7 @@ public:
     return true;
   }
 
-  Result Skip(Input::size_type len)
-  {
+  Result Skip(Input::size_type len) {
     Result rv = EnsureLength(len);
     if (rv != Success) {
       return rv;
@@ -238,8 +211,7 @@ public:
     return Success;
   }
 
-  Result Skip(Input::size_type len, Reader& skipped)
-  {
+  Result Skip(Input::size_type len, Reader& skipped) {
     Result rv = EnsureLength(len);
     if (rv != Success) {
       return rv;
@@ -252,8 +224,7 @@ public:
     return Success;
   }
 
-  Result Skip(Input::size_type len, /*out*/ Input& skipped)
-  {
+  Result Skip(Input::size_type len, /*out*/ Input& skipped) {
     Result rv = EnsureLength(len);
     if (rv != Success) {
       return rv;
@@ -266,18 +237,13 @@ public:
     return Success;
   }
 
-  void SkipToEnd()
-  {
-    input = end;
-  }
+  void SkipToEnd() { input = end; }
 
-  Result SkipToEnd(/*out*/ Input& skipped)
-  {
+  Result SkipToEnd(/*out*/ Input& skipped) {
     return Skip(static_cast<Input::size_type>(end - input), skipped);
   }
 
-  Result EnsureLength(Input::size_type len)
-  {
+  Result EnsureLength(Input::size_type len) {
     if (static_cast<size_t>(end - input) < len) {
       return Result::ERROR_BAD_DER;
     }
@@ -286,13 +252,12 @@ public:
 
   bool AtEnd() const { return input == end; }
 
-  class Mark final
-  {
-  public:
-    Mark(const Mark&) = default; // Intentionally not explicit.
-  private:
+  class Mark final {
+   public:
+    Mark(const Mark&) = default;  // Intentionally not explicit.
+   private:
     friend class Reader;
-    Mark(const Reader& input, const uint8_t* mark) : input(input), mark(mark) { }
+    Mark(const Reader& input, const uint8_t* mark) : input(input), mark(mark) {}
     const Reader& input;
     const uint8_t* const mark;
     void operator=(const Mark&) = delete;
@@ -300,8 +265,7 @@ public:
 
   Mark GetMark() const { return Mark(*this, input); }
 
-  Result GetInput(const Mark& mark, /*out*/ Input& item)
-  {
+  Result GetInput(const Mark& mark, /*out*/ Input& item) {
     if (&mark.input != this || mark.mark > input) {
       return NotReached("invalid mark", Result::FATAL_ERROR_INVALID_ARGS);
     }
@@ -309,9 +273,8 @@ public:
                      static_cast<Input::size_type>(input - mark.mark));
   }
 
-private:
-  Result Init(const uint8_t* data, Input::size_type len)
-  {
+ private:
+  Result Init(const uint8_t* data, Input::size_type len) {
     if (input) {
       // already initialized
       return Result::FATAL_ERROR_INVALID_ARGS;
@@ -328,9 +291,7 @@ private:
   void operator=(const Reader&) = delete;
 };
 
-inline bool
-InputContains(const Input& input, uint8_t toFind)
-{
+inline bool InputContains(const Input& input, uint8_t toFind) {
   Reader reader(input);
   for (;;) {
     uint8_t b;
@@ -343,6 +304,7 @@ InputContains(const Input& input, uint8_t toFind)
   }
 }
 
-} } // namespace mozilla::pkix
+}  // namespace pkix
+}  // namespace mozilla
 
-#endif // mozilla_pkix_Input_h
+#endif  // mozilla_pkix_Input_h
