@@ -29,7 +29,8 @@
 #include "prerror.h"
 #include "seccomon.h"
 
-namespace mozilla { namespace pkix {
+namespace mozilla {
+namespace pkix {
 
 // Verifies the PKCS#1.5 signature on the given data using the given RSA public
 // key.
@@ -54,10 +55,8 @@ Result VerifyECDSASignedDigestNSS(const SignedDigest& sd,
 // TODO: Taking the output buffer as (uint8_t*, size_t) is counter to our
 // other, extensive, memory safety efforts in mozilla::pkix, and we should find
 // a way to provide a more-obviously-safe interface.
-Result DigestBufNSS(Input item,
-                    DigestAlgorithm digestAlg,
-                    /*out*/ uint8_t* digestBuf,
-                    size_t digestBufLen);
+Result DigestBufNSS(Input item, DigestAlgorithm digestAlg,
+                    /*out*/ uint8_t* digestBuf, size_t digestBufLen);
 
 Result MapPRErrorCodeToResult(PRErrorCode errorCode);
 PRErrorCode MapResultToPRErrorCode(Result result);
@@ -72,8 +71,7 @@ PRErrorCode MapResultToPRErrorCode(Result result);
 static const PRErrorCode ERROR_BASE = -0x4000;
 static const PRErrorCode ERROR_LIMIT = ERROR_BASE + 1000;
 
-enum ErrorCode
-{
+enum ErrorCode {
   MOZILLA_PKIX_ERROR_KEY_PINNING_FAILURE = ERROR_BASE + 0,
   MOZILLA_PKIX_ERROR_CA_CERT_USED_AS_END_ENTITY = ERROR_BASE + 1,
   MOZILLA_PKIX_ERROR_INADEQUATE_KEY_SIZE = ERROR_BASE + 2,
@@ -87,23 +85,21 @@ enum ErrorCode
   MOZILLA_PKIX_ERROR_REQUIRED_TLS_FEATURE_MISSING = ERROR_BASE + 10,
   MOZILLA_PKIX_ERROR_INVALID_INTEGER_ENCODING = ERROR_BASE + 11,
   MOZILLA_PKIX_ERROR_EMPTY_ISSUER_NAME = ERROR_BASE + 12,
+  MOZILLA_PKIX_ERROR_ADDITIONAL_POLICY_CONSTRAINT_FAILED = ERROR_BASE + 13,
   END_OF_LIST
 };
 
 void RegisterErrorTable();
 
-inline SECItem UnsafeMapInputToSECItem(Input input)
-{
-  SECItem result = {
-    siBuffer,
-    const_cast<uint8_t*>(input.UnsafeGetData()),
-    input.GetLength()
-  };
+inline SECItem UnsafeMapInputToSECItem(Input input) {
+  SECItem result = {siBuffer, const_cast<uint8_t*>(input.UnsafeGetData()),
+                    input.GetLength()};
   static_assert(sizeof(decltype(input.GetLength())) <= sizeof(result.len),
                 "input.GetLength() must fit in a SECItem");
   return result;
 }
 
-} } // namespace mozilla::pkix
+}  // namespace pkix
+}  // namespace mozilla
 
-#endif // mozilla_pkix_pkixnss_h
+#endif  // mozilla_pkix_pkixnss_h
