@@ -27,18 +27,16 @@
 #include "pkixder.h"
 #include "pkixutil.h"
 
-namespace mozilla { namespace pkix {
+namespace mozilla {
+namespace pkix {
 
 // 4.1.1.2 signatureAlgorithm
 // 4.1.2.3 signature
 
-Result
-CheckSignatureAlgorithm(TrustDomain& trustDomain,
-                        EndEntityOrCA endEntityOrCA,
-                        Time notBefore,
-                        const der::SignedDataWithSignature& signedData,
-                        Input signatureValue)
-{
+Result CheckSignatureAlgorithm(TrustDomain& trustDomain,
+                               EndEntityOrCA endEntityOrCA, Time notBefore,
+                               const der::SignedDataWithSignature& signedData,
+                               Input signatureValue) {
   // 4.1.1.2. signatureAlgorithm
   der::PublicKeyAlgorithm publicKeyAlg;
   DigestAlgorithm digestAlg;
@@ -57,9 +55,8 @@ CheckSignatureAlgorithm(TrustDomain& trustDomain,
   der::PublicKeyAlgorithm signedPublicKeyAlg;
   DigestAlgorithm signedDigestAlg;
   Reader signedSignatureAlgorithmReader(signatureValue);
-  rv = der::SignatureAlgorithmIdentifierValue(signedSignatureAlgorithmReader,
-                                              signedPublicKeyAlg,
-                                              signedDigestAlg);
+  rv = der::SignatureAlgorithmIdentifierValue(
+      signedSignatureAlgorithmReader, signedPublicKeyAlg, signedDigestAlg);
   if (rv != Success) {
     return rv;
   }
@@ -99,8 +96,7 @@ CheckSignatureAlgorithm(TrustDomain& trustDomain,
   }
 
   switch (publicKeyAlg) {
-    case der::PublicKeyAlgorithm::RSA_PKCS1:
-    {
+    case der::PublicKeyAlgorithm::RSA_PKCS1: {
       // The RSA computation may give a result that requires fewer bytes to
       // encode than the public key (since it is modular arithmetic). However,
       // the last step of generating a PKCS#1.5 signature is the I2OSP
@@ -108,7 +104,7 @@ CheckSignatureAlgorithm(TrustDomain& trustDomain,
       // is exactly the same length as the public key.
       unsigned int signatureSizeInBits = signedData.signature.GetLength() * 8u;
       return trustDomain.CheckRSAPublicKeyModulusSizeInBits(
-               endEntityOrCA, signatureSizeInBits);
+          endEntityOrCA, signatureSizeInBits);
     }
 
     case der::PublicKeyAlgorithm::ECDSA:
@@ -118,7 +114,7 @@ CheckSignatureAlgorithm(TrustDomain& trustDomain,
       // during path building is too low to be worth bothering with.
       break;
 
-    MOZILLA_PKIX_UNREACHABLE_DEFAULT_ENUM
+      MOZILLA_PKIX_UNREACHABLE_DEFAULT_ENUM
   }
 
   return Success;
@@ -126,9 +122,7 @@ CheckSignatureAlgorithm(TrustDomain& trustDomain,
 
 // 4.1.2.4 Issuer
 
-Result
-CheckIssuer(Input encodedIssuer)
-{
+Result CheckIssuer(Input encodedIssuer) {
   // "The issuer field MUST contain a non-empty distinguished name (DN)."
   Reader issuer(encodedIssuer);
   Input encodedRDNs;
@@ -145,11 +139,9 @@ CheckIssuer(Input encodedIssuer)
 
 // 4.1.2.5 Validity
 
-Result
-ParseValidity(Input encodedValidity,
-              /*optional out*/ Time* notBeforeOut,
-              /*optional out*/ Time* notAfterOut)
-{
+Result ParseValidity(Input encodedValidity,
+                     /*optional out*/ Time* notBeforeOut,
+                     /*optional out*/ Time* notAfterOut) {
   Reader validity(encodedValidity);
   Time notBefore(Time::uninitialized);
   if (der::TimeChoice(validity, notBefore) != Success) {
@@ -179,9 +171,7 @@ ParseValidity(Input encodedValidity,
   return Success;
 }
 
-Result
-CheckValidity(Time time, Time notBefore, Time notAfter)
-{
+Result CheckValidity(Time time, Time notBefore, Time notAfter) {
   if (time < notBefore) {
     return Result::ERROR_NOT_YET_VALID_CERTIFICATE;
   }
@@ -195,10 +185,9 @@ CheckValidity(Time time, Time notBefore, Time notAfter)
 
 // 4.1.2.7 Subject Public Key Info
 
-Result
-CheckSubjectPublicKeyInfoContents(Reader& input, TrustDomain& trustDomain,
-                                  EndEntityOrCA endEntityOrCA)
-{
+Result CheckSubjectPublicKeyInfoContents(Reader& input,
+                                         TrustDomain& trustDomain,
+                                         EndEntityOrCA endEntityOrCA) {
   // Here, we validate the syntax and do very basic semantic validation of the
   // public key of the certificate. The intention here is to filter out the
   // types of bad inputs that are most likely to trigger non-mathematical
@@ -236,15 +225,13 @@ CheckSubjectPublicKeyInfoContents(Reader& input, TrustDomain& trustDomain,
 
   // RFC 3279 Section 2.3.1
   // python DottedOIDToCode.py rsaEncryption 1.2.840.113549.1.1.1
-  static const uint8_t rsaEncryption[] = {
-    0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d, 0x01, 0x01, 0x01
-  };
+  static const uint8_t rsaEncryption[] = {0x2a, 0x86, 0x48, 0x86, 0xf7,
+                                          0x0d, 0x01, 0x01, 0x01};
 
   // RFC 3279 Section 2.3.5 and RFC 5480 Section 2.1.1
   // python DottedOIDToCode.py id-ecPublicKey 1.2.840.10045.2.1
-  static const uint8_t id_ecPublicKey[] = {
-    0x2a, 0x86, 0x48, 0xce, 0x3d, 0x02, 0x01
-  };
+  static const uint8_t id_ecPublicKey[] = {0x2a, 0x86, 0x48, 0xce,
+                                           0x3d, 0x02, 0x01};
 
   if (algorithmOID.MatchRest(id_ecPublicKey)) {
     // An id-ecPublicKey AlgorithmIdentifier has a parameter that identifes
@@ -253,29 +240,23 @@ CheckSubjectPublicKeyInfoContents(Reader& input, TrustDomain& trustDomain,
     // OID.
 
     Reader namedCurveOIDValue;
-    rv = der::ExpectTagAndGetValue(algorithm, der::OIDTag,
-                                   namedCurveOIDValue);
+    rv = der::ExpectTagAndGetValue(algorithm, der::OIDTag, namedCurveOIDValue);
     if (rv != Success) {
       return rv;
     }
 
     // RFC 5480
     // python DottedOIDToCode.py secp256r1 1.2.840.10045.3.1.7
-    static const uint8_t secp256r1[] = {
-      0x2a, 0x86, 0x48, 0xce, 0x3d, 0x03, 0x01, 0x07
-    };
+    static const uint8_t secp256r1[] = {0x2a, 0x86, 0x48, 0xce,
+                                        0x3d, 0x03, 0x01, 0x07};
 
     // RFC 5480
     // python DottedOIDToCode.py secp384r1 1.3.132.0.34
-    static const uint8_t secp384r1[] = {
-      0x2b, 0x81, 0x04, 0x00, 0x22
-    };
+    static const uint8_t secp384r1[] = {0x2b, 0x81, 0x04, 0x00, 0x22};
 
     // RFC 5480
     // python DottedOIDToCode.py secp521r1 1.3.132.0.35
-    static const uint8_t secp521r1[] = {
-      0x2b, 0x81, 0x04, 0x00, 0x23
-    };
+    static const uint8_t secp521r1[] = {0x2b, 0x81, 0x04, 0x00, 0x23};
 
     // Matching is attempted based on a rough estimate of the commonality of the
     // elliptic curve, to minimize the number of MatchRest calls.
@@ -337,24 +318,27 @@ CheckSubjectPublicKeyInfoContents(Reader& input, TrustDomain& trustDomain,
     //    publicExponent     INTEGER  }  --e
     rv = der::Nested(subjectPublicKeyReader, der::SEQUENCE,
                      [&trustDomain, endEntityOrCA](Reader& r) {
-      Input modulus;
-      Input::size_type modulusSignificantBytes;
-      Result rv = der::PositiveInteger(r, modulus, &modulusSignificantBytes);
-      if (rv != Success) {
-        return rv;
-      }
-      // XXX: Should we do additional checks of the modulus?
-      rv = trustDomain.CheckRSAPublicKeyModulusSizeInBits(
-             endEntityOrCA, modulusSignificantBytes * 8u);
-      if (rv != Success) {
-        return rv;
-      }
+                       Input modulus;
+                       Input::size_type modulusSignificantBytes;
+                       Result rv = der::PositiveInteger(
+                           r, modulus, &modulusSignificantBytes);
+                       if (rv != Success) {
+                         return rv;
+                       }
+                       // XXX: Should we do additional checks of the modulus?
+                       rv = trustDomain.CheckRSAPublicKeyModulusSizeInBits(
+                           endEntityOrCA, modulusSignificantBytes * 8u);
+                       if (rv != Success) {
+                         return rv;
+                       }
 
-      // XXX: We don't allow the TrustDomain to validate the exponent.
-      // XXX: We don't do our own sanity checking of the exponent.
-      Input exponent;
-      return der::PositiveInteger(r, exponent);
-    });
+                       // XXX: We don't allow the TrustDomain to validate the
+                       // exponent.
+                       // XXX: We don't do our own sanity checking of the
+                       // exponent.
+                       Input exponent;
+                       return der::PositiveInteger(r, exponent);
+                     });
     if (rv != Success) {
       return rv;
     }
@@ -374,10 +358,9 @@ CheckSubjectPublicKeyInfoContents(Reader& input, TrustDomain& trustDomain,
   return Success;
 }
 
-Result
-CheckSubjectPublicKeyInfo(Input subjectPublicKeyInfo, TrustDomain& trustDomain,
-                          EndEntityOrCA endEntityOrCA)
-{
+Result CheckSubjectPublicKeyInfo(Input subjectPublicKeyInfo,
+                                 TrustDomain& trustDomain,
+                                 EndEntityOrCA endEntityOrCA) {
   Reader spkiReader(subjectPublicKeyInfo);
   Result rv = der::Nested(spkiReader, der::SEQUENCE, [&](Reader& r) {
     return CheckSubjectPublicKeyInfoContents(r, trustDomain, endEntityOrCA);
@@ -392,16 +375,13 @@ CheckSubjectPublicKeyInfo(Input subjectPublicKeyInfo, TrustDomain& trustDomain,
 
 // As explained in the comment in CheckKeyUsage, bit 0 is the most significant
 // bit and bit 7 is the least significant bit.
-inline uint8_t KeyUsageToBitMask(KeyUsage keyUsage)
-{
+inline uint8_t KeyUsageToBitMask(KeyUsage keyUsage) {
   assert(keyUsage != KeyUsage::noParticularKeyUsageRequired);
   return 0x80u >> static_cast<uint8_t>(keyUsage);
 }
 
-Result
-CheckKeyUsage(EndEntityOrCA endEntityOrCA, const Input* encodedKeyUsage,
-              KeyUsage requiredKeyUsageIfPresent)
-{
+Result CheckKeyUsage(EndEntityOrCA endEntityOrCA, const Input* encodedKeyUsage,
+                     KeyUsage requiredKeyUsageIfPresent) {
   if (!encodedKeyUsage) {
     // TODO(bug 970196): Reject certificates that are being used to verify
     // certificate signatures unless the certificate is a trust anchor, to
@@ -515,16 +495,12 @@ CheckKeyUsage(EndEntityOrCA endEntityOrCA, const Input* encodedKeyUsage,
 //
 // python DottedOIDToCode.py anyPolicy 2.5.29.32.0
 
-static const uint8_t anyPolicy[] = {
-  0x55, 0x1d, 0x20, 0x00
-};
+static const uint8_t anyPolicy[] = {0x55, 0x1d, 0x20, 0x00};
 
 /*static*/ const CertPolicyId CertPolicyId::anyPolicy = {
-  4, { 0x55, 0x1d, 0x20, 0x00 }
-};
+    4, {0x55, 0x1d, 0x20, 0x00}};
 
-bool
-CertPolicyId::IsAnyPolicy() const {
+bool CertPolicyId::IsAnyPolicy() const {
   if (this == &CertPolicyId::anyPolicy) {
     return true;
   }
@@ -532,14 +508,17 @@ CertPolicyId::IsAnyPolicy() const {
          std::equal(bytes, bytes + numBytes, ::mozilla::pkix::anyPolicy);
 }
 
+bool CertPolicyId::operator==(const CertPolicyId& other) const {
+  return numBytes == other.numBytes &&
+         std::equal(bytes, bytes + numBytes, other.bytes);
+}
+
 // certificatePolicies ::= SEQUENCE SIZE (1..MAX) OF PolicyInformation
-Result
-CheckCertificatePolicies(EndEntityOrCA endEntityOrCA,
-                         const Input* encodedCertificatePolicies,
-                         const Input* encodedInhibitAnyPolicy,
-                         TrustLevel trustLevel,
-                         const CertPolicyId& requiredPolicy)
-{
+Result CheckCertificatePolicies(EndEntityOrCA endEntityOrCA,
+                                const Input* encodedCertificatePolicies,
+                                const Input* encodedInhibitAnyPolicy,
+                                TrustLevel trustLevel,
+                                const CertPolicyId& requiredPolicy) {
   if (requiredPolicy.numBytes == 0 ||
       requiredPolicy.numBytes > sizeof requiredPolicy.bytes) {
     return Result::FATAL_ERROR_INVALID_ARGS;
@@ -566,8 +545,8 @@ CheckCertificatePolicies(EndEntityOrCA endEntityOrCA,
   }
 
   Input requiredPolicyDER;
-  if (requiredPolicyDER.Init(requiredPolicy.bytes, requiredPolicy.numBytes)
-        != Success) {
+  if (requiredPolicyDER.Init(requiredPolicy.bytes, requiredPolicy.numBytes) !=
+      Success) {
     return Result::FATAL_ERROR_INVALID_ARGS;
   }
 
@@ -610,11 +589,11 @@ CheckCertificatePolicies(EndEntityOrCA endEntityOrCA,
       }
 
       // RFC 5280 Section 4.2.1.4 says "Optional qualifiers, which MAY be
-      // present, are not expected to change the definition of the policy." Also,
-      // it seems that Section 6, which defines validation, does not require any
-      // matching of qualifiers. Thus, doing anything with the policy qualifiers
-      // would be a waste of time and a source of potential incompatibilities, so
-      // we just ignore them.
+      // present, are not expected to change the definition of the policy."
+      // Also, it seems that Section 6, which defines validation, does not
+      // require any matching of qualifiers. Thus, doing anything with the
+      // policy qualifiers would be a waste of time and a source of potential
+      // incompatibilities, so we just ignore them.
     } while (!requiredPolicyFound && !certificatePolicies.AtEnd());
   }
 
@@ -625,36 +604,34 @@ CheckCertificatePolicies(EndEntityOrCA endEntityOrCA,
   return Success;
 }
 
-static const long UNLIMITED_PATH_LEN = -1; // must be less than zero
+static const long UNLIMITED_PATH_LEN = -1;  // must be less than zero
 
 //  BasicConstraints ::= SEQUENCE {
 //          cA                      BOOLEAN DEFAULT FALSE,
 //          pathLenConstraint       INTEGER (0..MAX) OPTIONAL }
 
 // RFC5280 4.2.1.9. Basic Constraints (id-ce-basicConstraints)
-Result
-CheckBasicConstraints(EndEntityOrCA endEntityOrCA,
-                      const Input* encodedBasicConstraints,
-                      const der::Version version, TrustLevel trustLevel,
-                      unsigned int subCACount)
-{
+Result CheckBasicConstraints(EndEntityOrCA endEntityOrCA,
+                             const Input* encodedBasicConstraints,
+                             const der::Version version, TrustLevel trustLevel,
+                             unsigned int subCACount) {
   bool isCA = false;
   long pathLenConstraint = UNLIMITED_PATH_LEN;
 
   if (encodedBasicConstraints) {
     Reader input(*encodedBasicConstraints);
-    Result rv = der::Nested(input, der::SEQUENCE,
-                            [&isCA, &pathLenConstraint](Reader& r) {
-      Result rv = der::OptionalBoolean(r, isCA);
-      if (rv != Success) {
-        return rv;
-      }
-      // TODO(bug 985025): If isCA is false, pathLenConstraint
-      // MUST NOT be included (as per RFC 5280 section
-      // 4.2.1.9), but for compatibility reasons, we don't
-      // check this.
-      return der::OptionalInteger(r, UNLIMITED_PATH_LEN, pathLenConstraint);
-    });
+    Result rv = der::Nested(
+        input, der::SEQUENCE, [&isCA, &pathLenConstraint](Reader& r) {
+          Result rv = der::OptionalBoolean(r, isCA);
+          if (rv != Success) {
+            return rv;
+          }
+          // TODO(bug 985025): If isCA is false, pathLenConstraint
+          // MUST NOT be included (as per RFC 5280 section
+          // 4.2.1.9), but for compatibility reasons, we don't
+          // check this.
+          return der::OptionalInteger(r, UNLIMITED_PATH_LEN, pathLenConstraint);
+        });
     if (rv != Success) {
       return Result::ERROR_EXTENSION_VALUE_INVALID;
     }
@@ -676,7 +653,8 @@ CheckBasicConstraints(EndEntityOrCA endEntityOrCA,
     // overrides for only this case), we return a different error code.
     //
     // TODO: add check for self-signedness?
-    if (endEntityOrCA == EndEntityOrCA::MustBeCA && version == der::Version::v1) {
+    if (endEntityOrCA == EndEntityOrCA::MustBeCA &&
+        version == der::Version::v1) {
       if (trustLevel == TrustLevel::TrustAnchor) {
         isCA = true;
       } else {
@@ -715,12 +693,10 @@ CheckBasicConstraints(EndEntityOrCA endEntityOrCA,
 
 // 4.2.1.12. Extended Key Usage (id-ce-extKeyUsage)
 
-static Result
-MatchEKU(Reader& value, KeyPurposeId requiredEKU,
-         EndEntityOrCA endEntityOrCA, TrustDomain& trustDomain,
-         Time notBefore, /*in/out*/ bool& found,
-         /*in/out*/ bool& foundOCSPSigning)
-{
+static Result MatchEKU(Reader& value, KeyPurposeId requiredEKU,
+                       EndEntityOrCA endEntityOrCA, TrustDomain& trustDomain,
+                       Time notBefore, /*in/out*/ bool& found,
+                       /*in/out*/ bool& foundOCSPSigning) {
   // See Section 5.9 of "A Layman's Guide to a Subset of ASN.1, BER, and DER"
   // for a description of ASN.1 DER encoding of OIDs.
 
@@ -733,17 +709,17 @@ MatchEKU(Reader& value, KeyPurposeId requiredEKU,
   // id-kp-codeSigning     OBJECT IDENTIFIER ::= { id-kp 3 }
   // id-kp-emailProtection OBJECT IDENTIFIER ::= { id-kp 4 }
   // id-kp-OCSPSigning     OBJECT IDENTIFIER ::= { id-kp 9 }
-  static const uint8_t server[] = { (40*1)+3, 6, 1, 5, 5, 7, 3, 1 };
-  static const uint8_t client[] = { (40*1)+3, 6, 1, 5, 5, 7, 3, 2 };
-  static const uint8_t code  [] = { (40*1)+3, 6, 1, 5, 5, 7, 3, 3 };
-  static const uint8_t email [] = { (40*1)+3, 6, 1, 5, 5, 7, 3, 4 };
-  static const uint8_t ocsp  [] = { (40*1)+3, 6, 1, 5, 5, 7, 3, 9 };
+  static const uint8_t server[] = {(40 * 1) + 3, 6, 1, 5, 5, 7, 3, 1};
+  static const uint8_t client[] = {(40 * 1) + 3, 6, 1, 5, 5, 7, 3, 2};
+  static const uint8_t code[] = {(40 * 1) + 3, 6, 1, 5, 5, 7, 3, 3};
+  static const uint8_t email[] = {(40 * 1) + 3, 6, 1, 5, 5, 7, 3, 4};
+  static const uint8_t ocsp[] = {(40 * 1) + 3, 6, 1, 5, 5, 7, 3, 9};
 
   // id-Netscape        OBJECT IDENTIFIER ::= { 2 16 840 1 113730 }
   // id-Netscape-policy OBJECT IDENTIFIER ::= { id-Netscape 4 }
   // id-Netscape-stepUp OBJECT IDENTIFIER ::= { id-Netscape-policy 1 }
-  static const uint8_t serverStepUp[] =
-    { (40*2)+16, 128+6,72, 1, 128+6,128+120,66, 4, 1 };
+  static const uint8_t serverStepUp[] = {(40 * 2) + 16, 128 + 6, 72, 1, 128 + 6,
+                                         128 + 120,     66,      4,  1};
 
   bool match = false;
 
@@ -759,8 +735,8 @@ MatchEKU(Reader& value, KeyPurposeId requiredEKU,
         // don't expire until June 2020!
         if (endEntityOrCA == EndEntityOrCA::MustBeCA &&
             value.MatchRest(serverStepUp)) {
-          Result rv = trustDomain.NetscapeStepUpMatchesServerAuth(notBefore,
-                                                                  match);
+          Result rv =
+              trustDomain.NetscapeStepUpMatchesServerAuth(notBefore, match);
           if (rv != Success) {
             return rv;
           }
@@ -799,17 +775,15 @@ MatchEKU(Reader& value, KeyPurposeId requiredEKU,
     foundOCSPSigning = true;
   }
 
-  value.SkipToEnd(); // ignore unmatched OIDs.
+  value.SkipToEnd();  // ignore unmatched OIDs.
 
   return Success;
 }
 
-Result
-CheckExtendedKeyUsage(EndEntityOrCA endEntityOrCA,
-                      const Input* encodedExtendedKeyUsage,
-                      KeyPurposeId requiredEKU, TrustDomain& trustDomain,
-                      Time notBefore)
-{
+Result CheckExtendedKeyUsage(EndEntityOrCA endEntityOrCA,
+                             const Input* encodedExtendedKeyUsage,
+                             KeyPurposeId requiredEKU, TrustDomain& trustDomain,
+                             Time notBefore) {
   // XXX: We're using Result::ERROR_INADEQUATE_CERT_TYPE here so that callers
   // can distinguish EKU mismatch from KU mismatch from basic constraints
   // mismatch. We should probably add a new error code that is more clear for
@@ -823,9 +797,10 @@ CheckExtendedKeyUsage(EndEntityOrCA endEntityOrCA,
     Reader input(*encodedExtendedKeyUsage);
     Result rv = der::NestedOf(input, der::SEQUENCE, der::OIDTag,
                               der::EmptyAllowed::No, [&](Reader& r) {
-      return MatchEKU(r, requiredEKU, endEntityOrCA, trustDomain, notBefore,
-                      found, foundOCSPSigning);
-    });
+                                return MatchEKU(r, requiredEKU, endEntityOrCA,
+                                                trustDomain, notBefore, found,
+                                                foundOCSPSigning);
+                              });
     if (rv != Success) {
       return Result::ERROR_INADEQUATE_CERT_TYPE;
     }
@@ -875,17 +850,14 @@ CheckExtendedKeyUsage(EndEntityOrCA endEntityOrCA,
   return Success;
 }
 
-Result
-CheckTLSFeatures(const BackCert& subject, BackCert& potentialIssuer)
-{
+Result CheckTLSFeatures(const BackCert& subject, BackCert& potentialIssuer) {
   const Input* issuerTLSFeatures = potentialIssuer.GetRequiredTLSFeatures();
   if (!issuerTLSFeatures) {
     return Success;
   }
 
   const Input* subjectTLSFeatures = subject.GetRequiredTLSFeatures();
-  if (issuerTLSFeatures->GetLength() == 0 ||
-      !subjectTLSFeatures ||
+  if (issuerTLSFeatures->GetLength() == 0 || !subjectTLSFeatures ||
       !InputsAreEqual(*issuerTLSFeatures, *subjectTLSFeatures)) {
     return Result::ERROR_REQUIRED_TLS_FEATURE_MISSING;
   }
@@ -893,37 +865,33 @@ CheckTLSFeatures(const BackCert& subject, BackCert& potentialIssuer)
   return Success;
 }
 
-Result
-TLSFeaturesSatisfiedInternal(const Input* requiredTLSFeatures,
-                             const Input* stapledOCSPResponse)
-{
+Result TLSFeaturesSatisfiedInternal(const Input* requiredTLSFeatures,
+                                    const Input* stapledOCSPResponse) {
   if (!requiredTLSFeatures) {
     return Success;
   }
 
   // RFC 6066 10.2: ExtensionType status_request
   const static uint8_t status_request = 5;
-  const static uint8_t status_request_bytes[] = { status_request };
+  const static uint8_t status_request_bytes[] = {status_request};
 
   Reader input(*requiredTLSFeatures);
   return der::NestedOf(input, der::SEQUENCE, der::INTEGER,
                        der::EmptyAllowed::No, [&](Reader& r) {
-    if (!r.MatchRest(status_request_bytes)) {
-      return Result::ERROR_REQUIRED_TLS_FEATURE_MISSING;
-    }
+                         if (!r.MatchRest(status_request_bytes)) {
+                           return Result::ERROR_REQUIRED_TLS_FEATURE_MISSING;
+                         }
 
-    if (!stapledOCSPResponse) {
-      return Result::ERROR_REQUIRED_TLS_FEATURE_MISSING;
-    }
+                         if (!stapledOCSPResponse) {
+                           return Result::ERROR_REQUIRED_TLS_FEATURE_MISSING;
+                         }
 
-    return Result::Success;
-  });
+                         return Result::Success;
+                       });
 }
 
-Result
-CheckTLSFeaturesAreSatisfied(Input& cert,
-                             const Input* stapledOCSPResponse)
-{
+Result CheckTLSFeaturesAreSatisfied(Input& cert,
+                                    const Input* stapledOCSPResponse) {
   BackCert backCert(cert, EndEntityOrCA::MustBeEndEntity, nullptr);
   Result rv = backCert.Init();
   if (rv != Success) {
@@ -934,16 +902,13 @@ CheckTLSFeaturesAreSatisfied(Input& cert,
                                       stapledOCSPResponse);
 }
 
-Result
-CheckIssuerIndependentProperties(TrustDomain& trustDomain,
-                                 const BackCert& cert,
-                                 Time time,
-                                 KeyUsage requiredKeyUsageIfPresent,
-                                 KeyPurposeId requiredEKUIfPresent,
-                                 const CertPolicyId& requiredPolicy,
-                                 unsigned int subCACount,
-                                 /*out*/ TrustLevel& trustLevel)
-{
+Result CheckIssuerIndependentProperties(TrustDomain& trustDomain,
+                                        const BackCert& cert, Time time,
+                                        KeyUsage requiredKeyUsageIfPresent,
+                                        KeyPurposeId requiredEKUIfPresent,
+                                        const CertPolicyId& requiredPolicy,
+                                        unsigned int subCACount,
+                                        /*out*/ TrustLevel& trustLevel) {
   Result rv;
 
   const EndEntityOrCA endEntityOrCA = cert.endEntityOrCA;
@@ -1085,4 +1050,5 @@ CheckIssuerIndependentProperties(TrustDomain& trustDomain,
   return Success;
 }
 
-} } // namespace mozilla::pkix
+}  // namespace pkix
+}  // namespace mozilla
