@@ -40,23 +40,20 @@
 #include "pkix/Input.h"
 #include "pkix/pkixtypes.h"
 
-namespace mozilla { namespace pkix { namespace der {
+namespace mozilla {
+namespace pkix {
+namespace der {
 
-enum Class : uint8_t
-{
-   UNIVERSAL = 0 << 6,
-// APPLICATION = 1 << 6, // unused
-   CONTEXT_SPECIFIC = 2 << 6,
-// PRIVATE = 3 << 6 // unused
+enum Class : uint8_t {
+  UNIVERSAL = 0 << 6,
+  // APPLICATION = 1 << 6, // unused
+  CONTEXT_SPECIFIC = 2 << 6,
+  // PRIVATE = 3 << 6 // unused
 };
 
-enum Constructed
-{
-  CONSTRUCTED = 1 << 5
-};
+enum Constructed { CONSTRUCTED = 1 << 5 };
 
-enum Tag : uint8_t
-{
+enum Tag : uint8_t {
   BOOLEAN = UNIVERSAL | 0x01,
   INTEGER = UNIVERSAL | 0x02,
   BIT_STRING = UNIVERSAL | 0x03,
@@ -65,8 +62,8 @@ enum Tag : uint8_t
   OIDTag = UNIVERSAL | 0x06,
   ENUMERATED = UNIVERSAL | 0x0a,
   UTF8String = UNIVERSAL | 0x0c,
-  SEQUENCE = UNIVERSAL | CONSTRUCTED | 0x10, // 0x30
-  SET = UNIVERSAL | CONSTRUCTED | 0x11, // 0x31
+  SEQUENCE = UNIVERSAL | CONSTRUCTED | 0x10,  // 0x30
+  SET = UNIVERSAL | CONSTRUCTED | 0x11,       // 0x31
   PrintableString = UNIVERSAL | 0x13,
   TeletexString = UNIVERSAL | 0x14,
   IA5String = UNIVERSAL | 0x16,
@@ -80,9 +77,8 @@ Result ReadTagAndGetValue(Reader& input, /*out*/ uint8_t& tag,
                           /*out*/ Input& value);
 Result End(Reader& input);
 
-inline Result
-ExpectTagAndGetValue(Reader& input, uint8_t tag, /*out*/ Input& value)
-{
+inline Result ExpectTagAndGetValue(Reader& input, uint8_t tag,
+                                   /*out*/ Input& value) {
   uint8_t actualTag;
   Result rv = ReadTagAndGetValue(input, actualTag, value);
   if (rv != Success) {
@@ -94,9 +90,8 @@ ExpectTagAndGetValue(Reader& input, uint8_t tag, /*out*/ Input& value)
   return Success;
 }
 
-inline Result
-ExpectTagAndGetValue(Reader& input, uint8_t tag, /*out*/ Reader& value)
-{
+inline Result ExpectTagAndGetValue(Reader& input, uint8_t tag,
+                                   /*out*/ Reader& value) {
   Input valueInput;
   Result rv = ExpectTagAndGetValue(input, tag, valueInput);
   if (rv != Success) {
@@ -105,9 +100,7 @@ ExpectTagAndGetValue(Reader& input, uint8_t tag, /*out*/ Reader& value)
   return value.Init(valueInput);
 }
 
-inline Result
-ExpectTagAndEmptyValue(Reader& input, uint8_t tag)
-{
+inline Result ExpectTagAndEmptyValue(Reader& input, uint8_t tag) {
   Reader value;
   Result rv = ExpectTagAndGetValue(input, tag, value);
   if (rv != Success) {
@@ -116,18 +109,15 @@ ExpectTagAndEmptyValue(Reader& input, uint8_t tag)
   return End(value);
 }
 
-inline Result
-ExpectTagAndSkipValue(Reader& input, uint8_t tag)
-{
+inline Result ExpectTagAndSkipValue(Reader& input, uint8_t tag) {
   Input ignoredValue;
   return ExpectTagAndGetValue(input, tag, ignoredValue);
 }
 
 // Like ExpectTagAndGetValue, except the output Input will contain the
 // encoded tag and length along with the value.
-inline Result
-ExpectTagAndGetTLV(Reader& input, uint8_t tag, /*out*/ Input& tlv)
-{
+inline Result ExpectTagAndGetTLV(Reader& input, uint8_t tag,
+                                 /*out*/ Input& tlv) {
   Reader::Mark mark(input.GetMark());
   Result rv = ExpectTagAndSkipValue(input, tag);
   if (rv != Success) {
@@ -136,9 +126,7 @@ ExpectTagAndGetTLV(Reader& input, uint8_t tag, /*out*/ Input& tlv)
   return input.GetInput(mark, tlv);
 }
 
-inline Result
-End(Reader& input)
-{
+inline Result End(Reader& input) {
   if (!input.AtEnd()) {
     return Result::ERROR_BAD_DER;
   }
@@ -147,9 +135,7 @@ End(Reader& input)
 }
 
 template <typename Decoder>
-inline Result
-Nested(Reader& input, uint8_t tag, Decoder decoder)
-{
+inline Result Nested(Reader& input, uint8_t tag, Decoder decoder) {
   Reader nested;
   Result rv = ExpectTagAndGetValue(input, tag, nested);
   if (rv != Success) {
@@ -163,9 +149,8 @@ Nested(Reader& input, uint8_t tag, Decoder decoder)
 }
 
 template <typename Decoder>
-inline Result
-Nested(Reader& input, uint8_t outerTag, uint8_t innerTag, Decoder decoder)
-{
+inline Result Nested(Reader& input, uint8_t outerTag, uint8_t innerTag,
+                     Decoder decoder) {
   Reader nestedInput;
   Result rv = ExpectTagAndGetValue(input, outerTag, nestedInput);
   if (rv != Success) {
@@ -206,10 +191,8 @@ Nested(Reader& input, uint8_t outerTag, uint8_t innerTag, Decoder decoder)
 // foos.
 //
 template <typename Decoder>
-inline Result
-NestedOf(Reader& input, uint8_t outerTag, uint8_t innerTag,
-         EmptyAllowed mayBeEmpty, Decoder decoder)
-{
+inline Result NestedOf(Reader& input, uint8_t outerTag, uint8_t innerTag,
+                       EmptyAllowed mayBeEmpty, Decoder decoder) {
   Reader inner;
   Result rv = ExpectTagAndGetValue(input, outerTag, inner);
   if (rv != Success) {
@@ -237,10 +220,8 @@ NestedOf(Reader& input, uint8_t outerTag, uint8_t innerTag,
 // DER-encoded data wrapped in a SEQUENCE (or similar) with nothing after it.
 // This function reduces the boilerplate necessary for stripping the outermost
 // SEQUENCE (or similar) and ensuring that nothing follows it.
-inline Result
-ExpectTagAndGetValueAtEnd(Reader& outer, uint8_t expectedTag,
-                          /*out*/ Reader& inner)
-{
+inline Result ExpectTagAndGetValueAtEnd(Reader& outer, uint8_t expectedTag,
+                                        /*out*/ Reader& inner) {
   Result rv = der::ExpectTagAndGetValue(outer, expectedTag, inner);
   if (rv != Success) {
     return rv;
@@ -249,10 +230,8 @@ ExpectTagAndGetValueAtEnd(Reader& outer, uint8_t expectedTag,
 }
 
 // Similar to the above, but takes an Input instead of a Reader&.
-inline Result
-ExpectTagAndGetValueAtEnd(Input outer, uint8_t expectedTag,
-                          /*out*/ Reader& inner)
-{
+inline Result ExpectTagAndGetValueAtEnd(Input outer, uint8_t expectedTag,
+                                        /*out*/ Reader& inner) {
   Reader outerReader(outer);
   return ExpectTagAndGetValueAtEnd(outerReader, expectedTag, inner);
 }
@@ -261,30 +240,26 @@ ExpectTagAndGetValueAtEnd(Input outer, uint8_t expectedTag,
 
 namespace internal {
 
-enum class IntegralValueRestriction
-{
+enum class IntegralValueRestriction {
   NoRestriction,
   MustBePositive,
   MustBe0To127,
 };
 
-Result IntegralBytes(Reader& input, uint8_t tag,
-                     IntegralValueRestriction valueRestriction,
-             /*out*/ Input& value,
+Result IntegralBytes(
+    Reader& input, uint8_t tag, IntegralValueRestriction valueRestriction,
+    /*out*/ Input& value,
     /*optional out*/ Input::size_type* significantBytes = nullptr);
 
 // This parser will only parse values between 0..127. If this range is
 // increased then callers will need to be changed.
 Result IntegralValue(Reader& input, uint8_t tag, /*out*/ uint8_t& value);
 
-} // namespace internal
+}  // namespace internal
 
-Result
-BitStringWithNoUnusedBits(Reader& input, /*out*/ Input& value);
+Result BitStringWithNoUnusedBits(Reader& input, /*out*/ Input& value);
 
-inline Result
-Boolean(Reader& input, /*out*/ bool& value)
-{
+inline Result Boolean(Reader& input, /*out*/ bool& value) {
   Reader valueReader;
   Result rv = ExpectTagAndGetValue(input, BOOLEAN, valueReader);
   if (rv != Success) {
@@ -301,8 +276,12 @@ Boolean(Reader& input, /*out*/ bool& value)
     return rv;
   }
   switch (intValue) {
-    case 0: value = false; return Success;
-    case 0xFF: value = true; return Success;
+    case 0:
+      value = false;
+      return Success;
+    case 0xFF:
+      value = true;
+      return Success;
     default:
       return Result::ERROR_BAD_DER;
   }
@@ -314,9 +293,7 @@ Boolean(Reader& input, /*out*/ bool& value)
 // default value." However, it appears to be common that other libraries
 // incorrectly include the value of a BOOLEAN even when it's equal to the
 // default value, so we allow invalid explicit encodings here.
-inline Result
-OptionalBoolean(Reader& input, /*out*/ bool& value)
-{
+inline Result OptionalBoolean(Reader& input, /*out*/ bool& value) {
   value = false;
   if (input.Peek(BOOLEAN)) {
     Result rv = Boolean(input, value);
@@ -329,9 +306,7 @@ OptionalBoolean(Reader& input, /*out*/ bool& value)
 
 // This parser will only parse values between 0..127. If this range is
 // increased then callers will need to be changed.
-inline Result
-Enumerated(Reader& input, uint8_t& value)
-{
+inline Result Enumerated(Reader& input, uint8_t& value) {
   return internal::IntegralValue(input, ENUMERATED | 0, value);
 }
 
@@ -345,23 +320,19 @@ namespace internal {
 // time formats that start at 1970.
 Result TimeChoice(Reader& input, uint8_t tag, /*out*/ Time& time);
 
-} // namespace internal
+}  // namespace internal
 
 // Only times from 1970-01-01-00:00:00 onward are accepted, in order to
 // eliminate the chance for complications in converting times to traditional
 // time formats that start at 1970.
-inline Result
-GeneralizedTime(Reader& input, /*out*/ Time& time)
-{
+inline Result GeneralizedTime(Reader& input, /*out*/ Time& time) {
   return internal::TimeChoice(input, GENERALIZED_TIME, time);
 }
 
 // Only times from 1970-01-01-00:00:00 onward are accepted, in order to
 // eliminate the chance for complications in converting times to traditional
 // time formats that start at 1970.
-inline Result
-TimeChoice(Reader& input, /*out*/ Time& time)
-{
+inline Result TimeChoice(Reader& input, /*out*/ Time& time) {
   uint8_t expectedTag = input.Peek(UTCTime) ? UTCTime : GENERALIZED_TIME;
   return internal::TimeChoice(input, expectedTag, time);
 }
@@ -370,20 +341,17 @@ TimeChoice(Reader& input, /*out*/ Time& time)
 // zero are rejected. If significantBytes is not null, then it will be set to
 // the number of significant bytes in the value (the length of the value, less
 // the length of any leading padding), which is useful for key size checks.
-inline Result
-PositiveInteger(Reader& input, /*out*/ Input& value,
-                /*optional out*/ Input::size_type* significantBytes = nullptr)
-{
+inline Result PositiveInteger(
+    Reader& input, /*out*/ Input& value,
+    /*optional out*/ Input::size_type* significantBytes = nullptr) {
   return internal::IntegralBytes(
-           input, INTEGER, internal::IntegralValueRestriction::MustBePositive,
-           value, significantBytes);
+      input, INTEGER, internal::IntegralValueRestriction::MustBePositive, value,
+      significantBytes);
 }
 
 // This parser will only parse values between 0..127. If this range is
 // increased then callers will need to be changed.
-inline Result
-Integer(Reader& input, /*out*/ uint8_t& value)
-{
+inline Result Integer(Reader& input, /*out*/ uint8_t& value) {
   return internal::IntegralValue(input, INTEGER, value);
 }
 
@@ -391,9 +359,8 @@ Integer(Reader& input, /*out*/ uint8_t& value)
 // increased then callers will need to be changed. The default value must be
 // -1; defaultValue is only a parameter to make it clear in the calling code
 // what the default value is.
-inline Result
-OptionalInteger(Reader& input, long defaultValue, /*out*/ long& value)
-{
+inline Result OptionalInteger(Reader& input, long defaultValue,
+                              /*out*/ long& value) {
   // If we need to support a different default value in the future, we need to
   // test that parsedValue != defaultValue.
   if (defaultValue != -1) {
@@ -414,16 +381,12 @@ OptionalInteger(Reader& input, long defaultValue, /*out*/ long& value)
   return Success;
 }
 
-inline Result
-Null(Reader& input)
-{
+inline Result Null(Reader& input) {
   return ExpectTagAndEmptyValue(input, NULLTag);
 }
 
 template <uint8_t Len>
-Result
-OID(Reader& input, const uint8_t (&expectedOid)[Len])
-{
+Result OID(Reader& input, const uint8_t (&expectedOid)[Len]) {
   Reader value;
   Result rv = ExpectTagAndGetValue(input, OIDTag, value);
   if (rv != Success) {
@@ -437,9 +400,7 @@ OID(Reader& input, const uint8_t (&expectedOid)[Len])
 
 // PKI-specific types
 
-inline Result
-CertificateSerialNumber(Reader& input, /*out*/ Input& value)
-{
+inline Result CertificateSerialNumber(Reader& input, /*out*/ Input& value) {
   // http://tools.ietf.org/html/rfc5280#section-4.1.2.2:
   //
   // * "The serial number MUST be a positive integer assigned by the CA to
@@ -451,8 +412,7 @@ CertificateSerialNumber(Reader& input, /*out*/ Input& value)
   //   that are negative or zero.  Certificate users SHOULD be prepared to
   //   gracefully handle such certificates."
   return internal::IntegralBytes(
-           input, INTEGER, internal::IntegralValueRestriction::NoRestriction,
-           value);
+      input, INTEGER, internal::IntegralValueRestriction::NoRestriction, value);
 }
 
 // x.509 and OCSP both use this same version numbering scheme, though OCSP
@@ -466,10 +426,8 @@ enum class Version { v1 = 0, v2 = 1, v3 = 2, v4 = 3 };
 Result OptionalVersion(Reader& input, /*out*/ Version& version);
 
 template <typename ExtensionHandler>
-inline Result
-OptionalExtensions(Reader& input, uint8_t tag,
-                   ExtensionHandler extensionHandler)
-{
+inline Result OptionalExtensions(Reader& input, uint8_t tag,
+                                 ExtensionHandler extensionHandler) {
   if (!input.Peek(tag)) {
     return Success;
   }
@@ -480,58 +438,57 @@ OptionalExtensions(Reader& input, uint8_t tag,
     // TODO(bug 997994): According to the specification, there should never be
     // an empty sequence of extensions but we've found OCSP responses that have
     // that (see bug 991898).
-    return NestedOf(tagged, SEQUENCE, SEQUENCE, EmptyAllowed::Yes,
-                    [extensionHandler](Reader& extension) -> Result {
-      // Extension  ::=  SEQUENCE  {
-      //      extnID      OBJECT IDENTIFIER,
-      //      critical    BOOLEAN DEFAULT FALSE,
-      //      extnValue   OCTET STRING
-      //      }
-      Reader extnID;
-      Result rv = ExpectTagAndGetValue(extension, OIDTag, extnID);
-      if (rv != Success) {
-        return rv;
-      }
-      bool critical;
-      rv = OptionalBoolean(extension, critical);
-      if (rv != Success) {
-        return rv;
-      }
-      Input extnValue;
-      rv = ExpectTagAndGetValue(extension, OCTET_STRING, extnValue);
-      if (rv != Success) {
-        return rv;
-      }
-      bool understood = false;
-      rv = extensionHandler(extnID, extnValue, critical, understood);
-      if (rv != Success) {
-        return rv;
-      }
-      if (critical && !understood) {
-        return Result::ERROR_UNKNOWN_CRITICAL_EXTENSION;
-      }
-      return Success;
-    });
+    return NestedOf(
+        tagged, SEQUENCE, SEQUENCE, EmptyAllowed::Yes,
+        [extensionHandler](Reader& extension) -> Result {
+          // Extension  ::=  SEQUENCE  {
+          //      extnID      OBJECT IDENTIFIER,
+          //      critical    BOOLEAN DEFAULT FALSE,
+          //      extnValue   OCTET STRING
+          //      }
+          Reader extnID;
+          Result rv = ExpectTagAndGetValue(extension, OIDTag, extnID);
+          if (rv != Success) {
+            return rv;
+          }
+          bool critical;
+          rv = OptionalBoolean(extension, critical);
+          if (rv != Success) {
+            return rv;
+          }
+          Input extnValue;
+          rv = ExpectTagAndGetValue(extension, OCTET_STRING, extnValue);
+          if (rv != Success) {
+            return rv;
+          }
+          bool understood = false;
+          rv = extensionHandler(extnID, extnValue, critical, understood);
+          if (rv != Success) {
+            return rv;
+          }
+          if (critical && !understood) {
+            return Result::ERROR_UNKNOWN_CRITICAL_EXTENSION;
+          }
+          return Success;
+        });
   });
 }
 
 Result DigestAlgorithmIdentifier(Reader& input,
                                  /*out*/ DigestAlgorithm& algorithm);
 
-enum class PublicKeyAlgorithm
-{
+enum class PublicKeyAlgorithm {
   RSA_PKCS1,
   ECDSA,
 };
 
 Result SignatureAlgorithmIdentifierValue(
-         Reader& input,
-         /*out*/ PublicKeyAlgorithm& publicKeyAlgorithm,
-         /*out*/ DigestAlgorithm& digestAlgorithm);
+    Reader& input,
+    /*out*/ PublicKeyAlgorithm& publicKeyAlgorithm,
+    /*out*/ DigestAlgorithm& digestAlgorithm);
 
-struct SignedDataWithSignature final
-{
-public:
+struct SignedDataWithSignature final {
+ public:
   Input data;
   Input algorithm;
   Input signature;
@@ -560,6 +517,8 @@ public:
 Result SignedData(Reader& input, /*out*/ Reader& tbs,
                   /*out*/ SignedDataWithSignature& signedDataWithSignature);
 
-} } } // namespace mozilla::pkix::der
+}  // namespace der
+}  // namespace pkix
+}  // namespace mozilla
 
-#endif // mozilla_pkix_pkixder_h
+#endif  // mozilla_pkix_pkixder_h
