@@ -32,9 +32,10 @@ namespace {
 
 const size_t SHA1_DIGEST_LENGTH = 160 / 8;
 
-} // namespace
+}  // namespace
 
-namespace mozilla { namespace pkix {
+namespace mozilla {
+namespace pkix {
 
 // These values correspond to the tag values in the ASN.1 CertStatus
 enum class CertStatus : uint8_t {
@@ -43,22 +44,20 @@ enum class CertStatus : uint8_t {
   Unknown = der::CONTEXT_SPECIFIC | 2
 };
 
-class Context final
-{
-public:
+class Context final {
+ public:
   Context(TrustDomain& trustDomain, const CertID& certID, Time time,
           uint16_t maxLifetimeInDays, /*optional out*/ Time* thisUpdate,
           /*optional out*/ Time* validThrough)
-    : trustDomain(trustDomain)
-    , certID(certID)
-    , time(time)
-    , maxLifetimeInDays(maxLifetimeInDays)
-    , certStatus(CertStatus::Unknown)
-    , thisUpdate(thisUpdate)
-    , validThrough(validThrough)
-    , expired(false)
-    , matchFound(false)
-  {
+      : trustDomain(trustDomain),
+        certID(certID),
+        time(time),
+        maxLifetimeInDays(maxLifetimeInDays),
+        certStatus(CertStatus::Unknown),
+        thisUpdate(thisUpdate),
+        validThrough(validThrough),
+        expired(false),
+        matchFound(false) {
     if (thisUpdate) {
       *thisUpdate = TimeFromElapsedSecondsAD(0);
     }
@@ -90,13 +89,11 @@ public:
 
 // Verify that potentialSigner is a valid delegated OCSP response signing cert
 // according to RFC 6960 section 4.2.2.2.
-static Result
-CheckOCSPResponseSignerCert(TrustDomain& trustDomain,
-                            BackCert& potentialSigner,
-                            Input issuerSubject,
-                            Input issuerSubjectPublicKeyInfo,
-                            Time time)
-{
+static Result CheckOCSPResponseSignerCert(TrustDomain& trustDomain,
+                                          BackCert& potentialSigner,
+                                          Input issuerSubject,
+                                          Input issuerSubjectPublicKeyInfo,
+                                          Time time) {
   Result rv;
 
   // We don't need to do a complete verification of the signer (i.e. we don't
@@ -123,11 +120,10 @@ CheckOCSPResponseSignerCert(TrustDomain& trustDomain,
   // TODO(bug 926261): If we're validating for a policy then the policy OID we
   // are validating for should be passed to CheckIssuerIndependentProperties.
   TrustLevel unusedTrustLevel;
-  rv = CheckIssuerIndependentProperties(trustDomain, potentialSigner, time,
-                                        KeyUsage::noParticularKeyUsageRequired,
-                                        KeyPurposeId::id_kp_OCSPSigning,
-                                        CertPolicyId::anyPolicy, 0,
-                                        unusedTrustLevel);
+  rv = CheckIssuerIndependentProperties(
+      trustDomain, potentialSigner, time,
+      KeyUsage::noParticularKeyUsageRequired, KeyPurposeId::id_kp_OCSPSigning,
+      CertPolicyId::anyPolicy, 0, unusedTrustLevel);
   if (rv != Success) {
     return rv;
   }
@@ -146,15 +142,14 @@ CheckOCSPResponseSignerCert(TrustDomain& trustDomain,
   rv = VerifySignedData(trustDomain, potentialSigner.GetSignedData(),
                         issuerSubjectPublicKeyInfo);
 
-  // TODO: check for revocation of the OCSP responder certificate unless no-check
-  // or the caller forcing no-check. To properly support the no-check policy, we'd
-  // need to enforce policy constraints from the issuerChain.
+  // TODO: check for revocation of the OCSP responder certificate unless
+  // no-check or the caller forcing no-check. To properly support the no-check
+  // policy, we'd need to enforce policy constraints from the issuerChain.
 
   return rv;
 }
 
-enum class ResponderIDType : uint8_t
-{
+enum class ResponderIDType : uint8_t {
   byName = der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 1,
   byKey = der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 2
 };
@@ -163,35 +158,28 @@ static inline Result OCSPResponse(Reader&, Context&);
 static inline Result ResponseBytes(Reader&, Context&);
 static inline Result BasicResponse(Reader&, Context&);
 static inline Result ResponseData(
-                       Reader& tbsResponseData,
-                       Context& context,
-                       const der::SignedDataWithSignature& signedResponseData,
-                       const DERArray& certs);
+    Reader& tbsResponseData, Context& context,
+    const der::SignedDataWithSignature& signedResponseData,
+    const DERArray& certs);
 static inline Result SingleResponse(Reader& input, Context& context);
 static Result ExtensionNotUnderstood(Reader& extnID, Input extnValue,
                                      bool critical, /*out*/ bool& understood);
 static Result RememberSingleExtension(Context& context, Reader& extnID,
                                       Input extnValue, bool critical,
                                       /*out*/ bool& understood);
-static inline Result CertID(Reader& input,
-                            const Context& context,
+static inline Result CertID(Reader& input, const Context& context,
                             /*out*/ bool& match);
-static Result MatchKeyHash(TrustDomain& trustDomain,
-                           Input issuerKeyHash,
+static Result MatchKeyHash(TrustDomain& trustDomain, Input issuerKeyHash,
                            Input issuerSubjectPublicKeyInfo,
                            /*out*/ bool& match);
-static Result KeyHash(TrustDomain& trustDomain,
-                      Input subjectPublicKeyInfo,
+static Result KeyHash(TrustDomain& trustDomain, Input subjectPublicKeyInfo,
                       /*out*/ uint8_t* hashBuf, size_t hashBufSize);
 
-static Result
-MatchResponderID(TrustDomain& trustDomain,
-                 ResponderIDType responderIDType,
-                 Input responderID,
-                 Input potentialSignerSubject,
-                 Input potentialSignerSubjectPublicKeyInfo,
-                 /*out*/ bool& match)
-{
+static Result MatchResponderID(TrustDomain& trustDomain,
+                               ResponderIDType responderIDType,
+                               Input responderID, Input potentialSignerSubject,
+                               Input potentialSignerSubjectPublicKeyInfo,
+                               /*out*/ bool& match) {
   match = false;
 
   switch (responderIDType) {
@@ -201,8 +189,7 @@ MatchResponderID(TrustDomain& trustDomain,
       match = InputsAreEqual(responderID, potentialSignerSubject);
       return Success;
 
-    case ResponderIDType::byKey:
-    {
+    case ResponderIDType::byKey: {
       Reader input(responderID);
       Input keyHash;
       Result rv = der::ExpectTagAndGetValue(input, der::OCTET_STRING, keyHash);
@@ -213,15 +200,13 @@ MatchResponderID(TrustDomain& trustDomain,
                           potentialSignerSubjectPublicKeyInfo, match);
     }
 
-    MOZILLA_PKIX_UNREACHABLE_DEFAULT_ENUM
+      MOZILLA_PKIX_UNREACHABLE_DEFAULT_ENUM
   }
 }
 
-static Result
-VerifyOCSPSignedData(TrustDomain& trustDomain,
-                     const der::SignedDataWithSignature& signedResponseData,
-                     Input spki)
-{
+static Result VerifyOCSPSignedData(
+    TrustDomain& trustDomain,
+    const der::SignedDataWithSignature& signedResponseData, Input spki) {
   Result rv = VerifySignedData(trustDomain, signedResponseData, spki);
   if (rv == Result::ERROR_BAD_SIGNATURE) {
     rv = Result::ERROR_OCSP_BAD_SIGNATURE;
@@ -235,16 +220,14 @@ VerifyOCSPSignedData(TrustDomain& trustDomain,
 // signer, then its certificate is (probably) embedded within the OCSP
 // response and we'll need to verify that it is a valid certificate that chains
 // *directly* to issuerCert.
-static Result
-VerifySignature(Context& context, ResponderIDType responderIDType,
-                Input responderID, const DERArray& certs,
-                const der::SignedDataWithSignature& signedResponseData)
-{
+static Result VerifySignature(
+    Context& context, ResponderIDType responderIDType, Input responderID,
+    const DERArray& certs,
+    const der::SignedDataWithSignature& signedResponseData) {
   bool match;
-  Result rv = MatchResponderID(context.trustDomain, responderIDType,
-                               responderID, context.certID.issuer,
-                               context.certID.issuerSubjectPublicKeyInfo,
-                               match);
+  Result rv = MatchResponderID(
+      context.trustDomain, responderIDType, responderID, context.certID.issuer,
+      context.certID.issuerSubjectPublicKeyInfo, match);
   if (rv != Success) {
     return rv;
   }
@@ -271,10 +254,9 @@ VerifySignature(Context& context, ResponderIDType responderIDType,
     }
 
     if (match) {
-      rv = CheckOCSPResponseSignerCert(context.trustDomain, cert,
-                                       context.certID.issuer,
-                                       context.certID.issuerSubjectPublicKeyInfo,
-                                       context.time);
+      rv = CheckOCSPResponseSignerCert(
+          context.trustDomain, cert, context.certID.issuer,
+          context.certID.issuerSubjectPublicKeyInfo, context.time);
       if (rv != Success) {
         if (IsFatalError(rv)) {
           return rv;
@@ -290,28 +272,25 @@ VerifySignature(Context& context, ResponderIDType responderIDType,
   return Result::ERROR_OCSP_INVALID_SIGNING_CERT;
 }
 
-static inline Result
-MapBadDERToMalformedOCSPResponse(Result rv)
-{
+static inline Result MapBadDERToMalformedOCSPResponse(Result rv) {
   if (rv == Result::ERROR_BAD_DER) {
     return Result::ERROR_OCSP_MALFORMED_RESPONSE;
   }
   return rv;
 }
 
-Result
-VerifyEncodedOCSPResponse(TrustDomain& trustDomain, const struct CertID& certID,
-                          Time time, uint16_t maxOCSPLifetimeInDays,
-                          Input encodedResponse,
-                          /*out*/ bool& expired,
-                          /*optional out*/ Time* thisUpdate,
-                          /*optional out*/ Time* validThrough)
-{
+Result VerifyEncodedOCSPResponse(TrustDomain& trustDomain,
+                                 const struct CertID& certID, Time time,
+                                 uint16_t maxOCSPLifetimeInDays,
+                                 Input encodedResponse,
+                                 /*out*/ bool& expired,
+                                 /*optional out*/ Time* thisUpdate,
+                                 /*optional out*/ Time* validThrough) {
   // Always initialize this to something reasonable.
   expired = false;
 
-  Context context(trustDomain, certID, time, maxOCSPLifetimeInDays,
-                  thisUpdate, validThrough);
+  Context context(trustDomain, certID, time, maxOCSPLifetimeInDays, thisUpdate,
+                  validThrough);
 
   Reader input(encodedResponse);
   Result rv = der::Nested(input, der::SEQUENCE, [&context](Reader& r) {
@@ -338,19 +317,19 @@ VerifyEncodedOCSPResponse(TrustDomain& trustDomain, const struct CertID& certID,
       if (context.signedCertificateTimestamps.GetLength()) {
         Input sctList;
         rv = ExtractSignedCertificateTimestampListFromExtension(
-          context.signedCertificateTimestamps, sctList);
+            context.signedCertificateTimestamps, sctList);
         if (rv != Success) {
           return MapBadDERToMalformedOCSPResponse(rv);
         }
         context.trustDomain.NoteAuxiliaryExtension(
-          AuxiliaryExtension::SCTListFromOCSPResponse, sctList);
+            AuxiliaryExtension::SCTListFromOCSPResponse, sctList);
       }
       return Success;
     case CertStatus::Revoked:
       return Result::ERROR_REVOKED_CERTIFICATE;
     case CertStatus::Unknown:
       return Result::ERROR_OCSP_UNKNOWN_CERT;
-     MOZILLA_PKIX_UNREACHABLE_DEFAULT_ENUM
+      MOZILLA_PKIX_UNREACHABLE_DEFAULT_ENUM
   }
 }
 
@@ -358,9 +337,7 @@ VerifyEncodedOCSPResponse(TrustDomain& trustDomain, const struct CertID& certID,
 //       responseStatus         OCSPResponseStatus,
 //       responseBytes          [0] EXPLICIT ResponseBytes OPTIONAL }
 //
-static inline Result
-OCSPResponse(Reader& input, Context& context)
-{
+static inline Result OCSPResponse(Reader& input, Context& context) {
   // OCSPResponseStatus ::= ENUMERATED {
   //     successful            (0),  -- Response has valid confirmations
   //     malformedRequest      (1),  -- Illegal confirmation request
@@ -377,40 +354,42 @@ OCSPResponse(Reader& input, Context& context)
     return rv;
   }
   switch (responseStatus) {
-    case 0: break; // successful
-    case 1: return Result::ERROR_OCSP_MALFORMED_REQUEST;
-    case 2: return Result::ERROR_OCSP_SERVER_ERROR;
-    case 3: return Result::ERROR_OCSP_TRY_SERVER_LATER;
-    case 5: return Result::ERROR_OCSP_REQUEST_NEEDS_SIG;
-    case 6: return Result::ERROR_OCSP_UNAUTHORIZED_REQUEST;
-    default: return Result::ERROR_OCSP_UNKNOWN_RESPONSE_STATUS;
+    case 0:
+      break;  // successful
+    case 1:
+      return Result::ERROR_OCSP_MALFORMED_REQUEST;
+    case 2:
+      return Result::ERROR_OCSP_SERVER_ERROR;
+    case 3:
+      return Result::ERROR_OCSP_TRY_SERVER_LATER;
+    case 5:
+      return Result::ERROR_OCSP_REQUEST_NEEDS_SIG;
+    case 6:
+      return Result::ERROR_OCSP_UNAUTHORIZED_REQUEST;
+    default:
+      return Result::ERROR_OCSP_UNKNOWN_RESPONSE_STATUS;
   }
 
-  return der::Nested(input, der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0,
-                     der::SEQUENCE, [&context](Reader& r) {
-    return ResponseBytes(r, context);
-  });
+  return der::Nested(
+      input, der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0, der::SEQUENCE,
+      [&context](Reader& r) { return ResponseBytes(r, context); });
 }
 
 // ResponseBytes ::=       SEQUENCE {
 //     responseType   OBJECT IDENTIFIER,
 //     response       OCTET STRING }
-static inline Result
-ResponseBytes(Reader& input, Context& context)
-{
-  static const uint8_t id_pkix_ocsp_basic[] = {
-    0x2B, 0x06, 0x01, 0x05, 0x05, 0x07, 0x30, 0x01, 0x01
-  };
+static inline Result ResponseBytes(Reader& input, Context& context) {
+  static const uint8_t id_pkix_ocsp_basic[] = {0x2B, 0x06, 0x01, 0x05, 0x05,
+                                               0x07, 0x30, 0x01, 0x01};
 
   Result rv = der::OID(input, id_pkix_ocsp_basic);
   if (rv != Success) {
     return rv;
   }
 
-  return der::Nested(input, der::OCTET_STRING, der::SEQUENCE,
-                     [&context](Reader& r) {
-    return BasicResponse(r, context);
-  });
+  return der::Nested(
+      input, der::OCTET_STRING, der::SEQUENCE,
+      [&context](Reader& r) { return BasicResponse(r, context); });
 }
 
 // BasicOCSPResponse       ::= SEQUENCE {
@@ -418,9 +397,7 @@ ResponseBytes(Reader& input, Context& context)
 //    signatureAlgorithm   AlgorithmIdentifier,
 //    signature            BIT STRING,
 //    certs            [0] EXPLICIT SEQUENCE OF Certificate OPTIONAL }
-Result
-BasicResponse(Reader& input, Context& context)
-{
+Result BasicResponse(Reader& input, Context& context) {
   Reader tbsResponseData;
   der::SignedDataWithSignature signedData;
   Result rv = der::SignedData(input, tbsResponseData, signedData);
@@ -436,19 +413,20 @@ BasicResponse(Reader& input, Context& context)
   if (!input.AtEnd()) {
     rv = der::Nested(input, der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0,
                      der::SEQUENCE, [&certs](Reader& certsDER) -> Result {
-      while (!certsDER.AtEnd()) {
-        Input cert;
-        Result rv = der::ExpectTagAndGetTLV(certsDER, der::SEQUENCE, cert);
-        if (rv != Success) {
-          return rv;
-        }
-        rv = certs.Append(cert);
-        if (rv != Success) {
-          return Result::ERROR_BAD_DER; // Too many certs
-        }
-      }
-      return Success;
-    });
+                       while (!certsDER.AtEnd()) {
+                         Input cert;
+                         Result rv = der::ExpectTagAndGetTLV(
+                             certsDER, der::SEQUENCE, cert);
+                         if (rv != Success) {
+                           return rv;
+                         }
+                         rv = certs.Append(cert);
+                         if (rv != Success) {
+                           return Result::ERROR_BAD_DER;  // Too many certs
+                         }
+                       }
+                       return Success;
+                     });
     if (rv != Success) {
       return rv;
     }
@@ -463,11 +441,10 @@ BasicResponse(Reader& input, Context& context)
 //    producedAt              GeneralizedTime,
 //    responses               SEQUENCE OF SingleResponse,
 //    responseExtensions  [1] EXPLICIT Extensions OPTIONAL }
-static inline Result
-ResponseData(Reader& input, Context& context,
-             const der::SignedDataWithSignature& signedResponseData,
-             const DERArray& certs)
-{
+static inline Result ResponseData(
+    Reader& input, Context& context,
+    const der::SignedDataWithSignature& signedResponseData,
+    const DERArray& certs) {
   der::Version version;
   Result rv = der::OptionalVersion(input, version);
   if (rv != Success) {
@@ -482,10 +459,10 @@ ResponseData(Reader& input, Context& context,
   //    byName              [1] Name,
   //    byKey               [2] KeyHash }
   Input responderID;
-  ResponderIDType responderIDType
-    = input.Peek(static_cast<uint8_t>(ResponderIDType::byName))
-    ? ResponderIDType::byName
-    : ResponderIDType::byKey;
+  ResponderIDType responderIDType =
+      input.Peek(static_cast<uint8_t>(ResponderIDType::byName))
+          ? ResponderIDType::byName
+          : ResponderIDType::byKey;
   rv = der::ExpectTagAndGetValue(input, static_cast<uint8_t>(responderIDType),
                                  responderID);
   if (rv != Success) {
@@ -511,10 +488,9 @@ ResponseData(Reader& input, Context& context,
   // We don't accept an empty sequence of responses. In practice, a legit OCSP
   // responder will never return an empty response, and handling the case of an
   // empty response makes things unnecessarily complicated.
-  rv = der::NestedOf(input, der::SEQUENCE, der::SEQUENCE,
-                     der::EmptyAllowed::No, [&context](Reader& r) {
-    return SingleResponse(r, context);
-  });
+  rv = der::NestedOf(
+      input, der::SEQUENCE, der::SEQUENCE, der::EmptyAllowed::No,
+      [&context](Reader& r) { return SingleResponse(r, context); });
   if (rv != Success) {
     return rv;
   }
@@ -533,9 +509,7 @@ ResponseData(Reader& input, Context& context,
 //                                              re-ocsp-archive-cutoff |
 //                                              CrlEntryExtensions, ...}
 //                                              } OPTIONAL }
-static inline Result
-SingleResponse(Reader& input, Context& context)
-{
+static inline Result SingleResponse(Reader& input, Context& context) {
   bool match = false;
   Result rv = der::Nested(input, der::SEQUENCE, [&context, &match](Reader& r) {
     return CertID(r, context, match);
@@ -620,7 +594,7 @@ SingleResponse(Reader& input, Context& context)
 
   Time notAfter(Time::uninitialized);
   static const uint8_t NEXT_UPDATE_TAG =
-    der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0;
+      der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0;
   if (input.Peek(NEXT_UPDATE_TAG)) {
     Time nextUpdate(Time::uninitialized);
     rv = der::Nested(input, NEXT_UPDATE_TAG, [&nextUpdate](Reader& r) {
@@ -667,13 +641,12 @@ SingleResponse(Reader& input, Context& context)
   }
 
   rv = der::OptionalExtensions(
-    input,
-    der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 1,
-    [&context](Reader& extnID, const Input& extnValue, bool critical,
-               /*out*/ bool& understood) {
-      return RememberSingleExtension(context, extnID, extnValue, critical,
-                                     understood);
-    });
+      input, der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 1,
+      [&context](Reader& extnID, const Input& extnValue, bool critical,
+                 /*out*/ bool& understood) {
+        return RememberSingleExtension(context, extnID, extnValue, critical,
+                                       understood);
+      });
 
   if (rv != Success) {
     return rv;
@@ -694,9 +667,8 @@ SingleResponse(Reader& input, Context& context)
 //        issuerNameHash      OCTET STRING, -- Hash of issuer's DN
 //        issuerKeyHash       OCTET STRING, -- Hash of issuer's public key
 //        serialNumber        CertificateSerialNumber }
-static inline Result
-CertID(Reader& input, const Context& context, /*out*/ bool& match)
-{
+static inline Result CertID(Reader& input, const Context& context,
+                            /*out*/ bool& match) {
   match = false;
 
   DigestAlgorithm hashAlgorithm;
@@ -752,9 +724,8 @@ CertID(Reader& input, const Context& context, /*out*/ bool& match)
   // "The hash shall be calculated over the DER encoding of the
   // issuer's name field in the certificate being checked."
   uint8_t hashBuf[SHA1_DIGEST_LENGTH];
-  rv = context.trustDomain.DigestBuf(context.certID.issuer,
-                                     DigestAlgorithm::sha1, hashBuf,
-                                     sizeof(hashBuf));
+  rv = context.trustDomain.DigestBuf(
+      context.certID.issuer, DigestAlgorithm::sha1, hashBuf, sizeof(hashBuf));
   if (rv != Success) {
     return rv;
   }
@@ -779,16 +750,15 @@ CertID(Reader& input, const Context& context, /*out*/ bool& match)
 //                          -- BIT STRING subjectPublicKey [excluding
 //                          -- the tag, length, and number of unused
 //                          -- bits] in the responder's certificate)
-static Result
-MatchKeyHash(TrustDomain& trustDomain, Input keyHash,
-             const Input subjectPublicKeyInfo, /*out*/ bool& match)
-{
-  if (keyHash.GetLength() != SHA1_DIGEST_LENGTH)  {
+static Result MatchKeyHash(TrustDomain& trustDomain, Input keyHash,
+                           const Input subjectPublicKeyInfo,
+                           /*out*/ bool& match) {
+  if (keyHash.GetLength() != SHA1_DIGEST_LENGTH) {
     return Result::ERROR_OCSP_MALFORMED_RESPONSE;
   }
   uint8_t hashBuf[SHA1_DIGEST_LENGTH];
-  Result rv = KeyHash(trustDomain, subjectPublicKeyInfo, hashBuf,
-                      sizeof hashBuf);
+  Result rv =
+      KeyHash(trustDomain, subjectPublicKeyInfo, hashBuf, sizeof hashBuf);
   if (rv != Success) {
     return rv;
   }
@@ -798,10 +768,8 @@ MatchKeyHash(TrustDomain& trustDomain, Input keyHash,
 }
 
 // TODO(bug 966856): support SHA-2 hashes
-Result
-KeyHash(TrustDomain& trustDomain, const Input subjectPublicKeyInfo,
-        /*out*/ uint8_t* hashBuf, size_t hashBufSize)
-{
+Result KeyHash(TrustDomain& trustDomain, const Input subjectPublicKeyInfo,
+               /*out*/ uint8_t* hashBuf, size_t hashBufSize) {
   if (!hashBuf || hashBufSize != SHA1_DIGEST_LENGTH) {
     return Result::FATAL_ERROR_LIBRARY_FAILURE;
   }
@@ -813,8 +781,8 @@ KeyHash(TrustDomain& trustDomain, const Input subjectPublicKeyInfo,
   //    subjectPublicKey     BIT STRING  }
 
   Reader spki;
-  Result rv = der::ExpectTagAndGetValueAtEnd(subjectPublicKeyInfo,
-                                             der::SEQUENCE, spki);
+  Result rv =
+      der::ExpectTagAndGetValueAtEnd(subjectPublicKeyInfo, der::SEQUENCE, spki);
   if (rv != Success) {
     return rv;
   }
@@ -835,22 +803,19 @@ KeyHash(TrustDomain& trustDomain, const Input subjectPublicKeyInfo,
     return rv;
   }
 
-  return trustDomain.DigestBuf(subjectPublicKey, DigestAlgorithm::sha1,
-                               hashBuf, hashBufSize);
+  return trustDomain.DigestBuf(subjectPublicKey, DigestAlgorithm::sha1, hashBuf,
+                               hashBufSize);
 }
 
-Result
-ExtensionNotUnderstood(Reader& /*extnID*/, Input /*extnValue*/,
-                       bool /*critical*/, /*out*/ bool& understood)
-{
+Result ExtensionNotUnderstood(Reader& /*extnID*/, Input /*extnValue*/,
+                              bool /*critical*/, /*out*/ bool& understood) {
   understood = false;
   return Success;
 }
 
-Result
-RememberSingleExtension(Context& context, Reader& extnID, Input extnValue,
-                        bool /*critical*/, /*out*/ bool& understood)
-{
+Result RememberSingleExtension(Context& context, Reader& extnID,
+                               Input extnValue, bool /*critical*/,
+                               /*out*/ bool& understood) {
   understood = false;
 
   // SingleExtension for Signed Certificate Timestamp List.
@@ -858,8 +823,7 @@ RememberSingleExtension(Context& context, Reader& extnID, Input extnValue,
   // python DottedOIDToCode.py
   //   id_ocsp_singleExtensionSctList 1.3.6.1.4.1.11129.2.4.5
   static const uint8_t id_ocsp_singleExtensionSctList[] = {
-    0x2b, 0x06, 0x01, 0x04, 0x01, 0xd6, 0x79, 0x02, 0x04, 0x05
-  };
+      0x2b, 0x06, 0x01, 0x04, 0x01, 0xd6, 0x79, 0x02, 0x04, 0x05};
 
   if (extnID.MatchRest(id_ocsp_singleExtensionSctList)) {
     // Empty values are not allowed for this extension. Note that
@@ -900,11 +864,10 @@ RememberSingleExtension(Context& context, Reader& extnID, Input extnValue,
 //
 // http://tools.ietf.org/html/rfc5019#section-4
 
-Result
-CreateEncodedOCSPRequest(TrustDomain& trustDomain, const struct CertID& certID,
-                         /*out*/ uint8_t (&out)[OCSP_REQUEST_MAX_LENGTH],
-                         /*out*/ size_t& outLen)
-{
+Result CreateEncodedOCSPRequest(TrustDomain& trustDomain,
+                                const struct CertID& certID,
+                                /*out*/ uint8_t (&out)[OCSP_REQUEST_MAX_LENGTH],
+                                /*out*/ size_t& outLen) {
   // We do not add any extensions to the request.
 
   // RFC 6960 says "An OCSP client MAY wish to specify the kinds of response
@@ -922,22 +885,22 @@ CreateEncodedOCSPRequest(TrustDomain& trustDomain, const struct CertID& certID,
   // than SHA-1, we have no choice but to use SHA-1 for issuerNameHash and
   // issuerKeyHash.
   static const uint8_t hashAlgorithm[11] = {
-    0x30, 0x09,                               // SEQUENCE
-    0x06, 0x05, 0x2B, 0x0E, 0x03, 0x02, 0x1A, //   OBJECT IDENTIFIER id-sha1
-    0x05, 0x00,                               //   NULL
+      0x30, 0x09,                                // SEQUENCE
+      0x06, 0x05, 0x2B, 0x0E, 0x03, 0x02, 0x1A,  //   OBJECT IDENTIFIER id-sha1
+      0x05, 0x00,                                //   NULL
   };
   static const uint8_t hashLen = 160 / 8;
 
-  static const unsigned int totalLenWithoutSerialNumberData
-    = 2                             // OCSPRequest
-    + 2                             //   tbsRequest
-    + 2                             //     requestList
-    + 2                             //       Request
-    + 2                             //         reqCert (CertID)
-    + sizeof(hashAlgorithm)         //           hashAlgorithm
-    + 2 + hashLen                   //           issuerNameHash
-    + 2 + hashLen                   //           issuerKeyHash
-    + 2;                            //           serialNumber (header)
+  static const unsigned int totalLenWithoutSerialNumberData =
+      2                        // OCSPRequest
+      + 2                      //   tbsRequest
+      + 2                      //     requestList
+      + 2                      //       Request
+      + 2                      //         reqCert (CertID)
+      + sizeof(hashAlgorithm)  //           hashAlgorithm
+      + 2 + hashLen            //           issuerNameHash
+      + 2 + hashLen            //           issuerKeyHash
+      + 2;                     //           serialNumber (header)
 
   // The only way we could have a request this large is if the serialNumber was
   // ridiculously and unreasonably large. RFC 5280 says "Conforming CAs MUST
@@ -948,7 +911,7 @@ CreateEncodedOCSPRequest(TrustDomain& trustDomain, const struct CertID& certID,
   static_assert(totalLenWithoutSerialNumberData < OCSP_REQUEST_MAX_LENGTH,
                 "totalLenWithoutSerialNumberData too big");
   if (certID.serialNumber.GetLength() >
-        OCSP_REQUEST_MAX_LENGTH - totalLenWithoutSerialNumberData) {
+      OCSP_REQUEST_MAX_LENGTH - totalLenWithoutSerialNumberData) {
     return Result::ERROR_BAD_DER;
   }
 
@@ -957,22 +920,27 @@ CreateEncodedOCSPRequest(TrustDomain& trustDomain, const struct CertID& certID,
   uint8_t totalLen = static_cast<uint8_t>(outLen);
 
   uint8_t* d = out;
-  *d++ = 0x30; *d++ = totalLen - 2u;  // OCSPRequest (SEQUENCE)
-  *d++ = 0x30; *d++ = totalLen - 4u;  //   tbsRequest (SEQUENCE)
-  *d++ = 0x30; *d++ = totalLen - 6u;  //     requestList (SEQUENCE OF)
-  *d++ = 0x30; *d++ = totalLen - 8u;  //       Request (SEQUENCE)
-  *d++ = 0x30; *d++ = totalLen - 10u; //         reqCert (CertID SEQUENCE)
+  *d++ = 0x30;
+  *d++ = totalLen - 2u;  // OCSPRequest (SEQUENCE)
+  *d++ = 0x30;
+  *d++ = totalLen - 4u;  //   tbsRequest (SEQUENCE)
+  *d++ = 0x30;
+  *d++ = totalLen - 6u;  //     requestList (SEQUENCE OF)
+  *d++ = 0x30;
+  *d++ = totalLen - 8u;  //       Request (SEQUENCE)
+  *d++ = 0x30;
+  *d++ = totalLen - 10u;  //         reqCert (CertID SEQUENCE)
 
   // reqCert.hashAlgorithm
-  for (size_t i = 0; i < sizeof(hashAlgorithm); ++i) {
-    *d++ = hashAlgorithm[i];
+  for (const uint8_t hashAlgorithmByte : hashAlgorithm) {
+    *d++ = hashAlgorithmByte;
   }
 
   // reqCert.issuerNameHash (OCTET STRING)
   *d++ = 0x04;
   *d++ = hashLen;
-  Result rv = trustDomain.DigestBuf(certID.issuer, DigestAlgorithm::sha1, d,
-                                    hashLen);
+  Result rv =
+      trustDomain.DigestBuf(certID.issuer, DigestAlgorithm::sha1, d, hashLen);
   if (rv != Success) {
     return rv;
   }
@@ -988,7 +956,7 @@ CreateEncodedOCSPRequest(TrustDomain& trustDomain, const struct CertID& certID,
   d += hashLen;
 
   // reqCert.serialNumber (INTEGER)
-  *d++ = 0x02; // INTEGER
+  *d++ = 0x02;  // INTEGER
   *d++ = static_cast<uint8_t>(certID.serialNumber.GetLength());
   Reader serialNumber(certID.serialNumber);
   do {
@@ -1004,4 +972,5 @@ CreateEncodedOCSPRequest(TrustDomain& trustDomain, const struct CertID& certID,
   return Success;
 }
 
-} } // namespace mozilla::pkix
+}  // namespace pkix
+}  // namespace mozilla
