@@ -27,23 +27,23 @@
 using namespace mozilla::pkix;
 using namespace mozilla::pkix::test;
 
-namespace mozilla { namespace pkix {
+namespace mozilla {
+namespace pkix {
 
 extern Result CheckKeyUsage(EndEntityOrCA endEntityOrCA,
                             const Input* encodedKeyUsage,
                             KeyUsage requiredKeyUsageIfPresent);
+}
+}  // namespace mozilla
 
-} } // namespace mozilla::pkix
-
-class pkixcheck_CheckKeyUsage : public ::testing::Test { };
+class pkixcheck_CheckKeyUsage : public ::testing::Test {};
 
 #define ASSERT_BAD(x) ASSERT_EQ(Result::ERROR_INADEQUATE_KEY_USAGE, x)
 
 // Make it easy to define test data for the common, simplest cases.
-#define NAMED_SIMPLE_KU(name, unusedBits, bits) \
-  const uint8_t name##_bytes[4] = { \
-    0x03/*BIT STRING*/, 0x02/*LENGTH=2*/, unusedBits, bits \
-  }; \
+#define NAMED_SIMPLE_KU(name, unusedBits, bits)                            \
+  const uint8_t name##_bytes[4] = {0x03 /*BIT STRING*/, 0x02 /*LENGTH=2*/, \
+                                   unusedBits, bits};                      \
   const Input name(name##_bytes);
 
 static const Input empty_null;
@@ -51,8 +51,7 @@ static const Input empty_null;
 // Note that keyCertSign is really the only interesting case for CA
 // certificates since we don't support cRLSign.
 
-TEST_F(pkixcheck_CheckKeyUsage, EE_none)
-{
+TEST_F(pkixcheck_CheckKeyUsage, EE_none) {
   // The input Input is nullptr. This means the cert had no keyUsage
   // extension. This is always valid because no key usage in an end-entity
   // means that there are no key usage restrictions.
@@ -71,8 +70,7 @@ TEST_F(pkixcheck_CheckKeyUsage, EE_none)
                                    KeyUsage::keyAgreement));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, EE_empty)
-{
+TEST_F(pkixcheck_CheckKeyUsage, EE_empty) {
   // The input Input is empty. The cert had an empty keyUsage extension,
   // which is syntactically invalid.
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &empty_null,
@@ -84,15 +82,13 @@ TEST_F(pkixcheck_CheckKeyUsage, EE_empty)
                            KeyUsage::digitalSignature));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, CA_none)
-{
+TEST_F(pkixcheck_CheckKeyUsage, CA_none) {
   // A CA certificate does not have a KU extension.
   ASSERT_EQ(Success, CheckKeyUsage(EndEntityOrCA::MustBeCA, nullptr,
                                    KeyUsage::keyCertSign));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, CA_empty)
-{
+TEST_F(pkixcheck_CheckKeyUsage, CA_empty) {
   // A CA certificate has an empty KU extension.
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeCA, &empty_null,
                            KeyUsage::keyCertSign));
@@ -103,56 +99,49 @@ TEST_F(pkixcheck_CheckKeyUsage, CA_empty)
                            KeyUsage::keyCertSign));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, maxUnusedBits)
-{
+TEST_F(pkixcheck_CheckKeyUsage, maxUnusedBits) {
   NAMED_SIMPLE_KU(encoded, 7, 0x80);
   ASSERT_EQ(Success, CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &encoded,
                                    KeyUsage::digitalSignature));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, tooManyUnusedBits)
-{
-  static uint8_t oneValueByteData[] = {
-    0x03/*BIT STRING*/, 0x02/*LENGTH=2*/, 8/*unused bits*/, 0x80
-  };
+TEST_F(pkixcheck_CheckKeyUsage, tooManyUnusedBits) {
+  static uint8_t oneValueByteData[] = {0x03 /*BIT STRING*/, 0x02 /*LENGTH=2*/,
+                                       8 /*unused bits*/, 0x80};
   static const Input oneValueByte(oneValueByteData);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &oneValueByte,
                            KeyUsage::digitalSignature));
 
-  static uint8_t twoValueBytesData[] = {
-    0x03/*BIT STRING*/, 0x03/*LENGTH=3*/, 8/*unused bits*/, 0x01, 0x00
-  };
+  static uint8_t twoValueBytesData[] = {0x03 /*BIT STRING*/, 0x03 /*LENGTH=3*/,
+                                        8 /*unused bits*/, 0x01, 0x00};
   static const Input twoValueBytes(twoValueBytesData);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &twoValueBytes,
                            KeyUsage::digitalSignature));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, NoValueBytes_NoPaddingBits)
-{
+TEST_F(pkixcheck_CheckKeyUsage, NoValueBytes_NoPaddingBits) {
   static const uint8_t DER_BYTES[] = {
-    0x03/*BIT STRING*/, 0x01/*LENGTH=1*/, 0/*unused bits*/
+      0x03 /*BIT STRING*/, 0x01 /*LENGTH=1*/, 0 /*unused bits*/
   };
   static const Input DER(DER_BYTES);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &DER,
                            KeyUsage::digitalSignature));
-  ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeCA, &DER,
-                           KeyUsage::keyCertSign));
+  ASSERT_BAD(
+      CheckKeyUsage(EndEntityOrCA::MustBeCA, &DER, KeyUsage::keyCertSign));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, NoValueBytes_7PaddingBits)
-{
+TEST_F(pkixcheck_CheckKeyUsage, NoValueBytes_7PaddingBits) {
   static const uint8_t DER_BYTES[] = {
-    0x03/*BIT STRING*/, 0x01/*LENGTH=1*/, 7/*unused bits*/
+      0x03 /*BIT STRING*/, 0x01 /*LENGTH=1*/, 7 /*unused bits*/
   };
   static const Input DER(DER_BYTES);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &DER,
                            KeyUsage::digitalSignature));
-  ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeCA, &DER,
-                           KeyUsage::keyCertSign));
+  ASSERT_BAD(
+      CheckKeyUsage(EndEntityOrCA::MustBeCA, &DER, KeyUsage::keyCertSign));
 }
 
-void ASSERT_SimpleCase(uint8_t unusedBits, uint8_t bits, KeyUsage usage)
-{
+void ASSERT_SimpleCase(uint8_t unusedBits, uint8_t bits, KeyUsage usage) {
   // Test that only the right bit is accepted for the usage for both EE and CA
   // certs.
   NAMED_SIMPLE_KU(good, unusedBits, bits);
@@ -174,18 +163,16 @@ void ASSERT_SimpleCase(uint8_t unusedBits, uint8_t bits, KeyUsage usage)
   // Test that none of the other non-padding bits are mistaken for the given
   // key usage in the two-byte value case.
   const uint8_t twoByteNotGoodData[] = {
-    0x03/*BIT STRING*/, 0x03/*LENGTH=3*/, unusedBits,
-    static_cast<uint8_t>(~bits),
-    static_cast<uint8_t>((0xFFu >> unusedBits) << unusedBits)
-  };
+      0x03 /*BIT STRING*/, 0x03 /*LENGTH=3*/, unusedBits,
+      static_cast<uint8_t>(~bits),
+      static_cast<uint8_t>((0xFFu >> unusedBits) << unusedBits)};
   Input twoByteNotGood(twoByteNotGoodData);
-  ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &twoByteNotGood,
-                           usage));
+  ASSERT_BAD(
+      CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &twoByteNotGood, usage));
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeCA, &twoByteNotGood, usage));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, simpleCases)
-{
+TEST_F(pkixcheck_CheckKeyUsage, simpleCases) {
   ASSERT_SimpleCase(7, 0x80, KeyUsage::digitalSignature);
   ASSERT_SimpleCase(6, 0x40, KeyUsage::nonRepudiation);
   ASSERT_SimpleCase(5, 0x20, KeyUsage::keyEncipherment);
@@ -196,8 +183,7 @@ TEST_F(pkixcheck_CheckKeyUsage, simpleCases)
 // Only CAs are allowed to assert keyCertSign.
 // End-entity certs may assert it along with other key usages if keyCertSign
 // isn't the required key usage. This is for compatibility.
-TEST_F(pkixcheck_CheckKeyUsage, keyCertSign)
-{
+TEST_F(pkixcheck_CheckKeyUsage, keyCertSign) {
   NAMED_SIMPLE_KU(good, 2, 0x04);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &good,
                            KeyUsage::keyCertSign));
@@ -209,14 +195,13 @@ TEST_F(pkixcheck_CheckKeyUsage, keyCertSign)
   NAMED_SIMPLE_KU(notGood, 2, 0xFB);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &notGood,
                            KeyUsage::keyCertSign));
-  ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeCA, &notGood,
-                           KeyUsage::keyCertSign));
+  ASSERT_BAD(
+      CheckKeyUsage(EndEntityOrCA::MustBeCA, &notGood, KeyUsage::keyCertSign));
 
   // Test that none of the other non-padding bits are mistaken for the given
   // key usage in the two-byte value case.
-  static uint8_t twoByteNotGoodData[] = {
-    0x03/*BIT STRING*/, 0x03/*LENGTH=3*/, 2/*unused bits*/, 0xFBu, 0xFCu
-  };
+  static uint8_t twoByteNotGoodData[] = {0x03 /*BIT STRING*/, 0x03 /*LENGTH=3*/,
+                                         2 /*unused bits*/, 0xFBu, 0xFCu};
   static const Input twoByteNotGood(twoByteNotGoodData);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &twoByteNotGood,
                            KeyUsage::keyCertSign));
@@ -234,24 +219,21 @@ TEST_F(pkixcheck_CheckKeyUsage, keyCertSign)
                            KeyUsage::keyCertSign));
 }
 
-TEST_F(pkixcheck_CheckKeyUsage, unusedBitNotZero)
-{
+TEST_F(pkixcheck_CheckKeyUsage, unusedBitNotZero) {
   // single byte control case
   static uint8_t controlOneValueByteData[] = {
-    0x03/*BIT STRING*/, 0x02/*LENGTH=2*/, 7/*unused bits*/, 0x80
-  };
+      0x03 /*BIT STRING*/, 0x02 /*LENGTH=2*/, 7 /*unused bits*/, 0x80};
   static const Input controlOneValueByte(controlOneValueByteData);
-  ASSERT_EQ(Success, CheckKeyUsage(EndEntityOrCA::MustBeEndEntity,
-                                   &controlOneValueByte,
-                                   KeyUsage::digitalSignature));
-  ASSERT_EQ(Success, CheckKeyUsage(EndEntityOrCA::MustBeCA,
-                                   &controlOneValueByte,
-                                   KeyUsage::digitalSignature));
+  ASSERT_EQ(Success,
+            CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &controlOneValueByte,
+                          KeyUsage::digitalSignature));
+  ASSERT_EQ(Success,
+            CheckKeyUsage(EndEntityOrCA::MustBeCA, &controlOneValueByte,
+                          KeyUsage::digitalSignature));
 
   // single-byte test case
-  static uint8_t oneValueByteData[] = {
-    0x03/*BIT STRING*/, 0x02/*LENGTH=2*/, 7/*unused bits*/, 0x80 | 0x01
-  };
+  static uint8_t oneValueByteData[] = {0x03 /*BIT STRING*/, 0x02 /*LENGTH=2*/,
+                                       7 /*unused bits*/, 0x80 | 0x01};
   static const Input oneValueByte(oneValueByteData);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &oneValueByte,
                            KeyUsage::digitalSignature));
@@ -260,22 +242,20 @@ TEST_F(pkixcheck_CheckKeyUsage, unusedBitNotZero)
 
   // two-byte control case
   static uint8_t controlTwoValueBytesData[] = {
-    0x03/*BIT STRING*/, 0x03/*LENGTH=3*/, 7/*unused bits*/,
-    0x80 | 0x01, 0x80
-  };
+      0x03 /*BIT STRING*/, 0x03 /*LENGTH=3*/, 7 /*unused bits*/, 0x80 | 0x01,
+      0x80};
   static const Input controlTwoValueBytes(controlTwoValueBytesData);
-  ASSERT_EQ(Success, CheckKeyUsage(EndEntityOrCA::MustBeEndEntity,
-                                   &controlTwoValueBytes,
-                                   KeyUsage::digitalSignature));
-  ASSERT_EQ(Success, CheckKeyUsage(EndEntityOrCA::MustBeCA,
-                                   &controlTwoValueBytes,
-                                   KeyUsage::digitalSignature));
+  ASSERT_EQ(Success,
+            CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &controlTwoValueBytes,
+                          KeyUsage::digitalSignature));
+  ASSERT_EQ(Success,
+            CheckKeyUsage(EndEntityOrCA::MustBeCA, &controlTwoValueBytes,
+                          KeyUsage::digitalSignature));
 
   // two-byte test case
-  static uint8_t twoValueBytesData[] = {
-    0x03/*BIT STRING*/, 0x03/*LENGTH=3*/, 7/*unused bits*/,
-    0x80 | 0x01, 0x80 | 0x01
-  };
+  static uint8_t twoValueBytesData[] = {0x03 /*BIT STRING*/, 0x03 /*LENGTH=3*/,
+                                        7 /*unused bits*/, 0x80 | 0x01,
+                                        0x80 | 0x01};
   static const Input twoValueBytes(twoValueBytesData);
   ASSERT_BAD(CheckKeyUsage(EndEntityOrCA::MustBeEndEntity, &twoValueBytes,
                            KeyUsage::digitalSignature));
