@@ -33,69 +33,69 @@ using namespace mozilla::pkix::der;
 
 namespace {
 
-class pkixder_input_tests : public ::testing::Test { };
+class pkixder_input_tests : public ::testing::Test {};
 
 static const uint8_t DER_SEQUENCE_EMPTY[] = {
-  0x30,                       // SEQUENCE
-  0x00,                       // length
+    0x30,  // SEQUENCE
+    0x00,  // length
 };
 
 static const uint8_t DER_SEQUENCE_NOT_EMPTY[] = {
-  0x30,                       // SEQUENCE
-  0x01,                       // length
-  'X',                        // value
+    0x30,  // SEQUENCE
+    0x01,  // length
+    'X',   // value
 };
 
 static const uint8_t DER_SEQUENCE_NOT_EMPTY_VALUE[] = {
-  'X',                        // value
+    'X',  // value
 };
 
 static const uint8_t DER_SEQUENCE_NOT_EMPTY_VALUE_TRUNCATED[] = {
-  0x30,                       // SEQUENCE
-  0x01,                       // length
+    0x30,  // SEQUENCE
+    0x01,  // length
 };
 
 const uint8_t DER_SEQUENCE_OF_INT8[] = {
-  0x30,                       // SEQUENCE
-  0x09,                       // length
-  0x02, 0x01, 0x01,           // INTEGER length 1 value 0x01
-  0x02, 0x01, 0x02,           // INTEGER length 1 value 0x02
-  0x02, 0x01, 0x03            // INTEGER length 1 value 0x03
+    0x30,              // SEQUENCE
+    0x09,              // length
+    0x02, 0x01, 0x01,  // INTEGER length 1 value 0x01
+    0x02, 0x01, 0x02,  // INTEGER length 1 value 0x02
+    0x02, 0x01, 0x03   // INTEGER length 1 value 0x03
 };
 
 const uint8_t DER_TRUNCATED_SEQUENCE_OF_INT8[] = {
-  0x30,                       // SEQUENCE
-  0x09,                       // length
-  0x02, 0x01, 0x01,           // INTEGER length 1 value 0x01
-  0x02, 0x01, 0x02            // INTEGER length 1 value 0x02
-  // MISSING DATA HERE ON PURPOSE
+    0x30,  // SEQUENCE
+    0x09,  // length
+    0x02, 0x01,
+    0x01,  // INTEGER length 1 value 0x01
+    0x02, 0x01,
+    0x02  // INTEGER length 1 value 0x02
+          // MISSING DATA HERE ON PURPOSE
 };
 
 const uint8_t DER_OVERRUN_SEQUENCE_OF_INT8[] = {
-  0x30,                       // SEQUENCE
-  0x09,                       // length
-  0x02, 0x01, 0x01,           // INTEGER length 1 value 0x01
-  0x02, 0x01, 0x02,           // INTEGER length 1 value 0x02
-  0x02, 0x02, 0xFF, 0x03      // INTEGER length 2 value 0xFF03
+    0x30,                   // SEQUENCE
+    0x09,                   // length
+    0x02, 0x01, 0x01,       // INTEGER length 1 value 0x01
+    0x02, 0x01, 0x02,       // INTEGER length 1 value 0x02
+    0x02, 0x02, 0xFF, 0x03  // INTEGER length 2 value 0xFF03
 };
 
 const uint8_t DER_INT16[] = {
-  0x02,                       // INTEGER
-  0x02,                       // length
-  0x12, 0x34                  // 0x1234
+    0x02,       // INTEGER
+    0x02,       // length
+    0x12, 0x34  // 0x1234
 };
 
 static const Input EMPTY_INPUT;
 
-TEST_F(pkixder_input_tests, InputInit)
-{
+TEST_F(pkixder_input_tests, InputInit) {
   Input buf;
   ASSERT_EQ(Success,
             buf.Init(DER_SEQUENCE_OF_INT8, sizeof DER_SEQUENCE_OF_INT8));
 }
 
-TEST_F(pkixder_input_tests, InputInitWithNullPointerOrZeroLength)
-{
+TEST_F(pkixder_input_tests, InputInitWithNullPointerOrZeroLength) {
   Input buf;
   ASSERT_EQ(Result::ERROR_BAD_DER, buf.Init(nullptr, 0));
 
@@ -105,22 +105,20 @@ TEST_F(pkixder_input_tests, InputInitWithNullPointerOrZeroLength)
   // is working as intended. The Reader class was intended to protect against
   // buffer overflows, and there's no risk with the current behavior. See bug
   // 1000354.
-  ASSERT_EQ(Success, buf.Init((const uint8_t*) "hello", 0));
+  ASSERT_EQ(Success, buf.Init((const uint8_t*)"hello", 0));
   ASSERT_TRUE(buf.GetLength() == 0);
 }
 
-TEST_F(pkixder_input_tests, InputInitWithLargeData)
-{
+TEST_F(pkixder_input_tests, InputInitWithLargeData) {
   Input buf;
   // Data argument length does not matter, it is not touched, just
   // needs to be non-null
-  ASSERT_EQ(Result::ERROR_BAD_DER, buf.Init((const uint8_t*) "", 0xffff+1));
+  ASSERT_EQ(Result::ERROR_BAD_DER, buf.Init((const uint8_t*)"", 0xffff + 1));
 
-  ASSERT_EQ(Success, buf.Init((const uint8_t*) "", 0xffff));
+  ASSERT_EQ(Success, buf.Init((const uint8_t*)"", 0xffff));
 }
 
-TEST_F(pkixder_input_tests, InputInitMultipleTimes)
-{
+TEST_F(pkixder_input_tests, InputInitMultipleTimes) {
   Input buf;
 
   ASSERT_EQ(Success,
@@ -130,18 +128,16 @@ TEST_F(pkixder_input_tests, InputInitMultipleTimes)
             buf.Init(DER_SEQUENCE_OF_INT8, sizeof DER_SEQUENCE_OF_INT8));
 }
 
-TEST_F(pkixder_input_tests, PeekWithinBounds)
-{
-  const uint8_t der[] = { 0x11, 0x11 };
+TEST_F(pkixder_input_tests, PeekWithinBounds) {
+  const uint8_t der[] = {0x11, 0x11};
   Input buf(der);
   Reader input(buf);
   ASSERT_TRUE(input.Peek(0x11));
   ASSERT_FALSE(input.Peek(0x22));
 }
 
-TEST_F(pkixder_input_tests, PeekPastBounds)
-{
-  const uint8_t der[] = { 0x11, 0x22 };
+TEST_F(pkixder_input_tests, PeekPastBounds) {
+  const uint8_t der[] = {0x11, 0x22};
   Input buf;
   ASSERT_EQ(Success, buf.Init(der, 1));
   Reader input(buf);
@@ -152,9 +148,8 @@ TEST_F(pkixder_input_tests, PeekPastBounds)
   ASSERT_FALSE(input.Peek(0x22));
 }
 
-TEST_F(pkixder_input_tests, ReadByte)
-{
-  const uint8_t der[] = { 0x11, 0x22 };
+TEST_F(pkixder_input_tests, ReadByte) {
+  const uint8_t der[] = {0x11, 0x22};
   Input buf(der);
   Reader input(buf);
 
@@ -167,9 +162,8 @@ TEST_F(pkixder_input_tests, ReadByte)
   ASSERT_EQ(0x22, readByte2);
 }
 
-TEST_F(pkixder_input_tests, ReadBytePastEnd)
-{
-  const uint8_t der[] = { 0x11, 0x22 };
+TEST_F(pkixder_input_tests, ReadBytePastEnd) {
+  const uint8_t der[] = {0x11, 0x22};
   Input buf;
   ASSERT_EQ(Success, buf.Init(der, 1));
   Reader input(buf);
@@ -183,8 +177,7 @@ TEST_F(pkixder_input_tests, ReadBytePastEnd)
   ASSERT_NE(0x22, readByte2);
 }
 
-TEST_F(pkixder_input_tests, ReadByteWrapAroundPointer)
-{
+TEST_F(pkixder_input_tests, ReadByteWrapAroundPointer) {
   // The original implementation of our buffer read overflow checks was
   // susceptible to integer overflows which could make the checks ineffective.
   // This attempts to verify that we've fixed that. Unfortunately, decrementing
@@ -201,9 +194,8 @@ TEST_F(pkixder_input_tests, ReadByteWrapAroundPointer)
   ASSERT_EQ(Result::ERROR_BAD_DER, input.Read(b));
 }
 
-TEST_F(pkixder_input_tests, ReadWord)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, ReadWord) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
@@ -216,11 +208,10 @@ TEST_F(pkixder_input_tests, ReadWord)
   ASSERT_EQ(0x3344, readWord2);
 }
 
-TEST_F(pkixder_input_tests, ReadWordPastEnd)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, ReadWordPastEnd) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf;
-  ASSERT_EQ(Success, buf.Init(der, 2)); // Initialize with too-short length
+  ASSERT_EQ(Success, buf.Init(der, 2));  // Initialize with too-short length
   Reader input(buf);
 
   uint16_t readWord1 = 0;
@@ -232,9 +223,8 @@ TEST_F(pkixder_input_tests, ReadWordPastEnd)
   ASSERT_NE(0x3344, readWord2);
 }
 
-TEST_F(pkixder_input_tests, ReadWordWithInsufficentData)
-{
-  const uint8_t der[] = { 0x11, 0x22 };
+TEST_F(pkixder_input_tests, ReadWordWithInsufficentData) {
+  const uint8_t der[] = {0x11, 0x22};
   Input buf;
   ASSERT_EQ(Success, buf.Init(der, 1));
   Reader input(buf);
@@ -244,8 +234,7 @@ TEST_F(pkixder_input_tests, ReadWordWithInsufficentData)
   ASSERT_NE(0x1122, readWord1);
 }
 
-TEST_F(pkixder_input_tests, ReadWordWrapAroundPointer)
-{
+TEST_F(pkixder_input_tests, ReadWordWrapAroundPointer) {
   // The original implementation of our buffer read overflow checks was
   // susceptible to integer overflows which could make the checks ineffective.
   // This attempts to verify that we've fixed that. Unfortunately, decrementing
@@ -261,9 +250,8 @@ TEST_F(pkixder_input_tests, ReadWordWrapAroundPointer)
   ASSERT_EQ(Result::ERROR_BAD_DER, input.Read(b));
 }
 
-TEST_F(pkixder_input_tests, Skip)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, Skip) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
@@ -280,27 +268,24 @@ TEST_F(pkixder_input_tests, Skip)
   ASSERT_EQ(0x44, readByte2);
 }
 
-TEST_F(pkixder_input_tests, Skip_ToEnd)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, Skip_ToEnd) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
   ASSERT_EQ(Success, input.Skip(sizeof der));
   ASSERT_TRUE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, Skip_PastEnd)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, Skip_PastEnd) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
   ASSERT_EQ(Result::ERROR_BAD_DER, input.Skip(sizeof der + 1));
 }
 
-TEST_F(pkixder_input_tests, Skip_ToNewInput)
-{
-  const uint8_t der[] = { 0x01, 0x02, 0x03, 0x04 };
+TEST_F(pkixder_input_tests, Skip_ToNewInput) {
+  const uint8_t der[] = {0x01, 0x02, 0x03, 0x04};
   Input buf(der);
   Reader input(buf);
 
@@ -325,9 +310,8 @@ TEST_F(pkixder_input_tests, Skip_ToNewInput)
   ASSERT_TRUE(skippedInput.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, Skip_ToNewInputPastEnd)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, Skip_ToNewInputPastEnd) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
@@ -335,13 +319,12 @@ TEST_F(pkixder_input_tests, Skip_ToNewInputPastEnd)
   ASSERT_EQ(Result::ERROR_BAD_DER, input.Skip(sizeof der * 2, skippedInput));
 }
 
-TEST_F(pkixder_input_tests, Skip_ToInput)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, Skip_ToInput) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
-  const uint8_t expectedItemData[] = { 0x11, 0x22, 0x33 };
+  const uint8_t expectedItemData[] = {0x11, 0x22, 0x33};
 
   Input item;
   ASSERT_EQ(Success, input.Skip(sizeof expectedItemData, item));
@@ -350,8 +333,7 @@ TEST_F(pkixder_input_tests, Skip_ToInput)
   ASSERT_TRUE(InputsAreEqual(expected, item));
 }
 
-TEST_F(pkixder_input_tests, Skip_WrapAroundPointer)
-{
+TEST_F(pkixder_input_tests, Skip_WrapAroundPointer) {
   // The original implementation of our buffer read overflow checks was
   // susceptible to integer overflows which could make the checks ineffective.
   // This attempts to verify that we've fixed that. Unfortunately, decrementing
@@ -366,9 +348,8 @@ TEST_F(pkixder_input_tests, Skip_WrapAroundPointer)
   ASSERT_EQ(Result::ERROR_BAD_DER, input.Skip(1));
 }
 
-TEST_F(pkixder_input_tests, Skip_ToInputPastEnd)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, Skip_ToInputPastEnd) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
@@ -376,9 +357,8 @@ TEST_F(pkixder_input_tests, Skip_ToInputPastEnd)
   ASSERT_EQ(Result::ERROR_BAD_DER, input.Skip(sizeof der + 1, skipped));
 }
 
-TEST_F(pkixder_input_tests, SkipToEnd_ToInput)
-{
-  static const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, SkipToEnd_ToInput) {
+  static const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
@@ -386,13 +366,12 @@ TEST_F(pkixder_input_tests, SkipToEnd_ToInput)
   ASSERT_EQ(Success, input.SkipToEnd(skipped));
 }
 
-TEST_F(pkixder_input_tests, SkipToEnd_ToInput_InputAlreadyInited)
-{
-  static const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, SkipToEnd_ToInput_InputAlreadyInited) {
+  static const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
-  static const uint8_t initialValue[] = { 0x01, 0x02, 0x03 };
+  static const uint8_t initialValue[] = {0x01, 0x02, 0x03};
   Input x(initialValue);
   // Fails because skipped was already initialized once, and Inputs are not
   // allowed to be Init()d multiple times.
@@ -400,8 +379,7 @@ TEST_F(pkixder_input_tests, SkipToEnd_ToInput_InputAlreadyInited)
   ASSERT_TRUE(InputsAreEqual(x, Input(initialValue)));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndSkipValue)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndSkipValue) {
   Input buf(DER_SEQUENCE_OF_INT8);
   Reader input(buf);
 
@@ -409,54 +387,48 @@ TEST_F(pkixder_input_tests, ExpectTagAndSkipValue)
   ASSERT_EQ(Success, End(input));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndSkipValueWithTruncatedData)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndSkipValueWithTruncatedData) {
   Input buf(DER_TRUNCATED_SEQUENCE_OF_INT8);
   Reader input(buf);
 
   ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndSkipValue(input, SEQUENCE));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndSkipValueWithOverrunData)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndSkipValueWithOverrunData) {
   Input buf(DER_OVERRUN_SEQUENCE_OF_INT8);
   Reader input(buf);
   ASSERT_EQ(Success, ExpectTagAndSkipValue(input, SEQUENCE));
   ASSERT_EQ(Result::ERROR_BAD_DER, End(input));
 }
 
-TEST_F(pkixder_input_tests, AtEndOnUnInitializedInput)
-{
+TEST_F(pkixder_input_tests, AtEndOnUnInitializedInput) {
   Reader input;
   ASSERT_TRUE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, AtEndAtBeginning)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, AtEndAtBeginning) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
   ASSERT_FALSE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, AtEndAtEnd)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, AtEndAtEnd) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
   ASSERT_EQ(Success, input.Skip(sizeof der));
   ASSERT_TRUE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, MarkAndGetInput)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, MarkAndGetInput) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
   Reader::Mark mark = input.GetMark();
 
-  const uint8_t expectedItemData[] = { 0x11, 0x22, 0x33 };
+  const uint8_t expectedItemData[] = {0x11, 0x22, 0x33};
 
   ASSERT_EQ(Success, input.Skip(sizeof expectedItemData));
 
@@ -468,9 +440,8 @@ TEST_F(pkixder_input_tests, MarkAndGetInput)
 
 // Cannot run this test on debug builds because of the NotReached
 #ifdef NDEBUG
-TEST_F(pkixder_input_tests, MarkAndGetInputDifferentInput)
-{
-  const uint8_t der[] = { 0x11, 0x22, 0x33, 0x44 };
+TEST_F(pkixder_input_tests, MarkAndGetInputDifferentInput) {
+  const uint8_t der[] = {0x11, 0x22, 0x33, 0x44};
   Input buf(der);
   Reader input(buf);
 
@@ -484,17 +455,15 @@ TEST_F(pkixder_input_tests, MarkAndGetInputDifferentInput)
 }
 #endif
 
-TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_AtEnd)
-{
+TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_AtEnd) {
   Reader input(EMPTY_INPUT);
   uint8_t tag;
   Input value;
   ASSERT_EQ(Result::ERROR_BAD_DER, ReadTagAndGetValue(input, tag, value));
 }
 
-TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_TruncatedAfterTag)
-{
-  static const uint8_t DER[] = { SEQUENCE };
+TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_TruncatedAfterTag) {
+  static const uint8_t DER[] = {SEQUENCE};
   Input buf(DER);
   Reader input(buf);
   uint8_t tag;
@@ -502,8 +471,7 @@ TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_TruncatedAfterTag)
   ASSERT_EQ(Result::ERROR_BAD_DER, ReadTagAndGetValue(input, tag, value));
 }
 
-TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_ValidEmpty)
-{
+TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_ValidEmpty) {
   Input buf(DER_SEQUENCE_EMPTY);
   Reader input(buf);
   uint8_t tag = 0;
@@ -514,8 +482,7 @@ TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_ValidEmpty)
   ASSERT_TRUE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_ValidNotEmpty)
-{
+TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_ValidNotEmpty) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   uint8_t tag = 0;
@@ -528,8 +495,7 @@ TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_ValidNotEmpty)
 }
 
 TEST_F(pkixder_input_tests,
-       ReadTagAndGetValue_Input_InvalidNotEmptyValueTruncated)
-{
+       ReadTagAndGetValue_Input_InvalidNotEmptyValueTruncated) {
   Input buf(DER_SEQUENCE_NOT_EMPTY_VALUE_TRUNCATED);
   Reader input(buf);
   uint8_t tag;
@@ -537,18 +503,16 @@ TEST_F(pkixder_input_tests,
   ASSERT_EQ(Result::ERROR_BAD_DER, ReadTagAndGetValue(input, tag, value));
 }
 
-TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_InvalidWrongLength)
-{
+TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_InvalidWrongLength) {
   Input buf(DER_TRUNCATED_SEQUENCE_OF_INT8);
   Reader input(buf);
   uint8_t tag;
   Input value;
-  ASSERT_EQ(Result::ERROR_BAD_DER,
-            ReadTagAndGetValue(input, tag, value));
+  ASSERT_EQ(Result::ERROR_BAD_DER, ReadTagAndGetValue(input, tag, value));
 }
 
-TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_InvalidHighTagNumberForm1)
-{
+TEST_F(pkixder_input_tests,
+       ReadTagAndGetValue_Input_InvalidHighTagNumberForm1) {
   // High tag number form is not allowed (illegal 1 byte tag)
   //
   // If the decoder treats 0x1F as a valid low tag number tag, then it will
@@ -558,20 +522,19 @@ TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_InvalidHighTagNumberForm1)
   // It is illegal to encode tag 1 in the high tag number form because it isn't
   // the shortest encoding (the low tag number form is).
   static const uint8_t DER[] = {
-    0x1F, // high tag number form indicator
-    1,    // tag 1 (not legal!)
-    0     // length zero
+      0x1F,  // high tag number form indicator
+      1,     // tag 1 (not legal!)
+      0      // length zero
   };
   Input buf(DER);
   Reader input(buf);
   uint8_t tag;
   Input value;
-  ASSERT_EQ(Result::ERROR_BAD_DER,
-            ReadTagAndGetValue(input, tag, value));
+  ASSERT_EQ(Result::ERROR_BAD_DER, ReadTagAndGetValue(input, tag, value));
 }
 
-TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_InvalidHighTagNumberForm2)
-{
+TEST_F(pkixder_input_tests,
+       ReadTagAndGetValue_Input_InvalidHighTagNumberForm2) {
   // High tag number form is not allowed (legal 1 byte tag).
   //
   // ReadTagAndGetValue's check to prohibit the high tag number form has no
@@ -582,20 +545,19 @@ TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_InvalidHighTagNumberForm2)
   // that person that they need to add tests here, including in particular
   // tests for overly-long encodings.
   static const uint8_t DER[] = {
-    0x1F, // high tag number form indicator
-    31,   // tag 31
-    0     // length zero
+      0x1F,  // high tag number form indicator
+      31,    // tag 31
+      0      // length zero
   };
   Input buf(DER);
   Reader input(buf);
   uint8_t tag;
   Input value;
-  ASSERT_EQ(Result::ERROR_BAD_DER,
-            ReadTagAndGetValue(input, tag, value));
+  ASSERT_EQ(Result::ERROR_BAD_DER, ReadTagAndGetValue(input, tag, value));
 }
 
-TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_InvalidHighTagNumberForm3)
-{
+TEST_F(pkixder_input_tests,
+       ReadTagAndGetValue_Input_InvalidHighTagNumberForm3) {
   // High tag number form is not allowed (2 byte legal tag)
   //
   // ReadTagAndGetValue's check to prohibit the high tag number form has no
@@ -606,20 +568,18 @@ TEST_F(pkixder_input_tests, ReadTagAndGetValue_Input_InvalidHighTagNumberForm3)
   // that person that they need to add tests here, including in particular
   // tests for overly-long encodings.
   static const uint8_t DER[] = {
-    0x1F,              // high tag number form indicator
-    0x80 | 0x01, 0x00, // tag 0x100 (256)
-    0                  // length zero
+      0x1F,               // high tag number form indicator
+      0x80 | 0x01, 0x00,  // tag 0x100 (256)
+      0                   // length zero
   };
   Input buf(DER);
   Reader input(buf);
   uint8_t tag;
   Input value;
-  ASSERT_EQ(Result::ERROR_BAD_DER,
-            ReadTagAndGetValue(input, tag, value));
+  ASSERT_EQ(Result::ERROR_BAD_DER, ReadTagAndGetValue(input, tag, value));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_ValidEmpty)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_ValidEmpty) {
   Input buf(DER_SEQUENCE_EMPTY);
   Reader input(buf);
   Reader value;
@@ -628,8 +588,7 @@ TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_ValidEmpty)
   ASSERT_TRUE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_ValidNotEmpty)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_ValidNotEmpty) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   Reader value;
@@ -639,8 +598,7 @@ TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_ValidNotEmpty)
 }
 
 TEST_F(pkixder_input_tests,
-       ExpectTagAndGetValue_Reader_InvalidNotEmptyValueTruncated)
-{
+       ExpectTagAndGetValue_Reader_InvalidNotEmptyValueTruncated) {
   Input buf(DER_SEQUENCE_NOT_EMPTY_VALUE_TRUNCATED);
   Reader input(buf);
   Reader value;
@@ -648,8 +606,7 @@ TEST_F(pkixder_input_tests,
             ExpectTagAndGetValue(input, SEQUENCE, value));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_InvalidWrongLength)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_InvalidWrongLength) {
   Input buf(DER_TRUNCATED_SEQUENCE_OF_INT8);
   Reader input(buf);
   Reader value;
@@ -657,17 +614,14 @@ TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_InvalidWrongLength)
             ExpectTagAndGetValue(input, SEQUENCE, value));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_InvalidWrongTag)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Reader_InvalidWrongTag) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   Reader value;
-  ASSERT_EQ(Result::ERROR_BAD_DER,
-            ExpectTagAndGetValue(input, INTEGER, value));
+  ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndGetValue(input, INTEGER, value));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_ValidEmpty)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_ValidEmpty) {
   Input buf(DER_SEQUENCE_EMPTY);
   Reader input(buf);
   Input value;
@@ -676,8 +630,7 @@ TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_ValidEmpty)
   ASSERT_TRUE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_ValidNotEmpty)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_ValidNotEmpty) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   Input value;
@@ -688,8 +641,7 @@ TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_ValidNotEmpty)
 }
 
 TEST_F(pkixder_input_tests,
-       ExpectTagAndGetValue_Input_InvalidNotEmptyValueTruncated)
-{
+       ExpectTagAndGetValue_Input_InvalidNotEmptyValueTruncated) {
   Input buf(DER_SEQUENCE_NOT_EMPTY_VALUE_TRUNCATED);
   Reader input(buf);
   Input value;
@@ -697,8 +649,7 @@ TEST_F(pkixder_input_tests,
             ExpectTagAndGetValue(input, SEQUENCE, value));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_InvalidWrongLength)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_InvalidWrongLength) {
   Input buf(DER_TRUNCATED_SEQUENCE_OF_INT8);
   Reader input(buf);
   Input value;
@@ -706,54 +657,46 @@ TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_InvalidWrongLength)
             ExpectTagAndGetValue(input, SEQUENCE, value));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_InvalidWrongTag)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetValue_Input_InvalidWrongTag) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   Input value;
-  ASSERT_EQ(Result::ERROR_BAD_DER,
-            ExpectTagAndGetValue(input, INTEGER, value));
+  ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndGetValue(input, INTEGER, value));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndEmptyValue_ValidEmpty)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndEmptyValue_ValidEmpty) {
   Input buf(DER_SEQUENCE_EMPTY);
   Reader input(buf);
   ASSERT_EQ(Success, ExpectTagAndEmptyValue(input, SEQUENCE));
   ASSERT_TRUE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndEmptyValue_InValidNotEmpty)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndEmptyValue_InValidNotEmpty) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndEmptyValue(input, SEQUENCE));
 }
 
 TEST_F(pkixder_input_tests,
-       ExpectTagAndEmptyValue_Input_InvalidNotEmptyValueTruncated)
-{
+       ExpectTagAndEmptyValue_Input_InvalidNotEmptyValueTruncated) {
   Input buf(DER_SEQUENCE_NOT_EMPTY_VALUE_TRUNCATED);
   Reader input(buf);
   ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndEmptyValue(input, SEQUENCE));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndEmptyValue_InvalidWrongLength)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndEmptyValue_InvalidWrongLength) {
   Input buf(DER_TRUNCATED_SEQUENCE_OF_INT8);
   Reader input(buf);
   ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndEmptyValue(input, SEQUENCE));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndEmptyValue_InvalidWrongTag)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndEmptyValue_InvalidWrongTag) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndEmptyValue(input, INTEGER));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_ValidEmpty)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_ValidEmpty) {
   Input buf(DER_SEQUENCE_EMPTY);
   Reader input(buf);
   Input tlv;
@@ -763,8 +706,7 @@ TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_ValidEmpty)
   ASSERT_TRUE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_ValidNotEmpty)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_ValidNotEmpty) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   Input tlv;
@@ -775,48 +717,42 @@ TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_ValidNotEmpty)
 }
 
 TEST_F(pkixder_input_tests,
-       ExpectTagAndGetTLV_Input_InvalidNotEmptyValueTruncated)
-{
+       ExpectTagAndGetTLV_Input_InvalidNotEmptyValueTruncated) {
   Input buf(DER_SEQUENCE_NOT_EMPTY_VALUE_TRUNCATED);
   Reader input(buf);
   Input tlv;
   ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndGetTLV(input, SEQUENCE, tlv));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_InvalidWrongLength)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_InvalidWrongLength) {
   Input buf(DER_TRUNCATED_SEQUENCE_OF_INT8);
   Reader input(buf);
   Input tlv;
   ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndGetTLV(input, SEQUENCE, tlv));
 }
 
-TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_InvalidWrongTag)
-{
+TEST_F(pkixder_input_tests, ExpectTagAndGetTLV_Input_InvalidWrongTag) {
   Input buf(DER_SEQUENCE_NOT_EMPTY);
   Reader input(buf);
   Input tlv;
   ASSERT_EQ(Result::ERROR_BAD_DER, ExpectTagAndGetTLV(input, INTEGER, tlv));
 }
 
-TEST_F(pkixder_input_tests, EndAtEnd)
-{
+TEST_F(pkixder_input_tests, EndAtEnd) {
   Input buf(DER_INT16);
   Reader input(buf);
   ASSERT_EQ(Success, input.Skip(4));
   ASSERT_EQ(Success, End(input));
 }
 
-TEST_F(pkixder_input_tests, EndBeforeEnd)
-{
+TEST_F(pkixder_input_tests, EndBeforeEnd) {
   Input buf(DER_INT16);
   Reader input(buf);
   ASSERT_EQ(Success, input.Skip(2));
   ASSERT_EQ(Result::ERROR_BAD_DER, End(input));
 }
 
-TEST_F(pkixder_input_tests, EndAtBeginning)
-{
+TEST_F(pkixder_input_tests, EndAtBeginning) {
   Input buf(DER_INT16);
   Reader input(buf);
   ASSERT_EQ(Result::ERROR_BAD_DER, End(input));
@@ -824,8 +760,7 @@ TEST_F(pkixder_input_tests, EndAtBeginning)
 
 // TODO: Need tests for Nested too?
 
-Result NestedOfHelper(Reader& input, std::vector<uint8_t>& readValues)
-{
+Result NestedOfHelper(Reader& input, std::vector<uint8_t>& readValues) {
   uint8_t value = 0;
   Result rv = input.Read(value);
   EXPECT_EQ(Success, rv);
@@ -836,17 +771,15 @@ Result NestedOfHelper(Reader& input, std::vector<uint8_t>& readValues)
   return Success;
 }
 
-TEST_F(pkixder_input_tests, NestedOf)
-{
+TEST_F(pkixder_input_tests, NestedOf) {
   Input buf(DER_SEQUENCE_OF_INT8);
   Reader input(buf);
 
   std::vector<uint8_t> readValues;
-  ASSERT_EQ(Success,
-            NestedOf(input, SEQUENCE, INTEGER, EmptyAllowed::No,
-                     [&readValues](Reader& r) {
-                       return NestedOfHelper(r, readValues);
-                     }));
+  ASSERT_EQ(Success, NestedOf(input, SEQUENCE, INTEGER, EmptyAllowed::No,
+                              [&readValues](Reader& r) {
+                                return NestedOfHelper(r, readValues);
+                              }));
   ASSERT_EQ(3u, readValues.size());
   ASSERT_EQ(0x01, readValues[0]);
   ASSERT_EQ(0x02, readValues[1]);
@@ -854,8 +787,7 @@ TEST_F(pkixder_input_tests, NestedOf)
   ASSERT_EQ(Success, End(input));
 }
 
-TEST_F(pkixder_input_tests, NestedOfWithTruncatedData)
-{
+TEST_F(pkixder_input_tests, NestedOfWithTruncatedData) {
   Input buf(DER_TRUNCATED_SEQUENCE_OF_INT8);
   Reader input(buf);
 
@@ -868,53 +800,48 @@ TEST_F(pkixder_input_tests, NestedOfWithTruncatedData)
   ASSERT_EQ(0u, readValues.size());
 }
 
-TEST_F(pkixder_input_tests, MatchRestAtEnd)
-{
-  static const uint8_t der[1] = { };
+TEST_F(pkixder_input_tests, MatchRestAtEnd) {
+  static const uint8_t der[1] = {};
   Input buf;
   ASSERT_EQ(Success, buf.Init(der, 0));
   Reader input(buf);
   ASSERT_TRUE(input.AtEnd());
-  static const uint8_t toMatch[] = { 1 };
+  static const uint8_t toMatch[] = {1};
   ASSERT_FALSE(input.MatchRest(toMatch));
 }
 
-TEST_F(pkixder_input_tests, MatchRest1Match)
-{
-  static const uint8_t der[] = { 1 };
+TEST_F(pkixder_input_tests, MatchRest1Match) {
+  static const uint8_t der[] = {1};
   Input buf(der);
   Reader input(buf);
   ASSERT_FALSE(input.AtEnd());
   ASSERT_TRUE(input.MatchRest(der));
 }
 
-TEST_F(pkixder_input_tests, MatchRest1Mismatch)
-{
-  static const uint8_t der[] = { 1 };
+TEST_F(pkixder_input_tests, MatchRest1Mismatch) {
+  static const uint8_t der[] = {1};
   Input buf(der);
   Reader input(buf);
-  static const uint8_t toMatch[] = { 2 };
+  static const uint8_t toMatch[] = {2};
   ASSERT_FALSE(input.MatchRest(toMatch));
   ASSERT_FALSE(input.AtEnd());
 }
 
-TEST_F(pkixder_input_tests, MatchRest2WithTrailingByte)
-{
-  static const uint8_t der[] = { 1, 2, 3 };
+TEST_F(pkixder_input_tests, MatchRest2WithTrailingByte) {
+  static const uint8_t der[] = {1, 2, 3};
   Input buf(der);
   Reader input(buf);
-  static const uint8_t toMatch[] = { 1, 2 };
+  static const uint8_t toMatch[] = {1, 2};
   ASSERT_FALSE(input.MatchRest(toMatch));
 }
 
-TEST_F(pkixder_input_tests, MatchRest2Mismatch)
-{
-  static const uint8_t der[] = { 1, 2, 3 };
+TEST_F(pkixder_input_tests, MatchRest2Mismatch) {
+  static const uint8_t der[] = {1, 2, 3};
   Input buf(der);
   Reader input(buf);
-  static const uint8_t toMatchMismatch[] = { 1, 3 };
+  static const uint8_t toMatchMismatch[] = {1, 3};
   ASSERT_FALSE(input.MatchRest(toMatchMismatch));
   ASSERT_TRUE(input.MatchRest(der));
 }
 
-} // namespace
+}  // namespace
