@@ -40,10 +40,10 @@
 #pragma warning(push, 3)
 // C4224: Nonstandard extension used: formal parameter 'X' was previously
 //        defined as a type.
-#pragma warning(disable: 4224)
+#pragma warning(disable : 4224)
 // C4826: Conversion from 'type1 ' to 'type_2' is sign - extended. This may
 //        cause unexpected runtime behavior.
-#pragma warning(disable: 4826)
+#pragma warning(disable : 4826)
 #endif
 
 #include "gtest/gtest.h"
@@ -60,11 +60,10 @@
 #include "pkixtestutil.h"
 
 // PrintTo must be in the same namespace as the type we're overloading it for.
-namespace mozilla { namespace pkix {
+namespace mozilla {
+namespace pkix {
 
-inline void
-PrintTo(const Result& result, ::std::ostream* os)
-{
+inline void PrintTo(const Result& result, ::std::ostream* os) {
   const char* stringified = MapResultToName(result);
   if (stringified) {
     *os << stringified;
@@ -73,9 +72,12 @@ PrintTo(const Result& result, ::std::ostream* os)
   }
 }
 
-} } // namespace mozilla::pkix
+}  // namespace pkix
+}  // namespace mozilla
 
-namespace mozilla { namespace pkix { namespace test {
+namespace mozilla {
+namespace pkix {
+namespace test {
 
 extern const std::time_t oneDayBeforeNow;
 extern const std::time_t oneDayAfterNow;
@@ -84,172 +86,146 @@ extern const std::time_t twoDaysAfterNow;
 extern const std::time_t tenDaysBeforeNow;
 extern const std::time_t tenDaysAfterNow;
 
-
-class EverythingFailsByDefaultTrustDomain : public TrustDomain
-{
-public:
-  Result GetCertTrust(EndEntityOrCA, const CertPolicyId&,
-                      Input, /*out*/ TrustLevel&) override
-  {
+class EverythingFailsByDefaultTrustDomain : public TrustDomain {
+ public:
+  Result GetCertTrust(EndEntityOrCA, const CertPolicyId&, Input,
+                      /*out*/ TrustLevel&) override {
     ADD_FAILURE();
     return NotReached("GetCertTrust should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result FindIssuer(Input, IssuerChecker&, Time) override
-  {
+  Result FindIssuer(Input, IssuerChecker&, Time) override {
     ADD_FAILURE();
     return NotReached("FindIssuer should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
   Result CheckRevocation(EndEntityOrCA, const CertID&, Time, Duration,
-                          /*optional*/ const Input*,
-                          /*optional*/ const Input*) override
-  {
+                         /*optional*/ const Input*,
+                         /*optional*/ const Input*) override {
     ADD_FAILURE();
     return NotReached("CheckRevocation should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result IsChainValid(const DERArray&, Time) override
-  {
+  Result IsChainValid(const DERArray&, Time, const CertPolicyId&) override {
     ADD_FAILURE();
     return NotReached("IsChainValid should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result DigestBuf(Input, DigestAlgorithm, /*out*/ uint8_t*, size_t) override
-  {
+  Result DigestBuf(Input, DigestAlgorithm, /*out*/ uint8_t*, size_t) override {
     ADD_FAILURE();
     return NotReached("DigestBuf should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result CheckSignatureDigestAlgorithm(DigestAlgorithm,
-                                       EndEntityOrCA,
-                                       Time) override
-  {
+  Result CheckSignatureDigestAlgorithm(DigestAlgorithm, EndEntityOrCA,
+                                       Time) override {
     ADD_FAILURE();
     return NotReached("CheckSignatureDigestAlgorithm should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result CheckECDSACurveIsAcceptable(EndEntityOrCA, NamedCurve) override
-  {
+  Result CheckECDSACurveIsAcceptable(EndEntityOrCA, NamedCurve) override {
     ADD_FAILURE();
     return NotReached("CheckECDSACurveIsAcceptable should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result VerifyECDSASignedDigest(const SignedDigest&, Input) override
-  {
+  Result VerifyECDSASignedDigest(const SignedDigest&, Input) override {
     ADD_FAILURE();
     return NotReached("VerifyECDSASignedDigest should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result CheckRSAPublicKeyModulusSizeInBits(EndEntityOrCA, unsigned int)
-                                            override
-  {
+  Result CheckRSAPublicKeyModulusSizeInBits(EndEntityOrCA,
+                                            unsigned int) override {
     ADD_FAILURE();
     return NotReached("CheckRSAPublicKeyModulusSizeInBits should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result VerifyRSAPKCS1SignedDigest(const SignedDigest&, Input) override
-  {
+  Result VerifyRSAPKCS1SignedDigest(const SignedDigest&, Input) override {
     ADD_FAILURE();
     return NotReached("VerifyRSAPKCS1SignedDigest should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result CheckValidityIsAcceptable(Time, Time, EndEntityOrCA, KeyPurposeId)
-                                   override
-  {
+  Result CheckValidityIsAcceptable(Time, Time, EndEntityOrCA,
+                                   KeyPurposeId) override {
     ADD_FAILURE();
     return NotReached("CheckValidityIsAcceptable should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  Result NetscapeStepUpMatchesServerAuth(Time, bool&) override
-  {
+  Result NetscapeStepUpMatchesServerAuth(Time, bool&) override {
     ADD_FAILURE();
     return NotReached("NetscapeStepUpMatchesServerAuth should not be called",
                       Result::FATAL_ERROR_LIBRARY_FAILURE);
   }
 
-  virtual void NoteAuxiliaryExtension(AuxiliaryExtension, Input) override
-  {
+  virtual void NoteAuxiliaryExtension(AuxiliaryExtension, Input) override {
     ADD_FAILURE();
   }
 };
 
-class DefaultCryptoTrustDomain : public EverythingFailsByDefaultTrustDomain
-{
+class DefaultCryptoTrustDomain : public EverythingFailsByDefaultTrustDomain {
   Result DigestBuf(Input item, DigestAlgorithm digestAlg,
-                   /*out*/ uint8_t* digestBuf, size_t digestBufLen) override
-  {
+                   /*out*/ uint8_t* digestBuf, size_t digestBufLen) override {
     return TestDigestBuf(item, digestAlg, digestBuf, digestBufLen);
   }
 
-  Result CheckSignatureDigestAlgorithm(DigestAlgorithm, EndEntityOrCA, Time)
-                                       override
-  {
+  Result CheckSignatureDigestAlgorithm(DigestAlgorithm, EndEntityOrCA,
+                                       Time) override {
     return Success;
   }
 
-  Result CheckECDSACurveIsAcceptable(EndEntityOrCA, NamedCurve) override
-  {
+  Result CheckECDSACurveIsAcceptable(EndEntityOrCA, NamedCurve) override {
     return Success;
   }
 
   Result VerifyECDSASignedDigest(const SignedDigest& signedDigest,
-                                 Input subjectPublicKeyInfo) override
-  {
+                                 Input subjectPublicKeyInfo) override {
     return TestVerifyECDSASignedDigest(signedDigest, subjectPublicKeyInfo);
   }
 
-  Result CheckRSAPublicKeyModulusSizeInBits(EndEntityOrCA, unsigned int)
-                                            override
-  {
+  Result CheckRSAPublicKeyModulusSizeInBits(EndEntityOrCA,
+                                            unsigned int) override {
     return Success;
   }
 
   Result VerifyRSAPKCS1SignedDigest(const SignedDigest& signedDigest,
-                                    Input subjectPublicKeyInfo) override
-  {
+                                    Input subjectPublicKeyInfo) override {
     return TestVerifyRSAPKCS1SignedDigest(signedDigest, subjectPublicKeyInfo);
   }
 
-  Result CheckValidityIsAcceptable(Time, Time, EndEntityOrCA, KeyPurposeId)
-                                   override
-  {
+  Result CheckValidityIsAcceptable(Time, Time, EndEntityOrCA,
+                                   KeyPurposeId) override {
     return Success;
   }
 
-  Result NetscapeStepUpMatchesServerAuth(Time, /*out*/ bool& matches) override
-  {
+  Result NetscapeStepUpMatchesServerAuth(Time, /*out*/ bool& matches) override {
     matches = true;
     return Success;
   }
 
-  void NoteAuxiliaryExtension(AuxiliaryExtension, Input) override
-  {
-  }
+  void NoteAuxiliaryExtension(AuxiliaryExtension, Input) override {}
 };
 
-class DefaultNameMatchingPolicy : public NameMatchingPolicy
-{
-public:
+class DefaultNameMatchingPolicy : public NameMatchingPolicy {
+ public:
   virtual Result FallBackToCommonName(
-    Time, /*out*/ FallBackToSearchWithinSubject& fallBackToCommonName) override
-  {
+      Time,
+      /*out*/ FallBackToSearchWithinSubject& fallBackToCommonName) override {
     fallBackToCommonName = FallBackToSearchWithinSubject::Yes;
     return Success;
   }
 };
 
-} } } // namespace mozilla::pkix::test
+}  // namespace test
+}  // namespace pkix
+}  // namespace mozilla
 
-#endif // mozilla_pkix_pkixgtest_h
+#endif  // mozilla_pkix_pkixgtest_h
