@@ -34,22 +34,21 @@
 #include "pkixder.h"
 #include "pkixutil.h"
 
+#include "mozilla/Unused.h"
+
 using namespace std;
 
-namespace mozilla { namespace pkix { namespace test {
+namespace mozilla {
+namespace pkix {
+namespace test {
 
 namespace {
 
-inline void
-fclose_void(FILE* file) {
-  (void) fclose(file);
-}
+inline void fclose_void(FILE* file) { (void)fclose(file); }
 
 typedef mozilla::pkix::ScopedPtr<FILE, fclose_void> ScopedFILE;
 
-FILE*
-OpenFile(const string& dir, const string& filename, const string& mode)
-{
+FILE* OpenFile(const string& dir, const string& filename, const string& mode) {
   string path = dir + '/' + filename;
 
   ScopedFILE file;
@@ -69,11 +68,9 @@ OpenFile(const string& dir, const string& filename, const string& mode)
   return file.release();
 }
 
-} // namespace
+}  // namespace
 
-bool
-InputEqualsByteString(Input input, const ByteString& bs)
-{
+bool InputEqualsByteString(Input input, const ByteString& bs) {
   Input bsInput;
   if (bsInput.Init(bs.data(), bs.length()) != Success) {
     // Init can only fail if it is given a bad pointer or if the input is too
@@ -84,9 +81,7 @@ InputEqualsByteString(Input input, const ByteString& bs)
   return InputsAreEqual(input, bsInput);
 }
 
-ByteString
-InputToByteString(Input input)
-{
+ByteString InputToByteString(Input input) {
   ByteString result;
   Reader reader(input);
   for (;;) {
@@ -98,10 +93,8 @@ InputToByteString(Input input)
   }
 }
 
-Result
-TamperOnce(/*in/out*/ ByteString& item, const ByteString& from,
-           const ByteString& to)
-{
+Result TamperOnce(/*in/out*/ ByteString& item, const ByteString& from,
+                  const ByteString& to) {
   if (from.length() < 8) {
     return Result::FATAL_ERROR_INVALID_ARGS;
   }
@@ -110,19 +103,17 @@ TamperOnce(/*in/out*/ ByteString& item, const ByteString& from,
   }
   size_t pos = item.find(from);
   if (pos == string::npos) {
-    return Result::FATAL_ERROR_INVALID_ARGS; // No matches.
+    return Result::FATAL_ERROR_INVALID_ARGS;  // No matches.
   }
   if (item.find(from, pos + from.length()) != string::npos) {
-    return Result::FATAL_ERROR_INVALID_ARGS; // More than once match.
+    return Result::FATAL_ERROR_INVALID_ARGS;  // More than once match.
   }
   item.replace(pos, from.length(), to);
   return Success;
 }
 
 // Given a tag and a value, generates a DER-encoded tag-length-value item.
-ByteString
-TLV(uint8_t tag, size_t length, const ByteString& value)
-{
+ByteString TLV(uint8_t tag, size_t length, const ByteString& value) {
   ByteString result;
   result.push_back(tag);
 
@@ -145,32 +136,26 @@ TLV(uint8_t tag, size_t length, const ByteString& value)
 }
 
 OCSPResponseExtension::OCSPResponseExtension()
-  : id()
-  , critical(false)
-  , value()
-  , next(nullptr)
-{
-}
+    : id(), critical(false), value(), next(nullptr) {}
 
 OCSPResponseContext::OCSPResponseContext(const CertID& certID, time_t time)
-  : certID(certID)
-  , responseStatus(successful)
-  , skipResponseBytes(false)
-  , producedAt(time)
-  , singleExtensions(nullptr)
-  , responseExtensions(nullptr)
-  , includeEmptyExtensions(false)
-  , signatureAlgorithm(sha256WithRSAEncryption())
-  , badSignature(false)
-  , certs(nullptr)
+    : certID(certID),
+      responseStatus(successful),
+      skipResponseBytes(false),
+      producedAt(time),
+      singleExtensions(nullptr),
+      responseExtensions(nullptr),
+      includeEmptyExtensions(false),
+      signatureAlgorithm(sha256WithRSAEncryption()),
+      badSignature(false),
+      certs(nullptr)
 
-  , certStatus(good)
-  , revocationTime(0)
-  , thisUpdate(time)
-  , nextUpdate(time + static_cast<time_t>(Time::ONE_DAY_IN_SECONDS))
-  , includeNextUpdate(true)
-{
-}
+      ,
+      certStatus(good),
+      revocationTime(0),
+      thisUpdate(time),
+      nextUpdate(time + static_cast<time_t>(Time::ONE_DAY_IN_SECONDS)),
+      includeNextUpdate(true) {}
 
 static ByteString ResponseBytes(OCSPResponseContext& context);
 static ByteString BasicOCSPResponse(OCSPResponseContext& context);
@@ -181,25 +166,21 @@ static ByteString SingleResponse(OCSPResponseContext& context);
 static ByteString CertID(OCSPResponseContext& context);
 static ByteString CertStatus(OCSPResponseContext& context);
 
-static ByteString
-SHA1(const ByteString& toHash)
-{
+static ByteString SHA1(const ByteString& toHash) {
   uint8_t digestBuf[20];
   Input input;
   if (input.Init(toHash.data(), toHash.length()) != Success) {
     abort();
   }
-  Result rv = TestDigestBuf(input, DigestAlgorithm::sha1, digestBuf,
-                            sizeof(digestBuf));
+  Result rv =
+      TestDigestBuf(input, DigestAlgorithm::sha1, digestBuf, sizeof(digestBuf));
   if (rv != Success) {
     abort();
   }
   return ByteString(digestBuf, sizeof(digestBuf));
 }
 
-static ByteString
-HashedOctetString(const ByteString& bytes)
-{
+static ByteString HashedOctetString(const ByteString& bytes) {
   ByteString digest(SHA1(bytes));
   if (ENCODING_FAILED(digest)) {
     return ByteString();
@@ -207,9 +188,7 @@ HashedOctetString(const ByteString& bytes)
   return TLV(der::OCTET_STRING, digest);
 }
 
-static ByteString
-BitString(const ByteString& rawBytes, bool corrupt)
-{
+static ByteString BitString(const ByteString& rawBytes, bool corrupt) {
   ByteString prefixed;
   // We have to add a byte at the beginning indicating no unused bits.
   // TODO: add ability to have bit strings of bit length not divisible by 8,
@@ -223,17 +202,13 @@ BitString(const ByteString& rawBytes, bool corrupt)
   return TLV(der::BIT_STRING, prefixed);
 }
 
-ByteString
-Boolean(bool value)
-{
+ByteString Boolean(bool value) {
   ByteString encodedValue;
   encodedValue.push_back(value ? 0xffu : 0x00u);
   return TLV(der::BOOLEAN, encodedValue);
 }
 
-ByteString
-Integer(long value)
-{
+ByteString Integer(long value) {
   if (value < 0 || value > 127) {
     // TODO: add encoding of larger values
     // It is MUCH more convenient for Integer to be infallible than for it to
@@ -249,10 +224,9 @@ Integer(long value)
 enum TimeEncoding { UTCTime = 0, GeneralizedTime = 1 };
 
 // Windows doesn't provide gmtime_r, but it provides something very similar.
-#if defined(WIN32) && !defined(_POSIX_THREAD_SAFE_FUNCTIONS)
-static tm*
-gmtime_r(const time_t* t, /*out*/ tm* exploded)
-{
+#if defined(WIN32) && \
+    (!defined(_POSIX_C_SOURCE) || !defined(_POSIX_THREAD_SAFE_FUNCTIONS))
+static tm* gmtime_r(const time_t* t, /*out*/ tm* exploded) {
   if (gmtime_s(exploded, t) != 0) {
     return nullptr;
   }
@@ -266,9 +240,7 @@ gmtime_r(const time_t* t, /*out*/ tm* exploded)
 //
 // This assumes that time/time_t are POSIX-compliant in that time() returns
 // the number of seconds since the Unix epoch.
-static ByteString
-TimeToEncodedTime(time_t time, TimeEncoding encoding)
-{
+static ByteString TimeToEncodedTime(time_t time, TimeEncoding encoding) {
   assert(encoding == UTCTime || encoding == GeneralizedTime);
 
   tm exploded;
@@ -313,9 +285,7 @@ TimeToEncodedTime(time_t time, TimeEncoding encoding)
              value);
 }
 
-static ByteString
-TimeToGeneralizedTime(time_t time)
-{
+static ByteString TimeToGeneralizedTime(time_t time) {
   return TimeToEncodedTime(time, GeneralizedTime);
 }
 
@@ -324,25 +294,21 @@ TimeToGeneralizedTime(time_t time)
 // as UTCTime; certificate validity dates in 2050 or later MUST be encoded as
 // GeneralizedTime." (This is a special case of the rule that we must always
 // use the shortest possible encoding.)
-static ByteString
-TimeToTimeChoice(time_t time)
-{
+static ByteString TimeToTimeChoice(time_t time) {
   tm exploded;
   if (!gmtime_r(&time, &exploded)) {
     return ByteString();
   }
-  TimeEncoding encoding = (exploded.tm_year + 1900 >= 1950 &&
-                           exploded.tm_year + 1900 < 2050)
-                        ? UTCTime
-                        : GeneralizedTime;
+  TimeEncoding encoding =
+      (exploded.tm_year + 1900 >= 1950 && exploded.tm_year + 1900 < 2050)
+          ? UTCTime
+          : GeneralizedTime;
 
   return TimeToEncodedTime(time, encoding);
 }
 
-Time
-YMDHMS(uint16_t year, uint16_t month, uint16_t day,
-       uint16_t hour, uint16_t minutes, uint16_t seconds)
-{
+Time YMDHMS(uint16_t year, uint16_t month, uint16_t day, uint16_t hour,
+            uint16_t minutes, uint16_t seconds) {
   assert(year <= 9999);
   assert(month >= 1);
   assert(month <= 12);
@@ -354,9 +320,8 @@ YMDHMS(uint16_t year, uint16_t month, uint16_t day,
   uint64_t days = DaysBeforeYear(year);
 
   {
-    static const int16_t DAYS_IN_MONTH[] = {
-      31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
-    };
+    static const int16_t DAYS_IN_MONTH[] = {31, 28, 31, 30, 31, 30,
+                                            31, 31, 30, 31, 30, 31};
 
     int16_t i = 1;
     for (;;) {
@@ -384,12 +349,11 @@ YMDHMS(uint16_t year, uint16_t month, uint16_t day,
   return TimeFromElapsedSecondsAD(totalSeconds);
 }
 
-static ByteString
-SignedData(const ByteString& tbsData,
-           const TestKeyPair& keyPair,
-           const TestSignatureAlgorithm& signatureAlgorithm,
-           bool corrupt, /*optional*/ const ByteString* certs)
-{
+static ByteString SignedData(const ByteString& tbsData,
+                             const TestKeyPair& keyPair,
+                             const TestSignatureAlgorithm& signatureAlgorithm,
+                             bool corrupt,
+                             /*optional*/ const ByteString* certs) {
   ByteString signature;
   if (keyPair.SignData(tbsData, signatureAlgorithm, signature) != Success) {
     return ByteString();
@@ -410,8 +374,8 @@ SignedData(const ByteString& tbsData,
       ++certs;
     }
     ByteString certsSequence(TLV(der::SEQUENCE, certsSequenceValue));
-    certsNested = TLV(der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0,
-                      certsSequence);
+    certsNested =
+        TLV(der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0, certsSequence);
   }
 
   ByteString value;
@@ -430,9 +394,8 @@ SignedData(const ByteString& tbsData,
 //                  -- corresponding to the extension type identified
 //                  -- by extnID
 //      }
-static ByteString
-Extension(Input extnID, Critical critical, const ByteString& extnValueBytes)
-{
+static ByteString Extension(Input extnID, Critical critical,
+                            const ByteString& extnValueBytes) {
   ByteString encoded;
 
   encoded.append(ByteString(extnID.UnsafeGetData(), extnID.GetLength()));
@@ -447,9 +410,7 @@ Extension(Input extnID, Critical critical, const ByteString& extnValueBytes)
   return TLV(der::SEQUENCE, encoded);
 }
 
-static ByteString
-EmptyExtension(Input extnID, Critical critical)
-{
+static ByteString EmptyExtension(Input extnID, Critical critical) {
   ByteString encoded(extnID.UnsafeGetData(), extnID.GetLength());
 
   if (critical == Critical::Yes) {
@@ -461,9 +422,7 @@ EmptyExtension(Input extnID, Critical critical)
   return TLV(der::SEQUENCE, encoded);
 }
 
-std::string
-GetEnv(const char* name)
-{
+std::string GetEnv(const char* name) {
   std::string result;
 
 #ifndef _MSC_VER
@@ -486,9 +445,7 @@ GetEnv(const char* name)
   return result;
 }
 
-void
-MaybeLogOutput(const ByteString& result, const char* suffix)
-{
+void MaybeLogOutput(const ByteString& result, const char* suffix) {
   assert(suffix);
 
   // This allows us to more easily debug the generated output, by creating a
@@ -509,7 +466,7 @@ MaybeLogOutput(const ByteString& result, const char* suffix)
     ++counter;
     ScopedFILE file(OpenFile(logPath, filename, "wb"));
     if (file) {
-      (void) fwrite(result.data(), result.length(), 1, file.get());
+      Unused << fwrite(result.data(), result.length(), 1, file.get());
     }
   }
 }
@@ -519,9 +476,8 @@ MaybeLogOutput(const ByteString& result, const char* suffix)
 
 static ByteString TBSCertificate(long version, const ByteString& serialNumber,
                                  const ByteString& signature,
-                                 const ByteString& issuer,
-                                 time_t notBefore, time_t notAfter,
-                                 const ByteString& subject,
+                                 const ByteString& issuer, time_t notBefore,
+                                 time_t notAfter, const ByteString& subject,
                                  const ByteString& subjectPublicKeyInfo,
                                  /*optional*/ const ByteString* extensions);
 
@@ -529,24 +485,17 @@ static ByteString TBSCertificate(long version, const ByteString& serialNumber,
 //         tbsCertificate       TBSCertificate,
 //         signatureAlgorithm   AlgorithmIdentifier,
 //         signatureValue       BIT STRING  }
-ByteString
-CreateEncodedCertificate(long version,
-                         const TestSignatureAlgorithm& signature,
-                         const ByteString& serialNumber,
-                         const ByteString& issuerNameDER,
-                         time_t notBefore, time_t notAfter,
-                         const ByteString& subjectNameDER,
-                         const TestKeyPair& subjectKeyPair,
-                         /*optional*/ const ByteString* extensions,
-                         const TestKeyPair& issuerKeyPair,
-                         const TestSignatureAlgorithm& signatureAlgorithm)
-{
-  ByteString tbsCertificate(TBSCertificate(version, serialNumber,
-                                           signature.algorithmIdentifier,
-                                           issuerNameDER, notBefore,
-                                           notAfter, subjectNameDER,
-                                           subjectKeyPair.subjectPublicKeyInfo,
-                                           extensions));
+ByteString CreateEncodedCertificate(
+    long version, const TestSignatureAlgorithm& signature,
+    const ByteString& serialNumber, const ByteString& issuerNameDER,
+    time_t notBefore, time_t notAfter, const ByteString& subjectNameDER,
+    const TestKeyPair& subjectKeyPair,
+    /*optional*/ const ByteString* extensions, const TestKeyPair& issuerKeyPair,
+    const TestSignatureAlgorithm& signatureAlgorithm) {
+  ByteString tbsCertificate(
+      TBSCertificate(version, serialNumber, signature.algorithmIdentifier,
+                     issuerNameDER, notBefore, notAfter, subjectNameDER,
+                     subjectKeyPair.subjectPublicKeyInfo, extensions));
   if (ENCODING_FAILED(tbsCertificate)) {
     return ByteString();
   }
@@ -576,20 +525,19 @@ CreateEncodedCertificate(long version,
 //                           -- If present, version MUST be v2 or v3
 //      extensions      [3]  Extensions OPTIONAL
 //                           -- If present, version MUST be v3 --  }
-static ByteString
-TBSCertificate(long versionValue,
-               const ByteString& serialNumber, const ByteString& signature,
-               const ByteString& issuer, time_t notBeforeTime,
-               time_t notAfterTime, const ByteString& subject,
-               const ByteString& subjectPublicKeyInfo,
-               /*optional*/ const ByteString* extensions)
-{
+static ByteString TBSCertificate(long versionValue,
+                                 const ByteString& serialNumber,
+                                 const ByteString& signature,
+                                 const ByteString& issuer, time_t notBeforeTime,
+                                 time_t notAfterTime, const ByteString& subject,
+                                 const ByteString& subjectPublicKeyInfo,
+                                 /*optional*/ const ByteString* extensions) {
   ByteString value;
 
   if (versionValue != static_cast<long>(der::Version::v1)) {
     ByteString versionInteger(Integer(versionValue));
-    ByteString version(TLV(der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0,
-                           versionInteger));
+    ByteString version(
+        TLV(der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 0, versionInteger));
     value.append(version);
   }
 
@@ -635,7 +583,7 @@ TBSCertificate(long versionValue,
       return ByteString();
     }
     ByteString extensionsWrapped(
-      TLV(der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 3, extensionsSequence));
+        TLV(der::CONTEXT_SPECIFIC | der::CONSTRUCTED | 3, extensionsSequence));
     if (ENCODING_FAILED(extensionsWrapped)) {
       return ByteString();
     }
@@ -660,10 +608,8 @@ TBSCertificate(long versionValue,
 //       utf8String              UTF8String (SIZE (1..MAX)),
 //       bmpString               BMPString (SIZE (1..MAX)) }
 template <size_t N>
-static ByteString
-AVA(const uint8_t (&type)[N], uint8_t directoryStringType,
-    const ByteString& value)
-{
+static ByteString AVA(const uint8_t (&type)[N], uint8_t directoryStringType,
+                      const ByteString& value) {
   ByteString wrappedValue(TLV(directoryStringType, value));
   ByteString ava;
   ava.append(type, N);
@@ -671,39 +617,29 @@ AVA(const uint8_t (&type)[N], uint8_t directoryStringType,
   return TLV(der::SEQUENCE, ava);
 }
 
-ByteString
-CN(const ByteString& value, uint8_t encodingTag)
-{
+ByteString CN(const ByteString& value, uint8_t encodingTag) {
   // id-at OBJECT IDENTIFIER ::= { joint-iso-ccitt(2) ds(5) 4 }
   // id-at-commonName        AttributeType ::= { id-at 3 }
   // python DottedOIDToCode.py --tlv id-at-commonName 2.5.4.3
-  static const uint8_t tlv_id_at_commonName[] = {
-    0x06, 0x03, 0x55, 0x04, 0x03
-  };
+  static const uint8_t tlv_id_at_commonName[] = {0x06, 0x03, 0x55, 0x04, 0x03};
   return AVA(tlv_id_at_commonName, encodingTag, value);
 }
 
-ByteString
-OU(const ByteString& value, uint8_t encodingTag)
-{
+ByteString OU(const ByteString& value, uint8_t encodingTag) {
   // id-at OBJECT IDENTIFIER ::= { joint-iso-ccitt(2) ds(5) 4 }
   // id-at-organizationalUnitName AttributeType ::= { id-at 11 }
   // python DottedOIDToCode.py --tlv id-at-organizationalUnitName 2.5.4.11
-  static const uint8_t tlv_id_at_organizationalUnitName[] = {
-    0x06, 0x03, 0x55, 0x04, 0x0b
-  };
+  static const uint8_t tlv_id_at_organizationalUnitName[] = {0x06, 0x03, 0x55,
+                                                             0x04, 0x0b};
 
   return AVA(tlv_id_at_organizationalUnitName, encodingTag, value);
 }
 
-ByteString
-emailAddress(const ByteString& value)
-{
+ByteString emailAddress(const ByteString& value) {
   // id-emailAddress AttributeType ::= { pkcs-9 1 }
   // python DottedOIDToCode.py --tlv id-emailAddress 1.2.840.113549.1.9.1
   static const uint8_t tlv_id_emailAddress[] = {
-    0x06, 0x09, 0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d, 0x01, 0x09, 0x01
-  };
+      0x06, 0x09, 0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d, 0x01, 0x09, 0x01};
 
   return AVA(tlv_id_emailAddress, der::IA5String, value);
 }
@@ -711,37 +647,25 @@ emailAddress(const ByteString& value)
 // RelativeDistinguishedName ::=
 //   SET SIZE (1..MAX) OF AttributeTypeAndValue
 //
-ByteString
-RDN(const ByteString& avas)
-{
-  return TLV(der::SET, avas);
-}
+ByteString RDN(const ByteString& avas) { return TLV(der::SET, avas); }
 
 // Name ::= CHOICE { -- only one possibility for now --
 //   rdnSequence  RDNSequence }
 //
 // RDNSequence ::= SEQUENCE OF RelativeDistinguishedName
 //
-ByteString
-Name(const ByteString& rdns)
-{
-  return TLV(der::SEQUENCE, rdns);
-}
+ByteString Name(const ByteString& rdns) { return TLV(der::SEQUENCE, rdns); }
 
-ByteString
-CreateEncodedSerialNumber(long serialNumberValue)
-{
+ByteString CreateEncodedSerialNumber(long serialNumberValue) {
   return Integer(serialNumberValue);
 }
 
 // BasicConstraints ::= SEQUENCE {
 //         cA                      BOOLEAN DEFAULT FALSE,
 //         pathLenConstraint       INTEGER (0..MAX) OPTIONAL }
-ByteString
-CreateEncodedBasicConstraints(bool isCA,
-                              /*optional*/ long* pathLenConstraintValue,
-                              Critical critical)
-{
+ByteString CreateEncodedBasicConstraints(
+    bool isCA,
+    /*optional in*/ const long* pathLenConstraintValue, Critical critical) {
   ByteString value;
 
   if (isCA) {
@@ -755,50 +679,38 @@ CreateEncodedBasicConstraints(bool isCA,
   }
 
   // python DottedOIDToCode.py --tlv id-ce-basicConstraints 2.5.29.19
-  static const uint8_t tlv_id_ce_basicConstraints[] = {
-    0x06, 0x03, 0x55, 0x1d, 0x13
-  };
+  static const uint8_t tlv_id_ce_basicConstraints[] = {0x06, 0x03, 0x55, 0x1d,
+                                                       0x13};
   return Extension(Input(tlv_id_ce_basicConstraints), critical, value);
 }
 
 // ExtKeyUsageSyntax ::= SEQUENCE SIZE (1..MAX) OF KeyPurposeId
 // KeyPurposeId ::= OBJECT IDENTIFIER
-ByteString
-CreateEncodedEKUExtension(Input ekuOID, Critical critical)
-{
+ByteString CreateEncodedEKUExtension(Input ekuOID, Critical critical) {
   ByteString value(ekuOID.UnsafeGetData(), ekuOID.GetLength());
 
   // python DottedOIDToCode.py --tlv id-ce-extKeyUsage 2.5.29.37
-  static const uint8_t tlv_id_ce_extKeyUsage[] = {
-    0x06, 0x03, 0x55, 0x1d, 0x25
-  };
+  static const uint8_t tlv_id_ce_extKeyUsage[] = {0x06, 0x03, 0x55, 0x1d, 0x25};
 
   return Extension(Input(tlv_id_ce_extKeyUsage), critical, value);
 }
 
 // python DottedOIDToCode.py --tlv id-ce-subjectAltName 2.5.29.17
-static const uint8_t tlv_id_ce_subjectAltName[] = {
-  0x06, 0x03, 0x55, 0x1d, 0x11
-};
+static const uint8_t tlv_id_ce_subjectAltName[] = {0x06, 0x03, 0x55, 0x1d,
+                                                   0x11};
 
-ByteString
-CreateEncodedSubjectAltName(const ByteString& names)
-{
+ByteString CreateEncodedSubjectAltName(const ByteString& names) {
   return Extension(Input(tlv_id_ce_subjectAltName), Critical::No, names);
 }
 
-ByteString
-CreateEncodedEmptySubjectAltName()
-{
+ByteString CreateEncodedEmptySubjectAltName() {
   return EmptyExtension(Input(tlv_id_ce_subjectAltName), Critical::No);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 // OCSP responses
 
-ByteString
-CreateEncodedOCSPResponse(OCSPResponseContext& context)
-{
+ByteString CreateEncodedOCSPResponse(OCSPResponseContext& context) {
   if (!context.skipResponseBytes) {
     if (!context.signerKeyPair) {
       return ByteString();
@@ -829,8 +741,8 @@ CreateEncodedOCSPResponse(OCSPResponseContext& context)
       return ByteString();
     }
 
-    responseBytesNested = TLV(der::CONSTRUCTED | der::CONTEXT_SPECIFIC,
-                              responseBytes);
+    responseBytesNested =
+        TLV(der::CONSTRUCTED | der::CONTEXT_SPECIFIC, responseBytes);
   }
 
   ByteString value;
@@ -846,13 +758,10 @@ CreateEncodedOCSPResponse(OCSPResponseContext& context)
 // ResponseBytes ::= SEQUENCE {
 //    responseType            OBJECT IDENTIFIER,
 //    response                OCTET STRING }
-ByteString
-ResponseBytes(OCSPResponseContext& context)
-{
+ByteString ResponseBytes(OCSPResponseContext& context) {
   // Includes tag and length
   static const uint8_t id_pkix_ocsp_basic_encoded[] = {
-    0x06, 0x09, 0x2B, 0x06, 0x01, 0x05, 0x05, 0x07, 0x30, 0x01, 0x01
-  };
+      0x06, 0x09, 0x2B, 0x06, 0x01, 0x05, 0x05, 0x07, 0x30, 0x01, 0x01};
   ByteString response(BasicOCSPResponse(context));
   if (ENCODING_FAILED(response)) {
     return ByteString();
@@ -860,8 +769,7 @@ ResponseBytes(OCSPResponseContext& context)
   ByteString responseNested = TLV(der::OCTET_STRING, response);
 
   ByteString value;
-  value.append(id_pkix_ocsp_basic_encoded,
-               sizeof(id_pkix_ocsp_basic_encoded));
+  value.append(id_pkix_ocsp_basic_encoded, sizeof(id_pkix_ocsp_basic_encoded));
   value.append(responseNested);
   return TLV(der::SEQUENCE, value);
 }
@@ -871,9 +779,7 @@ ResponseBytes(OCSPResponseContext& context)
 //   signatureAlgorithm       AlgorithmIdentifier,
 //   signature                BIT STRING,
 //   certs                [0] EXPLICIT SEQUENCE OF Certificate OPTIONAL }
-ByteString
-BasicOCSPResponse(OCSPResponseContext& context)
-{
+ByteString BasicOCSPResponse(OCSPResponseContext& context) {
   ByteString tbsResponseData(ResponseData(context));
   if (ENCODING_FAILED(tbsResponseData)) {
     return ByteString();
@@ -889,9 +795,7 @@ BasicOCSPResponse(OCSPResponseContext& context)
 //   critical         BOOLEAN DEFAULT FALSE
 //   value            OCTET STRING
 // }
-static ByteString
-OCSPExtension(OCSPResponseExtension& extension)
-{
+static ByteString OCSPExtension(OCSPResponseExtension& extension) {
   ByteString encoded;
   encoded.append(extension.id);
   if (extension.critical) {
@@ -905,12 +809,10 @@ OCSPExtension(OCSPResponseExtension& extension)
 // Extensions ::= [1] {
 //   SEQUENCE OF Extension
 // }
-static ByteString
-OCSPExtensions(OCSPResponseExtension* extensions)
-{
+static ByteString OCSPExtensions(OCSPResponseExtension* extensions) {
   ByteString value;
-  for (OCSPResponseExtension* extension = extensions;
-       extension; extension = extension->next) {
+  for (OCSPResponseExtension* extension = extensions; extension;
+       extension = extension->next) {
     ByteString extensionEncoded(OCSPExtension(*extension));
     if (ENCODING_FAILED(extensionEncoded)) {
       return ByteString();
@@ -927,9 +829,7 @@ OCSPExtensions(OCSPResponseExtension* extensions)
 //    producedAt              GeneralizedTime,
 //    responses               SEQUENCE OF SingleResponse,
 //    responseExtensions  [1] EXPLICIT Extensions OPTIONAL }
-ByteString
-ResponseData(OCSPResponseContext& context)
-{
+ByteString ResponseData(OCSPResponseContext& context) {
   ByteString responderID(ResponderID(context));
   if (ENCODING_FAILED(responderID)) {
     return ByteString();
@@ -960,20 +860,18 @@ ResponseData(OCSPResponseContext& context)
 //    byName              [1] Name,
 //    byKey               [2] KeyHash }
 // }
-ByteString
-ResponderID(OCSPResponseContext& context)
-{
+ByteString ResponderID(OCSPResponseContext& context) {
   ByteString contents;
   uint8_t responderIDType;
   if (!context.signerNameDER.empty()) {
     contents = context.signerNameDER;
-    responderIDType = 1; // byName
+    responderIDType = 1;  // byName
   } else {
     contents = KeyHash(context.signerKeyPair->subjectPublicKey);
     if (ENCODING_FAILED(contents)) {
       return ByteString();
     }
-    responderIDType = 2; // byKey
+    responderIDType = 2;  // byKey
   }
 
   // XXX: MSVC 2015 wrongly warns about signed/unsigned conversion without the
@@ -988,9 +886,7 @@ ResponderID(OCSPResponseContext& context)
 //                          -- BIT STRING subjectPublicKey [excluding
 //                          -- the tag, length, and number of unused
 //                          -- bits] in the responder's certificate)
-ByteString
-KeyHash(const ByteString& subjectPublicKey)
-{
+ByteString KeyHash(const ByteString& subjectPublicKey) {
   return HashedOctetString(subjectPublicKey);
 }
 
@@ -1000,9 +896,7 @@ KeyHash(const ByteString& subjectPublicKey)
 //    thisUpdate              GeneralizedTime,
 //    nextUpdate          [0] EXPLICIT GeneralizedTime OPTIONAL,
 //    singleExtensions    [1] EXPLICIT Extensions OPTIONAL }
-ByteString
-SingleResponse(OCSPResponseContext& context)
-{
+ByteString SingleResponse(OCSPResponseContext& context) {
   ByteString certID(CertID(context));
   if (ENCODING_FAILED(certID)) {
     return ByteString();
@@ -1021,8 +915,8 @@ SingleResponse(OCSPResponseContext& context)
     if (ENCODING_FAILED(nextUpdateEncoded)) {
       return ByteString();
     }
-    nextUpdateEncodedNested = TLV(der::CONSTRUCTED | der::CONTEXT_SPECIFIC | 0,
-                                  nextUpdateEncoded);
+    nextUpdateEncodedNested =
+        TLV(der::CONSTRUCTED | der::CONTEXT_SPECIFIC | 0, nextUpdateEncoded);
   }
   ByteString singleExtensions;
   if (context.singleExtensions || context.includeEmptyExtensions) {
@@ -1043,9 +937,7 @@ SingleResponse(OCSPResponseContext& context)
 //        issuerNameHash      OCTET STRING, -- Hash of issuer's DN
 //        issuerKeyHash       OCTET STRING, -- Hash of issuer's public key
 //        serialNumber        CertificateSerialNumber }
-ByteString
-CertID(OCSPResponseContext& context)
-{
+ByteString CertID(OCSPResponseContext& context) {
   ByteString issuerName(context.certID.issuer.UnsafeGetData(),
                         context.certID.issuer.GetLength());
   ByteString issuerNameHash(HashedOctetString(issuerName));
@@ -1068,8 +960,7 @@ CertID(OCSPResponseContext& context)
       return ByteString();
     }
     Input subjectPublicKey;
-    if (der::BitStringWithNoUnusedBits(contents, subjectPublicKey)
-          != Success) {
+    if (der::BitStringWithNoUnusedBits(contents, subjectPublicKey) != Success) {
       return ByteString();
     }
     issuerKeyHash = KeyHash(ByteString(subjectPublicKey.UnsafeGetData(),
@@ -1084,9 +975,8 @@ CertID(OCSPResponseContext& context)
   ByteString serialNumber(TLV(der::INTEGER, serialNumberValue));
 
   // python DottedOIDToCode.py --alg id-sha1 1.3.14.3.2.26
-  static const uint8_t alg_id_sha1[] = {
-    0x30, 0x07, 0x06, 0x05, 0x2b, 0x0e, 0x03, 0x02, 0x1a
-  };
+  static const uint8_t alg_id_sha1[] = {0x30, 0x07, 0x06, 0x05, 0x2b,
+                                        0x0e, 0x03, 0x02, 0x1a};
 
   ByteString value;
   value.append(alg_id_sha1, sizeof(alg_id_sha1));
@@ -1107,22 +997,19 @@ CertID(OCSPResponseContext& context)
 //
 // UnknownInfo ::= NULL
 //
-ByteString
-CertStatus(OCSPResponseContext& context)
-{
+ByteString CertStatus(OCSPResponseContext& context) {
   switch (context.certStatus) {
     // Both good and unknown are ultimately represented as NULL - the only
     // difference is in the tag that identifies them.
     case 0:
-    case 2:
-    {
+    case 2: {
       // XXX: MSVC 2015 wrongly warns about signed/unsigned conversion without
       // the static cast.
-      return TLV(static_cast<uint8_t>(der::CONTEXT_SPECIFIC |
-                                      context.certStatus), ByteString());
+      return TLV(
+          static_cast<uint8_t>(der::CONTEXT_SPECIFIC | context.certStatus),
+          ByteString());
     }
-    case 1:
-    {
+    case 1: {
       ByteString revocationTime(TimeToGeneralizedTime(context.revocationTime));
       if (ENCODING_FAILED(revocationTime)) {
         return ByteString();
@@ -1142,12 +1029,12 @@ static const ByteString NO_UNUSED_BITS(1, 0x00);
 // The SubjectPublicKeyInfo syntax is specified in RFC 5280 Section 4.1.
 TestKeyPair::TestKeyPair(const TestPublicKeyAlgorithm& publicKeyAlg,
                          const ByteString& spk)
-  : publicKeyAlg(publicKeyAlg)
-  , subjectPublicKeyInfo(TLV(der::SEQUENCE,
-                             publicKeyAlg.algorithmIdentifier +
-                             TLV(der::BIT_STRING, NO_UNUSED_BITS + spk)))
-  , subjectPublicKey(spk)
-{
-}
+    : publicKeyAlg(publicKeyAlg),
+      subjectPublicKeyInfo(
+          TLV(der::SEQUENCE, publicKeyAlg.algorithmIdentifier +
+                                 TLV(der::BIT_STRING, NO_UNUSED_BITS + spk))),
+      subjectPublicKey(spk) {}
 
-} } } // namespace mozilla::pkix::test
+}  // namespace test
+}  // namespace pkix
+}  // namespace mozilla
