@@ -130,7 +130,7 @@ var prefs2 = [
  */
 
 // Add prefs,passwords and bookmarks to profile1 and sync.
-Phase('phase1', [
+Phase("phase1", [
   [Passwords.add, passwords_initial],
   [Bookmarks.add, bookmarks_initial],
   [Prefs.modify, prefs1],
@@ -139,7 +139,7 @@ Phase('phase1', [
 ]);
 
 // Sync profile2 and verify same prefs,passwords and bookmarks are present.
-Phase('phase2', [
+Phase("phase2", [
   [Sync],
   [Prefs.verify, prefs1],
   [Passwords.verify, passwords_initial],
@@ -149,7 +149,7 @@ Phase('phase2', [
 // Using profile1, change some prefs,bookmarks and pwds, then do another sync with wipe-client.
 // Verify that the cloud's  settings are restored, and the recent local changes
 // discarded.
-Phase('phase3', [
+Phase("phase3", [
   [Prefs.modify, prefs2],
   [Passwords.modify, passwords_initial],
   [Bookmarks.modify, bookmarks_initial],
