@@ -4,39 +4,19 @@
 _("Test that node reassignment responses are respected on all kinds of " +
   "requests.");
 
-Cu.import("resource://gre/modules/Log.jsm");
-Cu.import("resource://services-common/rest.js");
-Cu.import("resource://services-sync/constants.js");
-Cu.import("resource://services-sync/service.js");
-Cu.import("resource://services-sync/status.js");
-Cu.import("resource://services-sync/util.js");
-Cu.import("resource://testing-common/services/sync/rotaryengine.js");
-Cu.import("resource://testing-common/services/sync/utils.js");
+ChromeUtils.import("resource://gre/modules/Log.jsm");
+ChromeUtils.import("resource://services-common/rest.js");
+ChromeUtils.import("resource://services-sync/constants.js");
+ChromeUtils.import("resource://services-sync/service.js");
+ChromeUtils.import("resource://services-sync/status.js");
+ChromeUtils.import("resource://services-sync/util.js");
+ChromeUtils.import("resource://testing-common/services/sync/rotaryengine.js");
+ChromeUtils.import("resource://gre/modules/PromiseUtils.jsm");
 
-Service.engineManager.clear();
 
-function run_test() {
-  Log.repository.getLogger("Sync.AsyncResource").level = Log.Level.Trace;
-  Log.repository.getLogger("Sync.ErrorHandler").level  = Log.Level.Trace;
-  Log.repository.getLogger("Sync.Resource").level      = Log.Level.Trace;
-  Log.repository.getLogger("Sync.RESTRequest").level   = Log.Level.Trace;
-  Log.repository.getLogger("Sync.Service").level       = Log.Level.Trace;
-  Log.repository.getLogger("Sync.SyncScheduler").level = Log.Level.Trace;
-  initTestLogging();
-
-  ensureLegacyIdentityManager();
-
-  Service.engineManager.register(RotaryEngine);
-
-  // None of the failures in this file should result in a UI error.
-  function onUIError() {
-    do_throw("Errors should not be presented in the UI.");
-  }
-  Svc.Obs.add("weave:ui:login:error", onUIError);
-  Svc.Obs.add("weave:ui:sync:error", onUIError);
-
-  run_next_test();
-}
+add_task(async function setup() {
+  validate_all_future_pings();
+});
 
 /**
  * Emulate the following Zeus config:
@@ -58,46 +38,25 @@ function handleReassign(handler, req, resp) {
   resp.bodyOutputStream.write(reassignBody, reassignBody.length);
 }
 
-/**
- * A node assignment handler.
- */
-function installNodeHandler(server, next) {
-  let newNodeBody = server.baseURI;
-  function handleNodeRequest(req, resp) {
-    _("Client made a request for a node reassignment.");
-    resp.setStatusLine(req.httpVersion, 200, "OK");
-    resp.setHeader("Content-Type", "text/plain");
-    resp.bodyOutputStream.write(newNodeBody, newNodeBody.length);
-    Utils.nextTick(next);
-  }
-  let nodePath = "/user/1.0/johndoe/node/weave";
-  server.server.registerPathHandler(nodePath, handleNodeRequest);
-  _("Registered node handler at " + nodePath);
-}
-
-function prepareServer() {
-  let deferred = Promise.defer();
-  configureIdentity({username: "johndoe"}).then(() => {
-    let server = new SyncServer();
-    server.registerUser("johndoe");
-    server.start();
-    Service.serverURL = server.baseURI;
-    Service.clusterURL = server.baseURI;
-    do_check_eq(Service.userAPIURI, server.baseURI + "user/1.0/");
-    deferred.resolve(server);
-  });
-  return deferred.promise;
+async function prepareServer() {
+  let server = new SyncServer();
+  server.registerUser("johndoe");
+  server.start();
+  syncTestLogging();
+  await configureIdentity({username: "johndoe"}, server);
+  return server;
 }
 
 function getReassigned() {
   try {
     return Services.prefs.getBoolPref("services.sync.lastSyncReassigned");
-  } catch (ex if (ex.result == Cr.NS_ERROR_UNEXPECTED)) {
-    return false;
   } catch (ex) {
-    do_throw("Got exception retrieving lastSyncReassigned: " +
-             Utils.exceptionStr(ex));
+    if (ex.result != Cr.NS_ERROR_UNEXPECTED) {
+      do_throw("Got exception retrieving lastSyncReassigned: " +
+               Log.exceptionStr(ex));
+    }
   }
+  return false;
 }
 
 /**
@@ -106,79 +65,80 @@ function getReassigned() {
  * Runs `between` between the two. This can be used to undo deliberate failure
  * setup, detach observers, etc.
  */
-function syncAndExpectNodeReassignment(server, firstNotification, between,
+async function syncAndExpectNodeReassignment(server, firstNotification, between,
                                        secondNotification, url) {
-  let deferred = Promise.defer();
-  function onwards() {
-    let nodeFetched = false;
-    function onFirstSync() {
-      _("First sync completed.");
-      Svc.Obs.remove(firstNotification, onFirstSync);
-      Svc.Obs.add(secondNotification, onSecondSync);
+  let deferred = PromiseUtils.defer();
 
-      do_check_eq(Service.clusterURL, "");
-
-      // Track whether we fetched node/weave. We want to wait for the second
-      // sync to finish so that we're cleaned up for the next test, so don't
-      // run_next_test in the node handler.
-      nodeFetched = false;
-
-      // Verify that the client requests a node reassignment.
-      // Install a node handler to watch for these requests.
-      installNodeHandler(server, function () {
-        nodeFetched = true;
-      });
-
-      // Allow for tests to clean up error conditions.
-      between();
-    }
-    function onSecondSync() {
-      _("Second sync completed.");
-      Svc.Obs.remove(secondNotification, onSecondSync);
-      Service.scheduler.clearSyncTriggers();
-
-      // Make absolutely sure that any event listeners are done with their work
-      // before we proceed.
-      waitForZeroTimer(function () {
-        _("Second sync nextTick.");
-        do_check_true(nodeFetched);
-        Service.startOver();
-        server.stop(deferred.resolve);
-      });
-    }
-
-    Svc.Obs.add(firstNotification, onFirstSync);
-    Service.sync();
-  }
+  let getTokenCount = 0;
+  let mockTSC = { // TokenServerClient
+    async getTokenFromBrowserIDAssertion(uri, assertion) {
+      getTokenCount++;
+      return {endpoint: server.baseURI + "1.1/johndoe/"};
+    },
+  };
+  Service.identity._tokenServerClient = mockTSC;
 
   // Make sure that it works!
-  let request = new RESTRequest(url);
-  request.get(function () {
-    do_check_eq(request.response.status, 401);
-    Utils.nextTick(onwards);
+  await new Promise(res => {
+    let request = new RESTRequest(url);
+    request.get(function() {
+      Assert.equal(request.response.status, 401);
+      res();
+    });
   });
-  yield deferred.promise;
+
+  function onFirstSync() {
+    _("First sync completed.");
+    Svc.Obs.remove(firstNotification, onFirstSync);
+    Svc.Obs.add(secondNotification, onSecondSync);
+
+    Assert.equal(Service.clusterURL, "");
+
+    // Allow for tests to clean up error conditions.
+    between();
+  }
+  function onSecondSync() {
+    _("Second sync completed.");
+    Svc.Obs.remove(secondNotification, onSecondSync);
+    Service.scheduler.clearSyncTriggers();
+
+    // Make absolutely sure that any event listeners are done with their work
+    // before we proceed.
+    waitForZeroTimer(function() {
+      _("Second sync nextTick.");
+      Assert.equal(getTokenCount, 1);
+      Service.startOver().then(() => {
+        server.stop(deferred.resolve);
+      });
+    });
+  }
+
+  Svc.Obs.add(firstNotification, onFirstSync);
+  await Service.sync();
+
+  await deferred.promise;
 }
 
-add_task(function test_momentary_401_engine() {
+add_task(async function test_momentary_401_engine() {
+  enableValidationPrefs();
+
   _("Test a failure for engine URLs that's resolved by reassignment.");
-  let server = yield prepareServer();
+  let server = await prepareServer();
   let john   = server.user("johndoe");
 
   _("Enabling the Rotary engine.");
-  let engine = Service.engineManager.get("rotary");
-  engine.enabled = true;
+  let { engine, tracker } = await registerRotaryEngine();
 
   // We need the server to be correctly set up prior to experimenting. Do this
   // through a sync.
   let global = {syncID: Service.syncID,
                 storageVersion: STORAGE_VERSION,
                 rotary: {version: engine.version,
-                         syncID:  engine.syncID}}
+                         syncID:  engine.syncID}};
   john.createCollection("meta").insert("global", global);
 
   _("First sync to prepare server contents.");
-  Service.sync();
+  await Service.sync();
 
   _("Setting up Rotary collection to 401.");
   let rotary = john.createCollection("rotary");
@@ -197,27 +157,32 @@ add_task(function test_momentary_401_engine() {
       // lastSyncReassigned shouldn't be cleared until a sync has succeeded.
       _("Ensuring that lastSyncReassigned is still set at next sync start.");
       Svc.Obs.remove("weave:service:login:start", onLoginStart);
-      do_check_true(getReassigned());
+      Assert.ok(getReassigned());
     }
 
     _("Adding observer that lastSyncReassigned is still set on login.");
     Svc.Obs.add("weave:service:login:start", onLoginStart);
   }
 
-  yield syncAndExpectNodeReassignment(server,
+  await syncAndExpectNodeReassignment(server,
                                       "weave:service:sync:finish",
                                       between,
                                       "weave:service:sync:finish",
                                       Service.storageURL + "rotary");
+
+  await tracker.clearChangedIDs();
+  await Service.engineManager.unregister(engine);
 });
 
 // This test ends up being a failing fetch *after we're already logged in*.
-add_task(function test_momentary_401_info_collections() {
+add_task(async function test_momentary_401_info_collections() {
+  enableValidationPrefs();
+
   _("Test a failure for info/collections that's resolved by reassignment.");
-  let server = yield prepareServer();
+  let server = await prepareServer();
 
   _("First sync to prepare server contents.");
-  Service.sync();
+  await Service.sync();
 
   // Return a 401 for info requests, particularly info/collections.
   let oldHandler = server.toplevelHandlers.info;
@@ -228,20 +193,22 @@ add_task(function test_momentary_401_info_collections() {
     server.toplevelHandlers.info = oldHandler;
   }
 
-  yield syncAndExpectNodeReassignment(server,
+  await syncAndExpectNodeReassignment(server,
                                       "weave:service:sync:error",
                                       undo,
                                       "weave:service:sync:finish",
                                       Service.infoURL);
 });
 
-add_task(function test_momentary_401_storage_loggedin() {
+add_task(async function test_momentary_401_storage_loggedin() {
+  enableValidationPrefs();
+
   _("Test a failure for any storage URL, not just engine parts. " +
     "Resolved by reassignment.");
-  let server = yield prepareServer();
+  let server = await prepareServer();
 
-  _("Performing initial sync to ensure we are logged in.")
-  Service.sync();
+  _("Performing initial sync to ensure we are logged in.");
+  await Service.sync();
 
   // Return a 401 for all storage requests.
   let oldHandler = server.toplevelHandlers.storage;
@@ -252,18 +219,20 @@ add_task(function test_momentary_401_storage_loggedin() {
     server.toplevelHandlers.storage = oldHandler;
   }
 
-  do_check_true(Service.isLoggedIn, "already logged in");
-  yield syncAndExpectNodeReassignment(server,
+  Assert.ok(Service.isLoggedIn, "already logged in");
+  await syncAndExpectNodeReassignment(server,
                                       "weave:service:sync:error",
                                       undo,
                                       "weave:service:sync:finish",
                                       Service.storageURL + "meta/global");
 });
 
-add_task(function test_momentary_401_storage_loggedout() {
+add_task(async function test_momentary_401_storage_loggedout() {
+  enableValidationPrefs();
+
   _("Test a failure for any storage URL, not just engine parts. " +
     "Resolved by reassignment.");
-  let server = yield prepareServer();
+  let server = await prepareServer();
 
   // Return a 401 for all storage requests.
   let oldHandler = server.toplevelHandlers.storage;
@@ -274,19 +243,21 @@ add_task(function test_momentary_401_storage_loggedout() {
     server.toplevelHandlers.storage = oldHandler;
   }
 
-  do_check_false(Service.isLoggedIn, "not already logged in");
-  yield syncAndExpectNodeReassignment(server,
+  Assert.ok(!Service.isLoggedIn, "not already logged in");
+  await syncAndExpectNodeReassignment(server,
                                       "weave:service:login:error",
                                       undo,
                                       "weave:service:sync:finish",
                                       Service.storageURL + "meta/global");
 });
 
-add_task(function test_loop_avoidance_storage() {
+add_task(async function test_loop_avoidance_storage() {
+  enableValidationPrefs();
+
   _("Test that a repeated failure doesn't result in a sync loop " +
     "if node reassignment cannot resolve the failure.");
 
-  let server = yield prepareServer();
+  let server = await prepareServer();
 
   // Return a 401 for all storage requests.
   let oldHandler = server.toplevelHandlers.storage;
@@ -296,8 +267,16 @@ add_task(function test_loop_avoidance_storage() {
   let secondNotification = "weave:service:login:error";
   let thirdNotification  = "weave:service:sync:finish";
 
-  let nodeFetched = false;
-  let deferred = Promise.defer();
+  let deferred = PromiseUtils.defer();
+
+  let getTokenCount = 0;
+  let mockTSC = { // TokenServerClient
+    async getTokenFromBrowserIDAssertion(uri, assertion) {
+      getTokenCount++;
+      return {endpoint: server.baseURI + "1.1/johndoe/"};
+    },
+  };
+  Service.identity._tokenServerClient = mockTSC;
 
   // Track the time. We want to make sure the duration between the first and
   // second sync is small, and then that the duration between second and third
@@ -309,21 +288,10 @@ add_task(function test_loop_avoidance_storage() {
     Svc.Obs.remove(firstNotification, onFirstSync);
     Svc.Obs.add(secondNotification, onSecondSync);
 
-    do_check_eq(Service.clusterURL, "");
+    Assert.equal(Service.clusterURL, "");
 
     // We got a 401 mid-sync, and set the pref accordingly.
-    do_check_true(Services.prefs.getBoolPref("services.sync.lastSyncReassigned"));
-
-    // Track whether we fetched node/weave. We want to wait for the second
-    // sync to finish so that we're cleaned up for the next test, so don't
-    // run_next_test in the node handler.
-    nodeFetched = false;
-
-    // Verify that the client requests a node reassignment.
-    // Install a node handler to watch for these requests.
-    installNodeHandler(server, function () {
-      nodeFetched = true;
-    });
+    Assert.ok(Services.prefs.getBoolPref("services.sync.lastSyncReassigned"));
 
     // Update the timestamp.
     now = Date.now();
@@ -336,10 +304,10 @@ add_task(function test_loop_avoidance_storage() {
 
     // This sync occurred within the backoff interval.
     let elapsedTime = Date.now() - now;
-    do_check_true(elapsedTime < MINIMUM_BACKOFF_INTERVAL);
+    Assert.ok(elapsedTime < MINIMUM_BACKOFF_INTERVAL);
 
     // This pref will be true until a sync completes successfully.
-    do_check_true(getReassigned());
+    Assert.ok(getReassigned());
 
     // The timer will be set for some distant time.
     // We store nextSync in prefs, which offers us only limited resolution.
@@ -348,8 +316,8 @@ add_task(function test_loop_avoidance_storage() {
     _("Next sync scheduled for " + Service.scheduler.nextSync);
     _("Expected to be slightly greater than " + expectedNextSync);
 
-    do_check_true(Service.scheduler.nextSync >= expectedNextSync);
-    do_check_true(!!Service.scheduler.syncTimer);
+    Assert.ok(Service.scheduler.nextSync >= expectedNextSync);
+    Assert.ok(!!Service.scheduler.syncTimer);
 
     // Undo our evil scheme.
     server.toplevelHandlers.storage = oldHandler;
@@ -366,43 +334,54 @@ add_task(function test_loop_avoidance_storage() {
 
     // Make absolutely sure that any event listeners are done with their work
     // before we proceed.
-    waitForZeroTimer(function () {
+    waitForZeroTimer(function() {
       _("Third sync nextTick.");
-      do_check_false(getReassigned());
-      do_check_true(nodeFetched);
-      Service.startOver();
-      server.stop(deferred.resolve);
+      Assert.ok(!getReassigned());
+      Assert.equal(getTokenCount, 2);
+      Service.startOver().then(() => {
+        server.stop(deferred.resolve);
+      });
     });
   }
 
   Svc.Obs.add(firstNotification, onFirstSync);
 
   now = Date.now();
-  Service.sync();
-  yield deferred.promise;
+  await Service.sync();
+  await deferred.promise;
 });
 
-add_task(function test_loop_avoidance_engine() {
+add_task(async function test_loop_avoidance_engine() {
+  enableValidationPrefs();
+
   _("Test that a repeated 401 in an engine doesn't result in a sync loop " +
     "if node reassignment cannot resolve the failure.");
-  let server = yield prepareServer();
+  let server = await prepareServer();
   let john   = server.user("johndoe");
 
   _("Enabling the Rotary engine.");
-  let engine = Service.engineManager.get("rotary");
-  engine.enabled = true;
-  let deferred = Promise.defer();
+  let { engine, tracker } = await registerRotaryEngine();
+  let deferred = PromiseUtils.defer();
+
+  let getTokenCount = 0;
+  let mockTSC = { // TokenServerClient
+    getTokenFromBrowserIDAssertion(uri, assertion) {
+      getTokenCount++;
+      return {endpoint: server.baseURI + "1.1/johndoe/"};
+    },
+  };
+  Service.identity._tokenServerClient = mockTSC;
 
   // We need the server to be correctly set up prior to experimenting. Do this
   // through a sync.
   let global = {syncID: Service.syncID,
                 storageVersion: STORAGE_VERSION,
                 rotary: {version: engine.version,
-                         syncID:  engine.syncID}}
+                         syncID:  engine.syncID}};
   john.createCollection("meta").insert("global", global);
 
   _("First sync to prepare server contents.");
-  Service.sync();
+  await Service.sync();
 
   _("Setting up Rotary collection to 401.");
   let rotary = john.createCollection("rotary");
@@ -415,7 +394,7 @@ add_task(function test_loop_avoidance_engine() {
   function onLoginStart() {
     // lastSyncReassigned shouldn't be cleared until a sync has succeeded.
     _("Ensuring that lastSyncReassigned is still set at next sync start.");
-    do_check_true(getReassigned());
+    Assert.ok(getReassigned());
   }
 
   function beforeSuccessfulSync() {
@@ -423,18 +402,10 @@ add_task(function test_loop_avoidance_engine() {
     rotary.collectionHandler = oldHandler;
   }
 
-  function afterSuccessfulSync() {
-    Svc.Obs.remove("weave:service:login:start", onLoginStart);
-    Service.startOver();
-    server.stop(deferred.resolve);
-  }
-
   let firstNotification  = "weave:service:sync:finish";
   let secondNotification = "weave:service:sync:finish";
   let thirdNotification  = "weave:service:sync:finish";
 
-  let nodeFetched = false;
-
   // Track the time. We want to make sure the duration between the first and
   // second sync is small, and then that the duration between second and third
   // is set to be large.
@@ -445,24 +416,13 @@ add_task(function test_loop_avoidance_engine() {
     Svc.Obs.remove(firstNotification, onFirstSync);
     Svc.Obs.add(secondNotification, onSecondSync);
 
-    do_check_eq(Service.clusterURL, "");
+    Assert.equal(Service.clusterURL, "");
 
     _("Adding observer that lastSyncReassigned is still set on login.");
     Svc.Obs.add("weave:service:login:start", onLoginStart);
 
     // We got a 401 mid-sync, and set the pref accordingly.
-    do_check_true(Services.prefs.getBoolPref("services.sync.lastSyncReassigned"));
-
-    // Track whether we fetched node/weave. We want to wait for the second
-    // sync to finish so that we're cleaned up for the next test, so don't
-    // run_next_test in the node handler.
-    nodeFetched = false;
-
-    // Verify that the client requests a node reassignment.
-    // Install a node handler to watch for these requests.
-    installNodeHandler(server, function () {
-      nodeFetched = true;
-    });
+    Assert.ok(Services.prefs.getBoolPref("services.sync.lastSyncReassigned"));
 
     // Update the timestamp.
     now = Date.now();
@@ -475,10 +435,10 @@ add_task(function test_loop_avoidance_engine() {
 
     // This sync occurred within the backoff interval.
     let elapsedTime = Date.now() - now;
-    do_check_true(elapsedTime < MINIMUM_BACKOFF_INTERVAL);
+    Assert.ok(elapsedTime < MINIMUM_BACKOFF_INTERVAL);
 
     // This pref will be true until a sync completes successfully.
-    do_check_true(getReassigned());
+    Assert.ok(getReassigned());
 
     // The timer will be set for some distant time.
     // We store nextSync in prefs, which offers us only limited resolution.
@@ -487,8 +447,8 @@ add_task(function test_loop_avoidance_engine() {
     _("Next sync scheduled for " + Service.scheduler.nextSync);
     _("Expected to be slightly greater than " + expectedNextSync);
 
-    do_check_true(Service.scheduler.nextSync >= expectedNextSync);
-    do_check_true(!!Service.scheduler.syncTimer);
+    Assert.ok(Service.scheduler.nextSync >= expectedNextSync);
+    Assert.ok(!!Service.scheduler.syncTimer);
 
     // Undo our evil scheme.
     beforeSuccessfulSync();
@@ -506,17 +466,23 @@ add_task(function test_loop_avoidance_engine() {
 
     // Make absolutely sure that any event listeners are done with their work
     // before we proceed.
-    waitForZeroTimer(function () {
+    waitForZeroTimer(function() {
       _("Third sync nextTick.");
-      do_check_false(getReassigned());
-      do_check_true(nodeFetched);
-      afterSuccessfulSync();
+      Assert.ok(!getReassigned());
+      Assert.equal(getTokenCount, 2);
+      Svc.Obs.remove("weave:service:login:start", onLoginStart);
+      Service.startOver().then(() => {
+        server.stop(deferred.resolve);
+      });
     });
   }
 
   Svc.Obs.add(firstNotification, onFirstSync);
 
   now = Date.now();
-  Service.sync();
-  yield deferred.promise;
+  await Service.sync();
+  await deferred.promise;
+
+  await tracker.clearChangedIDs();
+  await Service.engineManager.unregister(engine);
 });
