@@ -8,12 +8,13 @@
 # Author: Darin Fisher
 #
 
-. $(dirname "$0")/common.sh
+# shellcheck disable=SC1090
+. "$(dirname "$0")/common.sh"
 
 # -----------------------------------------------------------------------------
 
 print_usage() {
-  notice "Usage: $(basename $0) [OPTIONS] ARCHIVE FROMDIR TODIR"
+  notice "Usage: $(basename "$0") [OPTIONS] ARCHIVE FROMDIR TODIR"
   notice ""
   notice "The differences between FROMDIR and TODIR will be stored in ARCHIVE."
   notice ""
@@ -31,48 +32,39 @@ check_for_forced_update() {
   local f
 
   if [ "$forced_file_chk" = "precomplete" ]; then
-    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "Contents/Resources/precomplete" ]; then
-    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "removed-files" ]; then
-    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "Contents/Resources/removed-files" ]; then
-    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "chrome.manifest" ]; then
-    ## "true" *giggle*
     return 0;
   fi
 
   if [ "$forced_file_chk" = "Contents/Resources/chrome.manifest" ]; then
-    ## "true" *giggle*
     return 0;
   fi
 
   if [ "${forced_file_chk##*.}" = "chk" ]; then
-    ## "true" *giggle*
     return 0;
   fi
 
   for f in $force_list; do
     #echo comparing $forced_file_chk to $f
     if [ "$forced_file_chk" = "$f" ]; then
-      ## "true" *giggle*
       return 0;
     fi
   done
-  ## 'false'... because this is bash. Oh yay!
   return 1;
 }
 
@@ -97,7 +89,7 @@ done
 
 # -----------------------------------------------------------------------------
 
-let arg_start=$OPTIND-1
+arg_start=$((OPTIND-1))
 shift $arg_start
 
 archive="$1"
@@ -105,10 +97,10 @@ olddir="$2"
 newdir="$3"
 # Prevent the workdir from being inside the targetdir so it isn't included in
 # the update mar.
-if [ $(echo "$newdir" | grep -c '\/$') = 1 ]; then
-  # Remove the /
-  newdir=$(echo "$newdir" | sed -e 's:\/$::')
-fi
+
+# Remove the /
+newdir="${newdir%/}"
+
 workdir="$newdir.work"
 updatemanifestv2="$workdir/updatev2.manifest"
 updatemanifestv3="$workdir/updatev3.manifest"
@@ -117,59 +109,56 @@ archivefiles="updatev2.manifest updatev3.manifest"
 mkdir -p "$workdir"
 
 # Generate a list of all files in the target directory.
-pushd "$olddir"
-if test $? -ne 0 ; then
-  exit 1
-fi
+pushd "$olddir" || exit 1
 
+declare -a oldfiles
 list_files oldfiles
+declare -a olddirs
 list_dirs olddirs
 
-popd
+popd || exit 1
 
-pushd "$newdir"
-if test $? -ne 0 ; then
+pushd "$newdir" || exit 1
+
+if [ ! -f "precomplete" ] && [ ! -f "Contents/Resources/precomplete" ]
+then
+  notice "precomplete file is missing!"
   exit 1
 fi
 
-if [ ! -f "precomplete" ]; then
-  if [ ! -f "Contents/Resources/precomplete" ]; then
-    notice "precomplete file is missing!"
-    exit 1
-  fi
-fi
-
-list_dirs newdirs
+declare -a newfiles
 list_files newfiles
 
-popd
+popd || exit 1
 
 # Add the type of update to the beginning of the update manifests.
 notice ""
 notice "Adding type instruction to update manifests"
-> $updatemanifestv2
-> $updatemanifestv3
+: > "$updatemanifestv2"
+: > "$updatemanifestv3"
 notice "       type partial"
-echo "type \"partial\"" >> $updatemanifestv2
-echo "type \"partial\"" >> $updatemanifestv3
+echo 'type "partial"' >> "$updatemanifestv2"
+echo 'type "partial"' >> "$updatemanifestv3"
 
 notice ""
 notice "Adding file patch and add instructions to update manifests"
 
-num_oldfiles=${#oldfiles[*]}
-remove_array=
+declare -a remove_array
 num_removes=0
 
-for ((i=0; $i<$num_oldfiles; i=$i+1)); do
-  f="${oldfiles[$i]}"
-
+for f in "${oldfiles[@]}"
+do
   # If this file exists in the new directory as well, then check if it differs.
   if [ -f "$newdir/$f" ]; then
 
     if check_for_add_if_not_update "$f"; then
       # The full workdir may not exist yet, so create it if necessary.
-      mkdir -p `dirname "$workdir/$f"`
-      $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
+      mkdir -p "$(dirname "$workdir/$f")"
+      if [[ -n $MAR_OLD_FORMAT ]]; then
+        $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
+      else
+        $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
+      fi
       copy_perm "$newdir/$f" "$workdir/$f"
       make_add_if_not_instruction "$f" "$updatemanifestv3"
       archivefiles="$archivefiles \"$f\""
@@ -178,8 +167,12 @@ for ((i=0; $i<$num_oldfiles; i=$i+1)); do
 
     if check_for_forced_update "$requested_forced_updates" "$f"; then
       # The full workdir may not exist yet, so create it if necessary.
-      mkdir -p `dirname "$workdir/$f"`
-      $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
+      mkdir -p "$(dirname "$workdir/$f")"
+      if [[ -n $MAR_OLD_FORMAT ]]; then
+        $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
+      else
+        $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
+      fi
       copy_perm "$newdir/$f" "$workdir/$f"
       make_add_instruction "$f" "$updatemanifestv2" "$updatemanifestv3" 1
       archivefiles="$archivefiles \"$f\""
@@ -202,30 +195,43 @@ for ((i=0; $i<$num_oldfiles; i=$i+1)); do
       # myscript.sh -A SERVER-URL [-c LOCAL-CACHE-DIR-PATH] [-g] [-u] \
       #   PATH-FROM-URL PATH-TO-URL PATH-PATCH SERVER-URL
       #
-      # Note: patches are bzipped stashed in funsize to gain more speed
+      # Note: patches are bzipped or xz stashed in funsize to gain more speed
 
-      # if service is not enabled then default to old behavior
-      if [ -z "$MBSDIFF_HOOK" ]; then
-        $MBSDIFF "$olddir/$f" "$newdir/$f" "$workdir/$f.patch"
-        $BZIP2 -z9 "$workdir/$f.patch"
+      if [[ -n $MAR_OLD_FORMAT ]]
+      then
+        COMPRESS="$BZIP2 -z9"
+        EXT=".bz2"
+        STDOUT="-c"
       else
-        # if service enabled then check patch existence for retrieval
-        if $MBSDIFF_HOOK -g "$olddir/$f" "$newdir/$f" "$workdir/$f.patch.bz2"; then
+        COMPRESS="$XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force"
+        EXT=".xz"
+        STDOUT="--stdout"
+      fi
+
+      if [ -z "$MBSDIFF_HOOK" ]
+      then
+        $MBSDIFF "$olddir/$f" "$newdir/$f" "$workdir/$f.patch"
+        $COMPRESS "$workdir/$f.patch"
+      else
+        if $MBSDIFF_HOOK -g "$olddir/$f" "$newdir/$f" "$workdir/$f.patch${EXT}"
+        then
           notice "file \"$f\" found in funsize, diffing skipped"
         else
           # if not found already - compute it and cache it for future use
           $MBSDIFF "$olddir/$f" "$newdir/$f" "$workdir/$f.patch"
-          $BZIP2 -z9 "$workdir/$f.patch"
-          $MBSDIFF_HOOK -u "$olddir/$f" "$newdir/$f" "$workdir/$f.patch.bz2"
+          $COMPRESS "$workdir/$f.patch"
+          $MBSDIFF_HOOK -u "$olddir/$f" "$newdir/$f" "$workdir/$f.patch${EXT}"
         fi
       fi
-      $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
+      $COMPRESS $STDOUT "$newdir/$f" > "$workdir/$f"
+
       copy_perm "$newdir/$f" "$workdir/$f"
-      patchfile="$workdir/$f.patch.bz2"
+      patchfile="$workdir/$f.patch${EXT}"
+
       patchsize=$(get_file_size "$patchfile")
       fullsize=$(get_file_size "$workdir/$f")
 
-      if [ $patchsize -lt $fullsize ]; then
+      if [ "$patchsize" -lt "$fullsize" ]; then
         make_patch_instruction "$f" "$updatemanifestv2" "$updatemanifestv3"
         mv -f "$patchfile" "$workdir/$f.patch"
         rm -f "$workdir/$f"
@@ -247,22 +253,24 @@ done
 # Newly added files
 notice ""
 notice "Adding file add instructions to update manifests"
-num_newfiles=${#newfiles[*]}
 
-for ((i=0; $i<$num_newfiles; i=$i+1)); do
-  f="${newfiles[$i]}"
-
-  # If we've already tested this file, then skip it
-  for ((j=0; $j<$num_oldfiles; j=$j+1)); do
-    if [ "$f" = "${oldfiles[j]}" ]; then
+for f in "${newfiles[@]}"
+do
+  for j in "${oldfiles[@]}"
+  do
+    if [ "$f" = "$j" ]
+    then
       continue 2
     fi
   done
-
   dir=$(dirname "$workdir/$f")
   mkdir -p "$dir"
 
-  $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
+  if [[ -n $MAR_OLD_FORMAT ]]; then
+    $BZIP2 -cz9 "$newdir/$f" > "$workdir/$f"
+  else
+    $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force --stdout "$newdir/$f" > "$workdir/$f"
+  fi
   copy_perm "$newdir/$f" "$workdir/$f"
 
   if check_for_add_if_not_update "$f"; then
@@ -277,11 +285,11 @@ done
 
 notice ""
 notice "Adding file remove instructions to update manifests"
-for ((i=0; $i<$num_removes; i=$i+1)); do
-  f="${remove_array[$i]}"
+for f in "${remove_array[@]}"
+do
   notice "     remove \"$f\""
-  echo "remove \"$f\"" >> $updatemanifestv2
-  echo "remove \"$f\"" >> $updatemanifestv3
+  echo "remove \"$f\"" >> "$updatemanifestv2"
+  echo "remove \"$f\"" >> "$updatemanifestv3"
 done
 
 # Add remove instructions for any dead files.
@@ -291,20 +299,24 @@ append_remove_instructions "$newdir" "$updatemanifestv2" "$updatemanifestv3"
 
 notice ""
 notice "Adding directory remove instructions for directories that no longer exist"
-num_olddirs=${#olddirs[*]}
 
-for ((i=0; $i<$num_olddirs; i=$i+1)); do
-  f="${olddirs[$i]}"
+for f in "${olddirs[@]}"
+do
   # If this dir doesn't exist in the new directory remove it.
   if [ ! -d "$newdir/$f" ]; then
     notice "      rmdir $f/"
-    echo "rmdir \"$f/\"" >> $updatemanifestv2
-    echo "rmdir \"$f/\"" >> $updatemanifestv3
+    echo "rmdir \"$f/\"" >> "$updatemanifestv2"
+    echo "rmdir \"$f/\"" >> "$updatemanifestv3"
   fi
 done
 
-$BZIP2 -z9 "$updatemanifestv2" && mv -f "$updatemanifestv2.bz2" "$updatemanifestv2"
-$BZIP2 -z9 "$updatemanifestv3" && mv -f "$updatemanifestv3.bz2" "$updatemanifestv3"
+if [[ -n $MAR_OLD_FORMAT ]]; then
+  $BZIP2 -z9 "$updatemanifestv2" && mv -f "$updatemanifestv2.bz2" "$updatemanifestv2"
+  $BZIP2 -z9 "$updatemanifestv3" && mv -f "$updatemanifestv3.bz2" "$updatemanifestv3"
+else
+  $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force "$updatemanifestv2" && mv -f "$updatemanifestv2.xz" "$updatemanifestv2"
+  $XZ --compress --x86 --lzma2 --format=xz --check=crc64 --force "$updatemanifestv3" && mv -f "$updatemanifestv3.xz" "$updatemanifestv3"
+fi
 
 mar_command="$MAR"
 if [[ -n $MOZ_PRODUCT_VERSION ]]
