@@ -7,13 +7,34 @@
 # Code shared by update packaging scripts.
 # Author: Darin Fisher
 #
-# In here to use the local common.sh to allow the full mars to have unfiltered files
 
 # -----------------------------------------------------------------------------
 # By default just assume that these tools exist on our path
 MAR=${MAR:-mar}
-BZIP2=${BZIP2:-bzip2}
 MBSDIFF=${MBSDIFF:-mbsdiff}
+if [[ -z "${MAR_OLD_FORMAT}" ]]; then
+  while read -r XZ
+  do
+    if ${XZ} --version > /dev/null 2>&1
+    then
+      break
+    fi
+  done << EOM
+${XZ:-xz}
+$(dirname "$(dirname "$(dirname "$0")")")/xz/xz.exe
+$(dirname "$(dirname "$(dirname "$(dirname "$0")")")")/xz/xz.exe
+EOM
+
+  if [ -z "${XZ}" ]
+  then
+      echo "xz was not found on this system!"
+      echo "exiting"
+      exit 1
+  fi
+else
+  MAR_OLD_FORMAT=1
+  BZIP2=${BZIP2:-bzip2}
+fi
 
 # -----------------------------------------------------------------------------
 # Helper routines
@@ -23,8 +44,7 @@ notice() {
 }
 
 get_file_size() {
-  info=($(ls -ln "$1"))
-  echo ${info[4]}
+  stat -f"%z" "$1"
 }
 
 copy_perm() {
@@ -49,27 +69,27 @@ make_add_instruction() {
   filev3="$3"
 
   # Used to log to the console
-  if [ $4 ]; then
+  if [ "$4" ]; then
     forced=" (forced)"
   else
     forced=
   fi
 
-  is_extension=$(echo "$f" | grep -c 'distribution/extensions/.*/')
-  if [ $is_extension = "1" ]; then
+  if [[ "$f" =~ distribution/extensions/.*/ ]]
+  then
     # Use the subdirectory of the extensions folder as the file to test
     # before performing this add instruction.
     testdir=$(echo "$f" | sed 's/\(.*distribution\/extensions\/[^\/]*\)\/.*/\1/')
     notice "     add-if \"$testdir\" \"$f\""
-    echo "add-if \"$testdir\" \"$f\"" >> $filev2
-    if [ ! $filev3 = "" ]; then
-      echo "add-if \"$testdir\" \"$f\"" >> $filev3
+    printf 'add-if "%s" "%s"\n' "${testdir}" "${f}" >> "${filev2}"
+    if [ -n "${filev3}" ]; then
+      printf 'add-if "%s" "%s"\n' "${testdir}" "${f}" >> "${filev3}"
     fi
   else
     notice "        add \"$f\"$forced"
-    echo "add \"$f\"" >> $filev2
-    if [ ! $filev3 = "" ]; then
-      echo "add \"$f\"" >> $filev3
+    printf 'add "%s"\n' "${f}" >> "${filev2}"
+    if [ ! "$filev3" = "" ]; then
+      printf 'add "%s"\n' "${f}" >> "${filev3}"
     fi
   fi
 }
@@ -77,23 +97,21 @@ make_add_instruction() {
 check_for_add_if_not_update() {
   add_if_not_file_chk="$1"
 
-  if [ `basename $add_if_not_file_chk` = "channel-prefs.js" -o \
-       `basename $add_if_not_file_chk` = "update-settings.ini" ]; then
-    ## "true" *giggle*
+  if [ "$(basename "$add_if_not_file_chk")" = "channel-prefs.js" ] || \
+     [ "$(basename "$add_if_not_file_chk")" = "update-settings.ini" ]
+  then
     return 0;
   fi
-  ## 'false'... because this is bash. Oh yay!
   return 1;
 }
 
 check_for_add_to_manifestv2() {
   add_if_not_file_chk="$1"
 
-  if [ `basename $add_if_not_file_chk` = "update-settings.ini" ]; then
-    ## "true" *giggle*
+  if [ "$(basename "$add_if_not_file_chk")" = "update-settings.ini" ]
+  then
     return 0;
   fi
-  ## 'false'... because this is bash. Oh yay!
   return 1;
 }
 
@@ -102,7 +120,7 @@ make_add_if_not_instruction() {
   filev3="$2"
 
   notice " add-if-not \"$f\" \"$f\""
-  echo "add-if-not \"$f\" \"$f\"" >> $filev3
+  printf 'add-if-not "%s" "%s"\n' "${f}" "${f}" >> "${filev3}"
 }
 
 make_patch_instruction() {
@@ -110,18 +128,18 @@ make_patch_instruction() {
   filev2="$2"
   filev3="$3"
 
-  is_extension=$(echo "$f" | grep -c 'distribution/extensions/.*/')
-  if [ $is_extension = "1" ]; then
+  if [[ "$f" =~ distribution/extensions/.*/ ]]
+  then
     # Use the subdirectory of the extensions folder as the file to test
     # before performing this add instruction.
     testdir=$(echo "$f" | sed 's/\(.*distribution\/extensions\/[^\/]*\)\/.*/\1/')
     notice "   patch-if \"$testdir\" \"$f.patch\" \"$f\""
-    echo "patch-if \"$testdir\" \"$f.patch\" \"$f\"" >> $filev2
-    echo "patch-if \"$testdir\" \"$f.patch\" \"$f\"" >> $filev3
+    printf 'patch-if "%s" "%s.patch" "%s"\n' "${testdir}" "${f}" "${f}" >> "${filev2}"
+    printf 'patch-if "%s" "%s.patch" "%s"\n' "${testdir}" "${f}" "${f}" >> "${filev3}"
   else
     notice "      patch \"$f.patch\" \"$f\""
-    echo "patch \"$f.patch\" \"$f\"" >> $filev2
-    echo "patch \"$f.patch\" \"$f\"" >> $filev3
+    printf 'patch "%s.patch" "%s"\n' "${f}" "${f}" >> "${filev2}"
+    printf 'patch "%s.patch" "%s"\n' "${f}" "${f}" >> "${filev3}"
   fi
 }
 
@@ -130,73 +148,83 @@ append_remove_instructions() {
   filev2="$2"
   filev3="$3"
 
-  if [ -f "$dir/removed-files" ]; then
+  if [ -f "$dir/removed-files" ]
+  then
     listfile="$dir/removed-files"
-  elif [ -f "$dir/Contents/Resources/removed-files" ]; then
+  elif [ -f "$dir/Contents/Resources/removed-files" ]
+  then
     listfile="$dir/Contents/Resources/removed-files"
   fi
-  if [ -n "$listfile" ]; then
-    # Map spaces to pipes so that we correctly handle filenames with spaces.
-    files=($(cat "$listfile" | tr " " "|"  | sort -r))
-    num_files=${#files[*]}
-    for ((i=0; $i<$num_files; i=$i+1)); do
-      # Map pipes back to whitespace and remove carriage returns
-      f=$(echo ${files[$i]} | tr "|" " " | tr -d '\r')
-      # Trim whitespace
-      f=$(echo $f)
-      # Exclude blank lines.
-      if [ -n "$f" ]; then
-        # Exclude comments
-        if [ ! $(echo "$f" | grep -c '^#') = 1 ]; then
-          if [ $(echo "$f" | grep -c '\/$') = 1 ]; then
-            notice "      rmdir \"$f\""
-            echo "rmdir \"$f\"" >> $filev2
-            echo "rmdir \"$f\"" >> $filev3
-          elif [ $(echo "$f" | grep -c '\/\*$') = 1 ]; then
-            # Remove the *
-            f=$(echo "$f" | sed -e 's:\*$::')
-            notice "    rmrfdir \"$f\""
-            echo "rmrfdir \"$f\"" >> $filev2
-            echo "rmrfdir \"$f\"" >> $filev3
-          else
-            notice "     remove \"$f\""
-            echo "remove \"$f\"" >> $filev2
-            echo "remove \"$f\"" >> $filev3
-          fi
-        fi
-      fi
-    done
+  if [ -z "$listfile" ]; then
+    return
   fi
+
+  while read -r f
+  do
+    # skip blank lines
+    if [ -z "$f" ]
+    then
+      continue
+    fi
+    # skip comments
+    if [[ "$f" =~ ^\#.* ]]
+    then
+      continue
+    fi
+
+    if [[ "$f" =~ .*/$ ]]
+    then
+      notice "      rmdir \"$f\""
+      printf 'rmdir "%s"\n' "${f}" >> "${filev2}"
+      printf 'rmdir "%s"\n' "${f}" >> "${filev3}"
+    elif [[ "$f" =~ .*/\*$ ]]
+    then
+      # Remove the *
+      f=${f%\*}
+      notice "    rmrfdir \"$f\""
+      printf 'rmrfdir "%s"\n' "${f}" >> "${filev2}"
+      printf 'rmrfdir "%s"\n' "${f}" >> "${filev3}"
+    else
+      notice "     remove \"$f\""
+      printf 'remove "%s"\n' "${f}" >> "${filev2}"
+      printf 'remove "%s"\n' "${f}" >> "${filev3}"
+    fi
+  done <"$listfile"
 }
 
 # List all files in the current directory, stripping leading "./"
 # Pass a variable name and it will be filled as an array.
 list_files() {
   count=0
-
-  # Removed the exclusion cases here to allow for generation of testing mars
+  tmpfile="$(mktemp)"
   find . -type f \
+    ! -name "update.manifest" \
+    ! -name "updatev2.manifest" \
+    ! -name "updatev3.manifest" \
+    ! -name "temp-dirlist" \
+    ! -name "temp-filelist" \
     | sed 's/\.\/\(.*\)/\1/' \
-    | sort -r > "$workdir/temp-filelist"
-  while read file; do
+    | sort -r > "${tmpfile}"
+  while read -r file; do
     eval "${1}[$count]=\"$file\""
     (( count++ ))
-  done < "$workdir/temp-filelist"
-  rm "$workdir/temp-filelist"
+  done <"${tmpfile}"
+  rm -f "${tmpfile}"
 }
 
 # List all directories in the current directory, stripping leading "./"
 list_dirs() {
   count=0
+  tmpfile="$(mktemp)"
 
   find . -type d \
     ! -name "." \
     ! -name ".." \
     | sed 's/\.\/\(.*\)/\1/' \
-    | sort -r > "$workdir/temp-dirlist"
-  while read dir; do
+    | sort -r > "${tmpfile}"
+  while read -r dir; do
     eval "${1}[$count]=\"$dir\""
     (( count++ ))
-  done < "$workdir/temp-dirlist"
-  rm "$workdir/temp-dirlist"
+  done <"${tmpfile}"
+  rm -f "${tmpfile}"
 }
