@@ -7,28 +7,32 @@
 #include "mozilla/DebuggerOnGCRunnable.h"
 
 #include "mozilla/dom/ScriptSettings.h"
-#include "mozilla/CycleCollectedJSRuntime.h"
+#include "mozilla/CycleCollectedJSContext.h"
 #include "mozilla/Move.h"
+#include "mozilla/SystemGroup.h"
 #include "js/Debug.h"
 
 namespace mozilla {
 
-/* static */ NS_METHOD
-DebuggerOnGCRunnable::Enqueue(JSRuntime* aRt, const JS::GCDescription& aDesc)
-{
-  auto gcEvent = aDesc.toGCEvent(aRt);
+/* static */ nsresult DebuggerOnGCRunnable::Enqueue(
+    JSContext* aCx, const JS::GCDescription& aDesc) {
+  auto gcEvent = aDesc.toGCEvent(aCx);
   if (!gcEvent) {
     return NS_ERROR_OUT_OF_MEMORY;
   }
 
   RefPtr<DebuggerOnGCRunnable> runOnGC =
-    new DebuggerOnGCRunnable(Move(gcEvent));
-  return NS_DispatchToCurrentThread(runOnGC);
+      new DebuggerOnGCRunnable(Move(gcEvent));
+  if (NS_IsMainThread()) {
+    return SystemGroup::Dispatch(TaskCategory::GarbageCollection,
+                                 runOnGC.forget());
+  } else {
+    return NS_DispatchToCurrentThread(runOnGC);
+  }
 }
 
 NS_IMETHODIMP
-DebuggerOnGCRunnable::Run()
-{
+DebuggerOnGCRunnable::Run() {
   AutoJSAPI jsapi;
   jsapi.Init();
   if (!JS::dbg::FireOnGarbageCollectionHook(jsapi.cx(), Move(mGCData))) {
@@ -37,11 +41,9 @@ DebuggerOnGCRunnable::Run()
   return NS_OK;
 }
 
-NS_IMETHODIMP
-DebuggerOnGCRunnable::Cancel()
-{
+nsresult DebuggerOnGCRunnable::Cancel() {
   mGCData = nullptr;
   return NS_OK;
 }
 
-} // namespace mozilla
+}  // namespace mozilla
