@@ -12,15 +12,16 @@
 #include "mozilla/FileUtils.h"
 #include "mozilla/Mutex.h"
 #include "mozilla/StaticPtr.h"
-#include "mozilla/Sprintf.h"
+#include "mozilla/Printf.h"
 #include "mozilla/Atomics.h"
+#include "mozilla/Sprintf.h"
 #include "mozilla/UniquePtrExtensions.h"
+#include "MainThreadUtils.h"
 #include "nsClassHashtable.h"
 #include "nsDebug.h"
 #include "NSPRLogModulesParser.h"
 
 #include "prenv.h"
-#include "prprf.h"
 #ifdef XP_WIN
 #include <process.h>
 #else
@@ -35,46 +36,46 @@ const uint32_t kInitialModuleCount = 256;
 // number of files we create and rotate.  When there is rotate:40,
 // we will keep four files per process, each limited to 10MB.  Sum is 40MB,
 // the given limit.
+//
+// (Note: When this is changed to be >= 10, SandboxBroker::LaunchApp must add
+// another rule to allow logfile.?? be written by content processes.)
 const uint32_t kRotateFilesNumber = 4;
 
 namespace mozilla {
 
-namespace detail {
+LazyLogModule::operator LogModule*() {
+  // NB: The use of an atomic makes the reading and assignment of mLog
+  //     thread-safe. There is a small chance that mLog will be set more
+  //     than once, but that's okay as it will be set to the same LogModule
+  //     instance each time. Also note LogModule::Get is thread-safe.
+  LogModule* tmp = mLog;
+  if (MOZ_UNLIKELY(!tmp)) {
+    tmp = LogModule::Get(mLogName);
+    mLog = tmp;
+  }
 
-void log_print(const PRLogModuleInfo* aModule,
-               LogLevel aLevel,
-               const char* aFmt, ...)
-{
-  va_list ap;
-  va_start(ap, aFmt);
-  char* buff = PR_vsmprintf(aFmt, ap);
-  PR_LogPrint("%s", buff);
-  PR_smprintf_free(buff);
-  va_end(ap);
+  return tmp;
 }
 
-void log_print(const LogModule* aModule,
-               LogLevel aLevel,
-               const char* aFmt, ...)
-{
+namespace detail {
+
+void log_print(const LogModule* aModule, LogLevel aLevel, const char* aFmt,
+               ...) {
   va_list ap;
   va_start(ap, aFmt);
   aModule->Printv(aLevel, aFmt, ap);
   va_end(ap);
 }
 
-} // detail
+}  // namespace detail
 
-LogLevel
-ToLogLevel(int32_t aLevel)
-{
+LogLevel ToLogLevel(int32_t aLevel) {
   aLevel = std::min(aLevel, static_cast<int32_t>(LogLevel::Verbose));
   aLevel = std::max(aLevel, static_cast<int32_t>(LogLevel::Disabled));
   return static_cast<LogLevel>(aLevel);
 }
 
-const char*
-ToLogStr(LogLevel aLevel) {
+const char* ToLogStr(LogLevel aLevel) {
   switch (aLevel) {
     case LogLevel::Error:
       return "E";
@@ -102,21 +103,15 @@ namespace detail {
  *  - the order number it was created for when rotating (actual path)
  *  - number of active references
  */
-class LogFile
-{
+class LogFile {
   FILE* mFile;
   uint32_t mFileNum;
 
-public:
+ public:
   LogFile(FILE* aFile, uint32_t aFileNum)
-    : mFile(aFile)
-    , mFileNum(aFileNum)
-    , mNextToRelease(nullptr)
-  {
-  }
+      : mFile(aFile), mFileNum(aFileNum), mNextToRelease(nullptr) {}
 
-  ~LogFile()
-  {
+  ~LogFile() {
     fclose(mFile);
     delete mNextToRelease;
   }
@@ -127,66 +122,65 @@ public:
   LogFile* mNextToRelease;
 };
 
-const char*
-ExpandPIDMarker(const char* aFilename, char (&buffer)[2048])
-{
+const char* ExpandPIDMarker(const char* aFilename, char (&buffer)[2048]) {
   MOZ_ASSERT(aFilename);
   static const char kPIDToken[] = "%PID";
   const char* pidTokenPtr = strstr(aFilename, kPIDToken);
   if (pidTokenPtr &&
-    SprintfLiteral(buffer, "%.*s%s%d%s",
-                   static_cast<int>(pidTokenPtr - aFilename), aFilename,
-                   XRE_IsParentProcess() ? "-main." : "-child.",
-                   base::GetCurrentProcId(),
-                   pidTokenPtr + strlen(kPIDToken)) > 0)
-  {
+      SprintfLiteral(
+          buffer, "%.*s%s%d%s", static_cast<int>(pidTokenPtr - aFilename),
+          aFilename, XRE_IsParentProcess() ? "-main." : "-child.",
+          base::GetCurrentProcId(), pidTokenPtr + strlen(kPIDToken)) > 0) {
     return buffer;
   }
 
   return aFilename;
 }
 
-} // detail
+}  // namespace detail
 
 namespace {
-  // Helper method that initializes an empty va_list to be empty.
-  void empty_va(va_list *va, ...)
-  {
-    va_start(*va, va);
-    va_end(*va);
-  }
+// Helper method that initializes an empty va_list to be empty.
+void empty_va(va_list* va, ...) {
+  va_start(*va, va);
+  va_end(*va);
 }
+}  // namespace
 
-class LogModuleManager
-{
-public:
+class LogModuleManager {
+ public:
   LogModuleManager()
-    : mModulesLock("logmodules")
-    , mModules(kInitialModuleCount)
-    , mPrintEntryCount(0)
-    , mOutFile(nullptr)
-    , mToReleaseFile(nullptr)
-    , mOutFileNum(0)
-    , mOutFilePath(strdup(""))
-    , mMainThread(PR_GetCurrentThread())
-    , mSetFromEnv(false)
-    , mAddTimestamp(false)
-    , mIsSync(false)
-    , mRotate(0)
-  {
-  }
+      : mModulesLock("logmodules"),
+        mModules(kInitialModuleCount),
+        mPrintEntryCount(0),
+        mOutFile(nullptr),
+        mToReleaseFile(nullptr),
+        mOutFileNum(0),
+        mOutFilePath(strdup("")),
+        mMainThread(PR_GetCurrentThread()),
+        mSetFromEnv(false),
+        mAddTimestamp(false),
+        mIsSync(false),
+        mRotate(0),
+        mInitialized(false) {}
 
-  ~LogModuleManager()
-  {
+  ~LogModuleManager() {
     detail::LogFile* logFile = mOutFile.exchange(nullptr);
     delete logFile;
   }
 
   /**
    * Loads config from env vars if present.
+   *
+   * Notes:
+   *
+   * 1) This function is only intended to be called once per session.
+   * 2) None of the functions used in Init should rely on logging.
    */
-  void Init()
-  {
+  void Init() {
+    MOZ_DIAGNOSTIC_ASSERT(!mInitialized);
+    mInitialized = true;
+
     bool shouldAppend = false;
     bool addTimestamp = false;
     bool isSync = false;
@@ -195,32 +189,36 @@ public:
     if (!modules || !modules[0]) {
       modules = PR_GetEnv("MOZ_LOG_MODULES");
       if (modules) {
-        NS_WARNING("MOZ_LOG_MODULES is deprecated."
+        NS_WARNING(
+            "MOZ_LOG_MODULES is deprecated."
             "\nPlease use MOZ_LOG instead.");
       }
     }
     if (!modules || !modules[0]) {
       modules = PR_GetEnv("NSPR_LOG_MODULES");
       if (modules) {
-        NS_WARNING("NSPR_LOG_MODULES is deprecated."
+        NS_WARNING(
+            "NSPR_LOG_MODULES is deprecated."
             "\nPlease use MOZ_LOG instead.");
       }
     }
 
-    NSPRLogModulesParser(modules,
-        [&shouldAppend, &addTimestamp, &isSync, &rotate]
-            (const char* aName, LogLevel aLevel, int32_t aValue) mutable {
-          if (strcmp(aName, "append") == 0) {
-            shouldAppend = true;
-          } else if (strcmp(aName, "timestamp") == 0) {
-            addTimestamp = true;
-          } else if (strcmp(aName, "sync") == 0) {
-            isSync = true;
-          } else if (strcmp(aName, "rotate") == 0) {
-            rotate = (aValue << 20) / kRotateFilesNumber;
-          } else {
-            LogModule::Get(aName)->SetLevel(aLevel);
-          }
+    // Need to capture `this` since `sLogModuleManager` is not set until after
+    // initialization is complete.
+    NSPRLogModulesParser(modules, [this, &shouldAppend, &addTimestamp, &isSync,
+                                   &rotate](const char* aName, LogLevel aLevel,
+                                            int32_t aValue) mutable {
+      if (strcmp(aName, "append") == 0) {
+        shouldAppend = true;
+      } else if (strcmp(aName, "timestamp") == 0) {
+        addTimestamp = true;
+      } else if (strcmp(aName, "sync") == 0) {
+        isSync = true;
+      } else if (strcmp(aName, "rotate") == 0) {
+        rotate = (aValue << 20) / kRotateFilesNumber;
+      } else {
+        this->CreateOrGetModule(aName)->SetLevel(aLevel);
+      }
     });
 
     // Rotate implies timestamp to make the files readable
@@ -258,21 +256,22 @@ public:
     }
   }
 
-  void SetLogFile(const char* aFilename)
-  {
+  void SetLogFile(const char* aFilename) {
     // For now we don't allow you to change the file at runtime.
     if (mSetFromEnv) {
-      NS_WARNING("LogModuleManager::SetLogFile - Log file was set from the "
-                 "MOZ_LOG_FILE environment variable.");
+      NS_WARNING(
+          "LogModuleManager::SetLogFile - Log file was set from the "
+          "MOZ_LOG_FILE environment variable.");
       return;
     }
 
-    const char * filename = aFilename ? aFilename : "";
+    const char* filename = aFilename ? aFilename : "";
     char buf[2048];
     filename = detail::ExpandPIDMarker(filename, buf);
 
     // Can't use rotate at runtime yet.
-    MOZ_ASSERT(mRotate == 0, "We don't allow rotate for runtime logfile changes");
+    MOZ_ASSERT(mRotate == 0,
+               "We don't allow rotate for runtime logfile changes");
     mOutFilePath.reset(strdup(filename));
 
     // Exchange mOutFile and set it to be released once all the writes are done.
@@ -280,8 +279,8 @@ public:
     detail::LogFile* oldFile = mOutFile.exchange(newFile);
 
     // Since we don't allow changing the logfile if MOZ_LOG_FILE is already set,
-    // and we don't allow log rotation when setting it at runtime, mToReleaseFile
-    // will be null, so we're not leaking.
+    // and we don't allow log rotation when setting it at runtime,
+    // mToReleaseFile will be null, so we're not leaking.
     DebugOnly<detail::LogFile*> prevFile = mToReleaseFile.exchange(oldFile);
     MOZ_ASSERT(!prevFile, "Should be null because rotation is not allowed");
 
@@ -294,8 +293,7 @@ public:
     }
   }
 
-  uint32_t GetLogFile(char *aBuffer, size_t aLength)
-  {
+  uint32_t GetLogFile(char* aBuffer, size_t aLength) {
     uint32_t len = strlen(mOutFilePath.get());
     if (len + 1 > aLength) {
       return 0;
@@ -304,18 +302,11 @@ public:
     return len;
   }
 
-  void SetIsSync(bool aIsSync)
-  {
-    mIsSync = aIsSync;
-  }
+  void SetIsSync(bool aIsSync) { mIsSync = aIsSync; }
 
-  void SetAddTimestamp(bool aAddTimestamp)
-  {
-    mAddTimestamp = aAddTimestamp;
-  }
+  void SetAddTimestamp(bool aAddTimestamp) { mAddTimestamp = aAddTimestamp; }
 
-  detail::LogFile* OpenFile(bool aShouldAppend, uint32_t aFileNum)
-  {
+  detail::LogFile* OpenFile(bool aShouldAppend, uint32_t aFileNum) {
     FILE* file;
 
     if (mRotate > 0) {
@@ -335,15 +326,13 @@ public:
     return new detail::LogFile(file, aFileNum);
   }
 
-  void RemoveFile(uint32_t aFileNum)
-  {
+  void RemoveFile(uint32_t aFileNum) {
     char buf[2048];
     SprintfLiteral(buf, "%s.%d", mOutFilePath.get(), aFileNum);
     remove(buf);
   }
 
-  LogModule* CreateOrGetModule(const char* aName)
-  {
+  LogModule* CreateOrGetModule(const char* aName) {
     OffTheBooksMutexAutoLock guard(mModulesLock);
     LogModule* module = nullptr;
     if (!mModules.Get(aName, &module)) {
@@ -354,23 +343,33 @@ public:
     return module;
   }
 
-  void Print(const char* aName, LogLevel aLevel, const char* aFmt, va_list aArgs)
-  {
+  void Print(const char* aName, LogLevel aLevel, const char* aFmt,
+             va_list aArgs) MOZ_FORMAT_PRINTF(4, 0) {
+    // We don't do nuwa-style forking anymore, so our pid can't change.
+    static long pid = static_cast<long>(base::GetCurrentProcId());
     const size_t kBuffSize = 1024;
     char buff[kBuffSize];
 
     char* buffToWrite = buff;
+    SmprintfPointer allocatedBuff;
 
-    // For backwards compat we need to use the NSPR format string versions
-    // of sprintf and friends and then hand off to printf.
     va_list argsCopy;
     va_copy(argsCopy, aArgs);
-    size_t charsWritten = PR_vsnprintf(buff, kBuffSize, aFmt, argsCopy);
+    int charsWritten = VsprintfLiteral(buff, aFmt, argsCopy);
     va_end(argsCopy);
 
-    if (charsWritten == kBuffSize - 1) {
+    if (charsWritten < 0) {
+      // Print out at least something.  We must copy to the local buff,
+      // can't just assign aFmt to buffToWrite, since when
+      // buffToWrite != buff, we try to release it.
+      MOZ_ASSERT(false, "Probably incorrect format string in LOG?");
+      strncpy(buff, aFmt, kBuffSize - 1);
+      buff[kBuffSize - 1] = '\0';
+      charsWritten = strlen(buff);
+    } else if (static_cast<size_t>(charsWritten) >= kBuffSize - 1) {
       // We may have maxed out, allocate a buffer instead.
-      buffToWrite = PR_vsmprintf(aFmt, aArgs);
+      allocatedBuff = mozilla::Vsmprintf(aFmt, aArgs);
+      buffToWrite = allocatedBuff.get();
       charsWritten = strlen(buffToWrite);
     }
 
@@ -398,10 +397,10 @@ public:
     //
     // Additionally we prefix the output with the abbreviated log level
     // and the module name.
-    PRThread *currentThread = PR_GetCurrentThread();
-    const char *currentThreadName = (mMainThread == currentThread)
-      ? "Main Thread"
-      : PR_GetThreadName(currentThread);
+    PRThread* currentThread = PR_GetCurrentThread();
+    const char* currentThreadName = (mMainThread == currentThread)
+                                        ? "Main Thread"
+                                        : PR_GetThreadName(currentThread);
 
     char noNameThread[40];
     if (!currentThreadName) {
@@ -410,19 +409,15 @@ public:
     }
 
     if (!mAddTimestamp) {
-      fprintf_stderr(out,
-                     "[%s]: %s/%s %s%s",
-                     currentThreadName, ToLogStr(aLevel),
-                     aName, buffToWrite, newline);
+      fprintf_stderr(out, "[%ld:%s]: %s/%s %s%s", pid, currentThreadName,
+                     ToLogStr(aLevel), aName, buffToWrite, newline);
     } else {
       PRExplodedTime now;
       PR_ExplodeTime(PR_Now(), PR_GMTParameters, &now);
       fprintf_stderr(
-          out,
-          "%04d-%02d-%02d %02d:%02d:%02d.%06d UTC - [%s]: %s/%s %s%s",
-          now.tm_year, now.tm_month + 1, now.tm_mday,
-          now.tm_hour, now.tm_min, now.tm_sec, now.tm_usec,
-          currentThreadName, ToLogStr(aLevel),
+          out, "%04d-%02d-%02d %02d:%02d:%02d.%06d UTC - [%ld:%s]: %s/%s %s%s",
+          now.tm_year, now.tm_month + 1, now.tm_mday, now.tm_hour, now.tm_min,
+          now.tm_sec, now.tm_usec, pid, currentThreadName, ToLogStr(aLevel),
           aName, buffToWrite, newline);
     }
 
@@ -430,10 +425,6 @@ public:
       fflush(out);
     }
 
-    if (buffToWrite != buff) {
-      PR_smprintf_free(buffToWrite);
-    }
-
     if (mRotate > 0 && outFile) {
       int32_t fileSize = ftell(out);
       if (fileSize > mRotate) {
@@ -472,7 +463,7 @@ public:
     }
   }
 
-private:
+ private:
   OffTheBooksMutex mModulesLock;
   nsClassHashtable<nsCharPtrHashKey, LogModule> mModules;
 
@@ -495,55 +486,46 @@ private:
   // Just keeps the actual file path for further use.
   UniqueFreePtr<char[]> mOutFilePath;
 
-  PRThread *mMainThread;
+  PRThread* mMainThread;
   bool mSetFromEnv;
   Atomic<bool, Relaxed> mAddTimestamp;
   Atomic<bool, Relaxed> mIsSync;
   int32_t mRotate;
+  bool mInitialized;
 };
 
 StaticAutoPtr<LogModuleManager> sLogModuleManager;
 
-LogModule*
-LogModule::Get(const char* aName)
-{
+LogModule* LogModule::Get(const char* aName) {
   // This is just a pass through to the LogModuleManager so
   // that the LogModuleManager implementation can be kept internal.
   MOZ_ASSERT(sLogModuleManager != nullptr);
   return sLogModuleManager->CreateOrGetModule(aName);
 }
 
-void
-LogModule::SetLogFile(const char* aFilename)
-{
+void LogModule::SetLogFile(const char* aFilename) {
   MOZ_ASSERT(sLogModuleManager);
   sLogModuleManager->SetLogFile(aFilename);
 }
 
-uint32_t
-LogModule::GetLogFile(char *aBuffer, size_t aLength)
-{
+uint32_t LogModule::GetLogFile(char* aBuffer, size_t aLength) {
   MOZ_ASSERT(sLogModuleManager);
   return sLogModuleManager->GetLogFile(aBuffer, aLength);
 }
 
-void
-LogModule::SetAddTimestamp(bool aAddTimestamp)
-{
+void LogModule::SetAddTimestamp(bool aAddTimestamp) {
   sLogModuleManager->SetAddTimestamp(aAddTimestamp);
 }
 
-void
-LogModule::SetIsSync(bool aIsSync)
-{
+void LogModule::SetIsSync(bool aIsSync) {
   sLogModuleManager->SetIsSync(aIsSync);
 }
 
-void
-LogModule::Init()
-{
+void LogModule::Init() {
   // NB: This method is not threadsafe; it is expected to be called very early
   //     in startup prior to any other threads being run.
+  MOZ_DIAGNOSTIC_ASSERT(NS_IsMainThread());
+
   if (sLogModuleManager) {
     // Already initialized.
     return;
@@ -552,17 +534,19 @@ LogModule::Init()
   // NB: We intentionally do not register for ClearOnShutdown as that happens
   //     before all logging is complete. And, yes, that means we leak, but
   //     we're doing that intentionally.
-  sLogModuleManager = new LogModuleManager();
-  sLogModuleManager->Init();
+
+  // Don't assign the pointer until after Init is called. This should help us
+  // detect if any of the functions called by Init somehow rely on logging.
+  auto mgr = new LogModuleManager();
+  mgr->Init();
+  sLogModuleManager = mgr;
 }
 
-void
-LogModule::Printv(LogLevel aLevel, const char* aFmt, va_list aArgs) const
-{
+void LogModule::Printv(LogLevel aLevel, const char* aFmt, va_list aArgs) const {
   MOZ_ASSERT(sLogModuleManager != nullptr);
 
   // Forward to LogModule manager w/ level and name
   sLogModuleManager->Print(Name(), aLevel, aFmt, aArgs);
 }
 
-} // namespace mozilla
+}  // namespace mozilla
