@@ -19,12 +19,15 @@
 #include "nsConsoleMessage.h"
 #include "nsIClassInfoImpl.h"
 #include "nsIConsoleListener.h"
+#include "nsIObserverService.h"
 #include "nsPrintfCString.h"
 #include "nsProxyRelease.h"
 #include "nsIScriptError.h"
 #include "nsISupportsPrimitives.h"
 
 #include "mozilla/Preferences.h"
+#include "mozilla/Services.h"
+#include "mozilla/SystemGroup.h"
 
 #if defined(ANDROID)
 #include <android/log.h>
@@ -49,35 +52,46 @@ NS_IMPL_CLASSINFO(nsConsoleService, nullptr,
 NS_IMPL_QUERY_INTERFACE_CI(nsConsoleService, nsIConsoleService, nsIObserver)
 NS_IMPL_CI_INTERFACE_GETTER(nsConsoleService, nsIConsoleService, nsIObserver)
 
-static bool sLoggingEnabled = true;
-static bool sLoggingBuffered = true;
+static const bool gLoggingEnabled = true;
+static const bool gLoggingBuffered = true;
+#ifdef XP_WIN
+static bool gLoggingToDebugger = true;
+#endif  // XP_WIN
 #if defined(ANDROID)
-static bool sLoggingLogcat = true;
-#endif // defined(ANDROID)
+static bool gLoggingLogcat = false;
+#endif  // defined(ANDROID)
 
-nsConsoleService::MessageElement::~MessageElement()
-{
-}
+nsConsoleService::MessageElement::~MessageElement() {}
 
 nsConsoleService::nsConsoleService()
-  : mCurrentSize(0)
-  , mDeliveringMessage(false)
-  , mLock("nsConsoleService.mLock")
-{
+    : mCurrentSize(0),
+      mDeliveringMessage(false),
+      mLock("nsConsoleService.mLock") {
   // XXX grab this from a pref!
   // hm, but worry about circularity, bc we want to be able to report
   // prefs errs...
   mMaximumSize = 250;
+
+#ifdef XP_WIN
+  // This environment variable controls whether the console service
+  // should be prevented from putting output to the attached debugger.
+  // It only affects the Windows platform.
+  //
+  // To disable OutputDebugString, set:
+  //   MOZ_CONSOLESERVICE_DISABLE_DEBUGGER_OUTPUT=1
+  //
+  const char* disableDebugLoggingVar =
+      getenv("MOZ_CONSOLESERVICE_DISABLE_DEBUGGER_OUTPUT");
+  gLoggingToDebugger =
+      !disableDebugLoggingVar || (disableDebugLoggingVar[0] == '0');
+#endif  // XP_WIN
 }
 
-
-void
-nsConsoleService::ClearMessagesForWindowID(const uint64_t innerID)
-{
+void nsConsoleService::ClearMessagesForWindowID(const uint64_t innerID) {
   MOZ_RELEASE_ASSERT(NS_IsMainThread());
   MutexAutoLock lock(mLock);
 
-  for (MessageElement* e = mMessages.getFirst(); e != nullptr; ) {
+  for (MessageElement* e = mMessages.getFirst(); e != nullptr;) {
     // Only messages implementing nsIScriptError interface expose the
     // inner window ID.
     nsCOMPtr<nsIScriptError> scriptError = do_QueryInterface(e->Get());
@@ -102,9 +116,7 @@ nsConsoleService::ClearMessagesForWindowID(const uint64_t innerID)
   }
 }
 
-void
-nsConsoleService::ClearMessages()
-{
+void nsConsoleService::ClearMessages() {
   // NB: A lock is not required here as it's only called from |Reset| which
   //     locks for us and from the dtor.
   while (!mMessages.isEmpty()) {
@@ -114,46 +126,44 @@ nsConsoleService::ClearMessages()
   mCurrentSize = 0;
 }
 
-nsConsoleService::~nsConsoleService()
-{
+nsConsoleService::~nsConsoleService() {
   MOZ_RELEASE_ASSERT(NS_IsMainThread());
 
   ClearMessages();
 }
 
-class AddConsolePrefWatchers : public Runnable
-{
-public:
-  explicit AddConsolePrefWatchers(nsConsoleService* aConsole) : mConsole(aConsole)
-  {
-  }
+class AddConsolePrefWatchers : public Runnable {
+ public:
+  explicit AddConsolePrefWatchers(nsConsoleService* aConsole)
+      : mozilla::Runnable("AddConsolePrefWatchers"), mConsole(aConsole) {}
 
-  NS_IMETHOD Run() override
-  {
-    Preferences::AddBoolVarCache(&sLoggingEnabled, "consoleservice.enabled", true);
-    Preferences::AddBoolVarCache(&sLoggingBuffered, "consoleservice.buffered", true);
+  NS_IMETHOD Run() override {
 #if defined(ANDROID)
-    Preferences::AddBoolVarCache(&sLoggingLogcat, "consoleservice.logcat", true);
-#endif // defined(ANDROID)
+    Preferences::AddBoolVarCache(&gLoggingLogcat, "consoleservice.logcat",
+#ifdef RELEASE_OR_BETA
+                                 false
+#else
+                                 true
+#endif
+    );
+#endif  // defined(ANDROID)
 
     nsCOMPtr<nsIObserverService> obs = mozilla::services::GetObserverService();
     MOZ_ASSERT(obs);
     obs->AddObserver(mConsole, NS_XPCOM_SHUTDOWN_OBSERVER_ID, false);
     obs->AddObserver(mConsole, "inner-window-destroyed", false);
 
-    if (!sLoggingBuffered) {
+    if (!gLoggingBuffered) {
       mConsole->Reset();
     }
     return NS_OK;
   }
 
-private:
+ private:
   RefPtr<nsConsoleService> mConsole;
 };
 
-nsresult
-nsConsoleService::Init()
-{
+nsresult nsConsoleService::Init() {
   NS_DispatchToMainThread(new AddConsolePrefWatchers(this));
 
   return NS_OK;
@@ -161,24 +171,22 @@ nsConsoleService::Init()
 
 namespace {
 
-class LogMessageRunnable : public Runnable
-{
-public:
+class LogMessageRunnable : public Runnable {
+ public:
   LogMessageRunnable(nsIConsoleMessage* aMessage, nsConsoleService* aService)
-    : mMessage(aMessage)
-    , mService(aService)
-  { }
+      : mozilla::Runnable("LogMessageRunnable"),
+        mMessage(aMessage),
+        mService(aService) {}
 
   NS_DECL_NSIRUNNABLE
 
-private:
+ private:
   nsCOMPtr<nsIConsoleMessage> mMessage;
   RefPtr<nsConsoleService> mService;
 };
 
 NS_IMETHODIMP
-LogMessageRunnable::Run()
-{
+LogMessageRunnable::Run() {
   MOZ_ASSERT(NS_IsMainThread());
 
   // Snapshot of listeners so that we don't reenter this hash during
@@ -197,34 +205,35 @@ LogMessageRunnable::Run()
   return NS_OK;
 }
 
-} // namespace
+}  // namespace
 
 // nsIConsoleService methods
 NS_IMETHODIMP
-nsConsoleService::LogMessage(nsIConsoleMessage* aMessage)
-{
+nsConsoleService::LogMessage(nsIConsoleMessage* aMessage) {
   return LogMessageWithMode(aMessage, OutputToLog);
 }
 
 // This can be called off the main thread.
-nsresult
-nsConsoleService::LogMessageWithMode(nsIConsoleMessage* aMessage,
-                                     nsConsoleService::OutputMode aOutputMode)
-{
+nsresult nsConsoleService::LogMessageWithMode(
+    nsIConsoleMessage* aMessage, nsConsoleService::OutputMode aOutputMode) {
   if (!aMessage) {
     return NS_ERROR_INVALID_ARG;
   }
 
-  if (!sLoggingEnabled) {
+  if (!gLoggingEnabled) {
     return NS_OK;
   }
 
   if (NS_IsMainThread() && mDeliveringMessage) {
     nsCString msg;
     aMessage->ToString(msg);
-    NS_WARNING(nsPrintfCString("Reentrancy error: some client attempted "
-      "to display a message to the console while in a console listener. "
-      "The following message was discarded: \"%s\"", msg.get()).get());
+    NS_WARNING(
+        nsPrintfCString(
+            "Reentrancy error: some client attempted to display a message to "
+            "the console while in a console listener. The following message "
+            "was discarded: \"%s\"",
+            msg.get())
+            .get());
     return NS_ERROR_FAILURE;
   }
 
@@ -239,7 +248,7 @@ nsConsoleService::LogMessageWithMode(nsIConsoleMessage* aMessage,
     MutexAutoLock lock(mLock);
 
 #if defined(ANDROID)
-    if (sLoggingLogcat && aOutputMode == OutputToLog) {
+    if (gLoggingLogcat && aOutputMode == OutputToLog) {
       nsCString msg;
       aMessage->ToString(msg);
 
@@ -276,7 +285,7 @@ nsConsoleService::LogMessageWithMode(nsIConsoleMessage* aMessage,
     }
 #endif
 #ifdef XP_WIN
-    if (IsDebuggerPresent()) {
+    if (gLoggingToDebugger && IsDebuggerPresent()) {
       nsString msg;
       aMessage->GetMessageMoz(getter_Copies(msg));
       msg.Append('\n');
@@ -284,7 +293,7 @@ nsConsoleService::LogMessageWithMode(nsIConsoleMessage* aMessage,
     }
 #endif
 #ifdef MOZ_TASK_TRACER
-    {
+    if (IsStartLogging()) {
       nsCString msg;
       aMessage->ToString(msg);
       int prefixPos = msg.Find(GetJSLabelPrefix());
@@ -295,7 +304,7 @@ nsConsoleService::LogMessageWithMode(nsIConsoleMessage* aMessage,
     }
 #endif
 
-    if (sLoggingBuffered) {
+    if (gLoggingBuffered) {
       MessageElement* e = new MessageElement(aMessage);
       mMessages.insertBack(e);
       if (mCurrentSize != mMaximumSize) {
@@ -317,24 +326,23 @@ nsConsoleService::LogMessageWithMode(nsIConsoleMessage* aMessage,
     // Release |retiredMessage| on the main thread in case it is an instance of
     // a mainthread-only class like nsScriptErrorWithStack and we're off the
     // main thread.
-    NS_ReleaseOnMainThread(retiredMessage.forget());
+    NS_ReleaseOnMainThreadSystemGroup("nsConsoleService::retiredMessage",
+                                      retiredMessage.forget());
   }
 
   if (r) {
     // avoid failing in XPCShell tests
     nsCOMPtr<nsIThread> mainThread = do_GetMainThread();
     if (mainThread) {
-      NS_DispatchToMainThread(r.forget());
+      SystemGroup::Dispatch(TaskCategory::Other, r.forget());
     }
   }
 
   return NS_OK;
 }
 
-void
-nsConsoleService::CollectCurrentListeners(
-  nsCOMArray<nsIConsoleListener>& aListeners)
-{
+void nsConsoleService::CollectCurrentListeners(
+    nsCOMArray<nsIConsoleListener>& aListeners) {
   MutexAutoLock lock(mLock);
   for (auto iter = mListeners.Iter(); !iter.Done(); iter.Next()) {
     nsIConsoleListener* value = iter.UserData();
@@ -343,9 +351,8 @@ nsConsoleService::CollectCurrentListeners(
 }
 
 NS_IMETHODIMP
-nsConsoleService::LogStringMessage(const char16_t* aMessage)
-{
-  if (!sLoggingEnabled) {
+nsConsoleService::LogStringMessage(const char16_t* aMessage) {
+  if (!gLoggingEnabled) {
     return NS_OK;
   }
 
@@ -355,8 +362,7 @@ nsConsoleService::LogStringMessage(const char16_t* aMessage)
 
 NS_IMETHODIMP
 nsConsoleService::GetMessageArray(uint32_t* aCount,
-                                  nsIConsoleMessage*** aMessages)
-{
+                                  nsIConsoleMessage*** aMessages) {
   MOZ_RELEASE_ASSERT(NS_IsMainThread());
 
   MutexAutoLock lock(mLock);
@@ -367,8 +373,8 @@ nsConsoleService::GetMessageArray(uint32_t* aCount,
      * and return a count of 0.  This should result in a 0-length
      * array object when called from script.
      */
-    nsIConsoleMessage** messageArray = (nsIConsoleMessage**)
-      moz_xmalloc(sizeof(nsIConsoleMessage*));
+    nsIConsoleMessage** messageArray =
+        (nsIConsoleMessage**)moz_xmalloc(sizeof(nsIConsoleMessage*));
     *messageArray = nullptr;
     *aMessages = messageArray;
     *aCount = 0;
@@ -377,12 +383,12 @@ nsConsoleService::GetMessageArray(uint32_t* aCount,
   }
 
   MOZ_ASSERT(mCurrentSize <= mMaximumSize);
-  nsIConsoleMessage** messageArray =
-    static_cast<nsIConsoleMessage**>(moz_xmalloc(sizeof(nsIConsoleMessage*)
-                                                 * mCurrentSize));
+  nsIConsoleMessage** messageArray = static_cast<nsIConsoleMessage**>(
+      moz_xmalloc(sizeof(nsIConsoleMessage*) * mCurrentSize));
 
   uint32_t i = 0;
-  for (MessageElement* e = mMessages.getFirst(); e != nullptr; e = e->getNext()) {
+  for (MessageElement* e = mMessages.getFirst(); e != nullptr;
+       e = e->getNext()) {
     nsCOMPtr<nsIConsoleMessage> m = e->Get();
     m.forget(&messageArray[i]);
     i++;
@@ -397,8 +403,7 @@ nsConsoleService::GetMessageArray(uint32_t* aCount,
 }
 
 NS_IMETHODIMP
-nsConsoleService::RegisterListener(nsIConsoleListener* aListener)
-{
+nsConsoleService::RegisterListener(nsIConsoleListener* aListener) {
   if (!NS_IsMainThread()) {
     NS_ERROR("nsConsoleService::RegisterListener is main thread only.");
     return NS_ERROR_NOT_SAME_THREAD;
@@ -416,8 +421,7 @@ nsConsoleService::RegisterListener(nsIConsoleListener* aListener)
 }
 
 NS_IMETHODIMP
-nsConsoleService::UnregisterListener(nsIConsoleListener* aListener)
-{
+nsConsoleService::UnregisterListener(nsIConsoleListener* aListener) {
   if (!NS_IsMainThread()) {
     NS_ERROR("nsConsoleService::UnregisterListener is main thread only.");
     return NS_ERROR_NOT_SAME_THREAD;
@@ -436,8 +440,7 @@ nsConsoleService::UnregisterListener(nsIConsoleListener* aListener)
 }
 
 NS_IMETHODIMP
-nsConsoleService::Reset()
-{
+nsConsoleService::Reset() {
   MOZ_RELEASE_ASSERT(NS_IsMainThread());
 
   /*
@@ -451,8 +454,7 @@ nsConsoleService::Reset()
 
 NS_IMETHODIMP
 nsConsoleService::Observe(nsISupports* aSubject, const char* aTopic,
-                          const char16_t* aData)
-{
+                          const char16_t* aData) {
   if (!strcmp(aTopic, NS_XPCOM_SHUTDOWN_OBSERVER_ID)) {
     // Dump all our messages, in case any are cycle collected.
     Reset();
