@@ -7,17 +7,12 @@
 #ifndef nsDebugImpl_h
 #define nsDebugImpl_h
 
-#include "nsIDebug.h"
 #include "nsIDebug2.h"
 
-class nsDebugImpl : public nsIDebug2
-{
-public:
-  nsDebugImpl()
-  {
-  }
+class nsDebugImpl : public nsIDebug2 {
+ public:
+  nsDebugImpl() = default;
   NS_DECL_ISUPPORTS
-  NS_DECL_NSIDEBUG
   NS_DECL_NSIDEBUG2
 
   static nsresult Create(nsISupports* aOuter, const nsIID& aIID,
@@ -32,14 +27,12 @@ public:
   static void SetMultiprocessMode(const char* aDesc);
 };
 
-
 #define NS_DEBUG_CONTRACTID "@mozilla.org/xpcom/debug;1"
 #define NS_DEBUG_CID                                 \
-{ /* a80b1fb3-aaf6-4852-b678-c27eb7a518af */         \
-  0xa80b1fb3,                                        \
-    0xaaf6,                                          \
-    0x4852,                                          \
-    {0xb6, 0x78, 0xc2, 0x7e, 0xb7, 0xa5, 0x18, 0xaf} \
-}
+  { /* cb6cdb94-e417-4601-b4a5-f991bf41453d */       \
+    0xcb6cdb94, 0xe417, 0x4601, {                    \
+      0xb4, 0xa5, 0xf9, 0x91, 0xbf, 0x41, 0x45, 0x3d \
+    }                                                \
+  }
 
-#endif // nsDebugImpl_h
+#endif  // nsDebugImpl_h
