@@ -21,37 +21,30 @@
 
 #ifdef ANDROID
 #include "android/log.h"
-#define LOG(...) __android_log_print(ANDROID_LOG_INFO, "Gecko:DumpUtils", ## __VA_ARGS__)
+#define LOG(...) \
+  __android_log_print(ANDROID_LOG_INFO, "Gecko:DumpUtils", ##__VA_ARGS__)
 #else
 #define LOG(...)
 #endif
 
-#ifdef XP_UNIX // {
+#ifdef XP_UNIX  // {
 
 /**
  * Abstract base class for something which watches an fd and takes action when
  * we can read from it without blocking.
  */
-class FdWatcher
-  : public MessageLoopForIO::Watcher
-  , public nsIObserver
-{
-protected:
+class FdWatcher : public MessageLoopForIO::Watcher, public nsIObserver {
+ protected:
   MessageLoopForIO::FileDescriptorWatcher mReadWatcher;
   int mFd;
 
-  virtual ~FdWatcher()
-  {
+  virtual ~FdWatcher() {
     // StopWatching should have run.
     MOZ_ASSERT(mFd == -1);
   }
 
-public:
-  FdWatcher()
-    : mFd(-1)
-  {
-    MOZ_ASSERT(NS_IsMainThread());
-  }
+ public:
+  FdWatcher() : mFd(-1) { MOZ_ASSERT(NS_IsMainThread()); }
 
   /**
    * Open the fd to watch.  If we encounter an error, return -1.
@@ -63,7 +56,7 @@ public:
    * function is also called when you're at eof (read() returns 0 in this case).
    */
   virtual void OnFileCanReadWithoutBlocking(int aFd) override = 0;
-  virtual void OnFileCanWriteWithoutBlocking(int aFd) override {};
+  virtual void OnFileCanWriteWithoutBlocking(int aFd) override{};
 
   NS_DECL_THREADSAFE_ISUPPORTS
 
@@ -84,28 +77,26 @@ public:
   virtual void StopWatching();
 
   NS_IMETHOD Observe(nsISupports* aSubject, const char* aTopic,
-                     const char16_t* aData) override
-  {
+                     const char16_t* aData) override {
     MOZ_ASSERT(NS_IsMainThread());
     MOZ_ASSERT(!strcmp(aTopic, "xpcom-shutdown"));
 
-    XRE_GetIOMessageLoop()->PostTask(mozilla::NewRunnableMethod(this, &FdWatcher::StopWatching));
+    XRE_GetIOMessageLoop()->PostTask(mozilla::NewRunnableMethod(
+        "FdWatcher::StopWatching", this, &FdWatcher::StopWatching));
 
     return NS_OK;
   }
 };
 
 typedef void (*FifoCallback)(const nsCString& aInputStr);
-struct FifoInfo
-{
+struct FifoInfo {
   nsCString mCommand;
   FifoCallback mCallback;
 };
 typedef nsTArray<FifoInfo> FifoInfoArray;
 
-class FifoWatcher : public FdWatcher
-{
-public:
+class FifoWatcher : public FdWatcher {
+ public:
   /**
    * The name of the preference used to enable/disable the FifoWatcher.
    */
@@ -119,36 +110,31 @@ public:
 
   virtual ~FifoWatcher();
 
-  virtual int OpenFd();
+  virtual int OpenFd() override;
 
-  virtual void OnFileCanReadWithoutBlocking(int aFd);
+  virtual void OnFileCanReadWithoutBlocking(int aFd) override;
 
-private:
+ private:
   nsAutoCString mDirPath;
 
   static mozilla::StaticRefPtr<FifoWatcher> sSingleton;
 
   explicit FifoWatcher(nsCString aPath)
-    : mDirPath(aPath)
-    , mFifoInfoLock("FifoWatcher.mFifoInfoLock")
-  {
-  }
+      : mDirPath(aPath), mFifoInfoLock("FifoWatcher.mFifoInfoLock") {}
 
-  mozilla::Mutex mFifoInfoLock; // protects mFifoInfo
+  mozilla::Mutex mFifoInfoLock;  // protects mFifoInfo
   FifoInfoArray mFifoInfo;
 };
 
 typedef void (*PipeCallback)(const uint8_t aRecvSig);
-struct SignalInfo
-{
+struct SignalInfo {
   uint8_t mSignal;
   PipeCallback mCallback;
 };
 typedef nsTArray<SignalInfo> SignalInfoArray;
 
-class SignalPipeWatcher : public FdWatcher
-{
-public:
+class SignalPipeWatcher : public FdWatcher {
+ public:
   static SignalPipeWatcher* GetSingleton();
 
   void RegisterCallback(uint8_t aSignal, PipeCallback aCallback);
@@ -157,35 +143,28 @@ public:
 
   virtual ~SignalPipeWatcher();
 
-  virtual int OpenFd();
+  virtual int OpenFd() override;
 
-  virtual void StopWatching();
+  virtual void StopWatching() override;
 
-  virtual void OnFileCanReadWithoutBlocking(int aFd);
+  virtual void OnFileCanReadWithoutBlocking(int aFd) override;
 
-private:
+ private:
   static mozilla::StaticRefPtr<SignalPipeWatcher> sSingleton;
 
-  SignalPipeWatcher()
-    : mSignalInfoLock("SignalPipeWatcher.mSignalInfoLock")
-  {
+  SignalPipeWatcher() : mSignalInfoLock("SignalPipeWatcher.mSignalInfoLock") {
     MOZ_ASSERT(NS_IsMainThread());
   }
 
-  mozilla::Mutex mSignalInfoLock; // protects mSignalInfo
+  mozilla::Mutex mSignalInfoLock;  // protects mSignalInfo
   SignalInfoArray mSignalInfo;
 };
 
-#endif // XP_UNIX }
+#endif  // XP_UNIX }
 
-class nsDumpUtils
-{
-public:
-
-  enum Mode {
-    CREATE,
-    CREATE_UNIQUE
-  };
+class nsDumpUtils {
+ public:
+  enum Mode { CREATE, CREATE_UNIQUE };
 
   /**
    * This function creates a new unique file based on |aFilename| in a
@@ -194,8 +173,7 @@ public:
    * non-null, it is assumed to point to a folder, and that folder is used
    * instead.
    */
-  static nsresult OpenTempFile(const nsACString& aFilename,
-                               nsIFile** aFile,
+  static nsresult OpenTempFile(const nsACString& aFilename, nsIFile** aFile,
                                const nsACString& aFoldername = EmptyCString(),
                                Mode aMode = CREATE_UNIQUE);
 };
