@@ -9,21 +9,28 @@
 #include "nsSystemInfo.h"
 #include "prsystem.h"
 #include "prio.h"
-#include "prprf.h"
 #include "mozilla/SSE.h"
 #include "mozilla/arm.h"
 #include "mozilla/Sprintf.h"
 
 #ifdef XP_WIN
+#include <comutil.h>
 #include <time.h>
+#ifndef __MINGW32__
+#include <iwscapi.h>
+#endif  // __MINGW32__
 #include <windows.h>
 #include <winioctl.h>
+#ifndef __MINGW32__
+#include <wscapi.h>
+#endif  // __MINGW32__
 #include "base/scoped_handle_win.h"
 #include "nsAppDirectoryServiceDefs.h"
 #include "nsDirectoryServiceDefs.h"
 #include "nsDirectoryServiceUtils.h"
 #include "nsIObserverService.h"
 #include "nsWindowsHelpers.h"
+
 #endif
 
 #ifdef XP_MACOSX
@@ -35,7 +42,7 @@
 #include <dlfcn.h>
 #endif
 
-#if defined (XP_LINUX) && !defined (ANDROID)
+#if defined(XP_LINUX) && !defined(ANDROID)
 #include <unistd.h>
 #include <fstream>
 #include "mozilla/Tokenizer.h"
@@ -50,12 +57,6 @@
 #include "mozilla/dom/ContentChild.h"
 #endif
 
-#ifdef MOZ_WIDGET_GONK
-#include <sys/system_properties.h>
-#include "mozilla/Preferences.h"
-#include "nsPrintfCString.h"
-#endif
-
 #ifdef ANDROID
 extern "C" {
 NS_EXPORT int android_sdk_version;
@@ -77,13 +78,14 @@ NS_EXPORT int android_sdk_version;
 // only happens well after that point.
 uint32_t nsSystemInfo::gUserUmask = 0;
 
-#if defined (XP_LINUX) && !defined (ANDROID)
-static void
-SimpleParseKeyValuePairs(const std::string& aFilename,
-                         std::map<nsCString, nsCString>& aKeyValuePairs)
-{
+using namespace mozilla::dom;
+
+#if defined(XP_LINUX) && !defined(ANDROID)
+static void SimpleParseKeyValuePairs(
+    const std::string& aFilename,
+    std::map<nsCString, nsCString>& aKeyValuePairs) {
   std::ifstream input(aFilename.c_str());
-  for (std::string line; std::getline(input, line); ) {
+  for (std::string line; std::getline(input, line);) {
     nsAutoCString key, value;
 
     nsCCharSeparatedTokenizer tokens(nsDependentCString(line.c_str()), ':');
@@ -103,25 +105,23 @@ SimpleParseKeyValuePairs(const std::string& aFilename,
 
 #if defined(XP_WIN)
 namespace {
-nsresult
-GetHDDInfo(const char* aSpecialDirName, nsAutoCString& aModel,
-           nsAutoCString& aRevision)
-{
+nsresult GetHDDInfo(const char* aSpecialDirName, nsAutoCString& aModel,
+                    nsAutoCString& aRevision) {
   aModel.Truncate();
   aRevision.Truncate();
 
   nsCOMPtr<nsIFile> profDir;
-  nsresult rv = NS_GetSpecialDirectory(aSpecialDirName,
-                                       getter_AddRefs(profDir));
+  nsresult rv =
+      NS_GetSpecialDirectory(aSpecialDirName, getter_AddRefs(profDir));
   NS_ENSURE_SUCCESS(rv, rv);
   nsAutoString profDirPath;
   rv = profDir->GetPath(profDirPath);
   NS_ENSURE_SUCCESS(rv, rv);
   wchar_t volumeMountPoint[MAX_PATH] = {L'\\', L'\\', L'.', L'\\'};
   const size_t PREFIX_LEN = 4;
-  if (!::GetVolumePathNameW(profDirPath.get(), volumeMountPoint + PREFIX_LEN,
-                            mozilla::ArrayLength(volumeMountPoint) -
-                            PREFIX_LEN)) {
+  if (!::GetVolumePathNameW(
+          profDirPath.get(), volumeMountPoint + PREFIX_LEN,
+          mozilla::ArrayLength(volumeMountPoint) - PREFIX_LEN)) {
     return NS_ERROR_UNEXPECTED;
   }
   size_t volumeMountPointLen = wcslen(volumeMountPoint);
@@ -132,28 +132,25 @@ GetHDDInfo(const char* aSpecialDirName, nsAutoCString& aModel,
     volumeMountPoint[volumeMountPointLen - 1] = L'\0';
   }
   ScopedHandle handle(::CreateFileW(volumeMountPoint, 0,
-                                    FILE_SHARE_READ | FILE_SHARE_WRITE,
-                                    nullptr, OPEN_EXISTING, 0, nullptr));
+                                    FILE_SHARE_READ | FILE_SHARE_WRITE, nullptr,
+                                    OPEN_EXISTING, 0, nullptr));
   if (!handle.IsValid()) {
     return NS_ERROR_UNEXPECTED;
   }
-  STORAGE_PROPERTY_QUERY queryParameters = {
-    StorageDeviceProperty, PropertyStandardQuery
-  };
+  STORAGE_PROPERTY_QUERY queryParameters = {StorageDeviceProperty,
+                                            PropertyStandardQuery};
   STORAGE_DEVICE_DESCRIPTOR outputHeader = {sizeof(STORAGE_DEVICE_DESCRIPTOR)};
   DWORD bytesRead = 0;
-  if (!::DeviceIoControl(handle, IOCTL_STORAGE_QUERY_PROPERTY,
-                         &queryParameters, sizeof(queryParameters),
-                         &outputHeader, sizeof(outputHeader), &bytesRead,
-                         nullptr)) {
+  if (!::DeviceIoControl(handle, IOCTL_STORAGE_QUERY_PROPERTY, &queryParameters,
+                         sizeof(queryParameters), &outputHeader,
+                         sizeof(outputHeader), &bytesRead, nullptr)) {
     return NS_ERROR_FAILURE;
   }
   PSTORAGE_DEVICE_DESCRIPTOR deviceOutput =
-    (PSTORAGE_DEVICE_DESCRIPTOR)malloc(outputHeader.Size);
-  if (!::DeviceIoControl(handle, IOCTL_STORAGE_QUERY_PROPERTY,
-                         &queryParameters, sizeof(queryParameters),
-                         deviceOutput, outputHeader.Size, &bytesRead,
-                         nullptr)) {
+      (PSTORAGE_DEVICE_DESCRIPTOR)malloc(outputHeader.Size);
+  if (!::DeviceIoControl(handle, IOCTL_STORAGE_QUERY_PROPERTY, &queryParameters,
+                         sizeof(queryParameters), deviceOutput,
+                         outputHeader.Size, &bytesRead, nullptr)) {
     free(deviceOutput);
     return NS_ERROR_FAILURE;
   }
@@ -161,31 +158,28 @@ GetHDDInfo(const char* aSpecialDirName, nsAutoCString& aModel,
   // IDs include vendor info and product ID concatenated together, we'll do
   // that here and interpret the result as a unique ID for the HDD model.
   if (deviceOutput->VendorIdOffset) {
-    aModel = reinterpret_cast<char*>(deviceOutput) +
-      deviceOutput->VendorIdOffset;
+    aModel =
+        reinterpret_cast<char*>(deviceOutput) + deviceOutput->VendorIdOffset;
   }
   if (deviceOutput->ProductIdOffset) {
-    aModel += reinterpret_cast<char*>(deviceOutput) +
-      deviceOutput->ProductIdOffset;
+    aModel +=
+        reinterpret_cast<char*>(deviceOutput) + deviceOutput->ProductIdOffset;
   }
   aModel.CompressWhitespace();
   if (deviceOutput->ProductRevisionOffset) {
     aRevision = reinterpret_cast<char*>(deviceOutput) +
-      deviceOutput->ProductRevisionOffset;
+                deviceOutput->ProductRevisionOffset;
     aRevision.CompressWhitespace();
   }
   free(deviceOutput);
   return NS_OK;
 }
 
-nsresult GetInstallYear(uint32_t& aYear)
-{
+nsresult GetInstallYear(uint32_t& aYear) {
   HKEY hKey;
-  LONG status = RegOpenKeyExW(HKEY_LOCAL_MACHINE,
-                              NS_LITERAL_STRING(
-                              "SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion"
-                              ).get(),
-                              0, KEY_READ | KEY_WOW64_64KEY, &hKey);
+  LONG status = RegOpenKeyExW(
+      HKEY_LOCAL_MACHINE, L"SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion", 0,
+      KEY_READ | KEY_WOW64_64KEY, &hKey);
 
   if (status != ERROR_SUCCESS) {
     return NS_ERROR_UNEXPECTED;
@@ -197,8 +191,8 @@ nsresult GetInstallYear(uint32_t& aYear)
   time_t raw_time = 0;
   DWORD time_size = sizeof(time_t);
 
-  status = RegQueryValueExW(hKey, L"InstallDate",
-                            nullptr, &type, (LPBYTE)&raw_time, &time_size);
+  status = RegQueryValueExW(hKey, L"InstallDate", nullptr, &type,
+                            (LPBYTE)&raw_time, &time_size);
 
   if (status != ERROR_SUCCESS) {
     return NS_ERROR_UNEXPECTED;
@@ -217,8 +211,7 @@ nsresult GetInstallYear(uint32_t& aYear)
   return NS_OK;
 }
 
-nsresult GetCountryCode(nsAString& aCountryCode)
-{
+nsresult GetCountryCode(nsAString& aCountryCode) {
   GEOID geoid = GetUserGeoID(GEOCLASS_NATION);
   if (geoid == GEOID_NOT_AVAILABLE) {
     return NS_ERROR_NOT_AVAILABLE;
@@ -230,8 +223,9 @@ nsresult GetCountryCode(nsAString& aCountryCode)
   }
   // Now get the string for real
   aCountryCode.SetLength(numChars);
-  numChars = GetGeoInfoW(geoid, GEO_ISO2, wwc(aCountryCode.BeginWriting()),
-                         aCountryCode.Length(), 0);
+  numChars =
+      GetGeoInfoW(geoid, GEO_ISO2, char16ptr_t(aCountryCode.BeginWriting()),
+                  aCountryCode.Length(), 0);
   if (!numChars) {
     return NS_ERROR_FAILURE;
   }
@@ -241,62 +235,172 @@ nsresult GetCountryCode(nsAString& aCountryCode)
   return NS_OK;
 }
 
-} // namespace
-#endif // defined(XP_WIN)
+}  // namespace
+
+#ifndef __MINGW32__
+
+static HRESULT EnumWSCProductList(nsAString& aOutput,
+                                  NotNull<IWSCProductList*> aProdList) {
+  MOZ_ASSERT(aOutput.IsEmpty());
+
+  LONG count;
+  HRESULT hr = aProdList->get_Count(&count);
+  if (FAILED(hr)) {
+    return hr;
+  }
+
+  for (LONG index = 0; index < count; ++index) {
+    RefPtr<IWscProduct> product;
+    hr = aProdList->get_Item(index, getter_AddRefs(product));
+    if (FAILED(hr)) {
+      return hr;
+    }
+
+    WSC_SECURITY_PRODUCT_STATE state;
+    hr = product->get_ProductState(&state);
+    if (FAILED(hr)) {
+      return hr;
+    }
+
+    // We only care about products that are active
+    if (state == WSC_SECURITY_PRODUCT_STATE_OFF ||
+        state == WSC_SECURITY_PRODUCT_STATE_SNOOZED) {
+      continue;
+    }
+
+    _bstr_t bName;
+    hr = product->get_ProductName(bName.GetAddress());
+    if (FAILED(hr)) {
+      return hr;
+    }
+
+    if (!aOutput.IsEmpty()) {
+      aOutput.AppendLiteral(u";");
+    }
+
+    aOutput.Append((wchar_t*)bName, bName.length());
+  }
+
+  return S_OK;
+}
+
+static nsresult GetWindowsSecurityCenterInfo(nsAString& aAVInfo,
+                                             nsAString& aAntiSpyInfo,
+                                             nsAString& aFirewallInfo) {
+  aAVInfo.Truncate();
+  aAntiSpyInfo.Truncate();
+  aFirewallInfo.Truncate();
+
+  if (!XRE_IsParentProcess()) {
+    return NS_ERROR_NOT_AVAILABLE;
+  }
+
+  const CLSID clsid = __uuidof(WSCProductList);
+  const IID iid = __uuidof(IWSCProductList);
+
+  // NB: A separate instance of IWSCProductList is needed for each distinct
+  // security provider type; MSDN says that we cannot reuse the same object
+  // and call Initialize() to pave over the previous data.
+
+  WSC_SECURITY_PROVIDER providerTypes[] = {WSC_SECURITY_PROVIDER_ANTIVIRUS,
+                                           WSC_SECURITY_PROVIDER_ANTISPYWARE,
+                                           WSC_SECURITY_PROVIDER_FIREWALL};
+
+  // Each output must match the corresponding entry in providerTypes.
+  nsAString* outputs[] = {&aAVInfo, &aAntiSpyInfo, &aFirewallInfo};
+
+  static_assert(ArrayLength(providerTypes) == ArrayLength(outputs),
+                "Length of providerTypes and outputs arrays must match");
+
+  for (uint32_t index = 0; index < ArrayLength(providerTypes); ++index) {
+    RefPtr<IWSCProductList> prodList;
+    HRESULT hr = ::CoCreateInstance(clsid, nullptr, CLSCTX_INPROC_SERVER, iid,
+                                    getter_AddRefs(prodList));
+    if (FAILED(hr)) {
+      return NS_ERROR_NOT_AVAILABLE;
+    }
+
+    hr = prodList->Initialize(providerTypes[index]);
+    if (FAILED(hr)) {
+      return NS_ERROR_UNEXPECTED;
+    }
+
+    hr = EnumWSCProductList(*outputs[index], WrapNotNull(prodList.get()));
+    if (FAILED(hr)) {
+      return NS_ERROR_UNEXPECTED;
+    }
+  }
+
+  return NS_OK;
+}
+
+#endif  // __MINGW32__
+
+#endif  // defined(XP_WIN)
+
+#ifdef XP_MACOSX
+static nsresult GetAppleModelId(nsAutoCString& aModelId) {
+  size_t numChars = 0;
+  size_t result = sysctlbyname("hw.model", nullptr, &numChars, nullptr, 0);
+  if (result != 0 || !numChars) {
+    return NS_ERROR_FAILURE;
+  }
+  aModelId.SetLength(numChars);
+  result =
+      sysctlbyname("hw.model", aModelId.BeginWriting(), &numChars, nullptr, 0);
+  if (result != 0) {
+    return NS_ERROR_FAILURE;
+  }
+  // numChars includes null terminator
+  aModelId.Truncate(numChars - 1);
+  return NS_OK;
+}
+#endif
 
 using namespace mozilla;
 
-nsSystemInfo::nsSystemInfo()
-{
-}
+nsSystemInfo::nsSystemInfo() {}
 
-nsSystemInfo::~nsSystemInfo()
-{
-}
+nsSystemInfo::~nsSystemInfo() {}
 
 // CPU-specific information.
-static const struct PropItems
-{
+static const struct PropItems {
   const char* name;
   bool (*propfun)(void);
 } cpuPropItems[] = {
-  // x86-specific bits.
-  { "hasMMX", mozilla::supports_mmx },
-  { "hasSSE", mozilla::supports_sse },
-  { "hasSSE2", mozilla::supports_sse2 },
-  { "hasSSE3", mozilla::supports_sse3 },
-  { "hasSSSE3", mozilla::supports_ssse3 },
-  { "hasSSE4A", mozilla::supports_sse4a },
-  { "hasSSE4_1", mozilla::supports_sse4_1 },
-  { "hasSSE4_2", mozilla::supports_sse4_2 },
-  { "hasAVX", mozilla::supports_avx },
-  { "hasAVX2", mozilla::supports_avx2 },
-  // ARM-specific bits.
-  { "hasEDSP", mozilla::supports_edsp },
-  { "hasARMv6", mozilla::supports_armv6 },
-  { "hasARMv7", mozilla::supports_armv7 },
-  { "hasNEON", mozilla::supports_neon }
-};
+    // x86-specific bits.
+    {"hasMMX", mozilla::supports_mmx},
+    {"hasSSE", mozilla::supports_sse},
+    {"hasSSE2", mozilla::supports_sse2},
+    {"hasSSE3", mozilla::supports_sse3},
+    {"hasSSSE3", mozilla::supports_ssse3},
+    {"hasSSE4A", mozilla::supports_sse4a},
+    {"hasSSE4_1", mozilla::supports_sse4_1},
+    {"hasSSE4_2", mozilla::supports_sse4_2},
+    {"hasAVX", mozilla::supports_avx},
+    {"hasAVX2", mozilla::supports_avx2},
+    {"hasAES", mozilla::supports_aes},
+    // ARM-specific bits.
+    {"hasEDSP", mozilla::supports_edsp},
+    {"hasARMv6", mozilla::supports_armv6},
+    {"hasARMv7", mozilla::supports_armv7},
+    {"hasNEON", mozilla::supports_neon}};
 
 #ifdef XP_WIN
 // Lifted from media/webrtc/trunk/webrtc/base/systeminfo.cc,
 // so keeping the _ instead of switching to camel case for now.
-typedef BOOL (WINAPI *LPFN_GLPI)(
-    PSYSTEM_LOGICAL_PROCESSOR_INFORMATION,
-    PDWORD);
-static void
-GetProcessorInformation(int* physical_cpus, int* cache_size_L2, int* cache_size_L3)
-{
+typedef BOOL(WINAPI* LPFN_GLPI)(PSYSTEM_LOGICAL_PROCESSOR_INFORMATION, PDWORD);
+static void GetProcessorInformation(int* physical_cpus, int* cache_size_L2,
+                                    int* cache_size_L3) {
   MOZ_ASSERT(physical_cpus && cache_size_L2 && cache_size_L3);
 
   *physical_cpus = 0;
-  *cache_size_L2 = 0; // This will be in kbytes
-  *cache_size_L3 = 0; // This will be in kbytes
+  *cache_size_L2 = 0;  // This will be in kbytes
+  *cache_size_L3 = 0;  // This will be in kbytes
 
   // GetLogicalProcessorInformation() is available on Windows XP SP3 and beyond.
   LPFN_GLPI glpi = reinterpret_cast<LPFN_GLPI>(GetProcAddress(
-      GetModuleHandle(L"kernel32"),
-      "GetLogicalProcessorInformation"));
+      GetModuleHandle(L"kernel32"), "GetLogicalProcessorInformation"));
   if (nullptr == glpi) {
     return;
   }
@@ -306,25 +410,27 @@ GetProcessorInformation(int* physical_cpus, int* cache_size_L2, int* cache_size_
   SYSTEM_LOGICAL_PROCESSOR_INFORMATION* infos = &info_buffer[0];
   DWORD return_length = sizeof(info_buffer);
   while (!glpi(infos, &return_length)) {
-    if (GetLastError() == ERROR_INSUFFICIENT_BUFFER && infos == &info_buffer[0]) {
-      infos = new SYSTEM_LOGICAL_PROCESSOR_INFORMATION[return_length / sizeof(SYSTEM_LOGICAL_PROCESSOR_INFORMATION)];
+    if (GetLastError() == ERROR_INSUFFICIENT_BUFFER &&
+        infos == &info_buffer[0]) {
+      infos = new SYSTEM_LOGICAL_PROCESSOR_INFORMATION
+          [return_length / sizeof(SYSTEM_LOGICAL_PROCESSOR_INFORMATION)];
     } else {
       return;
     }
   }
 
   for (size_t i = 0;
-      i < return_length / sizeof(SYSTEM_LOGICAL_PROCESSOR_INFORMATION); ++i) {
+       i < return_length / sizeof(SYSTEM_LOGICAL_PROCESSOR_INFORMATION); ++i) {
     if (infos[i].Relationship == RelationProcessorCore) {
       ++*physical_cpus;
     } else if (infos[i].Relationship == RelationCache) {
       // Only care about L2 and L3 cache
       switch (infos[i].Cache.Level) {
         case 2:
-          *cache_size_L2 = static_cast<int>(infos[i].Cache.Size/1024);
+          *cache_size_L2 = static_cast<int>(infos[i].Cache.Size / 1024);
           break;
         case 3:
-          *cache_size_L3 = static_cast<int>(infos[i].Cache.Size/1024);
+          *cache_size_L3 = static_cast<int>(infos[i].Cache.Size / 1024);
           break;
         default:
           break;
@@ -332,27 +438,25 @@ GetProcessorInformation(int* physical_cpus, int* cache_size_L2, int* cache_size_
     }
   }
   if (infos != &info_buffer[0]) {
-    delete [] infos;
+    delete[] infos;
   }
   return;
 }
 #endif
 
-nsresult
-nsSystemInfo::Init()
-{
+nsresult nsSystemInfo::Init() {
+  // This uses the observer service on Windows, so for simplicity
+  // check that it is called from the main thread on all platforms.
+  MOZ_ASSERT(NS_IsMainThread());
+
   nsresult rv;
 
-  static const struct
-  {
+  static const struct {
     PRSysInfo cmd;
     const char* name;
-  } items[] = {
-    { PR_SI_SYSNAME, "name" },
-    { PR_SI_HOSTNAME, "host" },
-    { PR_SI_ARCHITECTURE, "arch" },
-    { PR_SI_RELEASE, "version" }
-  };
+  } items[] = {{PR_SI_SYSNAME, "name"},
+               {PR_SI_ARCHITECTURE, "arch"},
+               {PR_SI_RELEASE, "version"}};
 
   for (uint32_t i = 0; i < (sizeof(items) / sizeof(items[0])); i++) {
     char buf[SYS_INFO_BUFFER_LENGTH];
@@ -389,7 +493,7 @@ nsSystemInfo::Init()
   int cacheSizeL2 = -1;
   int cacheSizeL3 = -1;
 
-#if defined (XP_WIN)
+#if defined(XP_WIN)
   // Virtual memory:
   MEMORYSTATUSEX memStat;
   memStat.dwLength = sizeof(memStat);
@@ -400,10 +504,10 @@ nsSystemInfo::Init()
   // CPU speed
   HKEY key;
   static const WCHAR keyName[] =
-    L"HARDWARE\\DESCRIPTION\\System\\CentralProcessor\\0";
+      L"HARDWARE\\DESCRIPTION\\System\\CentralProcessor\\0";
 
-  if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, keyName , 0, KEY_QUERY_VALUE, &key)
-      == ERROR_SUCCESS) {
+  if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, keyName, 0, KEY_QUERY_VALUE, &key) ==
+      ERROR_SUCCESS) {
     DWORD data, len, vtype;
     len = sizeof(data);
 
@@ -415,14 +519,13 @@ nsSystemInfo::Init()
     // Limit to 64 double byte characters, should be plenty, but create
     // a buffer one larger as the result may not be null terminated. If
     // it is more than 64, we will not get the value.
-    wchar_t cpuVendorStr[64+1];
-    len = sizeof(cpuVendorStr)-2;
-    if (RegQueryValueExW(key, L"VendorIdentifier",
-                         0, &vtype,
+    wchar_t cpuVendorStr[64 + 1];
+    len = sizeof(cpuVendorStr) - 2;
+    if (RegQueryValueExW(key, L"VendorIdentifier", 0, &vtype,
                          reinterpret_cast<LPBYTE>(cpuVendorStr),
                          &len) == ERROR_SUCCESS &&
         vtype == REG_SZ && len % 2 == 0 && len > 1) {
-      cpuVendorStr[len/2] = 0; // In case it isn't null terminated
+      cpuVendorStr[len / 2] = 0;  // In case it isn't null terminated
       CopyUTF16toUTF8(nsDependentString(cpuVendorStr), cpuVendor);
     }
 
@@ -440,14 +543,14 @@ nsSystemInfo::Init()
   cpuFamily = si.wProcessorLevel;
   cpuModel = si.wProcessorRevision >> 8;
   cpuStepping = si.wProcessorRevision & 0xFF;
-#elif defined (XP_MACOSX)
+#elif defined(XP_MACOSX)
   // CPU speed
   uint64_t sysctlValue64 = 0;
   uint32_t sysctlValue32 = 0;
   size_t len = 0;
   len = sizeof(sysctlValue64);
   if (!sysctlbyname("hw.cpufrequency_max", &sysctlValue64, &len, NULL, 0)) {
-    cpuSpeed = static_cast<int>(sysctlValue64/1000000);
+    cpuSpeed = static_cast<int>(sysctlValue64 / 1000000);
   }
   MOZ_ASSERT(sizeof(sysctlValue64) == len);
 
@@ -465,13 +568,13 @@ nsSystemInfo::Init()
 
   len = sizeof(sysctlValue64);
   if (!sysctlbyname("hw.l2cachesize", &sysctlValue64, &len, NULL, 0)) {
-    cacheSizeL2 = static_cast<int>(sysctlValue64/1024);
+    cacheSizeL2 = static_cast<int>(sysctlValue64 / 1024);
   }
   MOZ_ASSERT(sizeof(sysctlValue64) == len);
 
   len = sizeof(sysctlValue64);
   if (!sysctlbyname("hw.l3cachesize", &sysctlValue64, &len, NULL, 0)) {
-    cacheSizeL3 = static_cast<int>(sysctlValue64/1024);
+    cacheSizeL3 = static_cast<int>(sysctlValue64 / 1024);
   }
   MOZ_ASSERT(sizeof(sysctlValue64) == len);
 
@@ -480,7 +583,7 @@ nsSystemInfo::Init()
     if (!sysctlbyname("machdep.cpu.vendor", cpuVendorStr, &len, NULL, 0)) {
       cpuVendor = cpuVendorStr;
     }
-    delete [] cpuVendorStr;
+    delete[] cpuVendorStr;
   }
 
   len = sizeof(sysctlValue32);
@@ -501,7 +604,7 @@ nsSystemInfo::Init()
   }
   MOZ_ASSERT(sizeof(sysctlValue32) == len);
 
-#elif defined (XP_LINUX) && !defined (ANDROID)
+#elif defined(XP_LINUX) && !defined(ANDROID)
   // Get vendor, family, model, stepping, physical cores, L3 cache size
   // from /proc/cpuinfo file
   {
@@ -571,14 +674,15 @@ nsSystemInfo::Init()
 
   {
     // Get cpuSpeed from another file.
-    std::ifstream input("/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_max_freq");
+    std::ifstream input(
+        "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_max_freq");
     std::string line;
     if (getline(input, line)) {
       Tokenizer::Token t;
       Tokenizer p(line.c_str());
       if (p.Next(t) && t.Type() == Tokenizer::TOKEN_INTEGER &&
           t.AsInteger() <= INT32_MAX) {
-        cpuSpeed = static_cast<int>(t.AsInteger()/1000);
+        cpuSpeed = static_cast<int>(t.AsInteger() / 1000);
       }
     }
   }
@@ -602,18 +706,26 @@ nsSystemInfo::Init()
   SetInt32Property(NS_LITERAL_STRING("cpucount"), PR_GetNumberOfProcessors());
 #endif
 
-  if (virtualMem) SetUint64Property(NS_LITERAL_STRING("virtualmemsize"), virtualMem);
+  if (virtualMem)
+    SetUint64Property(NS_LITERAL_STRING("virtualmemsize"), virtualMem);
   if (cpuSpeed >= 0) SetInt32Property(NS_LITERAL_STRING("cpuspeed"), cpuSpeed);
-  if (!cpuVendor.IsEmpty()) SetPropertyAsACString(NS_LITERAL_STRING("cpuvendor"), cpuVendor);
-  if (cpuFamily >= 0) SetInt32Property(NS_LITERAL_STRING("cpufamily"), cpuFamily);
+  if (!cpuVendor.IsEmpty())
+    SetPropertyAsACString(NS_LITERAL_STRING("cpuvendor"), cpuVendor);
+  if (cpuFamily >= 0)
+    SetInt32Property(NS_LITERAL_STRING("cpufamily"), cpuFamily);
   if (cpuModel >= 0) SetInt32Property(NS_LITERAL_STRING("cpumodel"), cpuModel);
-  if (cpuStepping >= 0) SetInt32Property(NS_LITERAL_STRING("cpustepping"), cpuStepping);
+  if (cpuStepping >= 0)
+    SetInt32Property(NS_LITERAL_STRING("cpustepping"), cpuStepping);
 
-  if (logicalCPUs >= 0) SetInt32Property(NS_LITERAL_STRING("cpucount"), logicalCPUs);
-  if (physicalCPUs >= 0) SetInt32Property(NS_LITERAL_STRING("cpucores"), physicalCPUs);
+  if (logicalCPUs >= 0)
+    SetInt32Property(NS_LITERAL_STRING("cpucount"), logicalCPUs);
+  if (physicalCPUs >= 0)
+    SetInt32Property(NS_LITERAL_STRING("cpucores"), physicalCPUs);
 
-  if (cacheSizeL2 >= 0) SetInt32Property(NS_LITERAL_STRING("cpucachel2"), cacheSizeL2);
-  if (cacheSizeL3 >= 0) SetInt32Property(NS_LITERAL_STRING("cpucachel3"), cacheSizeL3);
+  if (cacheSizeL2 >= 0)
+    SetInt32Property(NS_LITERAL_STRING("cpucachel2"), cacheSizeL2);
+  if (cacheSizeL3 >= 0)
+    SetInt32Property(NS_LITERAL_STRING("cpucachel3"), cacheSizeL3);
 
   for (uint32_t i = 0; i < ArrayLength(cpuPropItems); i++) {
     rv = SetPropertyAsBool(NS_ConvertASCIItoUTF16(cpuPropItems[i].name),
@@ -637,7 +749,7 @@ nsSystemInfo::Init()
     // We might have been called before profile-do-change. We'll observe that
     // event so that we can fill this in later.
     nsCOMPtr<nsIObserverService> obsService =
-      do_GetService(NS_OBSERVERSERVICE_CONTRACTID, &rv);
+        do_GetService(NS_OBSERVERSERVICE_CONTRACTID, &rv);
     if (NS_WARN_IF(NS_FAILED(rv))) {
       return rv;
     }
@@ -650,15 +762,15 @@ nsSystemInfo::Init()
   if (NS_SUCCEEDED(GetHDDInfo(NS_GRE_DIR, hddModel, hddRevision))) {
     rv = SetPropertyAsACString(NS_LITERAL_STRING("binHDDModel"), hddModel);
     NS_ENSURE_SUCCESS(rv, rv);
-    rv = SetPropertyAsACString(NS_LITERAL_STRING("binHDDRevision"),
-                               hddRevision);
+    rv =
+        SetPropertyAsACString(NS_LITERAL_STRING("binHDDRevision"), hddRevision);
     NS_ENSURE_SUCCESS(rv, rv);
   }
   if (NS_SUCCEEDED(GetHDDInfo(NS_WIN_WINDOWS_DIR, hddModel, hddRevision))) {
     rv = SetPropertyAsACString(NS_LITERAL_STRING("winHDDModel"), hddModel);
     NS_ENSURE_SUCCESS(rv, rv);
-    rv = SetPropertyAsACString(NS_LITERAL_STRING("winHDDRevision"),
-                               hddRevision);
+    rv =
+        SetPropertyAsACString(NS_LITERAL_STRING("winHDDRevision"), hddRevision);
     NS_ENSURE_SUCCESS(rv, rv);
   }
 
@@ -675,6 +787,36 @@ nsSystemInfo::Init()
       return rv;
     }
   }
+
+#ifndef __MINGW32__
+  nsAutoString avInfo, antiSpyInfo, firewallInfo;
+  if (NS_SUCCEEDED(
+          GetWindowsSecurityCenterInfo(avInfo, antiSpyInfo, firewallInfo))) {
+    if (!avInfo.IsEmpty()) {
+      rv = SetPropertyAsAString(NS_LITERAL_STRING("registeredAntiVirus"),
+                                avInfo);
+      if (NS_WARN_IF(NS_FAILED(rv))) {
+        return rv;
+      }
+    }
+
+    if (!antiSpyInfo.IsEmpty()) {
+      rv = SetPropertyAsAString(NS_LITERAL_STRING("registeredAntiSpyware"),
+                                antiSpyInfo);
+      if (NS_WARN_IF(NS_FAILED(rv))) {
+        return rv;
+      }
+    }
+
+    if (!firewallInfo.IsEmpty()) {
+      rv = SetPropertyAsAString(NS_LITERAL_STRING("registeredFirewall"),
+                                firewallInfo);
+      if (NS_WARN_IF(NS_FAILED(rv))) {
+        return rv;
+      }
+    }
+  }
+#endif  // __MINGW32__
 #endif
 
 #if defined(XP_MACOSX)
@@ -683,41 +825,36 @@ nsSystemInfo::Init()
     rv = SetPropertyAsAString(NS_LITERAL_STRING("countryCode"), countryCode);
     NS_ENSURE_SUCCESS(rv, rv);
   }
+
+  nsAutoCString modelId;
+  if (NS_SUCCEEDED(GetAppleModelId(modelId))) {
+    rv = SetPropertyAsACString(NS_LITERAL_STRING("appleModelId"), modelId);
+    NS_ENSURE_SUCCESS(rv, rv);
+  }
 #endif
 
 #if defined(MOZ_WIDGET_GTK)
-  // This must be done here because NSPR can only separate OS's when compiled, not libraries.
-  // 64 bytes is going to be well enough for "GTK " followed by 3 integers
-  // separated with dots.
+  // This must be done here because NSPR can only separate OS's when compiled,
+  // not libraries. 64 bytes is going to be well enough for "GTK " followed by 3
+  // integers separated with dots.
   char gtkver[64];
   ssize_t gtkver_len = 0;
 
-#if MOZ_WIDGET_GTK == 2
-  extern int gtk_read_end_of_the_pipe;
-
-  if (gtk_read_end_of_the_pipe != -1) {
-    do {
-      gtkver_len = read(gtk_read_end_of_the_pipe, &gtkver, sizeof(gtkver));
-    } while (gtkver_len < 0 && errno == EINTR);
-    close(gtk_read_end_of_the_pipe);
-  }
-#endif
-
   if (gtkver_len <= 0) {
     gtkver_len = SprintfLiteral(gtkver, "GTK %u.%u.%u", gtk_major_version,
                                 gtk_minor_version, gtk_micro_version);
   }
 
   nsAutoCString secondaryLibrary;
-  if (gtkver_len > 0) {
+  if (gtkver_len > 0 && gtkver_len < int(sizeof(gtkver))) {
     secondaryLibrary.Append(nsDependentCSubstring(gtkver, gtkver_len));
   }
 
   void* libpulse = dlopen("libpulse.so.0", RTLD_LAZY);
   const char* libpulseVersion = "not-available";
   if (libpulse) {
-    auto pa_get_library_version = reinterpret_cast<const char* (*)()>
-      (dlsym(libpulse, "pa_get_library_version"));
+    auto pa_get_library_version = reinterpret_cast<const char* (*)()>(
+        dlsym(libpulse, "pa_get_library_version"));
 
     if (pa_get_library_version) {
       libpulseVersion = pa_get_library_version();
@@ -751,44 +888,6 @@ nsSystemInfo::Init()
   }
 #endif
 
-#ifdef MOZ_WIDGET_GONK
-  char sdk[PROP_VALUE_MAX];
-  if (__system_property_get("ro.build.version.sdk", sdk)) {
-    android_sdk_version = atoi(sdk);
-    SetPropertyAsInt32(NS_LITERAL_STRING("sdk_version"), android_sdk_version);
-
-    SetPropertyAsACString(NS_LITERAL_STRING("secondaryLibrary"),
-                          nsPrintfCString("SDK %u", android_sdk_version));
-  }
-
-  char characteristics[PROP_VALUE_MAX];
-  if (__system_property_get("ro.build.characteristics", characteristics)) {
-    if (!strcmp(characteristics, "tablet")) {
-      SetPropertyAsBool(NS_LITERAL_STRING("tablet"), true);
-    } else if (!strcmp(characteristics, "tv")) {
-      SetPropertyAsBool(NS_LITERAL_STRING("tv"), true);
-    }
-  }
-
-  nsAutoString str;
-  rv = GetPropertyAsAString(NS_LITERAL_STRING("version"), str);
-  if (NS_SUCCEEDED(rv)) {
-    SetPropertyAsAString(NS_LITERAL_STRING("kernel_version"), str);
-  }
-
-  const nsAdoptingString& b2g_os_name =
-    mozilla::Preferences::GetString("b2g.osName");
-  if (b2g_os_name) {
-    SetPropertyAsAString(NS_LITERAL_STRING("name"), b2g_os_name);
-  }
-
-  const nsAdoptingString& b2g_version =
-    mozilla::Preferences::GetString("b2g.version");
-  if (b2g_version) {
-    SetPropertyAsAString(NS_LITERAL_STRING("version"), b2g_version);
-  }
-#endif
-
 #if defined(XP_LINUX) && defined(MOZ_SANDBOX)
   SandboxInfo sandInfo = SandboxInfo::Get();
 
@@ -810,7 +909,7 @@ nsSystemInfo::Init()
     SetPropertyAsBool(NS_LITERAL_STRING("canSandboxMedia"),
                       sandInfo.CanSandboxMedia());
   }
-#endif // XP_LINUX && MOZ_SANDBOX
+#endif  // XP_LINUX && MOZ_SANDBOX
 
   return NS_OK;
 }
@@ -826,9 +925,7 @@ nsSystemInfo::Init()
 #define DEFAULT_ANDROID_VERSION "6.0.99"
 
 /* static */
-void
-nsSystemInfo::GetAndroidSystemInfo(AndroidSystemInfo* aInfo)
-{
+void nsSystemInfo::GetAndroidSystemInfo(AndroidSystemInfo* aInfo) {
   MOZ_ASSERT(XRE_IsParentProcess());
 
   if (!mozilla::AndroidBridge::Bridge()) {
@@ -837,60 +934,63 @@ nsSystemInfo::GetAndroidSystemInfo(AndroidSystemInfo* aInfo)
   }
 
   nsAutoString str;
-  if (mozilla::AndroidBridge::Bridge()->GetStaticStringField(
-      "android/os/Build", "MODEL", str)) {
+  if (mozilla::AndroidBridge::Bridge()->GetStaticStringField("android/os/Build",
+                                                             "MODEL", str)) {
     aInfo->device() = str;
   }
   if (mozilla::AndroidBridge::Bridge()->GetStaticStringField(
-      "android/os/Build", "MANUFACTURER", str)) {
+          "android/os/Build", "MANUFACTURER", str)) {
     aInfo->manufacturer() = str;
   }
   if (mozilla::AndroidBridge::Bridge()->GetStaticStringField(
-      "android/os/Build$VERSION", "RELEASE", str)) {
+          "android/os/Build$VERSION", "RELEASE", str)) {
     int major_version;
     int minor_version;
     int bugfix_version;
-    int num_read = sscanf(NS_ConvertUTF16toUTF8(str).get(), "%d.%d.%d", &major_version, &minor_version, &bugfix_version);
+    int num_read = sscanf(NS_ConvertUTF16toUTF8(str).get(), "%d.%d.%d",
+                          &major_version, &minor_version, &bugfix_version);
     if (num_read == 0) {
       aInfo->release_version() = NS_LITERAL_STRING(DEFAULT_ANDROID_VERSION);
     } else {
       aInfo->release_version() = str;
     }
   }
-  if (mozilla::AndroidBridge::Bridge()->GetStaticStringField(
-      "android/os/Build", "HARDWARE", str)) {
+  if (mozilla::AndroidBridge::Bridge()->GetStaticStringField("android/os/Build",
+                                                             "HARDWARE", str)) {
     aInfo->hardware() = str;
   }
   int32_t sdk_version;
   if (!mozilla::AndroidBridge::Bridge()->GetStaticIntField(
-      "android/os/Build$VERSION", "SDK_INT", &sdk_version)) {
+          "android/os/Build$VERSION", "SDK_INT", &sdk_version)) {
     sdk_version = 0;
   }
   aInfo->sdk_version() = sdk_version;
   aInfo->isTablet() = java::GeckoAppShell::IsTablet();
 }
 
-void
-nsSystemInfo::SetupAndroidInfo(const AndroidSystemInfo& aInfo)
-{
+void nsSystemInfo::SetupAndroidInfo(const AndroidSystemInfo& aInfo) {
   if (!aInfo.device().IsEmpty()) {
     SetPropertyAsAString(NS_LITERAL_STRING("device"), aInfo.device());
   }
   if (!aInfo.manufacturer().IsEmpty()) {
-    SetPropertyAsAString(NS_LITERAL_STRING("manufacturer"), aInfo.manufacturer());
+    SetPropertyAsAString(NS_LITERAL_STRING("manufacturer"),
+                         aInfo.manufacturer());
   }
   if (!aInfo.release_version().IsEmpty()) {
-    SetPropertyAsAString(NS_LITERAL_STRING("release_version"), aInfo.release_version());
+    SetPropertyAsAString(NS_LITERAL_STRING("release_version"),
+                         aInfo.release_version());
   }
   SetPropertyAsBool(NS_LITERAL_STRING("tablet"), aInfo.isTablet());
-  // NSPR "version" is the kernel version. For Android we want the Android version.
-  // Rename SDK version to version and put the kernel version into kernel_version.
+  // NSPR "version" is the kernel version. For Android we want the Android
+  // version. Rename SDK version to version and put the kernel version into
+  // kernel_version.
   nsAutoString str;
   nsresult rv = GetPropertyAsAString(NS_LITERAL_STRING("version"), str);
   if (NS_SUCCEEDED(rv)) {
     SetPropertyAsAString(NS_LITERAL_STRING("kernel_version"), str);
   }
-  // When AndroidBridge is not available (eg. in xpcshell tests), sdk_version is 0.
+  // When AndroidBridge is not available (eg. in xpcshell tests), sdk_version is
+  // 0.
   if (aInfo.sdk_version() != 0) {
     android_sdk_version = aInfo.sdk_version();
     if (android_sdk_version >= 8 && !aInfo.hardware().IsEmpty()) {
@@ -899,45 +999,39 @@ nsSystemInfo::SetupAndroidInfo(const AndroidSystemInfo& aInfo)
     SetPropertyAsInt32(NS_LITERAL_STRING("version"), android_sdk_version);
   }
 }
-#endif // MOZ_WIDGET_ANDROID
+#endif  // MOZ_WIDGET_ANDROID
 
-void
-nsSystemInfo::SetInt32Property(const nsAString& aPropertyName,
-                               const int32_t aValue)
-{
+void nsSystemInfo::SetInt32Property(const nsAString& aPropertyName,
+                                    const int32_t aValue) {
   NS_WARNING_ASSERTION(aValue > 0, "Unable to read system value");
   if (aValue > 0) {
 #ifdef DEBUG
     nsresult rv =
 #endif
-      SetPropertyAsInt32(aPropertyName, aValue);
+        SetPropertyAsInt32(aPropertyName, aValue);
     NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "Unable to set property");
   }
 }
 
-void
-nsSystemInfo::SetUint32Property(const nsAString& aPropertyName,
-                                const uint32_t aValue)
-{
-  // Only one property is currently set via this function.
-  // It may legitimately be zero.
+void nsSystemInfo::SetUint32Property(const nsAString& aPropertyName,
+                                     const uint32_t aValue) {
+// Only one property is currently set via this function.
+// It may legitimately be zero.
 #ifdef DEBUG
   nsresult rv =
 #endif
-    SetPropertyAsUint32(aPropertyName, aValue);
+      SetPropertyAsUint32(aPropertyName, aValue);
   NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "Unable to set property");
 }
 
-void
-nsSystemInfo::SetUint64Property(const nsAString& aPropertyName,
-                                const uint64_t aValue)
-{
+void nsSystemInfo::SetUint64Property(const nsAString& aPropertyName,
+                                     const uint64_t aValue) {
   NS_WARNING_ASSERTION(aValue > 0, "Unable to read system value");
   if (aValue > 0) {
 #ifdef DEBUG
     nsresult rv =
 #endif
-      SetPropertyAsUint64(aPropertyName, aValue);
+        SetPropertyAsUint64(aPropertyName, aValue);
     NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "Unable to set property");
   }
 }
@@ -945,12 +1039,11 @@ nsSystemInfo::SetUint64Property(const nsAString& aPropertyName,
 #if defined(XP_WIN)
 NS_IMETHODIMP
 nsSystemInfo::Observe(nsISupports* aSubject, const char* aTopic,
-                      const char16_t* aData)
-{
+                      const char16_t* aData) {
   if (!strcmp(aTopic, "profile-do-change")) {
     nsresult rv;
     nsCOMPtr<nsIObserverService> obsService =
-      do_GetService(NS_OBSERVERSERVICE_CONTRACTID, &rv);
+        do_GetService(NS_OBSERVERSERVICE_CONTRACTID, &rv);
     if (NS_FAILED(rv)) {
       return rv;
     }
@@ -963,9 +1056,7 @@ nsSystemInfo::Observe(nsISupports* aSubject, const char* aTopic,
   return NS_OK;
 }
 
-nsresult
-nsSystemInfo::GetProfileHDDInfo()
-{
+nsresult nsSystemInfo::GetProfileHDDInfo() {
   nsAutoCString hddModel, hddRevision;
   nsresult rv = GetHDDInfo(NS_APP_USER_PROFILE_50_DIR, hddModel, hddRevision);
   if (NS_FAILED(rv)) {
@@ -981,5 +1072,4 @@ nsSystemInfo::GetProfileHDDInfo()
 }
 
 NS_IMPL_ISUPPORTS_INHERITED(nsSystemInfo, nsHashPropertyBag, nsIObserver)
-#endif // defined(XP_WIN)
-
+#endif  // defined(XP_WIN)
