@@ -5,13 +5,14 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "mozilla/ArrayUtils.h"
+#include "mozilla/Printf.h"
+#include "mozilla/UniquePtr.h"
 
 #include "ManifestParser.h"
 
 #include <string.h>
 
 #include "prio.h"
-#include "prprf.h"
 #if defined(XP_WIN)
 #include <windows.h>
 #elif defined(MOZ_WIDGET_COCOA)
@@ -40,8 +41,7 @@
 
 using namespace mozilla;
 
-struct ManifestDirective
-{
+struct ManifestDirective {
   const char* directive;
   int argc;
 
@@ -55,175 +55,136 @@ struct ManifestDirective
 
   bool allowbootstrap;
 
-  // The platform/contentaccessible flags only apply to content directives.
+  // The contentaccessible flags only apply to content/resource directives.
   bool contentflags;
 
   // Function to handle this directive. This isn't a union because C++ still
   // hasn't learned how to initialize unions in a sane way.
   void (nsComponentManagerImpl::*mgrfunc)(
-    nsComponentManagerImpl::ManifestProcessingContext& aCx,
-    int aLineNo, char* const* aArgv);
+      nsComponentManagerImpl::ManifestProcessingContext& aCx, int aLineNo,
+      char* const* aArgv);
   void (nsChromeRegistry::*regfunc)(
-    nsChromeRegistry::ManifestProcessingContext& aCx,
-    int aLineNo, char* const* aArgv, int aFlags);
-  void* xptonlyfunc;
+      nsChromeRegistry::ManifestProcessingContext& aCx, int aLineNo,
+      char* const* aArgv, int aFlags);
 
   bool isContract;
 };
 static const ManifestDirective kParsingTable[] = {
+    // clang-format off
   {
     "manifest",         1, false, false, true, true, false,
-    &nsComponentManagerImpl::ManifestManifest, nullptr, nullptr
+    &nsComponentManagerImpl::ManifestManifest, nullptr,
   },
   {
     "binary-component", 1, true, true, false, false, false,
-    &nsComponentManagerImpl::ManifestBinaryComponent, nullptr, nullptr
+    &nsComponentManagerImpl::ManifestBinaryComponent, nullptr,
   },
   {
     "interfaces",       1, false, true, false, false, false,
-    &nsComponentManagerImpl::ManifestXPT, nullptr, nullptr
+    &nsComponentManagerImpl::ManifestXPT, nullptr,
   },
   {
     "component",        2, false, true, false, false, false,
-    &nsComponentManagerImpl::ManifestComponent, nullptr, nullptr
+    &nsComponentManagerImpl::ManifestComponent, nullptr,
   },
   {
     "contract",         2, false, true, false, false, false,
-    &nsComponentManagerImpl::ManifestContract, nullptr, nullptr, true
+    &nsComponentManagerImpl::ManifestContract, nullptr,
   },
   {
     "category",         3, false, true, false, false, false,
-    &nsComponentManagerImpl::ManifestCategory, nullptr, nullptr
+    &nsComponentManagerImpl::ManifestCategory, nullptr,
   },
   {
     "content",          2, false, true, true, true,  true,
-    nullptr, &nsChromeRegistry::ManifestContent, nullptr
+    nullptr, &nsChromeRegistry::ManifestContent,
   },
   {
     "locale",           3, false, true, true, true, false,
-    nullptr, &nsChromeRegistry::ManifestLocale, nullptr
+    nullptr, &nsChromeRegistry::ManifestLocale,
   },
   {
     "skin",             3, false, false, true, true, false,
-    nullptr, &nsChromeRegistry::ManifestSkin, nullptr
+    nullptr, &nsChromeRegistry::ManifestSkin,
   },
   {
     "overlay",          2, false, true, true, false, false,
-    nullptr, &nsChromeRegistry::ManifestOverlay, nullptr
+    nullptr, &nsChromeRegistry::ManifestOverlay,
   },
   {
     "style",            2, false, false, true, false, false,
-    nullptr, &nsChromeRegistry::ManifestStyle, nullptr
+    nullptr, &nsChromeRegistry::ManifestStyle,
   },
   {
     // NB: note that while skin manifests can use this, they are only allowed
     // to use it for chrome://../skin/ URLs
     "override",         2, false, false, true, true, false,
-    nullptr, &nsChromeRegistry::ManifestOverride, nullptr
+    nullptr, &nsChromeRegistry::ManifestOverride,
   },
   {
-    "resource",         2, false, true, true, true, false,
-    nullptr, &nsChromeRegistry::ManifestResource, nullptr
+    "resource",         2, false, true, true, true, true,
+    nullptr, &nsChromeRegistry::ManifestResource,
   }
+    // clang-format on
 };
 
 static const char kWhitespace[] = "\t ";
 
-static bool
-IsNewline(char aChar)
-{
-  return aChar == '\n' || aChar == '\r';
-}
+static bool IsNewline(char aChar) { return aChar == '\n' || aChar == '\r'; }
 
-namespace {
-struct AutoPR_smprintf_free
-{
-  explicit AutoPR_smprintf_free(char* aBuf) : mBuf(aBuf) {}
-
-  ~AutoPR_smprintf_free()
-  {
-    if (mBuf) {
-      PR_smprintf_free(mBuf);
-    }
-  }
-
-  operator char*() const { return mBuf; }
-
-  char* mBuf;
-};
-
-} // namespace
-
-/**
- * If we are pre-loading XPTs, this method may do nothing because the
- * console service is not initialized.
- */
-void
-LogMessage(const char* aMsg, ...)
-{
-  if (!nsComponentManagerImpl::gComponentManager) {
-    return;
-  }
+void LogMessage(const char* aMsg, ...) {
+  MOZ_ASSERT(nsComponentManagerImpl::gComponentManager);
 
   nsCOMPtr<nsIConsoleService> console =
-    do_GetService(NS_CONSOLESERVICE_CONTRACTID);
+      do_GetService(NS_CONSOLESERVICE_CONTRACTID);
   if (!console) {
     return;
   }
 
   va_list args;
   va_start(args, aMsg);
-  AutoPR_smprintf_free formatted(PR_vsmprintf(aMsg, args));
+  SmprintfPointer formatted(mozilla::Vsmprintf(aMsg, args));
   va_end(args);
 
   nsCOMPtr<nsIConsoleMessage> error =
-    new nsConsoleMessage(NS_ConvertUTF8toUTF16(formatted).get());
+      new nsConsoleMessage(NS_ConvertUTF8toUTF16(formatted.get()).get());
   console->LogMessage(error);
 }
 
-/**
- * If we are pre-loading XPTs, this method may do nothing because the
- * console service is not initialized.
- */
-void
-LogMessageWithContext(FileLocation& aFile,
-                      uint32_t aLineNumber, const char* aMsg, ...)
-{
+void LogMessageWithContext(FileLocation& aFile, uint32_t aLineNumber,
+                           const char* aMsg, ...) {
   va_list args;
   va_start(args, aMsg);
-  AutoPR_smprintf_free formatted(PR_vsmprintf(aMsg, args));
+  SmprintfPointer formatted(mozilla::Vsmprintf(aMsg, args));
   va_end(args);
   if (!formatted) {
     return;
   }
 
-  if (!nsComponentManagerImpl::gComponentManager) {
-    return;
-  }
+  MOZ_ASSERT(nsComponentManagerImpl::gComponentManager);
 
   nsCString file;
   aFile.GetURIString(file);
 
-  nsCOMPtr<nsIScriptError> error =
-    do_CreateInstance(NS_SCRIPTERROR_CONTRACTID);
+  nsCOMPtr<nsIScriptError> error = do_CreateInstance(NS_SCRIPTERROR_CONTRACTID);
   if (!error) {
     // This can happen early in component registration. Fall back to a
     // generic console message.
-    LogMessage("Warning: in '%s', line %i: %s", file.get(),
-               aLineNumber, (char*)formatted);
+    LogMessage("Warning: in '%s', line %i: %s", file.get(), aLineNumber,
+               formatted.get());
     return;
   }
 
   nsCOMPtr<nsIConsoleService> console =
-    do_GetService(NS_CONSOLESERVICE_CONTRACTID);
+      do_GetService(NS_CONSOLESERVICE_CONTRACTID);
   if (!console) {
     return;
   }
 
-  nsresult rv = error->Init(NS_ConvertUTF8toUTF16(formatted),
-                            NS_ConvertUTF8toUTF16(file), EmptyString(),
-                            aLineNumber, 0, nsIScriptError::warningFlag,
-                            "chrome registration");
+  nsresult rv =
+      error->Init(NS_ConvertUTF8toUTF16(formatted.get()),
+                  NS_ConvertUTF8toUTF16(file), EmptyString(), aLineNumber, 0,
+                  nsIScriptError::warningFlag, "chrome registration");
   if (NS_FAILED(rv)) {
     return;
   }
@@ -242,9 +203,8 @@ LogMessageWithContext(FileLocation& aFile,
  * @param aResult If the flag is found, the value is assigned here.
  * @return Whether the flag was handled.
  */
-static bool
-CheckFlag(const nsSubstring& aFlag, const nsSubstring& aData, bool& aResult)
-{
+static bool CheckFlag(const nsAString& aFlag, const nsAString& aData,
+                      bool& aResult) {
   if (!StringBeginsWith(aData, aFlag)) {
     return false;
   }
@@ -267,14 +227,14 @@ CheckFlag(const nsSubstring& aFlag, const nsSubstring& aData, bool& aResult)
 
   switch (aData.CharAt(aFlag.Length() + 1)) {
     case '1':
-    case 't': //true
-    case 'y': //yes
+    case 't':  // true
+    case 'y':  // yes
       aResult = true;
       return true;
 
     case '0':
-    case 'f': //false
-    case 'n': //no
+    case 'f':  // false
+    case 'n':  // no
       aResult = false;
       return true;
   }
@@ -282,12 +242,7 @@ CheckFlag(const nsSubstring& aFlag, const nsSubstring& aData, bool& aResult)
   return false;
 }
 
-enum TriState
-{
-  eUnspecified,
-  eBad,
-  eOK
-};
+enum TriState { eUnspecified, eBad, eOK };
 
 /**
  * Check for a modifier flag of the following form:
@@ -301,10 +256,8 @@ enum TriState
  *                Otherwise if the flag is found it is set to eBad or eOK.
  * @return Whether the flag was handled.
  */
-static bool
-CheckStringFlag(const nsSubstring& aFlag, const nsSubstring& aData,
-                const nsSubstring& aValue, TriState& aResult)
-{
+static bool CheckStringFlag(const nsAString& aFlag, const nsAString& aData,
+                            const nsAString& aValue, TriState& aResult) {
   if (aData.Length() < aFlag.Length() + 1) {
     return false;
   }
@@ -315,8 +268,7 @@ CheckStringFlag(const nsSubstring& aFlag, const nsSubstring& aData,
 
   bool comparison = true;
   if (aData[aFlag.Length()] != '=') {
-    if (aData[aFlag.Length()] == '!' &&
-        aData.Length() >= aFlag.Length() + 2 &&
+    if (aData[aFlag.Length()] == '!' && aData.Length() >= aFlag.Length() + 2 &&
         aData[aFlag.Length() + 1] == '=') {
       comparison = false;
     } else {
@@ -326,7 +278,7 @@ CheckStringFlag(const nsSubstring& aFlag, const nsSubstring& aData,
 
   if (aResult != eOK) {
     nsDependentSubstring testdata =
-      Substring(aData, aFlag.Length() + (comparison ? 1 : 2));
+        Substring(aData, aFlag.Length() + (comparison ? 1 : 2));
     if (testdata.Equals(aValue)) {
       aResult = comparison ? eOK : eBad;
     } else {
@@ -337,31 +289,41 @@ CheckStringFlag(const nsSubstring& aFlag, const nsSubstring& aData,
   return true;
 }
 
-/**
- * Check for a modifier flag of the following form:
- *   "flag=version"
- *   "flag<=version"
- *   "flag<version"
- *   "flag>=version"
- *   "flag>version"
- * @param aFlag The flag to compare.
- * @param aData The tokenized data to check; this is lowercased
- *              before being passed in.
- * @param aValue The value that is expected. If this is empty then no
- *               comparison will match.
- * @param aResult If this is eOK when passed in, this is left alone.
- *                Otherwise if the flag is found it is set to eBad or eOK.
- * @return Whether the flag was handled.
- */
+static bool CheckOsFlag(const nsAString& aFlag, const nsAString& aData,
+                        const nsAString& aValue, TriState& aResult) {
+  bool result = CheckStringFlag(aFlag, aData, aValue, aResult);
+#if defined(XP_UNIX) && !defined(XP_DARWIN) && !defined(ANDROID)
+  if (result && aResult == eBad) {
+    result =
+        CheckStringFlag(aFlag, aData, NS_LITERAL_STRING("likeunix"), aResult);
+  }
+#endif
+  return result;
+}
 
-#define COMPARE_EQ    1 << 0
-#define COMPARE_LT    1 << 1
-#define COMPARE_GT    1 << 2
+  /**
+   * Check for a modifier flag of the following form:
+   *   "flag=version"
+   *   "flag<=version"
+   *   "flag<version"
+   *   "flag>=version"
+   *   "flag>version"
+   * @param aFlag The flag to compare.
+   * @param aData The tokenized data to check; this is lowercased
+   *              before being passed in.
+   * @param aValue The value that is expected. If this is empty then no
+   *               comparison will match.
+   * @param aResult If this is eOK when passed in, this is left alone.
+   *                Otherwise if the flag is found it is set to eBad or eOK.
+   * @return Whether the flag was handled.
+   */
 
-static bool
-CheckVersionFlag(const nsString& aFlag, const nsString& aData,
-                 const nsString& aValue, TriState& aResult)
-{
+#define COMPARE_EQ 1 << 0
+#define COMPARE_LT 1 << 1
+#define COMPARE_GT 1 << 2
+
+static bool CheckVersionFlag(const nsString& aFlag, const nsString& aData,
+                             const nsString& aValue, TriState& aResult) {
   if (aData.Length() < aFlag.Length() + 2) {
     return false;
   }
@@ -430,9 +392,7 @@ CheckVersionFlag(const nsString& aFlag, const nsString& aData,
 }
 
 // In-place conversion of ascii characters to lower case
-static void
-ToLowerCase(char* aToken)
-{
+static void ToLowerCase(char* aToken) {
   for (; *aToken; ++aToken) {
     *aToken = NS_ToLower(*aToken);
   }
@@ -440,34 +400,20 @@ ToLowerCase(char* aToken)
 
 namespace {
 
-struct CachedDirective
-{
+struct CachedDirective {
   int lineno;
   char* argv[4];
 };
 
-} // namespace
+}  // namespace
 
-
-/**
- * For XPT-Only mode, the parser handles only directives of "manifest"
- * and "interfaces", and always call the function given by |xptonlyfunc|
- * variable of struct |ManifestDirective|.
- *
- * This function is safe to be called before the component manager is
- * ready if aXPTOnly is true for it don't invoke any component during
- * parsing.
- */
-void
-ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
-              bool aChromeOnly, bool aXPTOnly)
-{
+void ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
+                   bool aChromeOnly) {
   nsComponentManagerImpl::ManifestProcessingContext mgrcx(aType, aFile,
                                                           aChromeOnly);
   nsChromeRegistry::ManifestProcessingContext chromecx(aType, aFile);
   nsresult rv;
 
-  NS_NAMED_LITERAL_STRING(kPlatform, "platform");
   NS_NAMED_LITERAL_STRING(kContentAccessible, "contentaccessible");
   NS_NAMED_LITERAL_STRING(kRemoteEnabled, "remoteenabled");
   NS_NAMED_LITERAL_STRING(kRemoteRequired, "remoterequired");
@@ -495,12 +441,7 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
   nsAutoString abi;
   nsAutoString process;
 
-  nsCOMPtr<nsIXULAppInfo> xapp;
-  if (!aXPTOnly) {
-    // Avoid to create any component for XPT only mode.
-    // No xapp means no ID, version, ..., modifiers checking.
-    xapp = do_GetService(XULAPPINFO_SERVICE_CONTRACTID);
-  }
+  nsCOMPtr<nsIXULAppInfo> xapp(do_GetService(XULAPPINFO_SERVICE_CONTRACTID));
   if (xapp) {
     nsAutoCString s;
     rv = xapp->GetID(s);
@@ -539,30 +480,25 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
   nsAutoString osVersion;
 #if defined(XP_WIN)
 #pragma warning(push)
-#pragma warning(disable:4996) // VC12+ deprecates GetVersionEx
-  OSVERSIONINFO info = { sizeof(OSVERSIONINFO) };
+#pragma warning(disable : 4996)  // VC12+ deprecates GetVersionEx
+  OSVERSIONINFO info = {sizeof(OSVERSIONINFO)};
   if (GetVersionEx(&info)) {
-    nsTextFormatter::ssprintf(osVersion, u"%ld.%ld",
-                              info.dwMajorVersion,
+    nsTextFormatter::ssprintf(osVersion, u"%ld.%ld", info.dwMajorVersion,
                               info.dwMinorVersion);
   }
 #pragma warning(pop)
 #elif defined(MOZ_WIDGET_COCOA)
   SInt32 majorVersion = nsCocoaFeatures::OSXVersionMajor();
   SInt32 minorVersion = nsCocoaFeatures::OSXVersionMinor();
-  nsTextFormatter::ssprintf(osVersion, u"%ld.%ld",
-                            majorVersion,
-                            minorVersion);
+  nsTextFormatter::ssprintf(osVersion, u"%ld.%ld", majorVersion, minorVersion);
 #elif defined(MOZ_WIDGET_GTK)
-  nsTextFormatter::ssprintf(osVersion, u"%ld.%ld",
-                            gtk_major_version,
+  nsTextFormatter::ssprintf(osVersion, u"%ld.%ld", gtk_major_version,
                             gtk_minor_version);
 #elif defined(MOZ_WIDGET_ANDROID)
   bool isTablet = false;
   if (mozilla::AndroidBridge::Bridge()) {
-    mozilla::AndroidBridge::Bridge()->GetStaticStringField("android/os/Build$VERSION",
-                                                           "RELEASE",
-                                                           osVersion);
+    mozilla::AndroidBridge::Bridge()->GetStaticStringField(
+        "android/os/Build$VERSION", "RELEASE", osVersion);
     isTablet = java::GeckoAppShell::IsTablet();
   }
 #endif
@@ -602,7 +538,7 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
     }
     ++line;
 
-    if (*token == '#') { // ignore lines that begin with # as comments
+    if (*token == '#') {  // ignore lines that begin with # as comments
       continue;
     }
 
@@ -614,33 +550,32 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
 
     const ManifestDirective* directive = nullptr;
     for (const ManifestDirective* d = kParsingTable;
-         d < ArrayEnd(kParsingTable);
-         ++d) {
-      if (!strcmp(d->directive, token) &&
-          (!aXPTOnly || d->xptonlyfunc)) {
+         d < ArrayEnd(kParsingTable); ++d) {
+      if (!strcmp(d->directive, token)) {
         directive = d;
         break;
       }
     }
 
     if (!directive) {
-      LogMessageWithContext(aFile, line,
-                            "Ignoring unrecognized chrome manifest directive '%s'.",
-                            token);
+      LogMessageWithContext(
+          aFile, line, "Ignoring unrecognized chrome manifest directive '%s'.",
+          token);
       continue;
     }
 
     if (!directive->allowbootstrap && NS_BOOTSTRAPPED_LOCATION == aType) {
-      LogMessageWithContext(aFile, line,
-                            "Bootstrapped manifest not allowed to use '%s' directive.",
-                            token);
+      LogMessageWithContext(
+          aFile, line,
+          "Bootstrapped manifest not allowed to use '%s' directive.", token);
       continue;
     }
 
 #ifndef MOZ_BINARY_EXTENSIONS
     if (directive->apponly && NS_APP_LOCATION != aType) {
-      LogMessageWithContext(aFile, line,
-                            "Only application manifests may use the '%s' directive.", token);
+      LogMessageWithContext(
+          aFile, line, "Only application manifests may use the '%s' directive.",
+          token);
       continue;
     }
 #endif
@@ -660,7 +595,8 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
 
     if (!argv[directive->argc - 1]) {
       LogMessageWithContext(aFile, line,
-                            "Not enough arguments for chrome manifest directive '%s', expected %i.",
+                            "Not enough arguments for chrome manifest "
+                            "directive '%s', expected %i.",
                             token, directive->argc);
       continue;
     }
@@ -684,12 +620,13 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
       NS_ConvertASCIItoUTF16 wtoken(token);
 
       if (CheckStringFlag(kApplication, wtoken, appID, stApp) ||
-          CheckStringFlag(kOs, wtoken, osTarget, stOs) ||
+          CheckOsFlag(kOs, wtoken, osTarget, stOs) ||
           CheckStringFlag(kABI, wtoken, abi, stABI) ||
           CheckStringFlag(kProcess, wtoken, process, stProcess) ||
           CheckVersionFlag(kOsVersion, wtoken, osVersion, stOsVersion) ||
           CheckVersionFlag(kAppVersion, wtoken, appVersion, stAppVersion) ||
-          CheckVersionFlag(kGeckoVersion, wtoken, geckoVersion, stGeckoVersion)) {
+          CheckVersionFlag(kGeckoVersion, wtoken, geckoVersion,
+                           stGeckoVersion)) {
         continue;
       }
 
@@ -703,53 +640,39 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
 
       if (directive->contentflags) {
         bool flag;
-        if (CheckFlag(kPlatform, wtoken, flag)) {
-          if (flag)
-            flags |= nsChromeRegistry::PLATFORM_PACKAGE;
-          continue;
-        }
         if (CheckFlag(kContentAccessible, wtoken, flag)) {
-          if (flag)
-            flags |= nsChromeRegistry::CONTENT_ACCESSIBLE;
+          if (flag) flags |= nsChromeRegistry::CONTENT_ACCESSIBLE;
           continue;
         }
         if (CheckFlag(kRemoteEnabled, wtoken, flag)) {
-          if (flag)
-            flags |= nsChromeRegistry::REMOTE_ALLOWED;
+          if (flag) flags |= nsChromeRegistry::REMOTE_ALLOWED;
           continue;
         }
         if (CheckFlag(kRemoteRequired, wtoken, flag)) {
-          if (flag)
-            flags |= nsChromeRegistry::REMOTE_REQUIRED;
+          if (flag) flags |= nsChromeRegistry::REMOTE_REQUIRED;
           continue;
         }
       }
 
-      bool xpcNativeWrappers = true; // Dummy for CheckFlag.
+      bool xpcNativeWrappers = true;  // Dummy for CheckFlag.
       if (CheckFlag(kXPCNativeWrappers, wtoken, xpcNativeWrappers)) {
-        LogMessageWithContext(aFile, line,
-                              "Ignoring obsolete chrome registration modifier '%s'.",
-                              token);
+        LogMessageWithContext(
+            aFile, line, "Ignoring obsolete chrome registration modifier '%s'.",
+            token);
         continue;
       }
 
-      LogMessageWithContext(aFile, line,
-                            "Unrecognized chrome manifest modifier '%s'.",
-                            token);
+      LogMessageWithContext(
+          aFile, line, "Unrecognized chrome manifest modifier '%s'.", token);
       ok = false;
     }
 
-    if (!ok ||
-        stApp == eBad ||
-        stAppVersion == eBad ||
-        stGeckoVersion == eBad ||
-        stOs == eBad ||
-        stOsVersion == eBad ||
+    if (!ok || stApp == eBad || stAppVersion == eBad ||
+        stGeckoVersion == eBad || stOs == eBad || stOsVersion == eBad ||
 #ifdef MOZ_WIDGET_ANDROID
         stTablet == eBad ||
 #endif
-        stABI == eBad ||
-        stProcess == eBad) {
+        stABI == eBad || stProcess == eBad) {
       continue;
     }
 
@@ -760,7 +683,7 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
 
       if (!nsChromeRegistry::gChromeRegistry) {
         nsCOMPtr<nsIChromeRegistry> cr =
-          mozilla::services::GetChromeRegistryService();
+            mozilla::services::GetChromeRegistryService();
         if (!nsChromeRegistry::gChromeRegistry) {
           LogMessageWithContext(aFile, line,
                                 "Chrome registry isn't available yet.");
@@ -768,8 +691,8 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
         }
       }
 
-      (nsChromeRegistry::gChromeRegistry->*(directive->regfunc))(
-        chromecx, line, argv, flags);
+      (nsChromeRegistry::gChromeRegistry->*(directive->regfunc))(chromecx, line,
+                                                                 argv, flags);
     } else if (directive->ischrome || !aChromeOnly) {
       if (directive->isContract) {
         CachedDirective* cd = contracts.AppendElement();
@@ -778,15 +701,14 @@ ParseManifest(NSLocationType aType, FileLocation& aFile, char* aBuf,
         cd->argv[1] = argv[1];
       } else {
         (nsComponentManagerImpl::gComponentManager->*(directive->mgrfunc))(
-          mgrcx, line, argv);
+            mgrcx, line, argv);
       }
     }
   }
 
   for (uint32_t i = 0; i < contracts.Length(); ++i) {
     CachedDirective& d = contracts[i];
-    nsComponentManagerImpl::gComponentManager->ManifestContract(mgrcx,
-                                                                d.lineno,
+    nsComponentManagerImpl::gComponentManager->ManifestContract(mgrcx, d.lineno,
                                                                 d.argv);
   }
 }
