@@ -4,14 +4,10 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-#define PL_ARENA_CONST_ALIGN_MASK 7
-
 #include "nsICategoryManager.h"
 #include "nsCategoryManager.h"
 
-#include "plarena.h"
 #include "prio.h"
-#include "prprf.h"
 #include "prlock.h"
 #include "nsCOMPtr.h"
 #include "nsTHashtable.h"
@@ -28,6 +24,7 @@
 #include "nsQuickSort.h"
 #include "nsEnumeratorUtils.h"
 #include "nsThreadUtils.h"
+#include "mozilla/ArenaAllocatorExtensions.h"
 #include "mozilla/MemoryReporting.h"
 #include "mozilla/Services.h"
 
@@ -49,43 +46,28 @@ class nsIComponentLoaderManager;
   going to change much ;)
 */
 
-#define NS_CATEGORYMANAGER_ARENA_SIZE (1024 * 8)
-
-// pulled in from nsComponentManager.cpp
-char* ArenaStrdup(const char* aStr, PLArenaPool* aArena);
-
 //
 // BaseStringEnumerator is subclassed by EntryEnumerator and
 // CategoryEnumerator
 //
-class BaseStringEnumerator
-  : public nsISimpleEnumerator
-  , private nsIUTF8StringEnumerator
-{
-public:
+class BaseStringEnumerator : public nsISimpleEnumerator,
+                             private nsIUTF8StringEnumerator {
+ public:
   NS_DECL_ISUPPORTS
   NS_DECL_NSISIMPLEENUMERATOR
   NS_DECL_NSIUTF8STRINGENUMERATOR
 
-protected:
+ protected:
   // Callback function for NS_QuickSort to sort mArray
   static int SortCallback(const void*, const void*, void*);
 
   BaseStringEnumerator()
-    : mArray(nullptr)
-    , mCount(0)
-    , mSimpleCurItem(0)
-    , mStringCurItem(0)
-  {
-  }
+      : mArray(nullptr), mCount(0), mSimpleCurItem(0), mStringCurItem(0) {}
 
   // A virtual destructor is needed here because subclasses of
   // BaseStringEnumerator do not implement their own Release() method.
 
-  virtual ~BaseStringEnumerator()
-  {
-    delete [] mArray;
-  }
+  virtual ~BaseStringEnumerator() { delete[] mArray; }
 
   void Sort();
 
@@ -99,22 +81,19 @@ NS_IMPL_ISUPPORTS(BaseStringEnumerator, nsISimpleEnumerator,
                   nsIUTF8StringEnumerator)
 
 NS_IMETHODIMP
-BaseStringEnumerator::HasMoreElements(bool* aResult)
-{
+BaseStringEnumerator::HasMoreElements(bool* aResult) {
   *aResult = (mSimpleCurItem < mCount);
 
   return NS_OK;
 }
 
 NS_IMETHODIMP
-BaseStringEnumerator::GetNext(nsISupports** aResult)
-{
+BaseStringEnumerator::GetNext(nsISupports** aResult) {
   if (mSimpleCurItem >= mCount) {
     return NS_ERROR_FAILURE;
   }
 
-  nsSupportsDependentCString* str =
-    new nsSupportsDependentCString(mArray[mSimpleCurItem++]);
+  auto* str = new nsSupportsDependentCString(mArray[mSimpleCurItem++]);
   if (!str) {
     return NS_ERROR_OUT_OF_MEMORY;
   }
@@ -125,16 +104,14 @@ BaseStringEnumerator::GetNext(nsISupports** aResult)
 }
 
 NS_IMETHODIMP
-BaseStringEnumerator::HasMore(bool* aResult)
-{
+BaseStringEnumerator::HasMore(bool* aResult) {
   *aResult = (mStringCurItem < mCount);
 
   return NS_OK;
 }
 
 NS_IMETHODIMP
-BaseStringEnumerator::GetNext(nsACString& aResult)
-{
+BaseStringEnumerator::GetNext(nsACString& aResult) {
   if (mStringCurItem >= mCount) {
     return NS_ERROR_FAILURE;
   }
@@ -143,42 +120,34 @@ BaseStringEnumerator::GetNext(nsACString& aResult)
   return NS_OK;
 }
 
-int
-BaseStringEnumerator::SortCallback(const void* aE1, const void* aE2,
-                                   void* /*unused*/)
-{
+int BaseStringEnumerator::SortCallback(const void* aE1, const void* aE2,
+                                       void* /*unused*/) {
   char const* const* s1 = reinterpret_cast<char const* const*>(aE1);
   char const* const* s2 = reinterpret_cast<char const* const*>(aE2);
 
   return strcmp(*s1, *s2);
 }
 
-void
-BaseStringEnumerator::Sort()
-{
+void BaseStringEnumerator::Sort() {
   NS_QuickSort(mArray, mCount, sizeof(mArray[0]), SortCallback, nullptr);
 }
 
 //
-// EntryEnumerator is the wrapper that allows nsICategoryManager::EnumerateCategory
+// EntryEnumerator is the wrapper that allows
+// nsICategoryManager::EnumerateCategory
 //
-class EntryEnumerator
-  : public BaseStringEnumerator
-{
-public:
+class EntryEnumerator : public BaseStringEnumerator {
+ public:
   static EntryEnumerator* Create(nsTHashtable<CategoryLeaf>& aTable);
 };
 
-
-EntryEnumerator*
-EntryEnumerator::Create(nsTHashtable<CategoryLeaf>& aTable)
-{
-  EntryEnumerator* enumObj = new EntryEnumerator();
+EntryEnumerator* EntryEnumerator::Create(nsTHashtable<CategoryLeaf>& aTable) {
+  auto* enumObj = new EntryEnumerator();
   if (!enumObj) {
     return nullptr;
   }
 
-  enumObj->mArray = new char const* [aTable.Count()];
+  enumObj->mArray = new char const*[aTable.Count()];
   if (!enumObj->mArray) {
     delete enumObj;
     return nullptr;
@@ -196,33 +165,21 @@ EntryEnumerator::Create(nsTHashtable<CategoryLeaf>& aTable)
   return enumObj;
 }
 
-
 //
 // CategoryNode implementations
 //
 
-CategoryNode*
-CategoryNode::Create(PLArenaPool* aArena)
-{
+CategoryNode* CategoryNode::Create(CategoryAllocator* aArena) {
   return new (aArena) CategoryNode();
 }
 
-CategoryNode::~CategoryNode()
-{
+CategoryNode::~CategoryNode() = default;
+
+void* CategoryNode::operator new(size_t aSize, CategoryAllocator* aArena) {
+  return aArena->Allocate(aSize, mozilla::fallible);
 }
 
-void*
-CategoryNode::operator new(size_t aSize, PLArenaPool* aArena)
-{
-  void* p;
-  PL_ARENA_ALLOCATE(p, aArena, aSize);
-  return p;
-}
-
-nsresult
-CategoryNode::GetLeaf(const char* aEntryName,
-                      char** aResult)
-{
+nsresult CategoryNode::GetLeaf(const char* aEntryName, char** aResult) {
   MutexAutoLock lock(mLock);
   nsresult rv = NS_ERROR_NOT_AVAILABLE;
   CategoryLeaf* ent = mTable.GetEntry(aEntryName);
@@ -237,13 +194,9 @@ CategoryNode::GetLeaf(const char* aEntryName,
   return rv;
 }
 
-nsresult
-CategoryNode::AddLeaf(const char* aEntryName,
-                      const char* aValue,
-                      bool aReplace,
-                      char** aResult,
-                      PLArenaPool* aArena)
-{
+nsresult CategoryNode::AddLeaf(const char* aEntryName, const char* aValue,
+                               bool aReplace, char** aResult,
+                               CategoryAllocator* aArena) {
   if (aResult) {
     *aResult = nullptr;
   }
@@ -252,7 +205,7 @@ CategoryNode::AddLeaf(const char* aEntryName,
   CategoryLeaf* leaf = mTable.GetEntry(aEntryName);
 
   if (!leaf) {
-    const char* arenaEntryName = ArenaStrdup(aEntryName, aArena);
+    const char* arenaEntryName = ArenaStrdup(aEntryName, *aArena);
     if (!arenaEntryName) {
       return NS_ERROR_OUT_OF_MEMORY;
     }
@@ -267,7 +220,7 @@ CategoryNode::AddLeaf(const char* aEntryName,
     return NS_ERROR_INVALID_ARG;
   }
 
-  const char* arenaValue = ArenaStrdup(aValue, aArena);
+  const char* arenaValue = ArenaStrdup(aValue, *aArena);
   if (!arenaValue) {
     return NS_ERROR_OUT_OF_MEMORY;
   }
@@ -283,9 +236,7 @@ CategoryNode::AddLeaf(const char* aEntryName,
   return NS_OK;
 }
 
-void
-CategoryNode::DeleteLeaf(const char* aEntryName)
-{
+void CategoryNode::DeleteLeaf(const char* aEntryName) {
   // we don't throw any errors, because it normally doesn't matter
   // and it makes JS a lot cleaner
   MutexAutoLock lock(mLock);
@@ -294,9 +245,7 @@ CategoryNode::DeleteLeaf(const char* aEntryName)
   mTable.RemoveEntry(aEntryName);
 }
 
-nsresult
-CategoryNode::Enumerate(nsISimpleEnumerator** aResult)
-{
+nsresult CategoryNode::Enumerate(nsISimpleEnumerator** aResult) {
   if (NS_WARN_IF(!aResult)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -313,9 +262,7 @@ CategoryNode::Enumerate(nsISimpleEnumerator** aResult)
   return NS_OK;
 }
 
-size_t
-CategoryNode::SizeOfExcludingThis(MallocSizeOf aMallocSizeOf)
-{
+size_t CategoryNode::SizeOfExcludingThis(MallocSizeOf aMallocSizeOf) {
   // We don't measure the strings pointed to by the entries because the
   // pointers are non-owning.
   return mTable.ShallowSizeOfExcludingThis(aMallocSizeOf);
@@ -325,24 +272,20 @@ CategoryNode::SizeOfExcludingThis(MallocSizeOf aMallocSizeOf)
 // CategoryEnumerator class
 //
 
-class CategoryEnumerator
-  : public BaseStringEnumerator
-{
-public:
-  static CategoryEnumerator* Create(nsClassHashtable<nsDepCharHashKey,
-                                                     CategoryNode>& aTable);
+class CategoryEnumerator : public BaseStringEnumerator {
+ public:
+  static CategoryEnumerator* Create(
+      nsClassHashtable<nsDepCharHashKey, CategoryNode>& aTable);
 };
 
-CategoryEnumerator*
-CategoryEnumerator::Create(nsClassHashtable<nsDepCharHashKey, CategoryNode>&
-                           aTable)
-{
-  CategoryEnumerator* enumObj = new CategoryEnumerator();
+CategoryEnumerator* CategoryEnumerator::Create(
+    nsClassHashtable<nsDepCharHashKey, CategoryNode>& aTable) {
+  auto* enumObj = new CategoryEnumerator();
   if (!enumObj) {
     return nullptr;
   }
 
-  enumObj->mArray = new const char* [aTable.Count()];
+  enumObj->mArray = new const char*[aTable.Count()];
   if (!enumObj->mArray) {
     delete enumObj;
     return nullptr;
@@ -360,39 +303,29 @@ CategoryEnumerator::Create(nsClassHashtable<nsDepCharHashKey, CategoryNode>&
   return enumObj;
 }
 
-
 //
 // nsCategoryManager implementations
 //
 
-NS_IMPL_QUERY_INTERFACE(nsCategoryManager, nsICategoryManager, nsIMemoryReporter)
+NS_IMPL_QUERY_INTERFACE(nsCategoryManager, nsICategoryManager,
+                        nsIMemoryReporter)
 
 NS_IMETHODIMP_(MozExternalRefCountType)
-nsCategoryManager::AddRef()
-{
-  return 2;
-}
+nsCategoryManager::AddRef() { return 2; }
 
 NS_IMETHODIMP_(MozExternalRefCountType)
-nsCategoryManager::Release()
-{
-  return 1;
-}
+nsCategoryManager::Release() { return 1; }
 
 nsCategoryManager* nsCategoryManager::gCategoryManager;
 
-/* static */ nsCategoryManager*
-nsCategoryManager::GetSingleton()
-{
+/* static */ nsCategoryManager* nsCategoryManager::GetSingleton() {
   if (!gCategoryManager) {
     gCategoryManager = new nsCategoryManager();
   }
   return gCategoryManager;
 }
 
-/* static */ void
-nsCategoryManager::Destroy()
-{
+/* static */ void nsCategoryManager::Destroy() {
   // The nsMemoryReporterManager gets destroyed before the nsCategoryManager,
   // so we don't need to unregister the nsCategoryManager as a memory reporter.
   // In debug builds we assert that unregistering fails, as a way (imperfect
@@ -403,9 +336,8 @@ nsCategoryManager::Destroy()
   gCategoryManager = nullptr;
 }
 
-nsresult
-nsCategoryManager::Create(nsISupports* aOuter, REFNSIID aIID, void** aResult)
-{
+nsresult nsCategoryManager::Create(nsISupports* aOuter, REFNSIID aIID,
+                                   void** aResult) {
   if (aOuter) {
     return NS_ERROR_NO_AGGREGATION;
   }
@@ -414,32 +346,23 @@ nsCategoryManager::Create(nsISupports* aOuter, REFNSIID aIID, void** aResult)
 }
 
 nsCategoryManager::nsCategoryManager()
-  : mLock("nsCategoryManager")
-  , mSuppressNotifications(false)
-{
-  PL_INIT_ARENA_POOL(&mArena, "CategoryManagerArena",
-                     NS_CATEGORYMANAGER_ARENA_SIZE);
-}
+    : mArena(),
+      mTable(),
+      mLock("nsCategoryManager"),
+      mSuppressNotifications(false) {}
 
-void
-nsCategoryManager::InitMemoryReporter()
-{
+void nsCategoryManager::InitMemoryReporter() {
   RegisterWeakMemoryReporter(this);
 }
 
-nsCategoryManager::~nsCategoryManager()
-{
+nsCategoryManager::~nsCategoryManager() {
   // the hashtable contains entries that must be deleted before the arena is
   // destroyed, or else you will have PRLocks undestroyed and other Really
   // Bad Stuff (TM)
   mTable.Clear();
-
-  PL_FinishArenaPool(&mArena);
 }
 
-inline CategoryNode*
-nsCategoryManager::get_category(const char* aName)
-{
+inline CategoryNode* nsCategoryManager::get_category(const char* aName) {
   CategoryNode* node;
   if (!mTable.Get(aName, &node)) {
     return nullptr;
@@ -451,22 +374,19 @@ MOZ_DEFINE_MALLOC_SIZE_OF(CategoryManagerMallocSizeOf)
 
 NS_IMETHODIMP
 nsCategoryManager::CollectReports(nsIHandleReportCallback* aHandleReport,
-                                  nsISupports* aData, bool aAnonymize)
-{
-  MOZ_COLLECT_REPORT(
-    "explicit/xpcom/category-manager", KIND_HEAP, UNITS_BYTES,
-    SizeOfIncludingThis(CategoryManagerMallocSizeOf),
-    "Memory used for the XPCOM category manager.");
+                                  nsISupports* aData, bool aAnonymize) {
+  MOZ_COLLECT_REPORT("explicit/xpcom/category-manager", KIND_HEAP, UNITS_BYTES,
+                     SizeOfIncludingThis(CategoryManagerMallocSizeOf),
+                     "Memory used for the XPCOM category manager.");
 
   return NS_OK;
 }
 
-size_t
-nsCategoryManager::SizeOfIncludingThis(mozilla::MallocSizeOf aMallocSizeOf)
-{
+size_t nsCategoryManager::SizeOfIncludingThis(
+    mozilla::MallocSizeOf aMallocSizeOf) {
   size_t n = aMallocSizeOf(this);
 
-  n += PL_SizeOfArenaPoolExcludingPool(&mArena, aMallocSizeOf);
+  n += mArena.SizeOfExcludingThis(aMallocSizeOf);
 
   n += mTable.ShallowSizeOfExcludingThis(aMallocSizeOf);
   for (auto iter = mTable.ConstIter(); !iter.Done(); iter.Next()) {
@@ -479,31 +399,27 @@ nsCategoryManager::SizeOfIncludingThis(mozilla::MallocSizeOf aMallocSizeOf)
 
 namespace {
 
-class CategoryNotificationRunnable : public Runnable
-{
-public:
-  CategoryNotificationRunnable(nsISupports* aSubject,
-                               const char* aTopic,
+class CategoryNotificationRunnable : public Runnable {
+ public:
+  CategoryNotificationRunnable(nsISupports* aSubject, const char* aTopic,
                                const char* aData)
-    : mSubject(aSubject)
-    , mTopic(aTopic)
-    , mData(aData)
-  {
-  }
+      : Runnable("CategoryNotificationRunnable"),
+        mSubject(aSubject),
+        mTopic(aTopic),
+        mData(aData) {}
 
   NS_DECL_NSIRUNNABLE
 
-private:
+ private:
   nsCOMPtr<nsISupports> mSubject;
   const char* mTopic;
   NS_ConvertUTF8toUTF16 mData;
 };
 
 NS_IMETHODIMP
-CategoryNotificationRunnable::Run()
-{
+CategoryNotificationRunnable::Run() {
   nsCOMPtr<nsIObserverService> observerService =
-    mozilla::services::GetObserverService();
+      mozilla::services::GetObserverService();
   if (observerService) {
     observerService->NotifyObservers(mSubject, mTopic, mData.get());
   }
@@ -511,14 +427,11 @@ CategoryNotificationRunnable::Run()
   return NS_OK;
 }
 
-} // namespace
+}  // namespace
 
-
-void
-nsCategoryManager::NotifyObservers(const char* aTopic,
-                                   const char* aCategoryName,
-                                   const char* aEntryName)
-{
+void nsCategoryManager::NotifyObservers(const char* aTopic,
+                                        const char* aCategoryName,
+                                        const char* aEntryName) {
   if (mSuppressNotifications) {
     return;
   }
@@ -527,7 +440,7 @@ nsCategoryManager::NotifyObservers(const char* aTopic,
 
   if (aEntryName) {
     nsCOMPtr<nsISupportsCString> entry =
-      do_CreateInstance(NS_SUPPORTS_CSTRING_CONTRACTID);
+        do_CreateInstance(NS_SUPPORTS_CSTRING_CONTRACTID);
     if (!entry) {
       return;
     }
@@ -539,9 +452,8 @@ nsCategoryManager::NotifyObservers(const char* aTopic,
 
     r = new CategoryNotificationRunnable(entry, aTopic, aCategoryName);
   } else {
-    r = new CategoryNotificationRunnable(NS_ISUPPORTS_CAST(nsICategoryManager*,
-                                                           this),
-                                         aTopic, aCategoryName);
+    r = new CategoryNotificationRunnable(
+        NS_ISUPPORTS_CAST(nsICategoryManager*, this), aTopic, aCategoryName);
   }
 
   NS_DispatchToMainThread(r);
@@ -549,11 +461,8 @@ nsCategoryManager::NotifyObservers(const char* aTopic,
 
 NS_IMETHODIMP
 nsCategoryManager::GetCategoryEntry(const char* aCategoryName,
-                                    const char* aEntryName,
-                                    char** aResult)
-{
-  if (NS_WARN_IF(!aCategoryName) ||
-      NS_WARN_IF(!aEntryName) ||
+                                    const char* aEntryName, char** aResult) {
+  if (NS_WARN_IF(!aCategoryName) || NS_WARN_IF(!aEntryName) ||
       NS_WARN_IF(!aResult)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -575,12 +484,9 @@ nsCategoryManager::GetCategoryEntry(const char* aCategoryName,
 
 NS_IMETHODIMP
 nsCategoryManager::AddCategoryEntry(const char* aCategoryName,
-                                    const char* aEntryName,
-                                    const char* aValue,
-                                    bool aPersist,
-                                    bool aReplace,
-                                    char** aResult)
-{
+                                    const char* aEntryName, const char* aValue,
+                                    bool aPersist, bool aReplace,
+                                    char** aResult) {
   if (aPersist) {
     NS_ERROR("Category manager doesn't support persistence.");
     return NS_ERROR_INVALID_ARG;
@@ -590,13 +496,10 @@ nsCategoryManager::AddCategoryEntry(const char* aCategoryName,
   return NS_OK;
 }
 
-void
-nsCategoryManager::AddCategoryEntry(const char* aCategoryName,
-                                    const char* aEntryName,
-                                    const char* aValue,
-                                    bool aReplace,
-                                    char** aOldValue)
-{
+void nsCategoryManager::AddCategoryEntry(const char* aCategoryName,
+                                         const char* aEntryName,
+                                         const char* aValue, bool aReplace,
+                                         char** aOldValue) {
   if (aOldValue) {
     *aOldValue = nullptr;
   }
@@ -612,7 +515,7 @@ nsCategoryManager::AddCategoryEntry(const char* aCategoryName,
       // That category doesn't exist yet; let's make it.
       category = CategoryNode::Create(&mArena);
 
-      char* categoryName = ArenaStrdup(aCategoryName, &mArena);
+      char* categoryName = ArenaStrdup(aCategoryName, mArena);
       mTable.Put(categoryName, category);
     }
   }
@@ -624,19 +527,16 @@ nsCategoryManager::AddCategoryEntry(const char* aCategoryName,
   // We will need the return value of AddLeaf even if the called doesn't want it
   char* oldEntry = nullptr;
 
-  nsresult rv = category->AddLeaf(aEntryName,
-                                  aValue,
-                                  aReplace,
-                                  &oldEntry,
-                                  &mArena);
+  nsresult rv =
+      category->AddLeaf(aEntryName, aValue, aReplace, &oldEntry, &mArena);
 
   if (NS_SUCCEEDED(rv)) {
     if (oldEntry) {
       NotifyObservers(NS_XPCOM_CATEGORY_ENTRY_REMOVED_OBSERVER_ID,
                       aCategoryName, aEntryName);
     }
-    NotifyObservers(NS_XPCOM_CATEGORY_ENTRY_ADDED_OBSERVER_ID,
-                    aCategoryName, aEntryName);
+    NotifyObservers(NS_XPCOM_CATEGORY_ENTRY_ADDED_OBSERVER_ID, aCategoryName,
+                    aEntryName);
 
     if (aOldValue) {
       *aOldValue = oldEntry;
@@ -649,10 +549,8 @@ nsCategoryManager::AddCategoryEntry(const char* aCategoryName,
 NS_IMETHODIMP
 nsCategoryManager::DeleteCategoryEntry(const char* aCategoryName,
                                        const char* aEntryName,
-                                       bool aDontPersist)
-{
-  if (NS_WARN_IF(!aCategoryName) ||
-      NS_WARN_IF(!aEntryName)) {
+                                       bool aDontPersist) {
+  if (NS_WARN_IF(!aCategoryName) || NS_WARN_IF(!aEntryName)) {
     return NS_ERROR_INVALID_ARG;
   }
 
@@ -671,16 +569,15 @@ nsCategoryManager::DeleteCategoryEntry(const char* aCategoryName,
   if (category) {
     category->DeleteLeaf(aEntryName);
 
-    NotifyObservers(NS_XPCOM_CATEGORY_ENTRY_REMOVED_OBSERVER_ID,
-                    aCategoryName, aEntryName);
+    NotifyObservers(NS_XPCOM_CATEGORY_ENTRY_REMOVED_OBSERVER_ID, aCategoryName,
+                    aEntryName);
   }
 
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsCategoryManager::DeleteCategory(const char* aCategoryName)
-{
+nsCategoryManager::DeleteCategory(const char* aCategoryName) {
   if (NS_WARN_IF(!aCategoryName)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -697,8 +594,8 @@ nsCategoryManager::DeleteCategory(const char* aCategoryName)
 
   if (category) {
     category->Clear();
-    NotifyObservers(NS_XPCOM_CATEGORY_CLEARED_OBSERVER_ID,
-                    aCategoryName, nullptr);
+    NotifyObservers(NS_XPCOM_CATEGORY_CLEARED_OBSERVER_ID, aCategoryName,
+                    nullptr);
   }
 
   return NS_OK;
@@ -706,10 +603,8 @@ nsCategoryManager::DeleteCategory(const char* aCategoryName)
 
 NS_IMETHODIMP
 nsCategoryManager::EnumerateCategory(const char* aCategoryName,
-                                     nsISimpleEnumerator** aResult)
-{
-  if (NS_WARN_IF(!aCategoryName) ||
-      NS_WARN_IF(!aResult)) {
+                                     nsISimpleEnumerator** aResult) {
+  if (NS_WARN_IF(!aCategoryName) || NS_WARN_IF(!aResult)) {
     return NS_ERROR_INVALID_ARG;
   }
 
@@ -727,8 +622,7 @@ nsCategoryManager::EnumerateCategory(const char* aCategoryName,
 }
 
 NS_IMETHODIMP
-nsCategoryManager::EnumerateCategories(nsISimpleEnumerator** aResult)
-{
+nsCategoryManager::EnumerateCategories(nsISimpleEnumerator** aResult) {
   if (NS_WARN_IF(!aResult)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -745,15 +639,12 @@ nsCategoryManager::EnumerateCategories(nsISimpleEnumerator** aResult)
   return NS_OK;
 }
 
-struct writecat_struct
-{
+struct writecat_struct {
   PRFileDesc* fd;
-  bool        success;
+  bool success;
 };
 
-nsresult
-nsCategoryManager::SuppressNotifications(bool aSuppress)
-{
+nsresult nsCategoryManager::SuppressNotifications(bool aSuppress) {
   mSuppressNotifications = aSuppress;
   return NS_OK;
 }
@@ -764,32 +655,28 @@ nsCategoryManager::SuppressNotifications(bool aSuppress)
  * Given a category, this convenience functions enumerates the category and
  * creates a service of every CID or ContractID registered under the category.
  * If observerTopic is non null and the service implements nsIObserver,
- * this will attempt to notify the observer with the origin, observerTopic string
- * as parameter.
+ * this will attempt to notify the observer with the origin, observerTopic
+ * string as parameter.
  */
-void
-NS_CreateServicesFromCategory(const char* aCategory,
-                              nsISupports* aOrigin,
-                              const char* aObserverTopic,
-                              const char16_t* aObserverData)
-{
+void NS_CreateServicesFromCategory(const char* aCategory, nsISupports* aOrigin,
+                                   const char* aObserverTopic,
+                                   const char16_t* aObserverData) {
   nsresult rv;
 
   nsCOMPtr<nsICategoryManager> categoryManager =
-    do_GetService("@mozilla.org/categorymanager;1");
+      do_GetService("@mozilla.org/categorymanager;1");
   if (!categoryManager) {
     return;
   }
 
   nsCOMPtr<nsISimpleEnumerator> enumerator;
-  rv = categoryManager->EnumerateCategory(aCategory,
-                                          getter_AddRefs(enumerator));
+  rv =
+      categoryManager->EnumerateCategory(aCategory, getter_AddRefs(enumerator));
   if (NS_FAILED(rv)) {
     return;
   }
 
-  nsCOMPtr<nsIUTF8StringEnumerator> senumerator =
-    do_QueryInterface(enumerator);
+  nsCOMPtr<nsIUTF8StringEnumerator> senumerator = do_QueryInterface(enumerator);
   if (!senumerator) {
     NS_WARNING("Category enumerator doesn't support nsIUTF8StringEnumerator.");
     return;
@@ -803,17 +690,19 @@ NS_CreateServicesFromCategory(const char* aCategory,
       continue;
     }
 
-    nsXPIDLCString contractID;
+    nsCString contractID;
     rv = categoryManager->GetCategoryEntry(aCategory, entryString.get(),
                                            getter_Copies(contractID));
     if (NS_FAILED(rv)) {
       continue;
     }
 
-    nsCOMPtr<nsISupports> instance = do_GetService(contractID);
+    nsCOMPtr<nsISupports> instance = do_GetService(contractID.get());
     if (!instance) {
-      LogMessage("While creating services from category '%s', could not create service for entry '%s', contract ID '%s'",
-                 aCategory, entryString.get(), contractID.get());
+      LogMessage(
+          "While creating services from category '%s', could not create "
+          "service for entry '%s', contract ID '%s'",
+          aCategory, entryString.get(), contractID.get());
       continue;
     }
 
@@ -824,8 +713,10 @@ NS_CreateServicesFromCategory(const char* aCategory,
         observer->Observe(aOrigin, aObserverTopic,
                           aObserverData ? aObserverData : u"");
       } else {
-        LogMessage("While creating services from category '%s', service for entry '%s', contract ID '%s' does not implement nsIObserver.",
-                   aCategory, entryString.get(), contractID.get());
+        LogMessage(
+            "While creating services from category '%s', service for entry "
+            "'%s', contract ID '%s' does not implement nsIObserver.",
+            aCategory, entryString.get(), contractID.get());
       }
     }
   }
