@@ -17,23 +17,21 @@
 #include "nsISimpleEnumerator.h"
 #include "mozilla/Attributes.h"
 
-struct ObserverRef
-{
+struct ObserverRef {
   ObserverRef(const ObserverRef& aO) : isWeakRef(aO.isWeakRef), ref(aO.ref) {}
-  explicit ObserverRef(nsIObserver* aObserver) : isWeakRef(false), ref(aObserver) {}
+  explicit ObserverRef(nsIObserver* aObserver)
+      : isWeakRef(false), ref(aObserver) {}
   explicit ObserverRef(nsIWeakReference* aWeak) : isWeakRef(true), ref(aWeak) {}
 
   bool isWeakRef;
   nsCOMPtr<nsISupports> ref;
 
-  nsIObserver* asObserver()
-  {
+  nsIObserver* asObserver() {
     NS_ASSERTION(!isWeakRef, "Isn't a strong ref.");
     return static_cast<nsIObserver*>((nsISupports*)ref);
   }
 
-  nsIWeakReference* asWeak()
-  {
+  nsIWeakReference* asWeak() {
     NS_ASSERTION(isWeakRef, "Isn't a weak ref.");
     return static_cast<nsIWeakReference*>((nsISupports*)ref);
   }
@@ -41,28 +39,22 @@ struct ObserverRef
   bool operator==(nsISupports* aRhs) const { return ref == aRhs; }
 };
 
-class nsObserverList : public nsCharPtrHashKey
-{
+class nsObserverList : public nsCharPtrHashKey {
   friend class nsObserverService;
 
-public:
-  explicit nsObserverList(const char* aKey) : nsCharPtrHashKey(aKey)
-  {
+ public:
+  explicit nsObserverList(const char* aKey) : nsCharPtrHashKey(aKey) {
     MOZ_COUNT_CTOR(nsObserverList);
   }
 
-  ~nsObserverList()
-  {
-    MOZ_COUNT_DTOR(nsObserverList);
-  }
+  ~nsObserverList() { MOZ_COUNT_DTOR(nsObserverList); }
 
-  nsresult AddObserver(nsIObserver* aObserver, bool aOwnsWeak);
-  nsresult RemoveObserver(nsIObserver* aObserver);
+  MOZ_MUST_USE nsresult AddObserver(nsIObserver* aObserver, bool aOwnsWeak);
+  MOZ_MUST_USE nsresult RemoveObserver(nsIObserver* aObserver);
 
-  void NotifyObservers(nsISupports* aSubject,
-                       const char* aTopic,
+  void NotifyObservers(nsISupports* aSubject, const char* aTopic,
                        const char16_t* aSomeData);
-  nsresult GetObserverList(nsISimpleEnumerator** aEnumerator);
+  void GetObserverList(nsISimpleEnumerator** aEnumerator);
 
   // Fill an array with the observers of this category.
   // The array is filled in last-added-first order.
@@ -71,22 +63,21 @@ public:
   // Like FillObserverArray(), but only for strongly held observers.
   void AppendStrongObservers(nsCOMArray<nsIObserver>& aArray);
 
-private:
+ private:
   nsTArray<ObserverRef> mObservers;
 };
 
-class nsObserverEnumerator final : public nsISimpleEnumerator
-{
-public:
+class nsObserverEnumerator final : public nsISimpleEnumerator {
+ public:
   NS_DECL_ISUPPORTS
   NS_DECL_NSISIMPLEENUMERATOR
 
   explicit nsObserverEnumerator(nsObserverList* aObserverList);
 
-private:
+ private:
   ~nsObserverEnumerator() {}
 
-  int32_t mIndex; // Counts up from 0
+  int32_t mIndex;  // Counts up from 0
   nsCOMArray<nsIObserver> mObservers;
 };
 
