@@ -18,18 +18,24 @@
 #include "xpcpublic.h"
 #include "mozilla/net/NeckoCommon.h"
 #include "mozilla/Services.h"
+#include "mozilla/Telemetry.h"
+#include "mozilla/TimeStamp.h"
+#include "nsString.h"
+#include "GeckoProfiler.h"
 
 #define NOTIFY_GLOBAL_OBSERVERS
 
+static const uint32_t kMinTelemetryNotifyObserversLatencyMs = 1;
+
 // Log module for nsObserverService logging...
 //
 // To enable logging (see prlog.h for full details):
 //
-//    set NSPR_LOG_MODULES=ObserverService:5
-//    set NSPR_LOG_FILE=nspr.log
+//    set MOZ_LOG=ObserverService:5
+//    set MOZ_LOG_FILE=service.log
 //
-// this enables LogLevel::Debug level information and places all output in
-// the file nspr.log
+// This enables LogLevel::Debug level information and places all output in
+// the file service.log.
 static mozilla::LazyLogModule sObserverServiceLog("ObserverService");
 #define LOG(x) MOZ_LOG(sObserverServiceLog, mozilla::LogLevel::Debug, x)
 
@@ -37,14 +43,10 @@ using namespace mozilla;
 
 NS_IMETHODIMP
 nsObserverService::CollectReports(nsIHandleReportCallback* aHandleReport,
-                                  nsISupports* aData, bool aAnonymize)
-{
-  struct SuspectObserver
-  {
+                                  nsISupports* aData, bool aAnonymize) {
+  struct SuspectObserver {
     SuspectObserver(const char* aTopic, size_t aReferentCount)
-      : mTopic(aTopic)
-      , mReferentCount(aReferentCount)
-    {}
+        : mTopic(aTopic), mReferentCount(aReferentCount) {}
     const char* mTopic;
     size_t mReferentCount;
   };
@@ -68,7 +70,7 @@ nsObserverService::CollectReports(nsIHandleReportCallback* aHandleReport,
     for (uint32_t i = 0; i < observers.Length(); i++) {
       if (observers[i].isWeakRef) {
         nsCOMPtr<nsIObserver> observerRef(
-          do_QueryReferent(observers[i].asWeak()));
+            do_QueryReferent(observers[i].asWeak()));
         if (observerRef) {
           topicNumWeakAlive++;
         } else {
@@ -93,60 +95,36 @@ nsObserverService::CollectReports(nsIHandleReportCallback* aHandleReport,
   }
 
   // These aren't privacy-sensitive and so don't need anonymizing.
-  nsresult rv;
   for (uint32_t i = 0; i < suspectObservers.Length(); i++) {
     SuspectObserver& suspect = suspectObservers[i];
     nsPrintfCString suspectPath("observer-service-suspect/referent(topic=%s)",
                                 suspect.mTopic);
-    rv = aHandleReport->Callback(
-      /* process */ EmptyCString(),
-      suspectPath, KIND_OTHER, UNITS_COUNT, suspect.mReferentCount,
-      NS_LITERAL_CSTRING("A topic with a suspiciously large number of "
-                         "referents.  This may be symptomatic of a leak "
-                         "if the number of referents is high with "
-                         "respect to the number of windows."),
-      aData);
-
-    if (NS_WARN_IF(NS_FAILED(rv))) {
-      return rv;
-    }
+    aHandleReport->Callback(
+        /* process */ EmptyCString(), suspectPath, KIND_OTHER, UNITS_COUNT,
+        suspect.mReferentCount,
+        NS_LITERAL_CSTRING("A topic with a suspiciously large number of "
+                           "referents.  This may be symptomatic of a leak "
+                           "if the number of referents is high with "
+                           "respect to the number of windows."),
+        aData);
   }
 
-  rv = aHandleReport->Callback(
-         /* process */ EmptyCString(),
-         NS_LITERAL_CSTRING("observer-service/referent/strong"),
-         KIND_OTHER, UNITS_COUNT, totalNumStrong,
-         NS_LITERAL_CSTRING("The number of strong references held by the "
-                            "observer service."),
-         aData);
+  MOZ_COLLECT_REPORT(
+      "observer-service/referent/strong", KIND_OTHER, UNITS_COUNT,
+      totalNumStrong,
+      "The number of strong references held by the observer service.");
 
-  if (NS_WARN_IF(NS_FAILED(rv))) {
-    return rv;
-  }
+  MOZ_COLLECT_REPORT(
+      "observer-service/referent/weak/alive", KIND_OTHER, UNITS_COUNT,
+      totalNumWeakAlive,
+      "The number of weak references held by the observer service that are "
+      "still alive.");
 
-  rv = aHandleReport->Callback(
-         /* process */ EmptyCString(),
-         NS_LITERAL_CSTRING("observer-service/referent/weak/alive"),
-         KIND_OTHER, UNITS_COUNT, totalNumWeakAlive,
-         NS_LITERAL_CSTRING("The number of weak references held by the "
-                            "observer service that are still alive."),
-         aData);
-
-  if (NS_WARN_IF(NS_FAILED(rv))) {
-    return rv;
-  }
-
-  rv = aHandleReport->Callback(
-         /* process */ EmptyCString(),
-         NS_LITERAL_CSTRING("observer-service/referent/weak/dead"),
-         KIND_OTHER, UNITS_COUNT, totalNumWeakDead,
-         NS_LITERAL_CSTRING("The number of weak references held by the "
-                            "observer service that are dead."),
-         aData);
-
-  if (NS_WARN_IF(NS_FAILED(rv))) {
-    return rv;
-  }
+  MOZ_COLLECT_REPORT(
+      "observer-service/referent/weak/dead", KIND_OTHER, UNITS_COUNT,
+      totalNumWeakDead,
+      "The number of weak references held by the observer service that are "
+      "dead.");
 
   return NS_OK;
 }
@@ -154,45 +132,25 @@ nsObserverService::CollectReports(nsIHandleReportCallback* aHandleReport,
 ////////////////////////////////////////////////////////////////////////////////
 // nsObserverService Implementation
 
-NS_IMPL_ISUPPORTS(nsObserverService,
-                  nsIObserverService,
-                  nsObserverService,
+NS_IMPL_ISUPPORTS(nsObserverService, nsIObserverService, nsObserverService,
                   nsIMemoryReporter)
 
-nsObserverService::nsObserverService()
-  : mShuttingDown(false)
-{
-}
+nsObserverService::nsObserverService() : mShuttingDown(false) {}
 
-nsObserverService::~nsObserverService(void)
-{
-  Shutdown();
-}
+nsObserverService::~nsObserverService(void) { Shutdown(); }
 
-void
-nsObserverService::RegisterReporter()
-{
-#if !defined(MOZILLA_XPCOMRT_API)
-  RegisterWeakMemoryReporter(this);
-#endif // !defined(MOZILLA_XPCOMRT_API)
-}
+void nsObserverService::RegisterReporter() { RegisterWeakMemoryReporter(this); }
 
-void
-nsObserverService::Shutdown()
-{
-#if !defined(MOZILLA_XPCOMRT_API)
+void nsObserverService::Shutdown() {
   UnregisterWeakMemoryReporter(this);
-#endif // !defined(MOZILLA_XPCOMRT_API)
 
   mShuttingDown = true;
 
   mObserverTopicTable.Clear();
 }
 
-nsresult
-nsObserverService::Create(nsISupports* aOuter, const nsIID& aIID,
-                          void** aInstancePtr)
-{
+nsresult nsObserverService::Create(nsISupports* aOuter, const nsIID& aIID,
+                                   void** aInstancePtr) {
   LOG(("nsObserverService::Create()"));
 
   RefPtr<nsObserverService> os = new nsObserverService();
@@ -204,41 +162,46 @@ nsObserverService::Create(nsISupports* aOuter, const nsIID& aIID,
   // The memory reporter can not be immediately registered here because
   // the nsMemoryReporterManager may attempt to get the nsObserverService
   // during initialization, causing a recursive GetService.
-  RefPtr<nsRunnableMethod<nsObserverService>> registerRunnable =
-    NS_NewRunnableMethod(os, &nsObserverService::RegisterReporter);
-  NS_DispatchToCurrentThread(registerRunnable);
+  NS_DispatchToCurrentThread(
+      NewRunnableMethod("nsObserverService::RegisterReporter", os,
+                        &nsObserverService::RegisterReporter));
 
   return os->QueryInterface(aIID, aInstancePtr);
 }
 
-#define NS_ENSURE_VALIDCALL \
-    if (!NS_IsMainThread()) {                                     \
-        MOZ_CRASH("Using observer service off the main thread!"); \
-        return NS_ERROR_UNEXPECTED;                               \
-    }                                                             \
-    if (mShuttingDown) {                                          \
-        NS_ERROR("Using observer service after XPCOM shutdown!"); \
-        return NS_ERROR_ILLEGAL_DURING_SHUTDOWN;                  \
-    }
+#define NS_ENSURE_VALIDCALL                                   \
+  if (!NS_IsMainThread()) {                                   \
+    MOZ_CRASH("Using observer service off the main thread!"); \
+    return NS_ERROR_UNEXPECTED;                               \
+  }                                                           \
+  if (mShuttingDown) {                                        \
+    NS_ERROR("Using observer service after XPCOM shutdown!"); \
+    return NS_ERROR_ILLEGAL_DURING_SHUTDOWN;                  \
+  }
 
 NS_IMETHODIMP
 nsObserverService::AddObserver(nsIObserver* aObserver, const char* aTopic,
-                               bool aOwnsWeak)
-{
-  LOG(("nsObserverService::AddObserver(%p: %s)",
-       (void*)aObserver, aTopic));
+                               bool aOwnsWeak) {
+  LOG(("nsObserverService::AddObserver(%p: %s)", (void*)aObserver, aTopic));
 
   NS_ENSURE_VALIDCALL
   if (NS_WARN_IF(!aObserver) || NS_WARN_IF(!aTopic)) {
     return NS_ERROR_INVALID_ARG;
   }
 
-  if (mozilla::net::IsNeckoChild() && !strncmp(aTopic, "http-on-", 8)) {
-    nsCOMPtr<nsIConsoleService> console(do_GetService(NS_CONSOLESERVICE_CONTRACTID));
-    nsCOMPtr<nsIScriptError> error(do_CreateInstance(NS_SCRIPTERROR_CONTRACTID));
-    error->Init(NS_LITERAL_STRING("http-on-* observers only work in the parent process"),
-                EmptyString(), EmptyString(), 0, 0,
-                nsIScriptError::warningFlag, "chrome javascript");
+  // Specifically allow http-on-opening-request and http-on-stop-request in the
+  // child process; see bug 1269765.
+  if (mozilla::net::IsNeckoChild() && !strncmp(aTopic, "http-on-", 8) &&
+      strcmp(aTopic, "http-on-opening-request") &&
+      strcmp(aTopic, "http-on-stop-request")) {
+    nsCOMPtr<nsIConsoleService> console(
+        do_GetService(NS_CONSOLESERVICE_CONTRACTID));
+    nsCOMPtr<nsIScriptError> error(
+        do_CreateInstance(NS_SCRIPTERROR_CONTRACTID));
+    error->Init(NS_LITERAL_STRING(
+                    "http-on-* observers only work in the parent process"),
+                EmptyString(), EmptyString(), 0, 0, nsIScriptError::warningFlag,
+                "chrome javascript");
     console->LogMessage(error);
 
     return NS_ERROR_NOT_IMPLEMENTED;
@@ -253,10 +216,8 @@ nsObserverService::AddObserver(nsIObserver* aObserver, const char* aTopic,
 }
 
 NS_IMETHODIMP
-nsObserverService::RemoveObserver(nsIObserver* aObserver, const char* aTopic)
-{
-  LOG(("nsObserverService::RemoveObserver(%p: %s)",
-       (void*)aObserver, aTopic));
+nsObserverService::RemoveObserver(nsIObserver* aObserver, const char* aTopic) {
+  LOG(("nsObserverService::RemoveObserver(%p: %s)", (void*)aObserver, aTopic));
   NS_ENSURE_VALIDCALL
   if (NS_WARN_IF(!aObserver) || NS_WARN_IF(!aTopic)) {
     return NS_ERROR_INVALID_ARG;
@@ -275,8 +236,7 @@ nsObserverService::RemoveObserver(nsIObserver* aObserver, const char* aTopic)
 
 NS_IMETHODIMP
 nsObserverService::EnumerateObservers(const char* aTopic,
-                                      nsISimpleEnumerator** anEnumerator)
-{
+                                      nsISimpleEnumerator** anEnumerator) {
   NS_ENSURE_VALIDCALL
   if (NS_WARN_IF(!anEnumerator) || NS_WARN_IF(!aTopic)) {
     return NS_ERROR_INVALID_ARG;
@@ -287,14 +247,14 @@ nsObserverService::EnumerateObservers(const char* aTopic,
     return NS_NewEmptyEnumerator(anEnumerator);
   }
 
-  return observerList->GetObserverList(anEnumerator);
+  observerList->GetObserverList(anEnumerator);
+  return NS_OK;
 }
 
 // Enumerate observers of aTopic and call Observe on each.
 NS_IMETHODIMP nsObserverService::NotifyObservers(nsISupports* aSubject,
                                                  const char* aTopic,
-                                                 const char16_t* aSomeData)
-{
+                                                 const char16_t* aSomeData) {
   LOG(("nsObserverService::NotifyObservers(%s)", aTopic));
 
   NS_ENSURE_VALIDCALL
@@ -302,6 +262,11 @@ NS_IMETHODIMP nsObserverService::NotifyObservers(nsISupports* aSubject,
     return NS_ERROR_INVALID_ARG;
   }
 
+  mozilla::TimeStamp start = TimeStamp::Now();
+
+  AUTO_PROFILER_LABEL_DYNAMIC_CSTR("nsObserverService::NotifyObservers", OTHER,
+                                   aTopic);
+
   nsObserverList* observerList = mObserverTopicTable.GetEntry(aTopic);
   if (observerList) {
     observerList->NotifyObservers(aSubject, aTopic, aSomeData);
@@ -314,15 +279,19 @@ NS_IMETHODIMP nsObserverService::NotifyObservers(nsISupports* aSubject,
   }
 #endif
 
+  uint32_t latencyMs = round((TimeStamp::Now() - start).ToMilliseconds());
+  if (latencyMs >= kMinTelemetryNotifyObserversLatencyMs) {
+    Telemetry::Accumulate(Telemetry::NOTIFY_OBSERVERS_LATENCY_MS,
+                          nsDependentCString(aTopic), latencyMs);
+  }
+
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsObserverService::UnmarkGrayStrongObservers()
-{
+nsObserverService::UnmarkGrayStrongObservers() {
   NS_ENSURE_VALIDCALL
 
-#if !defined(MOZILLA_XPCOMRT_API)
   nsCOMArray<nsIObserver> strongObservers;
   for (auto iter = mObserverTopicTable.Iter(); !iter.Done(); iter.Next()) {
     nsObserverList* aObserverList = iter.Get();
@@ -334,7 +303,6 @@ nsObserverService::UnmarkGrayStrongObservers()
   for (uint32_t i = 0; i < strongObservers.Length(); ++i) {
     xpc_TryUnmarkWrappedGrayObject(strongObservers[i]);
   }
-#endif // !defined(MOZILLA_XPCOMRT_API)
 
   return NS_OK;
 }
