@@ -11,58 +11,31 @@
 #include "nsPrintfCString.h"
 #include "nsAutoPtr.h"
 
-#define PL_ARENA_CONST_ALIGN_MASK 3
 #include "nsPersistentProperties.h"
 #include "nsIProperties.h"
 
-struct PropertyTableEntry : public PLDHashEntryHdr
-{
+#include "mozilla/ArenaAllocatorExtensions.h"
+
+using mozilla::ArenaStrdup;
+
+struct PropertyTableEntry : public PLDHashEntryHdr {
   // both of these are arena-allocated
   const char* mKey;
   const char16_t* mValue;
 };
 
-static char16_t*
-ArenaStrdup(const nsAFlatString& aString, PLArenaPool* aArena)
-{
-  void* mem;
-  // add one to include the null terminator
-  int32_t len = (aString.Length() + 1) * sizeof(char16_t);
-  PL_ARENA_ALLOCATE(mem, aArena, len);
-  NS_ASSERTION(mem, "Couldn't allocate space!\n");
-  if (mem) {
-    memcpy(mem, aString.get(), len);
-  }
-  return static_cast<char16_t*>(mem);
-}
-
-static char*
-ArenaStrdup(const nsAFlatCString& aString, PLArenaPool* aArena)
-{
-  void* mem;
-  // add one to include the null terminator
-  int32_t len = (aString.Length() + 1) * sizeof(char);
-  PL_ARENA_ALLOCATE(mem, aArena, len);
-  NS_ASSERTION(mem, "Couldn't allocate space!\n");
-  if (mem) {
-    memcpy(mem, aString.get(), len);
-  }
-  return static_cast<char*>(mem);
-}
-
 static const struct PLDHashTableOps property_HashTableOps = {
-  PLDHashTable::HashStringKey,
-  PLDHashTable::MatchStringKey,
-  PLDHashTable::MoveEntryStub,
-  PLDHashTable::ClearEntryStub,
-  nullptr,
+    PLDHashTable::HashStringKey,
+    PLDHashTable::MatchStringKey,
+    PLDHashTable::MoveEntryStub,
+    PLDHashTable::ClearEntryStub,
+    nullptr,
 };
 
 //
 // parser stuff
 //
-enum EParserState
-{
+enum EParserState {
   eParserState_AwaitingKey,
   eParserState_Key,
   eParserState_AwaitingValue,
@@ -70,25 +43,20 @@ enum EParserState
   eParserState_Comment
 };
 
-enum EParserSpecial
-{
-  eParserSpecial_None,          // not parsing a special character
-  eParserSpecial_Escaped,       // awaiting a special character
-  eParserSpecial_Unicode        // parsing a \Uxxx value
+enum EParserSpecial {
+  eParserSpecial_None,     // not parsing a special character
+  eParserSpecial_Escaped,  // awaiting a special character
+  eParserSpecial_Unicode   // parsing a \Uxxx value
 };
 
-class MOZ_STACK_CLASS nsPropertiesParser
-{
-public:
+class MOZ_STACK_CLASS nsPropertiesParser {
+ public:
   explicit nsPropertiesParser(nsIPersistentProperties* aProps)
-    : mHaveMultiLine(false)
-    , mState(eParserState_AwaitingKey)
-    , mProps(aProps)
-  {
-  }
+      : mHaveMultiLine(false),
+        mState(eParserState_AwaitingKey),
+        mProps(aProps) {}
 
-  void FinishValueState(nsAString& aOldValue)
-  {
+  void FinishValueState(nsAString& aOldValue) {
     static const char trimThese[] = " \t";
     mKey.Trim(trimThese, false, true);
 
@@ -111,69 +79,57 @@ public:
 
   EParserState GetState() { return mState; }
 
-  static nsresult SegmentWriter(nsIUnicharInputStream* aStream,
-                                void* aClosure,
+  static nsresult SegmentWriter(nsIUnicharInputStream* aStream, void* aClosure,
                                 const char16_t* aFromSegment,
-                                uint32_t aToOffset,
-                                uint32_t aCount,
+                                uint32_t aToOffset, uint32_t aCount,
                                 uint32_t* aWriteCount);
 
   nsresult ParseBuffer(const char16_t* aBuffer, uint32_t aBufferLength);
 
-private:
+ private:
   bool ParseValueCharacter(
-    char16_t aChar,               // character that is just being parsed
-    const char16_t* aCur,         // pointer to character aChar in the buffer
-    const char16_t*& aTokenStart, // string copying is done in blocks as big as
-                                  // possible, aTokenStart points to the beginning
-                                  // of this block
-    nsAString& aOldValue);        // when duplicate property is found, new value
-                                  // is stored into hashtable and the old one is
-                                  // placed in this variable
+      char16_t aChar,        // character that is just being parsed
+      const char16_t* aCur,  // pointer to character aChar in the buffer
+      const char16_t*&
+          aTokenStart,        // string copying is done in blocks as big as
+                              // possible, aTokenStart points to the beginning
+                              // of this block
+      nsAString& aOldValue);  // when duplicate property is found, new value
+                              // is stored into hashtable and the old one is
+                              // placed in this variable
 
-  void WaitForKey()
-  {
-    mState = eParserState_AwaitingKey;
-  }
+  void WaitForKey() { mState = eParserState_AwaitingKey; }
 
-  void EnterKeyState()
-  {
+  void EnterKeyState() {
     mKey.Truncate();
     mState = eParserState_Key;
   }
 
-  void WaitForValue()
-  {
-    mState = eParserState_AwaitingValue;
-  }
+  void WaitForValue() { mState = eParserState_AwaitingValue; }
 
-  void EnterValueState()
-  {
+  void EnterValueState() {
     mValue.Truncate();
     mMinLength = 0;
     mState = eParserState_Value;
     mSpecialState = eParserSpecial_None;
   }
 
-  void EnterCommentState()
-  {
-    mState = eParserState_Comment;
-  }
+  void EnterCommentState() { mState = eParserState_Comment; }
 
   nsAutoString mKey;
   nsAutoString mValue;
 
-  uint32_t  mUnicodeValuesRead; // should be 4!
-  char16_t mUnicodeValue;      // currently parsed unicode value
-  bool      mHaveMultiLine;     // is TRUE when last processed characters form
+  uint32_t mUnicodeValuesRead;  // should be 4!
+  char16_t mUnicodeValue;       // currently parsed unicode value
+  bool mHaveMultiLine;          // is TRUE when last processed characters form
                                 // any of following sequences:
                                 //  - "\\\r"
                                 //  - "\\\n"
                                 //  - "\\\r\n"
                                 //  - any sequence above followed by any
                                 //    combination of ' ' and '\t'
-  bool      mMultiLineCanSkipN; // TRUE if "\\\r" was detected
-  uint32_t  mMinLength;         // limit right trimming at the end to not trim
+  bool mMultiLineCanSkipN;      // TRUE if "\\\r" was detected
+  uint32_t mMinLength;          // limit right trimming at the end to not trim
                                 // escaped whitespaces
   EParserState mState;
   // if we see a '\' then we enter this special state
@@ -181,25 +137,17 @@ private:
   nsCOMPtr<nsIPersistentProperties> mProps;
 };
 
-inline bool
-IsWhiteSpace(char16_t aChar)
-{
-  return (aChar == ' ') || (aChar == '\t') ||
-         (aChar == '\r') || (aChar == '\n');
+inline bool IsWhiteSpace(char16_t aChar) {
+  return (aChar == ' ') || (aChar == '\t') || (aChar == '\r') ||
+         (aChar == '\n');
 }
 
-inline bool
-IsEOL(char16_t aChar)
-{
-  return (aChar == '\r') || (aChar == '\n');
-}
+inline bool IsEOL(char16_t aChar) { return (aChar == '\r') || (aChar == '\n'); }
 
-
-bool
-nsPropertiesParser::ParseValueCharacter(char16_t aChar, const char16_t* aCur,
-                                        const char16_t*& aTokenStart,
-                                        nsAString& aOldValue)
-{
+bool nsPropertiesParser::ParseValueCharacter(char16_t aChar,
+                                             const char16_t* aCur,
+                                             const char16_t*& aTokenStart,
+                                             nsAString& aOldValue) {
   switch (mSpecialState) {
     // the normal state - look for special characters
     case eParserSpecial_None:
@@ -216,14 +164,16 @@ nsPropertiesParser::ParseValueCharacter(char16_t aChar, const char16_t* aCur,
           break;
 
         case '\n':
-          // if we detected multiline and got only "\\\r" ignore next "\n" if any
+          // if we detected multiline and got only "\\\r" ignore next "\n" if
+          // any
           if (mHaveMultiLine && mMultiLineCanSkipN) {
             // but don't allow another '\n' to be skipped
             mMultiLineCanSkipN = false;
-            // Now there is nothing to append to the mValue since we are skipping
-            // whitespaces at the beginning of the new line of the multiline
-            // property. Set aTokenStart properly to ensure that nothing is appended
-            // if we find regular line-end or the end of the buffer.
+            // Now there is nothing to append to the mValue since we are
+            // skipping whitespaces at the beginning of the new line of the
+            // multiline property. Set aTokenStart properly to ensure that
+            // nothing is appended if we find regular line-end or the end of the
+            // buffer.
             aTokenStart = aCur + 1;
             break;
           }
@@ -243,19 +193,20 @@ nsPropertiesParser::ParseValueCharacter(char16_t aChar, const char16_t* aCur,
             if (aChar == ' ' || aChar == '\t') {
               // don't allow another '\n' to be skipped
               mMultiLineCanSkipN = false;
-              // Now there is nothing to append to the mValue since we are skipping
-              // whitespaces at the beginning of the new line of the multiline
-              // property. Set aTokenStart properly to ensure that nothing is appended
-              // if we find regular line-end or the end of the buffer.
+              // Now there is nothing to append to the mValue since we are
+              // skipping whitespaces at the beginning of the new line of the
+              // multiline property. Set aTokenStart properly to ensure that
+              // nothing is appended if we find regular line-end or the end of
+              // the buffer.
               aTokenStart = aCur + 1;
               break;
             }
             mHaveMultiLine = false;
             aTokenStart = aCur;
           }
-          break; // from switch on (aChar)
+          break;  // from switch on (aChar)
       }
-      break; // from switch on (mSpecialState)
+      break;  // from switch on (mSpecialState)
 
     // saw a \ character, so parse the character after that
     case eParserSpecial_Escaped:
@@ -309,14 +260,11 @@ nsPropertiesParser::ParseValueCharacter(char16_t aChar, const char16_t* aCur,
     // like \u5f39
     case eParserSpecial_Unicode:
       if ('0' <= aChar && aChar <= '9') {
-        mUnicodeValue =
-          (mUnicodeValue << 4) | (aChar - '0');
+        mUnicodeValue = (mUnicodeValue << 4) | (aChar - '0');
       } else if ('a' <= aChar && aChar <= 'f') {
-        mUnicodeValue =
-          (mUnicodeValue << 4) | (aChar - 'a' + 0x0a);
+        mUnicodeValue = (mUnicodeValue << 4) | (aChar - 'a' + 0x0a);
       } else if ('A' <= aChar && aChar <= 'F') {
-        mUnicodeValue =
-          (mUnicodeValue << 4) | (aChar - 'A' + 0x0a);
+        mUnicodeValue = (mUnicodeValue << 4) | (aChar - 'A' + 0x0a);
       } else {
         // non-hex character. Append what we have, and move on.
         mValue += mUnicodeValue;
@@ -343,14 +291,11 @@ nsPropertiesParser::ParseValueCharacter(char16_t aChar, const char16_t* aCur,
   return true;
 }
 
-nsresult
-nsPropertiesParser::SegmentWriter(nsIUnicharInputStream* aStream,
-                                  void* aClosure,
-                                  const char16_t* aFromSegment,
-                                  uint32_t aToOffset,
-                                  uint32_t aCount,
-                                  uint32_t* aWriteCount)
-{
+nsresult nsPropertiesParser::SegmentWriter(nsIUnicharInputStream* aStream,
+                                           void* aClosure,
+                                           const char16_t* aFromSegment,
+                                           uint32_t aToOffset, uint32_t aCount,
+                                           uint32_t* aWriteCount) {
   nsPropertiesParser* parser = static_cast<nsPropertiesParser*>(aClosure);
   parser->ParseBuffer(aFromSegment, aCount);
 
@@ -358,10 +303,8 @@ nsPropertiesParser::SegmentWriter(nsIUnicharInputStream* aStream,
   return NS_OK;
 }
 
-nsresult
-nsPropertiesParser::ParseBuffer(const char16_t* aBuffer,
-                                uint32_t aBufferLength)
-{
+nsresult nsPropertiesParser::ParseBuffer(const char16_t* aBuffer,
+                                         uint32_t aBufferLength) {
   const char16_t* cur = aBuffer;
   const char16_t* end = aBuffer + aBufferLength;
 
@@ -370,15 +313,13 @@ nsPropertiesParser::ParseBuffer(const char16_t* aBuffer,
 
   // if we're in the middle of parsing a key or value, make sure
   // the current token points to the beginning of the current buffer
-  if (mState == eParserState_Key ||
-      mState == eParserState_Value) {
+  if (mState == eParserState_Key || mState == eParserState_Value) {
     tokenStart = aBuffer;
   }
 
   nsAutoString oldValue;
 
   while (cur != end) {
-
     char16_t c = *cur;
 
     switch (mState) {
@@ -459,21 +400,14 @@ nsPropertiesParser::ParseBuffer(const char16_t* aBuffer,
 }
 
 nsPersistentProperties::nsPersistentProperties()
-  : mIn(nullptr)
-  , mTable(&property_HashTableOps, sizeof(PropertyTableEntry), 16)
-{
-  PL_INIT_ARENA_POOL(&mArena, "PersistentPropertyArena", 2048);
-}
+    : mIn(nullptr),
+      mTable(&property_HashTableOps, sizeof(PropertyTableEntry), 16),
+      mArena() {}
 
-nsPersistentProperties::~nsPersistentProperties()
-{
-  PL_FinishArenaPool(&mArena);
-}
+nsPersistentProperties::~nsPersistentProperties() {}
 
-nsresult
-nsPersistentProperties::Create(nsISupports* aOuter, REFNSIID aIID,
-                               void** aResult)
-{
+nsresult nsPersistentProperties::Create(nsISupports* aOuter, REFNSIID aIID,
+                                        void** aResult) {
   if (aOuter) {
     return NS_ERROR_NO_AGGREGATION;
   }
@@ -481,11 +415,11 @@ nsPersistentProperties::Create(nsISupports* aOuter, REFNSIID aIID,
   return props->QueryInterface(aIID, aResult);
 }
 
-NS_IMPL_ISUPPORTS(nsPersistentProperties, nsIPersistentProperties, nsIProperties)
+NS_IMPL_ISUPPORTS(nsPersistentProperties, nsIPersistentProperties,
+                  nsIProperties)
 
 NS_IMETHODIMP
-nsPersistentProperties::Load(nsIInputStream* aIn)
-{
+nsPersistentProperties::Load(nsIInputStream* aIn) {
   nsresult rv = NS_NewUnicharInputStream(aIn, getter_AddRefs(mIn));
 
   if (rv != NS_OK) {
@@ -500,7 +434,8 @@ nsPersistentProperties::Load(nsIInputStream* aIn)
   // the bug121341.properties test file accordingly.
   while (NS_SUCCEEDED(rv = mIn->ReadSegments(nsPropertiesParser::SegmentWriter,
                                              &parser, 4096, &nProcessed)) &&
-         nProcessed != 0);
+         nProcessed != 0)
+    ;
   mIn = nullptr;
   if (NS_FAILED(rv)) {
     return rv;
@@ -519,37 +454,33 @@ nsPersistentProperties::Load(nsIInputStream* aIn)
 NS_IMETHODIMP
 nsPersistentProperties::SetStringProperty(const nsACString& aKey,
                                           const nsAString& aNewValue,
-                                          nsAString& aOldValue)
-{
-  const nsAFlatCString&  flatKey = PromiseFlatCString(aKey);
-  auto entry = static_cast<PropertyTableEntry*>
-                          (mTable.Add(flatKey.get()));
+                                          nsAString& aOldValue) {
+  const nsCString& flatKey = PromiseFlatCString(aKey);
+  auto entry = static_cast<PropertyTableEntry*>(mTable.Add(flatKey.get()));
 
   if (entry->mKey) {
     aOldValue = entry->mValue;
-    NS_WARNING(nsPrintfCString("the property %s already exists",
-                               flatKey.get()).get());
+    NS_WARNING(
+        nsPrintfCString("the property %s already exists", flatKey.get()).get());
   } else {
     aOldValue.Truncate();
   }
 
-  entry->mKey = ArenaStrdup(flatKey, &mArena);
-  entry->mValue = ArenaStrdup(PromiseFlatString(aNewValue), &mArena);
+  entry->mKey = ArenaStrdup(flatKey, mArena);
+  entry->mValue = ArenaStrdup(aNewValue, mArena);
 
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsPersistentProperties::Save(nsIOutputStream* aOut, const nsACString& aHeader)
-{
+nsPersistentProperties::Save(nsIOutputStream* aOut, const nsACString& aHeader) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
 nsPersistentProperties::GetStringProperty(const nsACString& aKey,
-                                          nsAString& aValue)
-{
-  const nsAFlatCString&  flatKey = PromiseFlatCString(aKey);
+                                          nsAString& aValue) {
+  const nsCString& flatKey = PromiseFlatCString(aKey);
 
   auto entry = static_cast<PropertyTableEntry*>(mTable.Search(flatKey.get()));
   if (!entry) {
@@ -561,8 +492,7 @@ nsPersistentProperties::GetStringProperty(const nsACString& aKey,
 }
 
 NS_IMETHODIMP
-nsPersistentProperties::Enumerate(nsISimpleEnumerator** aResult)
-{
+nsPersistentProperties::Enumerate(nsISimpleEnumerator** aResult) {
   nsCOMArray<nsIPropertyElement> props;
 
   // We know the necessary size; we can avoid growing it while adding elements
@@ -572,9 +502,8 @@ nsPersistentProperties::Enumerate(nsISimpleEnumerator** aResult)
   for (auto iter = mTable.Iter(); !iter.Done(); iter.Next()) {
     auto entry = static_cast<PropertyTableEntry*>(iter.Get());
 
-    RefPtr<nsPropertyElement> element =
-      new nsPropertyElement(nsDependentCString(entry->mKey),
-                            nsDependentString(entry->mValue));
+    RefPtr<nsPropertyElement> element = new nsPropertyElement(
+        nsDependentCString(entry->mKey), nsDependentString(entry->mValue));
 
     if (!props.AppendObject(element)) {
       return NS_ERROR_OUT_OF_MEMORY;
@@ -590,32 +519,27 @@ nsPersistentProperties::Enumerate(nsISimpleEnumerator** aResult)
 
 NS_IMETHODIMP
 nsPersistentProperties::Get(const char* aProp, const nsIID& aUUID,
-                            void** aResult)
-{
+                            void** aResult) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
-nsPersistentProperties::Set(const char* aProp, nsISupports* value)
-{
+nsPersistentProperties::Set(const char* aProp, nsISupports* value) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 NS_IMETHODIMP
-nsPersistentProperties::Undefine(const char* aProp)
-{
+nsPersistentProperties::Undefine(const char* aProp) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
-nsPersistentProperties::Has(const char* aProp, bool* aResult)
-{
+nsPersistentProperties::Has(const char* aProp, bool* aResult) {
   *aResult = !!mTable.Search(aProp);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsPersistentProperties::GetKeys(uint32_t* aCount, char*** aKeys)
-{
+nsPersistentProperties::GetKeys(uint32_t* aCount, char*** aKeys) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
@@ -623,9 +547,8 @@ nsPersistentProperties::GetKeys(uint32_t* aCount, char*** aKeys)
 // PropertyElement
 ////////////////////////////////////////////////////////////////////////////////
 
-nsresult
-nsPropertyElement::Create(nsISupports* aOuter, REFNSIID aIID, void** aResult)
-{
+nsresult nsPropertyElement::Create(nsISupports* aOuter, REFNSIID aIID,
+                                   void** aResult) {
   if (aOuter) {
     return NS_ERROR_NO_AGGREGATION;
   }
@@ -636,29 +559,25 @@ nsPropertyElement::Create(nsISupports* aOuter, REFNSIID aIID, void** aResult)
 NS_IMPL_ISUPPORTS(nsPropertyElement, nsIPropertyElement)
 
 NS_IMETHODIMP
-nsPropertyElement::GetKey(nsACString& aReturnKey)
-{
+nsPropertyElement::GetKey(nsACString& aReturnKey) {
   aReturnKey = mKey;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsPropertyElement::GetValue(nsAString& aReturnValue)
-{
+nsPropertyElement::GetValue(nsAString& aReturnValue) {
   aReturnValue = mValue;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsPropertyElement::SetKey(const nsACString& aKey)
-{
+nsPropertyElement::SetKey(const nsACString& aKey) {
   mKey = aKey;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsPropertyElement::SetValue(const nsAString& aValue)
-{
+nsPropertyElement::SetValue(const nsAString& aValue) {
   mValue = aValue;
   return NS_OK;
 }
