@@ -1,4 +1,5 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* vim: set ts=8 sts=2 et sw=2 tw=80: */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -13,8 +14,7 @@ NS_INTERFACE_MAP_BEGIN_AGGREGATED(nsProperties)
 NS_INTERFACE_MAP_END
 
 NS_IMETHODIMP
-nsProperties::Get(const char* prop, const nsIID& uuid, void** result)
-{
+nsProperties::Get(const char* prop, const nsIID& uuid, void** result) {
   if (NS_WARN_IF(!prop)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -27,8 +27,7 @@ nsProperties::Get(const char* prop, const nsIID& uuid, void** result)
 }
 
 NS_IMETHODIMP
-nsProperties::Set(const char* prop, nsISupports* value)
-{
+nsProperties::Set(const char* prop, nsISupports* value) {
   if (NS_WARN_IF(!prop)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -37,84 +36,51 @@ nsProperties::Set(const char* prop, nsISupports* value)
 }
 
 NS_IMETHODIMP
-nsProperties::Undefine(const char* prop)
-{
+nsProperties::Undefine(const char* prop) {
   if (NS_WARN_IF(!prop)) {
     return NS_ERROR_INVALID_ARG;
   }
 
-  nsCOMPtr<nsISupports> value;
-  if (!nsProperties_HashBase::Get(prop, getter_AddRefs(value))) {
-    return NS_ERROR_FAILURE;
-  }
-
-  Remove(prop);
-  return NS_OK;
+  return nsProperties_HashBase::Remove(prop) ? NS_OK : NS_ERROR_FAILURE;
 }
 
 NS_IMETHODIMP
-nsProperties::Has(const char* prop, bool* result)
-{
+nsProperties::Has(const char* prop, bool* result) {
   if (NS_WARN_IF(!prop)) {
     return NS_ERROR_INVALID_ARG;
   }
 
-  nsCOMPtr<nsISupports> value;
-  *result = nsProperties_HashBase::Get(prop, getter_AddRefs(value));
+  *result = nsProperties_HashBase::Contains(prop);
   return NS_OK;
 }
 
-struct GetKeysEnumData
-{
-  char** keys;
-  uint32_t next;
-  nsresult res;
-};
-
-PLDHashOperator
-GetKeysEnumerate(const char* aKey, nsISupports* aData, void* aArg)
-{
-  GetKeysEnumData* gkedp = (GetKeysEnumData*)aArg;
-  gkedp->keys[gkedp->next] = strdup(aKey);
-
-  if (!gkedp->keys[gkedp->next]) {
-    gkedp->res = NS_ERROR_OUT_OF_MEMORY;
-    return PL_DHASH_STOP;
-  }
-
-  gkedp->next++;
-  return PL_DHASH_NEXT;
-}
-
 NS_IMETHODIMP
-nsProperties::GetKeys(uint32_t* aCount, char*** aKeys)
-{
+nsProperties::GetKeys(uint32_t* aCount, char*** aKeys) {
   if (NS_WARN_IF(!aCount) || NS_WARN_IF(!aKeys)) {
     return NS_ERROR_INVALID_ARG;
   }
 
-  uint32_t n = Count();
-  char** k = (char**)nsMemory::Alloc(n * sizeof(char*));
+  uint32_t count = Count();
+  char** keys = (char**)moz_xmalloc(count * sizeof(char*));
+  uint32_t j = 0;
 
-  GetKeysEnumData gked;
-  gked.keys = k;
-  gked.next = 0;
-  gked.res = NS_OK;
+  for (auto iter = this->Iter(); !iter.Done(); iter.Next()) {
+    const char* key = iter.Key();
+    keys[j] = strdup(key);
 
-  EnumerateRead(GetKeysEnumerate, &gked);
-
-  nsresult rv = gked.res;
-  if (NS_FAILED(rv)) {
-    // Free 'em all
-    for (uint32_t i = 0; i < gked.next; i++) {
-      nsMemory::Free(k[i]);
+    if (!keys[j]) {
+      // Free 'em all
+      for (uint32_t i = 0; i < j; i++) {
+        free(keys[i]);
+      }
+      free(keys);
+      return NS_ERROR_OUT_OF_MEMORY;
     }
-    nsMemory::Free(k);
-    return rv;
+    j++;
   }
 
-  *aCount = n;
-  *aKeys = k;
+  *aCount = count;
+  *aKeys = keys;
   return NS_OK;
 }
 
