@@ -12,7 +12,6 @@
 #if defined(XP_WIN)
 
 #include <windows.h>
-#include <shlobj.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -20,9 +19,6 @@
 #include <shlobj.h>
 #include <knownfolders.h>
 #include <guiddef.h>
-#include "mozilla/WindowsVersion.h"
-
-using mozilla::IsWin7OrLater;
 
 #elif defined(XP_UNIX)
 
@@ -31,6 +27,9 @@ using mozilla::IsWin7OrLater;
 #include <stdlib.h>
 #include <sys/param.h>
 #include "prenv.h"
+#if defined(MOZ_WIDGET_COCOA)
+#include "CocoaFileUtils.h"
+#endif
 
 #endif
 
@@ -48,56 +47,27 @@ using mozilla::IsWin7OrLater;
 #endif
 #endif
 
-#ifdef XP_WIN
-typedef HRESULT (WINAPI* nsGetKnownFolderPath)(GUID& rfid,
-                                               DWORD dwFlags,
-                                               HANDLE hToken,
-                                               PWSTR* ppszPath);
+#if defined(XP_WIN)
 
-static nsGetKnownFolderPath gGetKnownFolderPath = nullptr;
-#endif
-
-void
-StartupSpecialSystemDirectory()
-{
-#if defined (XP_WIN)
-  // SHGetKnownFolderPath is only available on Windows Vista
-  // so that we need to use GetProcAddress to get the pointer.
-  HMODULE hShell32DLLInst = GetModuleHandleW(L"shell32.dll");
-  if (hShell32DLLInst) {
-    gGetKnownFolderPath = (nsGetKnownFolderPath)
-      GetProcAddress(hShell32DLLInst, "SHGetKnownFolderPath");
-  }
-#endif
-}
-
-#if defined (XP_WIN)
-
-static nsresult
-GetKnownFolder(GUID* aGuid, nsIFile** aFile)
-{
-  if (!aGuid || !gGetKnownFolderPath) {
+static nsresult GetKnownFolder(GUID* aGuid, nsIFile** aFile) {
+  if (!aGuid) {
     return NS_ERROR_FAILURE;
   }
 
   PWSTR path = nullptr;
-  gGetKnownFolderPath(*aGuid, 0, nullptr, &path);
+  SHGetKnownFolderPath(*aGuid, 0, nullptr, &path);
 
   if (!path) {
     return NS_ERROR_FAILURE;
   }
 
-  nsresult rv = NS_NewLocalFile(nsDependentString(path),
-                                true,
-                                aFile);
+  nsresult rv = NS_NewLocalFile(nsDependentString(path), true, aFile);
 
   CoTaskMemFree(path);
   return rv;
 }
 
-static nsresult
-GetWindowsFolder(int aFolder, nsIFile** aFile)
-{
+static nsresult GetWindowsFolder(int aFolder, nsIFile** aFile) {
   WCHAR path_orig[MAX_PATH + 3];
   WCHAR* path = path_orig + 1;
   HRESULT result = SHGetSpecialFolderPathW(nullptr, path, aFolder, true);
@@ -108,23 +78,25 @@ GetWindowsFolder(int aFolder, nsIFile** aFile)
 
   // Append the trailing slash
   int len = wcslen(path);
+  if (len == 0) {
+    return NS_ERROR_FILE_UNRECOGNIZED_PATH;
+  }
   if (len > 1 && path[len - 1] != L'\\') {
-    path[len]   = L'\\';
+    path[len] = L'\\';
     path[++len] = L'\0';
   }
 
   return NS_NewLocalFile(nsDependentString(path, len), true, aFile);
 }
 
-__inline HRESULT
-SHLoadLibraryFromKnownFolder(REFKNOWNFOLDERID aFolderId, DWORD aMode,
-                             REFIID riid, void** ppv)
-{
+#if WINVER < 0x0601
+__inline HRESULT SHLoadLibraryFromKnownFolder(REFKNOWNFOLDERID aFolderId,
+                                              DWORD aMode, REFIID riid,
+                                              void** ppv) {
   *ppv = nullptr;
   IShellLibrary* plib;
   HRESULT hr = CoCreateInstance(CLSID_ShellLibrary, nullptr,
-                                CLSCTX_INPROC_SERVER,
-                                IID_PPV_ARGS(&plib));
+                                CLSCTX_INPROC_SERVER, IID_PPV_ARGS(&plib));
   if (SUCCEEDED(hr)) {
     hr = plib->LoadLibraryFromKnownFolder(aFolderId, aMode);
     if (SUCCEEDED(hr)) {
@@ -134,37 +106,28 @@ SHLoadLibraryFromKnownFolder(REFKNOWNFOLDERID aFolderId, DWORD aMode,
   }
   return hr;
 }
+#endif
 
 /*
- * Check to see if we're on Win7 and up, and if so, returns the default
- * save-to location for the Windows Library passed in through aFolderId.
- * Otherwise falls back on pre-win7 GetWindowsFolder.
+ * Return the default save-to location for the Windows Library passed in
+ * through aFolderId.
  */
-static nsresult
-GetLibrarySaveToPath(int aFallbackFolderId, REFKNOWNFOLDERID aFolderId,
-                     nsIFile** aFile)
-{
-  // Skip off checking for library support if the os is Vista or lower.
-  if (!IsWin7OrLater()) {
-    return GetWindowsFolder(aFallbackFolderId, aFile);
-  }
-
+static nsresult GetLibrarySaveToPath(int aFallbackFolderId,
+                                     REFKNOWNFOLDERID aFolderId,
+                                     nsIFile** aFile) {
   RefPtr<IShellLibrary> shellLib;
   RefPtr<IShellItem> savePath;
-  HRESULT hr =
-    SHLoadLibraryFromKnownFolder(aFolderId, STGM_READ,
-                                 IID_IShellLibrary, getter_AddRefs(shellLib));
+  SHLoadLibraryFromKnownFolder(aFolderId, STGM_READ, IID_IShellLibrary,
+                               getter_AddRefs(shellLib));
 
-  if (shellLib &&
-      SUCCEEDED(shellLib->GetDefaultSaveFolder(DSFT_DETECT, IID_IShellItem,
-                                               getter_AddRefs(savePath)))) {
+  if (shellLib && SUCCEEDED(shellLib->GetDefaultSaveFolder(
+                      DSFT_DETECT, IID_IShellItem, getter_AddRefs(savePath)))) {
     wchar_t* str = nullptr;
     if (SUCCEEDED(savePath->GetDisplayName(SIGDN_FILESYSPATH, &str))) {
       nsAutoString path;
       path.Assign(str);
       path.Append('\\');
-      nsresult rv =
-        NS_NewLocalFile(path, false, aFile);
+      nsresult rv = NS_NewLocalFile(path, false, aFile);
       CoTaskMemFree(str);
       return rv;
     }
@@ -178,22 +141,19 @@ GetLibrarySaveToPath(int aFallbackFolderId, REFKNOWNFOLDERID aFolderId,
  * querying the registry when the call to SHGetSpecialFolderPathW is unable to
  * provide these paths (Bug 513958).
  */
-static nsresult
-GetRegWindowsAppDataFolder(bool aLocal, nsIFile** aFile)
-{
+static nsresult GetRegWindowsAppDataFolder(bool aLocal, nsIFile** aFile) {
   HKEY key;
-  NS_NAMED_LITERAL_STRING(keyName,
-    "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders");
-  DWORD res = ::RegOpenKeyExW(HKEY_CURRENT_USER, keyName.get(), 0, KEY_READ,
-                              &key);
+  LPCWSTR keyName =
+      L"Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders";
+  DWORD res = ::RegOpenKeyExW(HKEY_CURRENT_USER, keyName, 0, KEY_READ, &key);
   if (res != ERROR_SUCCESS) {
     return NS_ERROR_FAILURE;
   }
 
   WCHAR path[MAX_PATH + 2];
   DWORD type, size;
-  res = RegQueryValueExW(key, (aLocal ? L"Local AppData" : L"AppData"),
-                         nullptr, &type, (LPBYTE)&path, &size);
+  res = RegQueryValueExW(key, (aLocal ? L"Local AppData" : L"AppData"), nullptr,
+                         &type, (LPBYTE)&path, &size);
   ::RegCloseKey(key);
   // The call to RegQueryValueExW must succeed, the type must be REG_SZ, the
   // buffer size must not equal 0, and the buffer size be a multiple of 2.
@@ -204,25 +164,23 @@ GetRegWindowsAppDataFolder(bool aLocal, nsIFile** aFile)
   // Append the trailing slash
   int len = wcslen(path);
   if (len > 1 && path[len - 1] != L'\\') {
-    path[len]   = L'\\';
+    path[len] = L'\\';
     path[++len] = L'\0';
   }
 
   return NS_NewLocalFile(nsDependentString(path, len), true, aFile);
 }
 
-#endif // XP_WIN
+#endif  // XP_WIN
 
 #if defined(XP_UNIX)
-static nsresult
-GetUnixHomeDir(nsIFile** aFile)
-{
+static nsresult GetUnixHomeDir(nsIFile** aFile) {
 #if defined(ANDROID)
   // XXX no home dir on android; maybe we should return the sdcard if present?
   return NS_ERROR_FAILURE;
 #else
-  return NS_NewNativeLocalFile(nsDependentCString(PR_GetEnv("HOME")),
-                               true, aFile);
+  return NS_NewNativeLocalFile(nsDependentCString(PR_GetEnv("HOME")), true,
+                               aFile);
 #endif
 }
 
@@ -252,9 +210,7 @@ GetUnixHomeDir(nsIFile** aFile)
   SOFTWARE.
 */
 
-static char*
-xdg_user_dir_lookup(const char* aType)
-{
+static char* xdg_user_dir_lookup(const char* aType) {
   FILE* file;
   char* home_dir;
   char* config_home;
@@ -274,8 +230,8 @@ xdg_user_dir_lookup(const char* aType)
 
   config_home = getenv("XDG_CONFIG_HOME");
   if (!config_home || config_home[0] == 0) {
-    config_file = (char*)malloc(strlen(home_dir) +
-                                strlen("/.config/user-dirs.dirs") + 1);
+    config_file =
+        (char*)malloc(strlen(home_dir) + strlen("/.config/user-dirs.dirs") + 1);
     if (!config_file) {
       goto error;
     }
@@ -283,8 +239,8 @@ xdg_user_dir_lookup(const char* aType)
     strcpy(config_file, home_dir);
     strcat(config_file, "/.config/user-dirs.dirs");
   } else {
-    config_file = (char*)malloc(strlen(config_home) +
-                                strlen("/user-dirs.dirs") + 1);
+    config_file =
+        (char*)malloc(strlen(config_home) + strlen("/user-dirs.dirs") + 1);
     if (!config_file) {
       goto error;
     }
@@ -389,32 +345,22 @@ error:
 }
 
 static const char xdg_user_dirs[] =
-  "DESKTOP\0"
-  "DOCUMENTS\0"
-  "DOWNLOAD\0"
-  "MUSIC\0"
-  "PICTURES\0"
-  "PUBLICSHARE\0"
-  "TEMPLATES\0"
-  "VIDEOS";
+    "DESKTOP\0"
+    "DOCUMENTS\0"
+    "DOWNLOAD\0"
+    "MUSIC\0"
+    "PICTURES\0"
+    "PUBLICSHARE\0"
+    "TEMPLATES\0"
+    "VIDEOS";
 
-static const uint8_t xdg_user_dir_offsets[] = {
-  0,
-  8,
-  18,
-  27,
-  33,
-  42,
-  54,
-  64
-};
+static const uint8_t xdg_user_dir_offsets[] = {0, 8, 18, 27, 33, 42, 54, 64};
 
-static nsresult
-GetUnixXDGUserDirectory(SystemDirectories aSystemDirectory,
-                        nsIFile** aFile)
-{
+static nsresult GetUnixXDGUserDirectory(SystemDirectories aSystemDirectory,
+                                        nsIFile** aFile) {
   char* dir = xdg_user_dir_lookup(
-    xdg_user_dirs + xdg_user_dir_offsets[aSystemDirectory - Unix_XDG_Desktop]);
+      xdg_user_dirs +
+      xdg_user_dir_offsets[aSystemDirectory - Unix_XDG_Desktop]);
 
   nsresult rv;
   nsCOMPtr<nsIFile> file;
@@ -459,10 +405,8 @@ GetUnixXDGUserDirectory(SystemDirectories aSystemDirectory,
 }
 #endif
 
-nsresult
-GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
-                          nsIFile** aFile)
-{
+nsresult GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
+                                   nsIFile** aFile) {
 #if defined(XP_WIN)
   WCHAR path[MAX_PATH];
 #else
@@ -475,9 +419,7 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
       if (!_wgetcwd(path, MAX_PATH)) {
         return NS_ERROR_FAILURE;
       }
-      return NS_NewLocalFile(nsDependentString(path),
-                             true,
-                             aFile);
+      return NS_NewLocalFile(nsDependentString(path), true, aFile);
 #else
       if (!getcwd(path, MAXPATHLEN)) {
         return NS_ERROR_FAILURE;
@@ -485,13 +427,11 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
 #endif
 
 #if !defined(XP_WIN)
-      return NS_NewNativeLocalFile(nsDependentCString(path),
-                                   true,
-                                   aFile);
+      return NS_NewNativeLocalFile(nsDependentCString(path), true, aFile);
 #endif
 
     case OS_DriveDirectory:
-#if defined (XP_WIN)
+#if defined(XP_WIN)
     {
       int32_t len = ::GetWindowsDirectoryW(path, MAX_PATH);
       if (len == 0) {
@@ -501,27 +441,21 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
         path[3] = 0;
       }
 
-      return NS_NewLocalFile(nsDependentString(path),
-                             true,
-                             aFile);
+      return NS_NewLocalFile(nsDependentString(path), true, aFile);
     }
 #else
-    return NS_NewNativeLocalFile(nsDependentCString("/"),
-                                 true,
-                                 aFile);
+      return NS_NewNativeLocalFile(nsDependentCString("/"), true, aFile);
 
 #endif
 
     case OS_TemporaryDirectory:
-#if defined (XP_WIN)
+#if defined(XP_WIN)
     {
       DWORD len = ::GetTempPathW(MAX_PATH, path);
       if (len == 0) {
         break;
       }
-      return NS_NewLocalFile(nsDependentString(path, len),
-                             true,
-                             aFile);
+      return NS_NewLocalFile(nsDependentString(path, len), true, aFile);
     }
 #elif defined(MOZ_WIDGET_COCOA)
     {
@@ -543,14 +477,12 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
           }
         }
       }
-      return NS_NewNativeLocalFile(nsDependentCString(tPath),
-                                   true,
-                                   aFile);
+      return NS_NewNativeLocalFile(nsDependentCString(tPath), true, aFile);
     }
 #else
-    break;
+      break;
 #endif
-#if defined (XP_WIN)
+#if defined(XP_WIN)
     case Win_SystemDirectory: {
       int32_t len = ::GetSystemDirectoryW(path, MAX_PATH);
 
@@ -558,12 +490,10 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
       if (!len || len > MAX_PATH - 2) {
         break;
       }
-      path[len]   = L'\\';
+      path[len] = L'\\';
       path[++len] = L'\0';
 
-      return NS_NewLocalFile(nsDependentString(path, len),
-                             true,
-                             aFile);
+      return NS_NewLocalFile(nsDependentString(path, len), true, aFile);
     }
 
     case Win_WindowsDirectory: {
@@ -574,12 +504,10 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
         break;
       }
 
-      path[len]   = L'\\';
+      path[len] = L'\\';
       path[++len] = L'\0';
 
-      return NS_NewLocalFile(nsDependentString(path, len),
-                             true,
-                             aFile);
+      return NS_NewLocalFile(nsDependentString(path, len), true, aFile);
     }
 
     case Win_ProgramFiles: {
@@ -599,12 +527,10 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
           break;
         }
 
-        path[len]   = L'\\';
+        path[len] = L'\\';
         path[++len] = L'\0';
 
-        rv = NS_NewLocalFile(nsDependentString(path, len),
-                             true,
-                             aFile);
+        rv = NS_NewLocalFile(nsDependentString(path, len), true, aFile);
         if (NS_SUCCEEDED(rv)) {
           return rv;
         }
@@ -625,12 +551,10 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
           break;
         }
 
-        path[len]   = L'\\';
+        path[len] = L'\\';
         path[++len] = L'\0';
 
-        return NS_NewLocalFile(nsDependentString(path, len),
-                               true,
-                               aFile);
+        return NS_NewLocalFile(nsDependentString(path, len), true, aFile);
       }
     }
     case Win_Desktop: {
@@ -643,9 +567,10 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
     case Win_Downloads: {
       // Defined in KnownFolders.h.
       GUID folderid_downloads = {
-        0x374de290, 0x123f, 0x4565,
-        { 0x91, 0x64, 0x39, 0xc4, 0x92, 0x5e, 0x46, 0x7b }
-      };
+          0x374de290,
+          0x123f,
+          0x4565,
+          {0x91, 0x64, 0x39, 0xc4, 0x92, 0x5e, 0x46, 0x7b}};
       nsresult rv = GetKnownFolder(&folderid_downloads, aFile);
       // On WinXP, there is no downloads folder, default
       // to 'Desktop'.
@@ -737,43 +662,33 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
     }
 #if defined(MOZ_CONTENT_SANDBOX)
     case Win_LocalAppdataLow: {
-      // This should only really fail on versions pre-Vista, in which case this
-      // shouldn't have been used in the first place.
       GUID localAppDataLowGuid = FOLDERID_LocalAppDataLow;
       return GetKnownFolder(&localAppDataLowGuid, aFile);
     }
 #endif
     case Win_Documents: {
-      return GetLibrarySaveToPath(CSIDL_MYDOCUMENTS,
-                                  FOLDERID_DocumentsLibrary,
+      return GetLibrarySaveToPath(CSIDL_MYDOCUMENTS, FOLDERID_DocumentsLibrary,
                                   aFile);
     }
     case Win_Pictures: {
-      return GetLibrarySaveToPath(CSIDL_MYPICTURES,
-                                  FOLDERID_PicturesLibrary,
+      return GetLibrarySaveToPath(CSIDL_MYPICTURES, FOLDERID_PicturesLibrary,
                                   aFile);
     }
     case Win_Music: {
-      return GetLibrarySaveToPath(CSIDL_MYMUSIC,
-                                  FOLDERID_MusicLibrary,
-                                  aFile);
+      return GetLibrarySaveToPath(CSIDL_MYMUSIC, FOLDERID_MusicLibrary, aFile);
     }
     case Win_Videos: {
-      return GetLibrarySaveToPath(CSIDL_MYVIDEO,
-                                  FOLDERID_VideosLibrary,
-                                  aFile);
+      return GetLibrarySaveToPath(CSIDL_MYVIDEO, FOLDERID_VideosLibrary, aFile);
     }
 #endif  // XP_WIN
 
 #if defined(XP_UNIX)
     case Unix_LocalDirectory:
       return NS_NewNativeLocalFile(nsDependentCString("/usr/local/netscape/"),
-                                   true,
-                                   aFile);
+                                   true, aFile);
     case Unix_LibDirectory:
-      return NS_NewNativeLocalFile(nsDependentCString("/usr/local/lib/netscape/"),
-                                   true,
-                                   aFile);
+      return NS_NewNativeLocalFile(
+          nsDependentCString("/usr/local/lib/netscape/"), true, aFile);
 
     case Unix_HomeDirectory:
       return GetUnixHomeDir(aFile);
@@ -795,14 +710,23 @@ GetSpecialSystemDirectory(SystemDirectories aSystemSystemDirectory,
   return NS_ERROR_NOT_AVAILABLE;
 }
 
-#if defined (MOZ_WIDGET_COCOA)
-nsresult
-GetOSXFolderType(short aDomain, OSType aFolderType, nsIFile** aLocalFile)
-{
-  OSErr err;
-  FSRef fsRef;
+#if defined(MOZ_WIDGET_COCOA)
+nsresult GetOSXFolderType(short aDomain, OSType aFolderType,
+                          nsIFile** aLocalFile) {
   nsresult rv = NS_ERROR_FAILURE;
 
+  if (aFolderType == kTemporaryFolderType) {
+    NS_NewLocalFile(EmptyString(), true, aLocalFile);
+    nsCOMPtr<nsILocalFileMac> localMacFile(do_QueryInterface(*aLocalFile));
+    if (localMacFile) {
+      rv = localMacFile->InitWithCFURL(
+          CocoaFileUtils::GetTemporaryFolderCFURLRef());
+    }
+    return rv;
+  }
+
+  OSErr err;
+  FSRef fsRef;
   err = ::FSFindFolder(aDomain, aFolderType, kCreateFolder, &fsRef);
   if (err == noErr) {
     NS_NewLocalFile(EmptyString(), true, aLocalFile);
@@ -814,4 +738,3 @@ GetOSXFolderType(short aDomain, OSType aFolderType, nsIFile** aLocalFile)
   return rv;
 }
 #endif
-
