@@ -13,11 +13,10 @@ extern "C" {
 //
 //    ComputeCrc32c(~0, buffer, bufferLength);
 //
-uint32_t
-ComputeCrc32c(uint32_t aCrc, const void *aBuf, size_t aSize);
+uint32_t ComputeCrc32c(uint32_t aCrc, const void *aBuf, size_t aSize);
 
 #ifdef __cplusplus
-} // extern "C"
+}  // extern "C"
 #endif
 
-#endif // crc32c_h
+#endif  // crc32c_h
