@@ -25,6 +25,7 @@
 
 #include "mozilla/EndianUtils.h"
 #include "mozilla/PodOperations.h"
+#include "mozilla/RefPtr.h"
 #include "mozilla/UniquePtr.h"
 
 #include "nsCRT.h"
@@ -32,8 +33,8 @@
 #include "nsISerializable.h"
 #include "nsIClassInfo.h"
 #include "nsComponentManagerUtils.h"
-#include "nsIURI.h" // for NS_IURI_IID
-#include "nsIX509Cert.h" // for NS_IX509CERT_IID
+#include "nsIURI.h"       // for NS_IURI_IID
+#include "nsIX509Cert.h"  // for NS_IX509CERT_IID
 
 #include "jsfriendapi.h"
 
@@ -41,14 +42,29 @@ using mozilla::MakeUnique;
 using mozilla::PodCopy;
 using mozilla::UniquePtr;
 
-NS_IMPL_ISUPPORTS(nsBinaryOutputStream,
-                  nsIObjectOutputStream,
-                  nsIBinaryOutputStream,
-                  nsIOutputStream)
+already_AddRefed<nsIObjectOutputStream> NS_NewObjectOutputStream(
+    nsIOutputStream* aOutputStream) {
+  MOZ_ASSERT(aOutputStream);
+  auto stream = mozilla::MakeRefPtr<nsBinaryOutputStream>();
+
+  MOZ_ALWAYS_SUCCEEDS(stream->SetOutputStream(aOutputStream));
+  return stream.forget();
+}
+
+already_AddRefed<nsIObjectInputStream> NS_NewObjectInputStream(
+    nsIInputStream* aInputStream) {
+  MOZ_ASSERT(aInputStream);
+  auto stream = mozilla::MakeRefPtr<nsBinaryInputStream>();
+
+  MOZ_ALWAYS_SUCCEEDS(stream->SetInputStream(aInputStream));
+  return stream.forget();
+}
+
+NS_IMPL_ISUPPORTS(nsBinaryOutputStream, nsIObjectOutputStream,
+                  nsIBinaryOutputStream, nsIOutputStream)
 
 NS_IMETHODIMP
-nsBinaryOutputStream::Flush()
-{
+nsBinaryOutputStream::Flush() {
   if (NS_WARN_IF(!mOutputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
@@ -56,8 +72,7 @@ nsBinaryOutputStream::Flush()
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::Close()
-{
+nsBinaryOutputStream::Close() {
   if (NS_WARN_IF(!mOutputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
@@ -66,8 +81,7 @@ nsBinaryOutputStream::Close()
 
 NS_IMETHODIMP
 nsBinaryOutputStream::Write(const char* aBuf, uint32_t aCount,
-                            uint32_t* aActualBytes)
-{
+                            uint32_t* aActualBytes) {
   if (NS_WARN_IF(!mOutputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
@@ -76,32 +90,27 @@ nsBinaryOutputStream::Write(const char* aBuf, uint32_t aCount,
 
 NS_IMETHODIMP
 nsBinaryOutputStream::WriteFrom(nsIInputStream* aInStr, uint32_t aCount,
-                                uint32_t* aResult)
-{
+                                uint32_t* aResult) {
   NS_NOTREACHED("WriteFrom");
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
 nsBinaryOutputStream::WriteSegments(nsReadSegmentFun aReader, void* aClosure,
-                                    uint32_t aCount, uint32_t* aResult)
-{
+                                    uint32_t aCount, uint32_t* aResult) {
   NS_NOTREACHED("WriteSegments");
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::IsNonBlocking(bool* aNonBlocking)
-{
+nsBinaryOutputStream::IsNonBlocking(bool* aNonBlocking) {
   if (NS_WARN_IF(!mOutputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
   return mOutputStream->IsNonBlocking(aNonBlocking);
 }
 
-nsresult
-nsBinaryOutputStream::WriteFully(const char* aBuf, uint32_t aCount)
-{
+nsresult nsBinaryOutputStream::WriteFully(const char* aBuf, uint32_t aCount) {
   if (NS_WARN_IF(!mOutputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
@@ -120,8 +129,7 @@ nsBinaryOutputStream::WriteFully(const char* aBuf, uint32_t aCount)
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::SetOutputStream(nsIOutputStream* aOutputStream)
-{
+nsBinaryOutputStream::SetOutputStream(nsIOutputStream* aOutputStream) {
   if (NS_WARN_IF(!aOutputStream)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -131,34 +139,27 @@ nsBinaryOutputStream::SetOutputStream(nsIOutputStream* aOutputStream)
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteBoolean(bool aBoolean)
-{
-  return Write8(aBoolean);
-}
+nsBinaryOutputStream::WriteBoolean(bool aBoolean) { return Write8(aBoolean); }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::Write8(uint8_t aByte)
-{
+nsBinaryOutputStream::Write8(uint8_t aByte) {
   return WriteFully((const char*)&aByte, sizeof(aByte));
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::Write16(uint16_t aNum)
-{
+nsBinaryOutputStream::Write16(uint16_t aNum) {
   aNum = mozilla::NativeEndian::swapToBigEndian(aNum);
   return WriteFully((const char*)&aNum, sizeof(aNum));
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::Write32(uint32_t aNum)
-{
+nsBinaryOutputStream::Write32(uint32_t aNum) {
   aNum = mozilla::NativeEndian::swapToBigEndian(aNum);
   return WriteFully((const char*)&aNum, sizeof(aNum));
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::Write64(uint64_t aNum)
-{
+nsBinaryOutputStream::Write64(uint64_t aNum) {
   nsresult rv;
   uint32_t bytesWritten;
 
@@ -174,24 +175,21 @@ nsBinaryOutputStream::Write64(uint64_t aNum)
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteFloat(float aFloat)
-{
-  NS_ASSERTION(sizeof(float) == sizeof(uint32_t),
-               "False assumption about sizeof(float)");
+nsBinaryOutputStream::WriteFloat(float aFloat) {
+  static_assert(sizeof(float) == sizeof(uint32_t),
+                "False assumption about sizeof(float)");
   return Write32(*reinterpret_cast<uint32_t*>(&aFloat));
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteDouble(double aDouble)
-{
-  NS_ASSERTION(sizeof(double) == sizeof(uint64_t),
-               "False assumption about sizeof(double)");
+nsBinaryOutputStream::WriteDouble(double aDouble) {
+  static_assert(sizeof(double) == sizeof(uint64_t),
+                "False assumption about sizeof(double)");
   return Write64(*reinterpret_cast<uint64_t*>(&aDouble));
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteStringZ(const char* aString)
-{
+nsBinaryOutputStream::WriteStringZ(const char* aString) {
   uint32_t length;
   nsresult rv;
 
@@ -204,8 +202,7 @@ nsBinaryOutputStream::WriteStringZ(const char* aString)
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteWStringZ(const char16_t* aString)
-{
+nsBinaryOutputStream::WriteWStringZ(const char16_t* aString) {
   uint32_t length, byteCount;
   nsresult rv;
 
@@ -246,14 +243,12 @@ nsBinaryOutputStream::WriteWStringZ(const char16_t* aString)
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteUtf8Z(const char16_t* aString)
-{
+nsBinaryOutputStream::WriteUtf8Z(const char16_t* aString) {
   return WriteStringZ(NS_ConvertUTF16toUTF8(aString).get());
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteBytes(const char* aString, uint32_t aLength)
-{
+nsBinaryOutputStream::WriteBytes(const char* aString, uint32_t aLength) {
   nsresult rv;
   uint32_t bytesWritten;
 
@@ -268,30 +263,24 @@ nsBinaryOutputStream::WriteBytes(const char* aString, uint32_t aLength)
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteByteArray(uint8_t* aBytes, uint32_t aLength)
-{
+nsBinaryOutputStream::WriteByteArray(uint8_t* aBytes, uint32_t aLength) {
   return WriteBytes(reinterpret_cast<char*>(aBytes), aLength);
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteObject(nsISupports* aObject, bool aIsStrongRef)
-{
-  return WriteCompoundObject(aObject, NS_GET_IID(nsISupports),
-                             aIsStrongRef);
+nsBinaryOutputStream::WriteObject(nsISupports* aObject, bool aIsStrongRef) {
+  return WriteCompoundObject(aObject, NS_GET_IID(nsISupports), aIsStrongRef);
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteSingleRefObject(nsISupports* aObject)
-{
-  return WriteCompoundObject(aObject, NS_GET_IID(nsISupports),
-                             true);
+nsBinaryOutputStream::WriteSingleRefObject(nsISupports* aObject) {
+  return WriteCompoundObject(aObject, NS_GET_IID(nsISupports), true);
 }
 
 NS_IMETHODIMP
 nsBinaryOutputStream::WriteCompoundObject(nsISupports* aObject,
                                           const nsIID& aIID,
-                                          bool aIsStrongRef)
-{
+                                          bool aIsStrongRef) {
   nsCOMPtr<nsIClassInfo> classInfo = do_QueryInterface(aObject);
   nsCOMPtr<nsISerializable> serializable = do_QueryInterface(aObject);
 
@@ -332,8 +321,7 @@ nsBinaryOutputStream::WriteCompoundObject(nsISupports* aObject,
 }
 
 NS_IMETHODIMP
-nsBinaryOutputStream::WriteID(const nsIID& aIID)
-{
+nsBinaryOutputStream::WriteID(const nsIID& aIID) {
   nsresult rv = Write32(aIID.m0);
   if (NS_WARN_IF(NS_FAILED(rv))) {
     return rv;
@@ -349,19 +337,16 @@ nsBinaryOutputStream::WriteID(const nsIID& aIID)
     return rv;
   }
 
-  for (int i = 0; i < 8; ++i) {
-    rv = Write8(aIID.m3[i]);
-    if (NS_WARN_IF(NS_FAILED(rv))) {
-      return rv;
-    }
+  rv = WriteBytes(reinterpret_cast<const char*>(&aIID.m3[0]), sizeof(aIID.m3));
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
   }
 
   return NS_OK;
 }
 
 NS_IMETHODIMP_(char*)
-nsBinaryOutputStream::GetBuffer(uint32_t aLength, uint32_t aAlignMask)
-{
+nsBinaryOutputStream::GetBuffer(uint32_t aLength, uint32_t aAlignMask) {
   if (mBufferAccess) {
     return mBufferAccess->GetBuffer(aLength, aAlignMask);
   }
@@ -369,21 +354,17 @@ nsBinaryOutputStream::GetBuffer(uint32_t aLength, uint32_t aAlignMask)
 }
 
 NS_IMETHODIMP_(void)
-nsBinaryOutputStream::PutBuffer(char* aBuffer, uint32_t aLength)
-{
+nsBinaryOutputStream::PutBuffer(char* aBuffer, uint32_t aLength) {
   if (mBufferAccess) {
     mBufferAccess->PutBuffer(aBuffer, aLength);
   }
 }
 
-NS_IMPL_ISUPPORTS(nsBinaryInputStream,
-                  nsIObjectInputStream,
-                  nsIBinaryInputStream,
-                  nsIInputStream)
+NS_IMPL_ISUPPORTS(nsBinaryInputStream, nsIObjectInputStream,
+                  nsIBinaryInputStream, nsIInputStream)
 
 NS_IMETHODIMP
-nsBinaryInputStream::Available(uint64_t* aResult)
-{
+nsBinaryInputStream::Available(uint64_t* aResult) {
   if (NS_WARN_IF(!mInputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
@@ -391,8 +372,7 @@ nsBinaryInputStream::Available(uint64_t* aResult)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::Read(char* aBuffer, uint32_t aCount, uint32_t* aNumRead)
-{
+nsBinaryInputStream::Read(char* aBuffer, uint32_t aCount, uint32_t* aNumRead) {
   if (NS_WARN_IF(!mInputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
@@ -422,14 +402,12 @@ nsBinaryInputStream::Read(char* aBuffer, uint32_t aCount, uint32_t* aNumRead)
   return NS_OK;
 }
 
-
 // when forwarding ReadSegments to mInputStream, we need to make sure
 // 'this' is being passed to the writer each time. To do this, we need
 // a thunking function which keeps the real input stream around.
 
 // the closure wrapper
-struct MOZ_STACK_CLASS ReadSegmentsClosure
-{
+struct MOZ_STACK_CLASS ReadSegmentsClosure {
   nsCOMPtr<nsIInputStream> mRealInputStream;
   void* mRealClosure;
   nsWriteSegmentFun mRealWriter;
@@ -438,47 +416,38 @@ struct MOZ_STACK_CLASS ReadSegmentsClosure
 };
 
 // the thunking function
-static nsresult
-ReadSegmentForwardingThunk(nsIInputStream* aStream,
-                           void* aClosure,
-                           const char* aFromSegment,
-                           uint32_t aToOffset,
-                           uint32_t aCount,
-                           uint32_t* aWriteCount)
-{
+static nsresult ReadSegmentForwardingThunk(nsIInputStream* aStream,
+                                           void* aClosure,
+                                           const char* aFromSegment,
+                                           uint32_t aToOffset, uint32_t aCount,
+                                           uint32_t* aWriteCount) {
   ReadSegmentsClosure* thunkClosure =
-    reinterpret_cast<ReadSegmentsClosure*>(aClosure);
+      reinterpret_cast<ReadSegmentsClosure*>(aClosure);
 
   NS_ASSERTION(NS_SUCCEEDED(thunkClosure->mRealResult),
                "How did this get to be a failure status?");
 
-  thunkClosure->mRealResult =
-    thunkClosure->mRealWriter(thunkClosure->mRealInputStream,
-                              thunkClosure->mRealClosure,
-                              aFromSegment,
-                              thunkClosure->mBytesRead + aToOffset,
-                              aCount, aWriteCount);
+  thunkClosure->mRealResult = thunkClosure->mRealWriter(
+      thunkClosure->mRealInputStream, thunkClosure->mRealClosure, aFromSegment,
+      thunkClosure->mBytesRead + aToOffset, aCount, aWriteCount);
 
   return thunkClosure->mRealResult;
 }
 
-
 NS_IMETHODIMP
 nsBinaryInputStream::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
-                                  uint32_t aCount, uint32_t* aResult)
-{
+                                  uint32_t aCount, uint32_t* aResult) {
   if (NS_WARN_IF(!mInputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
 
-  ReadSegmentsClosure thunkClosure = { this, aClosure, aWriter, NS_OK, 0 };
+  ReadSegmentsClosure thunkClosure = {this, aClosure, aWriter, NS_OK, 0};
 
   // mInputStream might give us short reads, so deal with that.
   uint32_t bytesRead;
   do {
     nsresult rv = mInputStream->ReadSegments(ReadSegmentForwardingThunk,
-                                             &thunkClosure,
-                                             aCount, &bytesRead);
+                                             &thunkClosure, aCount, &bytesRead);
 
     if (rv == NS_BASE_STREAM_WOULD_BLOCK && thunkClosure.mBytesRead != 0) {
       // We already read some data.  Return it.
@@ -500,8 +469,7 @@ nsBinaryInputStream::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::IsNonBlocking(bool* aNonBlocking)
-{
+nsBinaryInputStream::IsNonBlocking(bool* aNonBlocking) {
   if (NS_WARN_IF(!mInputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
@@ -509,8 +477,7 @@ nsBinaryInputStream::IsNonBlocking(bool* aNonBlocking)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::Close()
-{
+nsBinaryInputStream::Close() {
   if (NS_WARN_IF(!mInputStream)) {
     return NS_ERROR_UNEXPECTED;
   }
@@ -518,8 +485,7 @@ nsBinaryInputStream::Close()
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::SetInputStream(nsIInputStream* aInputStream)
-{
+nsBinaryInputStream::SetInputStream(nsIInputStream* aInputStream) {
   if (NS_WARN_IF(!aInputStream)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -529,8 +495,7 @@ nsBinaryInputStream::SetInputStream(nsIInputStream* aInputStream)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::ReadBoolean(bool* aBoolean)
-{
+nsBinaryInputStream::ReadBoolean(bool* aBoolean) {
   uint8_t byteResult;
   nsresult rv = Read8(&byteResult);
   if (NS_FAILED(rv)) {
@@ -541,8 +506,7 @@ nsBinaryInputStream::ReadBoolean(bool* aBoolean)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::Read8(uint8_t* aByte)
-{
+nsBinaryInputStream::Read8(uint8_t* aByte) {
   nsresult rv;
   uint32_t bytesRead;
 
@@ -557,8 +521,7 @@ nsBinaryInputStream::Read8(uint8_t* aByte)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::Read16(uint16_t* aNum)
-{
+nsBinaryInputStream::Read16(uint16_t* aNum) {
   uint32_t bytesRead;
   nsresult rv = Read(reinterpret_cast<char*>(aNum), sizeof(*aNum), &bytesRead);
   if (NS_FAILED(rv)) {
@@ -572,8 +535,7 @@ nsBinaryInputStream::Read16(uint16_t* aNum)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::Read32(uint32_t* aNum)
-{
+nsBinaryInputStream::Read32(uint32_t* aNum) {
   uint32_t bytesRead;
   nsresult rv = Read(reinterpret_cast<char*>(aNum), sizeof(*aNum), &bytesRead);
   if (NS_FAILED(rv)) {
@@ -587,8 +549,7 @@ nsBinaryInputStream::Read32(uint32_t* aNum)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::Read64(uint64_t* aNum)
-{
+nsBinaryInputStream::Read64(uint64_t* aNum) {
   uint32_t bytesRead;
   nsresult rv = Read(reinterpret_cast<char*>(aNum), sizeof(*aNum), &bytesRead);
   if (NS_FAILED(rv)) {
@@ -602,29 +563,23 @@ nsBinaryInputStream::Read64(uint64_t* aNum)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::ReadFloat(float* aFloat)
-{
-  NS_ASSERTION(sizeof(float) == sizeof(uint32_t),
-               "False assumption about sizeof(float)");
+nsBinaryInputStream::ReadFloat(float* aFloat) {
+  static_assert(sizeof(float) == sizeof(uint32_t),
+                "False assumption about sizeof(float)");
   return Read32(reinterpret_cast<uint32_t*>(aFloat));
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::ReadDouble(double* aDouble)
-{
-  NS_ASSERTION(sizeof(double) == sizeof(uint64_t),
-               "False assumption about sizeof(double)");
+nsBinaryInputStream::ReadDouble(double* aDouble) {
+  static_assert(sizeof(double) == sizeof(uint64_t),
+                "False assumption about sizeof(double)");
   return Read64(reinterpret_cast<uint64_t*>(aDouble));
 }
 
-static nsresult
-WriteSegmentToCString(nsIInputStream* aStream,
-                      void* aClosure,
-                      const char* aFromSegment,
-                      uint32_t aToOffset,
-                      uint32_t aCount,
-                      uint32_t* aWriteCount)
-{
+static nsresult WriteSegmentToCString(nsIInputStream* aStream, void* aClosure,
+                                      const char* aFromSegment,
+                                      uint32_t aToOffset, uint32_t aCount,
+                                      uint32_t* aWriteCount) {
   nsACString* outString = static_cast<nsACString*>(aClosure);
 
   outString->Append(aFromSegment, aCount);
@@ -635,8 +590,7 @@ WriteSegmentToCString(nsIInputStream* aStream,
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::ReadCString(nsACString& aString)
-{
+nsBinaryInputStream::ReadCString(nsACString& aString) {
   nsresult rv;
   uint32_t length, bytesRead;
 
@@ -658,11 +612,9 @@ nsBinaryInputStream::ReadCString(nsACString& aString)
   return NS_OK;
 }
 
-
 // sometimes, WriteSegmentToString will be handed an odd-number of
 // bytes, which means we only have half of the last char16_t
-struct WriteStringClosure
-{
+struct WriteStringClosure {
   char16_t* mWriteCursor;
   bool mHasCarryoverByte;
   char mCarryoverByte;
@@ -682,18 +634,13 @@ struct WriteStringClosure
 //                              so you have to save the last byte for
 //                              the next carryover
 
-
 // same version of the above, but with correct casting and endian swapping
-static nsresult
-WriteSegmentToString(nsIInputStream* aStream,
-                     void* aClosure,
-                     const char* aFromSegment,
-                     uint32_t aToOffset,
-                     uint32_t aCount,
-                     uint32_t* aWriteCount)
-{
+static nsresult WriteSegmentToString(nsIInputStream* aStream, void* aClosure,
+                                     const char* aFromSegment,
+                                     uint32_t aToOffset, uint32_t aCount,
+                                     uint32_t* aWriteCount) {
   NS_PRECONDITION(aCount > 0, "Why are we being told to write 0 bytes?");
-  NS_PRECONDITION(sizeof(char16_t) == 2, "We can't handle other sizes!");
+  static_assert(sizeof(char16_t) == 2, "We can't handle other sizes!");
 
   WriteStringClosure* closure = static_cast<WriteStringClosure*>(aClosure);
   char16_t* cursor = closure->mWriteCursor;
@@ -706,7 +653,7 @@ WriteSegmentToString(nsIInputStream* aStream,
   // if the last Write had an odd-number of bytes read, then
   if (closure->mHasCarryoverByte) {
     // re-create the two-byte sequence we want to work with
-    char bytes[2] = { closure->mCarryoverByte, *aFromSegment };
+    char bytes[2] = {closure->mCarryoverByte, *aFromSegment};
     *cursor = *(char16_t*)bytes;
     // Now the little endianness dance
     mozilla::NativeEndian::swapToBigEndianInPlace(cursor, 1);
@@ -723,7 +670,7 @@ WriteSegmentToString(nsIInputStream* aStream,
 
   // this array is possibly unaligned... be careful how we access it!
   const char16_t* unicodeSegment =
-    reinterpret_cast<const char16_t*>(aFromSegment);
+      reinterpret_cast<const char16_t*>(aFromSegment);
 
   // calculate number of full characters in segment (aCount could be odd!)
   uint32_t segmentLength = aCount / sizeof(char16_t);
@@ -748,10 +695,8 @@ WriteSegmentToString(nsIInputStream* aStream,
   return NS_OK;
 }
 
-
 NS_IMETHODIMP
-nsBinaryInputStream::ReadString(nsAString& aString)
-{
+nsBinaryInputStream::ReadString(nsAString& aString) {
   nsresult rv;
   uint32_t length, bytesRead;
 
@@ -777,8 +722,8 @@ nsBinaryInputStream::ReadString(nsAString& aString)
   closure.mWriteCursor = start.get();
   closure.mHasCarryoverByte = false;
 
-  rv = ReadSegments(WriteSegmentToString, &closure,
-                    length * sizeof(char16_t), &bytesRead);
+  rv = ReadSegments(WriteSegmentToString, &closure, length * sizeof(char16_t),
+                    &bytesRead);
   if (NS_FAILED(rv)) {
     return rv;
   }
@@ -793,8 +738,7 @@ nsBinaryInputStream::ReadString(nsAString& aString)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::ReadBytes(uint32_t aLength, char** aResult)
-{
+nsBinaryInputStream::ReadBytes(uint32_t aLength, char** aResult) {
   nsresult rv;
   uint32_t bytesRead;
   char* s;
@@ -819,16 +763,14 @@ nsBinaryInputStream::ReadBytes(uint32_t aLength, char** aResult)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::ReadByteArray(uint32_t aLength, uint8_t** aResult)
-{
+nsBinaryInputStream::ReadByteArray(uint32_t aLength, uint8_t** aResult) {
   return ReadBytes(aLength, reinterpret_cast<char**>(aResult));
 }
 
 NS_IMETHODIMP
 nsBinaryInputStream::ReadArrayBuffer(uint32_t aLength,
                                      JS::Handle<JS::Value> aBuffer,
-                                     JSContext* aCx, uint32_t* aReadLength)
-{
+                                     JSContext* aCx, uint32_t* aReadLength) {
   if (!aBuffer.isObject()) {
     return NS_ERROR_FAILURE;
   }
@@ -869,8 +811,9 @@ nsBinaryInputStream::ReadArrayBuffer(uint32_t aLength,
       return NS_ERROR_FAILURE;
     }
 
-    char* data = reinterpret_cast<char*>(JS_GetArrayBufferData(buffer, &isShared, nogc));
-    MOZ_ASSERT(!isShared);      // Implied by JS_GetArrayBufferData()
+    char* data =
+        reinterpret_cast<char*>(JS_GetArrayBufferData(buffer, &isShared, nogc));
+    MOZ_ASSERT(!isShared);  // Implied by JS_GetArrayBufferData()
     if (!data) {
       return NS_ERROR_FAILURE;
     }
@@ -885,8 +828,7 @@ nsBinaryInputStream::ReadArrayBuffer(uint32_t aLength,
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::ReadObject(bool aIsStrongRef, nsISupports** aObject)
-{
+nsBinaryInputStream::ReadObject(bool aIsStrongRef, nsISupports** aObject) {
   nsCID cid;
   nsIID iid;
   nsresult rv = ReadID(&cid);
@@ -904,32 +846,34 @@ nsBinaryInputStream::ReadObject(bool aIsStrongRef, nsISupports** aObject)
   // (As soon as we drop support for upgrading from pre-gecko6, we can
   // remove this chunk.)
   static const nsIID oldURIiid = {
-    0x7a22cc0, 0xce5, 0x11d3,
-    { 0x93, 0x31, 0x0, 0x10, 0x4b, 0xa0, 0xfd, 0x40 }
-  };
+      0x7a22cc0,
+      0xce5,
+      0x11d3,
+      {0x93, 0x31, 0x0, 0x10, 0x4b, 0xa0, 0xfd, 0x40}};
 
   // hackaround for bug 670542
   static const nsIID oldURIiid2 = {
-    0xd6d04c36, 0x0fa4, 0x4db3,
-    { 0xbe, 0x05, 0x4a, 0x18, 0x39, 0x71, 0x03, 0xe2 }
-  };
+      0xd6d04c36,
+      0x0fa4,
+      0x4db3,
+      {0xbe, 0x05, 0x4a, 0x18, 0x39, 0x71, 0x03, 0xe2}};
 
   // hackaround for bug 682031
   static const nsIID oldURIiid3 = {
-    0x12120b20, 0x0929, 0x40e9,
-    { 0x88, 0xcf, 0x6e, 0x08, 0x76, 0x6e, 0x8b, 0x23 }
-  };
+      0x12120b20,
+      0x0929,
+      0x40e9,
+      {0x88, 0xcf, 0x6e, 0x08, 0x76, 0x6e, 0x8b, 0x23}};
 
   // hackaround for bug 1195415
   static const nsIID oldURIiid4 = {
-    0x395fe045, 0x7d18, 0x4adb,
-    { 0xa3, 0xfd, 0xaf, 0x98, 0xc8, 0xa1, 0xaf, 0x11 }
-  };
+      0x395fe045,
+      0x7d18,
+      0x4adb,
+      {0xa3, 0xfd, 0xaf, 0x98, 0xc8, 0xa1, 0xaf, 0x11}};
 
-  if (iid.Equals(oldURIiid) ||
-      iid.Equals(oldURIiid2) ||
-      iid.Equals(oldURIiid3) ||
-      iid.Equals(oldURIiid4)) {
+  if (iid.Equals(oldURIiid) || iid.Equals(oldURIiid2) ||
+      iid.Equals(oldURIiid3) || iid.Equals(oldURIiid4)) {
     const nsIID newURIiid = NS_IURI_IID;
     iid = newURIiid;
   }
@@ -942,9 +886,10 @@ nsBinaryInputStream::ReadObject(bool aIsStrongRef, nsISupports** aObject)
 
   // hackaround for bug 1247580 (FF45 to FF46 transition)
   static const nsIID oldCertIID = {
-    0xf8ed8364, 0xced9, 0x4c6e,
-    { 0x86, 0xba, 0x48, 0xaf, 0x53, 0xc3, 0x93, 0xe6 }
-  };
+      0xf8ed8364,
+      0xced9,
+      0x4c6e,
+      {0x86, 0xba, 0x48, 0xaf, 0x53, 0xc3, 0x93, 0xe6}};
 
   if (iid.Equals(oldCertIID)) {
     const nsIID newCertIID = NS_IX509CERT_IID;
@@ -971,8 +916,7 @@ nsBinaryInputStream::ReadObject(bool aIsStrongRef, nsISupports** aObject)
 }
 
 NS_IMETHODIMP
-nsBinaryInputStream::ReadID(nsID* aResult)
-{
+nsBinaryInputStream::ReadID(nsID* aResult) {
   nsresult rv = Read32(&aResult->m0);
   if (NS_WARN_IF(NS_FAILED(rv))) {
     return rv;
@@ -988,19 +932,21 @@ nsBinaryInputStream::ReadID(nsID* aResult)
     return rv;
   }
 
-  for (int i = 0; i < 8; ++i) {
-    rv = Read8(&aResult->m3[i]);
-    if (NS_WARN_IF(NS_FAILED(rv))) {
-      return rv;
-    }
+  const uint32_t toRead = sizeof(aResult->m3);
+  uint32_t bytesRead = 0;
+  rv = Read(reinterpret_cast<char*>(&aResult->m3[0]), toRead, &bytesRead);
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
+  if (bytesRead != toRead) {
+    return NS_ERROR_FAILURE;
   }
 
   return NS_OK;
 }
 
 NS_IMETHODIMP_(char*)
-nsBinaryInputStream::GetBuffer(uint32_t aLength, uint32_t aAlignMask)
-{
+nsBinaryInputStream::GetBuffer(uint32_t aLength, uint32_t aAlignMask) {
   if (mBufferAccess) {
     return mBufferAccess->GetBuffer(aLength, aAlignMask);
   }
@@ -1008,8 +954,7 @@ nsBinaryInputStream::GetBuffer(uint32_t aLength, uint32_t aAlignMask)
 }
 
 NS_IMETHODIMP_(void)
-nsBinaryInputStream::PutBuffer(char* aBuffer, uint32_t aLength)
-{
+nsBinaryInputStream::PutBuffer(char* aBuffer, uint32_t aLength) {
   if (mBufferAccess) {
     mBufferAccess->PutBuffer(aBuffer, aLength);
   }
