@@ -22,6 +22,7 @@
 #include "nsIClassInfoImpl.h"
 #include "mozilla/Attributes.h"
 #include "mozilla/ipc/InputStreamUtils.h"
+#include "mozilla/ReentrantMonitor.h"
 #include "nsIIPCSerializableInputStream.h"
 
 using namespace mozilla::ipc;
@@ -32,14 +33,12 @@ using mozilla::Some;
 // nsIStringInputStream implementation
 //-----------------------------------------------------------------------------
 
-class nsStringInputStream final
-  : public nsIStringInputStream
-  , public nsISeekableStream
-  , public nsISupportsCString
-  , public nsIIPCSerializableInputStream
-  , public nsICloneableInputStream
-{
-public:
+class nsStringInputStream final : public nsIStringInputStream,
+                                  public nsISeekableStream,
+                                  public nsISupportsCString,
+                                  public nsIIPCSerializableInputStream,
+                                  public nsICloneableInputStream {
+ public:
   NS_DECL_THREADSAFE_ISUPPORTS
   NS_DECL_NSIINPUTSTREAM
   NS_DECL_NSISTRINGINPUTSTREAM
@@ -49,46 +48,23 @@ public:
   NS_DECL_NSIIPCSERIALIZABLEINPUTSTREAM
   NS_DECL_NSICLONEABLEINPUTSTREAM
 
-  nsStringInputStream()
-  {
-    Clear();
-  }
+  nsStringInputStream() : mMon("nsStringInputStream") { Clear(); }
 
-  explicit nsStringInputStream(const nsStringInputStream& aOther)
-    : mOffset(aOther.mOffset)
-  {
-    // Use Assign() here because we don't want the life of the clone to be
-    // dependent on the life of the original stream.
-    mData.Assign(aOther.mData);
-  }
+ private:
+  ~nsStringInputStream() {}
 
-private:
-  ~nsStringInputStream()
-  {
-  }
+  uint32_t Length() const { return mData.Length(); }
 
-  uint32_t Length() const
-  {
-    return mData.Length();
-  }
+  uint32_t LengthRemaining() const { return Length() - mOffset; }
 
-  uint32_t LengthRemaining() const
-  {
-    return Length() - mOffset;
-  }
+  void Clear() { mData.SetIsVoid(true); }
 
-  void Clear()
-  {
-    mData.SetIsVoid(true);
-  }
-
-  bool Closed()
-  {
-    return mData.IsVoid();
-  }
+  bool Closed() { return mData.IsVoid(); }
 
   nsDependentCSubstring mData;
   uint32_t mOffset;
+
+  mozilla::ReentrantMonitor mMon;
 };
 
 // This class needs to support threadsafe refcounting since people often
@@ -98,34 +74,28 @@ NS_IMPL_RELEASE(nsStringInputStream)
 
 NS_IMPL_CLASSINFO(nsStringInputStream, nullptr, nsIClassInfo::THREADSAFE,
                   NS_STRINGINPUTSTREAM_CID)
-NS_IMPL_QUERY_INTERFACE_CI(nsStringInputStream,
-                           nsIStringInputStream,
-                           nsIInputStream,
-                           nsISupportsCString,
-                           nsISeekableStream,
-                           nsIIPCSerializableInputStream,
+NS_IMPL_QUERY_INTERFACE_CI(nsStringInputStream, nsIStringInputStream,
+                           nsIInputStream, nsISupportsCString,
+                           nsISeekableStream, nsIIPCSerializableInputStream,
                            nsICloneableInputStream)
-NS_IMPL_CI_INTERFACE_GETTER(nsStringInputStream,
-                            nsIStringInputStream,
-                            nsIInputStream,
-                            nsISupportsCString,
-                            nsISeekableStream,
-                            nsICloneableInputStream)
+NS_IMPL_CI_INTERFACE_GETTER(nsStringInputStream, nsIStringInputStream,
+                            nsIInputStream, nsISupportsCString,
+                            nsISeekableStream, nsICloneableInputStream)
 
 /////////
 // nsISupportsCString implementation
 /////////
 
 NS_IMETHODIMP
-nsStringInputStream::GetType(uint16_t* aType)
-{
+nsStringInputStream::GetType(uint16_t* aType) {
   *aType = TYPE_CSTRING;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsStringInputStream::GetData(nsACString& data)
-{
+nsStringInputStream::GetData(nsACString& data) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   // The stream doesn't have any data when it is closed.  We could fake it
   // and return an empty string here, but it seems better to keep this return
   // value consistent with the behavior of the other 'getter' methods.
@@ -138,16 +108,19 @@ nsStringInputStream::GetData(nsACString& data)
 }
 
 NS_IMETHODIMP
-nsStringInputStream::SetData(const nsACString& aData)
-{
-  mData.Assign(aData);
+nsStringInputStream::SetData(const nsACString& aData) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
+  if (NS_WARN_IF(!mData.Assign(aData, fallible))) {
+    return NS_ERROR_OUT_OF_MEMORY;
+  }
+
   mOffset = 0;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsStringInputStream::ToString(char** aResult)
-{
+nsStringInputStream::ToString(char** aResult) {
   // NOTE: This method may result in data loss, so we do not implement it.
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -157,19 +130,25 @@ nsStringInputStream::ToString(char** aResult)
 /////////
 
 NS_IMETHODIMP
-nsStringInputStream::SetData(const char* aData, int32_t aDataLen)
-{
+nsStringInputStream::SetData(const char* aData, int32_t aDataLen) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   if (NS_WARN_IF(!aData)) {
     return NS_ERROR_INVALID_ARG;
   }
-  mData.Assign(aData, aDataLen);
+
+  if (NS_WARN_IF(!mData.Assign(aData, aDataLen, fallible))) {
+    return NS_ERROR_OUT_OF_MEMORY;
+  }
+
   mOffset = 0;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsStringInputStream::AdoptData(char* aData, int32_t aDataLen)
-{
+nsStringInputStream::AdoptData(char* aData, int32_t aDataLen) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   if (NS_WARN_IF(!aData)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -179,8 +158,9 @@ nsStringInputStream::AdoptData(char* aData, int32_t aDataLen)
 }
 
 NS_IMETHODIMP
-nsStringInputStream::ShareData(const char* aData, int32_t aDataLen)
-{
+nsStringInputStream::ShareData(const char* aData, int32_t aDataLen) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   if (NS_WARN_IF(!aData)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -195,8 +175,9 @@ nsStringInputStream::ShareData(const char* aData, int32_t aDataLen)
 }
 
 NS_IMETHODIMP_(size_t)
-nsStringInputStream::SizeOfIncludingThis(MallocSizeOf aMallocSizeOf)
-{
+nsStringInputStream::SizeOfIncludingThis(MallocSizeOf aMallocSizeOf) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   size_t n = aMallocSizeOf(this);
   n += mData.SizeOfExcludingThisIfUnshared(aMallocSizeOf);
   return n;
@@ -207,15 +188,17 @@ nsStringInputStream::SizeOfIncludingThis(MallocSizeOf aMallocSizeOf)
 /////////
 
 NS_IMETHODIMP
-nsStringInputStream::Close()
-{
+nsStringInputStream::Close() {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   Clear();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsStringInputStream::Available(uint64_t* aLength)
-{
+nsStringInputStream::Available(uint64_t* aLength) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   NS_ASSERTION(aLength, "null ptr");
 
   if (Closed()) {
@@ -227,16 +210,16 @@ nsStringInputStream::Available(uint64_t* aLength)
 }
 
 NS_IMETHODIMP
-nsStringInputStream::Read(char* aBuf, uint32_t aCount, uint32_t* aReadCount)
-{
+nsStringInputStream::Read(char* aBuf, uint32_t aCount, uint32_t* aReadCount) {
   NS_ASSERTION(aBuf, "null ptr");
   return ReadSegments(NS_CopySegmentToBuffer, aBuf, aCount, aReadCount);
 }
 
 NS_IMETHODIMP
 nsStringInputStream::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
-                                  uint32_t aCount, uint32_t* aResult)
-{
+                                  uint32_t aCount, uint32_t* aResult) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   NS_ASSERTION(aResult, "null ptr");
   NS_ASSERTION(Length() >= mOffset, "bad stream state");
 
@@ -267,8 +250,7 @@ nsStringInputStream::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
 }
 
 NS_IMETHODIMP
-nsStringInputStream::IsNonBlocking(bool* aNonBlocking)
-{
+nsStringInputStream::IsNonBlocking(bool* aNonBlocking) {
   *aNonBlocking = true;
   return NS_OK;
 }
@@ -278,8 +260,9 @@ nsStringInputStream::IsNonBlocking(bool* aNonBlocking)
 /////////
 
 NS_IMETHODIMP
-nsStringInputStream::Seek(int32_t aWhence, int64_t aOffset)
-{
+nsStringInputStream::Seek(int32_t aWhence, int64_t aOffset) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   if (Closed()) {
     return NS_BASE_STREAM_CLOSED;
   }
@@ -310,8 +293,9 @@ nsStringInputStream::Seek(int32_t aWhence, int64_t aOffset)
 }
 
 NS_IMETHODIMP
-nsStringInputStream::Tell(int64_t* aOutWhere)
-{
+nsStringInputStream::Tell(int64_t* aOutWhere) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   if (Closed()) {
     return NS_BASE_STREAM_CLOSED;
   }
@@ -321,8 +305,9 @@ nsStringInputStream::Tell(int64_t* aOutWhere)
 }
 
 NS_IMETHODIMP
-nsStringInputStream::SetEOF()
-{
+nsStringInputStream::SetEOF() {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   if (Closed()) {
     return NS_BASE_STREAM_CLOSED;
   }
@@ -335,26 +320,23 @@ nsStringInputStream::SetEOF()
 // nsIIPCSerializableInputStream implementation
 /////////
 
-void
-nsStringInputStream::Serialize(InputStreamParams& aParams,
-                               FileDescriptorArray& /* aFDs */)
-{
+void nsStringInputStream::Serialize(InputStreamParams& aParams,
+                                    FileDescriptorArray& /* aFDs */) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   StringInputStreamParams params;
   params.data() = PromiseFlatCString(mData);
   aParams = params;
 }
 
-bool
-nsStringInputStream::Deserialize(const InputStreamParams& aParams,
-                                 const FileDescriptorArray& /* aFDs */)
-{
+bool nsStringInputStream::Deserialize(const InputStreamParams& aParams,
+                                      const FileDescriptorArray& /* aFDs */) {
   if (aParams.type() != InputStreamParams::TStringInputStreamParams) {
     NS_ERROR("Received unknown parameters from the other process!");
     return false;
   }
 
-  const StringInputStreamParams& params =
-    aParams.get_StringInputStreamParams();
+  const StringInputStreamParams& params = aParams.get_StringInputStreamParams();
 
   if (NS_FAILED(SetData(params.data()))) {
     NS_WARNING("SetData failed!");
@@ -364,9 +346,9 @@ nsStringInputStream::Deserialize(const InputStreamParams& aParams,
   return true;
 }
 
-Maybe<uint64_t>
-nsStringInputStream::ExpectedSerializedLength()
-{
+Maybe<uint64_t> nsStringInputStream::ExpectedSerializedLength() {
+  ReentrantMonitorAutoEnter lock(mMon);
+
   return Some(static_cast<uint64_t>(Length()));
 }
 
@@ -375,25 +357,31 @@ nsStringInputStream::ExpectedSerializedLength()
 /////////
 
 NS_IMETHODIMP
-nsStringInputStream::GetCloneable(bool* aCloneableOut)
-{
+nsStringInputStream::GetCloneable(bool* aCloneableOut) {
   *aCloneableOut = true;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsStringInputStream::Clone(nsIInputStream** aCloneOut)
-{
-  RefPtr<nsIInputStream> ref = new nsStringInputStream(*this);
+nsStringInputStream::Clone(nsIInputStream** aCloneOut) {
+  ReentrantMonitorAutoEnter lock(mMon);
+
+  RefPtr<nsStringInputStream> ref = new nsStringInputStream();
+  nsresult rv = ref->SetData(mData);
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
+
+  // mOffset is overwritten by SetData().
+  ref->mOffset = mOffset;
+
   ref.forget(aCloneOut);
   return NS_OK;
 }
 
-nsresult
-NS_NewByteInputStream(nsIInputStream** aStreamResult,
-                      const char* aStringToRead, int32_t aLength,
-                      nsAssignmentType aAssignment)
-{
+nsresult NS_NewByteInputStream(nsIInputStream** aStreamResult,
+                               const char* aStringToRead, int32_t aLength,
+                               nsAssignmentType aAssignment) {
   NS_PRECONDITION(aStreamResult, "null out ptr");
 
   RefPtr<nsStringInputStream> stream = new nsStringInputStream();
@@ -422,25 +410,24 @@ NS_NewByteInputStream(nsIInputStream** aStreamResult,
   return NS_OK;
 }
 
-nsresult
-NS_NewCStringInputStream(nsIInputStream** aStreamResult,
-                         const nsACString& aStringToRead)
-{
+nsresult NS_NewCStringInputStream(nsIInputStream** aStreamResult,
+                                  const nsACString& aStringToRead) {
   NS_PRECONDITION(aStreamResult, "null out ptr");
 
   RefPtr<nsStringInputStream> stream = new nsStringInputStream();
 
-  stream->SetData(aStringToRead);
+  nsresult rv = stream->SetData(aStringToRead);
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   stream.forget(aStreamResult);
   return NS_OK;
 }
 
 // factory method for constructing a nsStringInputStream object
-nsresult
-nsStringInputStreamConstructor(nsISupports* aOuter, REFNSIID aIID,
-                               void** aResult)
-{
+nsresult nsStringInputStreamConstructor(nsISupports* aOuter, REFNSIID aIID,
+                                        void** aResult) {
   *aResult = nullptr;
 
   if (NS_WARN_IF(aOuter)) {
