@@ -607,7 +607,7 @@ static bool is_heap(const Array& ary, size_t len) {
     index++;
   }
   return true;
-} 
+}
 
 //----
 
@@ -902,7 +902,16 @@ TEST(TArray, test_fallible)
     if (!success) {
       // We got our OOM.  Check that it didn't come too early.
       oomed = true;
-      ASSERT_GE(i, size_t(8)) << "Got OOM on iteration " << i << ". Too early!";
+#ifdef XP_WIN
+      // 32-bit Windows sometimes OOMs on the 7th, sometimes on the 8th.  To
+      // keep the test green, choose the lower of those: the important thing
+      // here is that some allocations fail and some succeed.  We're not too
+      // concerned about how many iterations it takes.
+      const size_t kOOMIterations = 7;
+#else
+      const size_t kOOMIterations = 8;
+#endif
+      ASSERT_GE(i, kOOMIterations) << "Got OOM on iteration " << i << ". Too early!";
     }
   }
 
