@@ -14,24 +14,20 @@
 #include "mozilla/Telemetry.h"
 #include "mozilla/StaticPtr.h"
 #include "mozilla/UniquePtr.h"
+#include "nsExceptionHandler.h"
 #include "nsReadableUtils.h"
+#include "nsThreadUtils.h"
 #include "mozilla/StackWalk.h"
-#ifdef _WIN64
-#include "mozilla/StackWalk_windows.h"
-#endif
 #include "nsThreadUtils.h"
 #include "nsXULAppAPI.h"
-
-#ifdef MOZ_CRASHREPORTER
-#include "nsExceptionHandler.h"
-#endif
+#include "GeckoProfiler.h"
 
 #ifdef XP_WIN
 #include <windows.h>
 #endif
 
-#if defined(MOZ_ENABLE_PROFILER_SPS) && defined(MOZ_PROFILING) && defined(XP_WIN)
-  #define REPORT_CHROME_HANGS
+#if defined(MOZ_GECKO_PROFILER) && defined(MOZ_PROFILING) && defined(XP_WIN)
+#define REPORT_CHROME_HANGS
 #endif
 
 namespace mozilla {
@@ -78,9 +74,7 @@ static const int32_t MAX_CALL_STACK_PCS = 400;
 #endif
 
 // PrefChangedFunc
-void
-PrefChanged(const char*, void*)
-{
+void PrefChanged(const char*, void*) {
   int32_t newval = Preferences::GetInt(kHangMonitorPrefName);
 #ifdef REPORT_CHROME_HANGS
   // Monitor chrome hangs on the profiling branch if Telemetry enabled
@@ -98,9 +92,7 @@ PrefChanged(const char*, void*)
   }
 }
 
-void
-Crash()
-{
+void Crash() {
   if (gDebugDisableHangMonitor) {
     return;
   }
@@ -111,26 +103,24 @@ Crash()
   }
 #endif
 
-#ifdef MOZ_CRASHREPORTER
-  // If you change this, you must also deal with the threadsafety of AnnotateCrashReport in
-  // non-chrome processes!
+  // If you change this, you must also deal with the threadsafety of
+  // AnnotateCrashReport in non-chrome processes!
   if (GeckoProcessType_Default == XRE_GetProcessType()) {
     CrashReporter::AnnotateCrashReport(NS_LITERAL_CSTRING("Hang"),
                                        NS_LITERAL_CSTRING("1"));
+    CrashReporter::SetMinidumpAnalysisAllThreads();
   }
-#endif
 
-  NS_RUNTIMEABORT("HangMonitor triggered");
+  MOZ_CRASH("HangMonitor triggered");
 }
 
 #ifdef REPORT_CHROME_HANGS
 
-static void
-ChromeStackWalker(uint32_t aFrameNumber, void* aPC, void* aSP, void* aClosure)
-{
+static void ChromeStackWalker(uint32_t aFrameNumber, void* aPC, void* aSP,
+                              void* aClosure) {
   MOZ_ASSERT(aClosure);
   std::vector<uintptr_t>* stack =
-    static_cast<std::vector<uintptr_t>*>(aClosure);
+      static_cast<std::vector<uintptr_t>*>(aClosure);
   if (stack->size() == MAX_CALL_STACK_PCS) {
     return;
   }
@@ -138,11 +128,9 @@ ChromeStackWalker(uint32_t aFrameNumber, void* aPC, void* aSP, void* aClosure)
   stack->push_back(reinterpret_cast<uintptr_t>(aPC));
 }
 
-static void
-GetChromeHangReport(Telemetry::ProcessedStack& aStack,
-                    int32_t& aSystemUptime,
-                    int32_t& aIceCatUptime)
-{
+static void GetChromeHangReport(Telemetry::ProcessedStack& aStack,
+                                int32_t& aSystemUptime,
+                                int32_t& aIceCatUptime) {
   MOZ_ASSERT(winMainThreadHandle);
 
   // The thread we're about to suspend might have the alloc lock
@@ -150,16 +138,9 @@ GetChromeHangReport(Telemetry::ProcessedStack& aStack,
   std::vector<uintptr_t> rawStack;
   rawStack.reserve(MAX_CALL_STACK_PCS);
 
-  // Workaround possible deadlock where the main thread is running a
-  // long-standing JS job, and happens to be in the JIT allocator when we
-  // suspend it. Since, on win 64, this requires holding a process lock that
-  // MozStackWalk requires, take this "workaround lock" to avoid deadlock.
-#ifdef _WIN64
-  AcquireStackWalkWorkaroundLock();
-#endif
   DWORD ret = ::SuspendThread(winMainThreadHandle);
   bool suspended = false;
-  if (ret != -1) {
+  if (ret != (DWORD)-1) {
     // SuspendThread is asynchronous, so the thread may still be running. Use
     // GetThreadContext to ensure it's really suspended.
     // See https://blogs.msdn.microsoft.com/oldnewthing/20150205-00/?p=44743.
@@ -170,22 +151,17 @@ GetChromeHangReport(Telemetry::ProcessedStack& aStack,
     }
   }
 
-#ifdef _WIN64
-  ReleaseStackWalkWorkaroundLock();
-#endif
-
   if (!suspended) {
-    if (ret != -1) {
+    if (ret != (DWORD)-1) {
       MOZ_ALWAYS_TRUE(::ResumeThread(winMainThreadHandle) != DWORD(-1));
     }
     return;
   }
 
-  MozStackWalk(ChromeStackWalker, /* skipFrames */ 0, /* maxFrames */ 0,
-               reinterpret_cast<void*>(&rawStack),
-               reinterpret_cast<uintptr_t>(winMainThreadHandle), nullptr);
+  MozStackWalkThread(ChromeStackWalker, /* skipFrames */ 0, /* maxFrames */ 0,
+                     &rawStack, winMainThreadHandle, nullptr);
   ret = ::ResumeThread(winMainThreadHandle);
-  if (ret == -1) {
+  if (ret == (DWORD)-1) {
     return;
   }
   aStack = Telemetry::GetStackAndModules(rawStack);
@@ -195,10 +171,11 @@ GetChromeHangReport(Telemetry::ProcessedStack& aStack,
 
   // Record IceCat uptime (in minutes) at the time of the hang
   bool error;
-  TimeStamp processCreation = TimeStamp::ProcessCreation(error);
+  TimeStamp processCreation = TimeStamp::ProcessCreation(&error);
   if (!error) {
     TimeDuration td = TimeStamp::Now() - processCreation;
-    aIceCatUptime = (static_cast<int32_t>(td.ToSeconds()) - (gTimeout * 2)) / 60;
+    aIceCatUptime =
+        (static_cast<int32_t>(td.ToSeconds()) - (gTimeout * 2)) / 60;
   } else {
     aIceCatUptime = -1;
   }
@@ -206,10 +183,9 @@ GetChromeHangReport(Telemetry::ProcessedStack& aStack,
 
 #endif
 
-void
-ThreadMain(void*)
-{
-  PR_SetCurrentThreadName("Hang Monitor");
+void ThreadMain(void*) {
+  AUTO_PROFILER_REGISTER_THREAD("Hang Monitor");
+  NS_SetCurrentThreadName("Hang Monitor");
 
   MonitorAutoLock lock(*gMonitor);
 
@@ -223,12 +199,12 @@ ThreadMain(void*)
   Telemetry::ProcessedStack stack;
   int32_t systemUptime = -1;
   int32_t icecatUptime = -1;
-  UniquePtr<HangAnnotations> annotations;
+  HangAnnotations annotations;
 #endif
 
   while (true) {
     if (gShutdown) {
-      return; // Exit the thread
+      return;  // Exit the thread
     }
 
     // avoid rereading the volatile value in this loop
@@ -236,14 +212,12 @@ ThreadMain(void*)
 
     PRIntervalTime now = PR_IntervalNow();
 
-    if (timestamp != PR_INTERVAL_NO_WAIT &&
-        now < timestamp) {
+    if (timestamp != PR_INTERVAL_NO_WAIT && now < timestamp) {
       // 32-bit overflow, reset for another waiting period
-      timestamp = 1; // lowest legal PRInterval value
+      timestamp = 1;  // lowest legal PRInterval value
     }
 
-    if (timestamp != PR_INTERVAL_NO_WAIT &&
-        timestamp == lastTimestamp &&
+    if (timestamp != PR_INTERVAL_NO_WAIT && timestamp == lastTimestamp &&
         gTimeout > 0) {
       ++waitCount;
 #ifdef REPORT_CHROME_HANGS
@@ -257,8 +231,7 @@ ThreadMain(void*)
       // This is the crash-on-hang feature.
       // See bug 867313 for the quirk in the waitCount comparison
       if (waitCount >= 2) {
-        int32_t delay =
-          int32_t(PR_IntervalToSeconds(now - timestamp));
+        int32_t delay = int32_t(PR_IntervalToSeconds(now - timestamp));
         if (delay >= gTimeout) {
           MonitorAutoUnlock unlock(*gMonitor);
           Crash();
@@ -288,9 +261,7 @@ ThreadMain(void*)
   }
 }
 
-void
-Startup()
-{
+void Startup() {
   if (GeckoProcessType_Default != XRE_GetProcessType() &&
       GeckoProcessType_Content != XRE_GetProcessType()) {
     return;
@@ -299,13 +270,13 @@ Startup()
   MOZ_ASSERT(!gMonitor, "Hang monitor already initialized");
   gMonitor = new Monitor("HangMonitor");
 
-  Preferences::RegisterCallback(PrefChanged, kHangMonitorPrefName, nullptr);
+  Preferences::RegisterCallback(PrefChanged, kHangMonitorPrefName);
   PrefChanged(nullptr, nullptr);
 
 #ifdef REPORT_CHROME_HANGS
-  Preferences::RegisterCallback(PrefChanged, kTelemetryPrefName, nullptr);
+  Preferences::RegisterCallback(PrefChanged, kTelemetryPrefName);
   winMainThreadHandle =
-    OpenThread(THREAD_ALL_ACCESS, FALSE, GetCurrentThreadId());
+      OpenThread(THREAD_ALL_ACCESS, FALSE, GetCurrentThreadId());
   if (!winMainThreadHandle) {
     return;
   }
@@ -317,15 +288,12 @@ Startup()
   // start XPCOM but don't ever start the event loop.
   Suspend();
 
-  gThread = PR_CreateThread(PR_USER_THREAD,
-                            ThreadMain,
-                            nullptr, PR_PRIORITY_LOW, PR_GLOBAL_THREAD,
-                            PR_JOINABLE_THREAD, 0);
+  gThread =
+      PR_CreateThread(PR_USER_THREAD, ThreadMain, nullptr, PR_PRIORITY_LOW,
+                      PR_GLOBAL_THREAD, PR_JOINABLE_THREAD, 0);
 }
 
-void
-Shutdown()
-{
+void Shutdown() {
   if (GeckoProcessType_Default != XRE_GetProcessType() &&
       GeckoProcessType_Content != XRE_GetProcessType()) {
     return;
@@ -350,36 +318,38 @@ Shutdown()
   gMonitor = nullptr;
 }
 
-static bool
-IsUIMessageWaiting()
-{
+static bool IsUIMessageWaiting() {
 #ifndef XP_WIN
   return false;
 #else
+  // There should never be mouse, keyboard, or IME messages in a message queue
+  // in the content process, so don't waste time making multiple PeekMessage
+  // calls.
+  if (GeckoProcessType_Content == XRE_GetProcessType()) {
+    return false;
+  }
 #define NS_WM_IMEFIRST WM_IME_SETCONTEXT
-#define NS_WM_IMELAST  WM_IME_KEYUP
+#define NS_WM_IMELAST WM_IME_KEYUP
   BOOL haveUIMessageWaiting = FALSE;
   MSG msg;
-  haveUIMessageWaiting |= ::PeekMessageW(&msg, nullptr, WM_KEYFIRST,
-                                         WM_IME_KEYLAST, PM_NOREMOVE);
-  haveUIMessageWaiting |= ::PeekMessageW(&msg, nullptr, NS_WM_IMEFIRST,
-                                         NS_WM_IMELAST, PM_NOREMOVE);
-  haveUIMessageWaiting |= ::PeekMessageW(&msg, nullptr, WM_MOUSEFIRST,
-                                         WM_MOUSELAST, PM_NOREMOVE);
+  haveUIMessageWaiting |=
+      ::PeekMessageW(&msg, nullptr, WM_KEYFIRST, WM_IME_KEYLAST, PM_NOREMOVE);
+  haveUIMessageWaiting |=
+      ::PeekMessageW(&msg, nullptr, NS_WM_IMEFIRST, NS_WM_IMELAST, PM_NOREMOVE);
+  haveUIMessageWaiting |=
+      ::PeekMessageW(&msg, nullptr, WM_MOUSEFIRST, WM_MOUSELAST, PM_NOREMOVE);
   return haveUIMessageWaiting;
 #endif
 }
 
-void
-NotifyActivity(ActivityType aActivityType)
-{
+void NotifyActivity(ActivityType aActivityType) {
   MOZ_ASSERT(NS_IsMainThread(),
              "HangMonitor::Notify called from off the main thread.");
 
   // Determine the activity type more specifically
   if (aActivityType == kGeneralActivity) {
-    aActivityType = IsUIMessageWaiting() ? kActivityUIAVail :
-                                           kActivityNoUIAVail;
+    aActivityType =
+        IsUIMessageWaiting() ? kActivityUIAVail : kActivityNoUIAVail;
   }
 
   // Calculate the cumulative amount of lag time since the last UI message
@@ -391,8 +361,8 @@ NotifyActivity(ActivityType aActivityType)
     case kActivityUIAVail:
     case kUIActivity:
       if (gTimestamp != PR_INTERVAL_NO_WAIT) {
-        cumulativeUILagMS += PR_IntervalToMilliseconds(PR_IntervalNow() -
-                                                       gTimestamp);
+        cumulativeUILagMS +=
+            PR_IntervalToMilliseconds(PR_IntervalNow() - gTimestamp);
       }
       break;
     default:
@@ -406,8 +376,8 @@ NotifyActivity(ActivityType aActivityType)
 
   // If we have UI activity we should reset the timer and report it
   if (aActivityType == kUIActivity) {
-    mozilla::Telemetry::Accumulate(mozilla::Telemetry::EVENTLOOP_UI_ACTIVITY_EXP_MS,
-                                     cumulativeUILagMS);
+    mozilla::Telemetry::Accumulate(
+        mozilla::Telemetry::EVENTLOOP_UI_ACTIVITY_EXP_MS, cumulativeUILagMS);
     cumulativeUILagMS = 0;
   }
 
@@ -416,9 +386,7 @@ NotifyActivity(ActivityType aActivityType)
   }
 }
 
-void
-Suspend()
-{
+void Suspend() {
   MOZ_ASSERT(NS_IsMainThread(),
              "HangMonitor::Suspend called from off the main thread.");
 
@@ -430,5 +398,5 @@ Suspend()
   }
 }
 
-} // namespace HangMonitor
-} // namespace mozilla
+}  // namespace HangMonitor
+}  // namespace mozilla
