@@ -8,13 +8,13 @@
 #include "TimerThread.h"
 
 #include "nsThreadUtils.h"
-#include "plarena.h"
 #include "pratom.h"
 
 #include "nsIObserverService.h"
 #include "nsIServiceManager.h"
 #include "mozilla/Services.h"
 #include "mozilla/ChaosMode.h"
+#include "mozilla/ArenaAllocator.h"
 #include "mozilla/ArrayUtils.h"
 #include "mozilla/BinarySearch.h"
 
@@ -28,61 +28,52 @@ using namespace mozilla::tasktracer;
 
 NS_IMPL_ISUPPORTS(TimerThread, nsIRunnable, nsIObserver)
 
-TimerThread::TimerThread() :
-  mInitInProgress(false),
-  mInitialized(false),
-  mMonitor("TimerThread.mMonitor"),
-  mShutdown(false),
-  mWaiting(false),
-  mNotified(false),
-  mSleeping(false)
-{
-}
+TimerThread::TimerThread()
+    : mInitialized(false),
+      mMonitor("TimerThread.mMonitor"),
+      mShutdown(false),
+      mWaiting(false),
+      mNotified(false),
+      mSleeping(false),
+      mAllowedEarlyFiringMicroseconds(0) {}
 
-TimerThread::~TimerThread()
-{
+TimerThread::~TimerThread() {
   mThread = nullptr;
 
   NS_ASSERTION(mTimers.IsEmpty(), "Timers remain in TimerThread::~TimerThread");
 }
 
-nsresult
-TimerThread::InitLocks()
-{
-  return NS_OK;
-}
+nsresult TimerThread::InitLocks() { return NS_OK; }
 
 namespace {
 
-class TimerObserverRunnable : public Runnable
-{
-public:
+class TimerObserverRunnable : public Runnable {
+ public:
   explicit TimerObserverRunnable(nsIObserver* aObserver)
-    : mObserver(aObserver)
-  {
-  }
+      : mozilla::Runnable("TimerObserverRunnable"), mObserver(aObserver) {}
 
   NS_DECL_NSIRUNNABLE
 
-private:
+ private:
   nsCOMPtr<nsIObserver> mObserver;
 };
 
 NS_IMETHODIMP
-TimerObserverRunnable::Run()
-{
+TimerObserverRunnable::Run() {
   nsCOMPtr<nsIObserverService> observerService =
-    mozilla::services::GetObserverService();
+      mozilla::services::GetObserverService();
   if (observerService) {
     observerService->AddObserver(mObserver, "sleep_notification", false);
     observerService->AddObserver(mObserver, "wake_notification", false);
-    observerService->AddObserver(mObserver, "suspend_process_notification", false);
-    observerService->AddObserver(mObserver, "resume_process_notification", false);
+    observerService->AddObserver(mObserver, "suspend_process_notification",
+                                 false);
+    observerService->AddObserver(mObserver, "resume_process_notification",
+                                 false);
   }
   return NS_OK;
 }
 
-} // namespace
+}  // namespace
 
 namespace {
 
@@ -93,66 +84,51 @@ namespace {
 // thread.  Because TimerEventAllocator has its own lock, contention over that
 // lock is limited to the allocation and deallocation of nsTimerEvent objects.
 //
-// Because this allocator is layered over PLArenaPool, it never shrinks -- even
+// Because this is layered over ArenaAllocator, it never shrinks -- even
 // "freed" nsTimerEvents aren't truly freed, they're just put onto a free-list
 // for later recycling.  So the amount of memory consumed will always be equal
 // to the high-water mark consumption.  But nsTimerEvents are small and it's
 // unusual to have more than a few hundred of them, so this shouldn't be a
 // problem in practice.
 
-class TimerEventAllocator
-{
-private:
-  struct FreeEntry
-  {
+class TimerEventAllocator {
+ private:
+  struct FreeEntry {
     FreeEntry* mNext;
   };
 
-  PLArenaPool mPool;
+  ArenaAllocator<4096> mPool;
   FreeEntry* mFirstFree;
   mozilla::Monitor mMonitor;
 
-public:
+ public:
   TimerEventAllocator()
-    : mFirstFree(nullptr)
-    , mMonitor("TimerEventAllocator")
-  {
-    PL_InitArenaPool(&mPool, "TimerEventPool", 4096, /* align = */ 0);
-  }
+      : mPool(), mFirstFree(nullptr), mMonitor("TimerEventAllocator") {}
 
-  ~TimerEventAllocator()
-  {
-    PL_FinishArenaPool(&mPool);
-  }
+  ~TimerEventAllocator() {}
 
   void* Alloc(size_t aSize);
   void Free(void* aPtr);
 };
 
-} // namespace
+}  // namespace
 
 // This is a nsICancelableRunnable because we can dispatch it to Workers and
 // those can be shut down at any time, and in these cases, Cancel() is called
 // instead of Run().
-class nsTimerEvent final : public CancelableRunnable
-{
-public:
+class nsTimerEvent final : public CancelableRunnable {
+ public:
   NS_IMETHOD Run() override;
 
-  nsresult Cancel() override
-  {
-    // Since nsTimerImpl is not thread-safe, we should release |mTimer|
-    // here in the target thread to avoid race condition. Otherwise,
-    // ~nsTimerEvent() which calls nsTimerImpl::Release() could run in the
-    // timer thread and result in race condition.
-    mTimer = nullptr;
+  nsresult Cancel() override {
+    mTimer->Cancel();
     return NS_OK;
   }
 
+  NS_IMETHOD GetName(nsACString& aName) override;
+
   nsTimerEvent()
-    : mTimer()
-    , mGeneration(0)
-  {
+      : mozilla::CancelableRunnable("nsTimerEvent"), mTimer(), mGeneration(0) {
     // Note: We override operator new for this class, and the override is
     // fallible!
     sAllocatorUsers++;
@@ -164,41 +140,35 @@ public:
   static void Shutdown();
   static void DeleteAllocatorIfNeeded();
 
-  static void* operator new(size_t aSize) CPP_THROW_NEW
-  {
+  static void* operator new(size_t aSize) CPP_THROW_NEW {
     return sAllocator->Alloc(aSize);
   }
-  void operator delete(void* aPtr)
-  {
+  void operator delete(void* aPtr) {
     sAllocator->Free(aPtr);
     DeleteAllocatorIfNeeded();
   }
 
-  already_AddRefed<nsTimerImpl> ForgetTimer()
-  {
-    return mTimer.forget();
-  }
+  already_AddRefed<nsTimerImpl> ForgetTimer() { return mTimer.forget(); }
 
-  void SetTimer(already_AddRefed<nsTimerImpl> aTimer)
-  {
+  void SetTimer(already_AddRefed<nsTimerImpl> aTimer) {
     mTimer = aTimer;
     mGeneration = mTimer->GetGeneration();
   }
 
-private:
+ private:
   nsTimerEvent(const nsTimerEvent&) = delete;
   nsTimerEvent& operator=(const nsTimerEvent&) = delete;
   nsTimerEvent& operator=(const nsTimerEvent&&) = delete;
 
-  ~nsTimerEvent()
-  {
+  ~nsTimerEvent() {
     MOZ_ASSERT(!sCanDeleteAllocator || sAllocatorUsers > 0,
-               "This will result in us attempting to deallocate the nsTimerEvent allocator twice");
+               "This will result in us attempting to deallocate the "
+               "nsTimerEvent allocator twice");
     sAllocatorUsers--;
   }
 
   RefPtr<nsTimerImpl> mTimer;
-  int32_t      mGeneration;
+  int32_t mGeneration;
 
   static TimerEventAllocator* sAllocator;
   static Atomic<int32_t> sAllocatorUsers;
@@ -211,9 +181,7 @@ bool nsTimerEvent::sCanDeleteAllocator = false;
 
 namespace {
 
-void*
-TimerEventAllocator::Alloc(size_t aSize)
-{
+void* TimerEventAllocator::Alloc(size_t aSize) {
   MOZ_ASSERT(aSize == sizeof(nsTimerEvent));
 
   mozilla::MonitorAutoLock lock(mMonitor);
@@ -223,18 +191,13 @@ TimerEventAllocator::Alloc(size_t aSize)
     p = mFirstFree;
     mFirstFree = mFirstFree->mNext;
   } else {
-    PL_ARENA_ALLOCATE(p, &mPool, aSize);
-    if (!p) {
-      return nullptr;
-    }
+    p = mPool.Allocate(aSize, fallible);
   }
 
   return p;
 }
 
-void
-TimerEventAllocator::Free(void* aPtr)
-{
+void TimerEventAllocator::Free(void* aPtr) {
   mozilla::MonitorAutoLock lock(mMonitor);
 
   FreeEntry* entry = reinterpret_cast<FreeEntry*>(aPtr);
@@ -243,24 +206,16 @@ TimerEventAllocator::Free(void* aPtr)
   mFirstFree = entry;
 }
 
-} // namespace
+}  // namespace
 
-void
-nsTimerEvent::Init()
-{
-  sAllocator = new TimerEventAllocator();
-}
+void nsTimerEvent::Init() { sAllocator = new TimerEventAllocator(); }
 
-void
-nsTimerEvent::Shutdown()
-{
+void nsTimerEvent::Shutdown() {
   sCanDeleteAllocator = true;
   DeleteAllocatorIfNeeded();
 }
 
-void
-nsTimerEvent::DeleteAllocatorIfNeeded()
-{
+void nsTimerEvent::DeleteAllocatorIfNeeded() {
   if (sCanDeleteAllocator && sAllocatorUsers == 0) {
     delete sAllocator;
     sAllocator = nullptr;
@@ -268,46 +223,41 @@ nsTimerEvent::DeleteAllocatorIfNeeded()
 }
 
 NS_IMETHODIMP
-nsTimerEvent::Run()
-{
-  if (!mTimer) {
-    MOZ_ASSERT(false);
-    return NS_OK;
-  }
+nsTimerEvent::GetName(nsACString& aName) {
+  bool current;
+  MOZ_RELEASE_ASSERT(
+      NS_SUCCEEDED(mTimer->mEventTarget->IsOnCurrentThread(&current)) &&
+      current);
 
+  mTimer->GetName(aName);
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsTimerEvent::Run() {
   if (MOZ_LOG_TEST(GetTimerLog(), LogLevel::Debug)) {
     TimeStamp now = TimeStamp::Now();
     MOZ_LOG(GetTimerLog(), LogLevel::Debug,
-           ("[this=%p] time between PostTimerEvent() and Fire(): %fms\n",
-            this, (now - mInitTime).ToMilliseconds()));
+            ("[this=%p] time between PostTimerEvent() and Fire(): %fms\n", this,
+             (now - mInitTime).ToMilliseconds()));
   }
 
   mTimer->Fire(mGeneration);
 
-  // We call Cancel() to correctly release mTimer.
-  // Read more in the Cancel() implementation.
-  return Cancel();
+  return NS_OK;
 }
 
-nsresult
-TimerThread::Init()
-{
+nsresult TimerThread::Init() {
+  mMonitor.AssertCurrentThreadOwns();
   MOZ_LOG(GetTimerLog(), LogLevel::Debug,
-         ("TimerThread::Init [%d]\n", mInitialized));
+          ("TimerThread::Init [%d]\n", mInitialized));
 
-  if (mInitialized) {
-    if (!mThread) {
-      return NS_ERROR_FAILURE;
-    }
+  if (!mInitialized) {
+    nsTimerEvent::Init();
 
-    return NS_OK;
-  }
-
-  nsTimerEvent::Init();
-
-  if (mInitInProgress.exchange(true) == false) {
     // We hold on to mThread to keep the thread alive.
-    nsresult rv = NS_NewThread(getter_AddRefs(mThread), this);
+    nsresult rv =
+        NS_NewNamedThread("Timer Thread", getter_AddRefs(mThread), this);
     if (NS_FAILED(rv)) {
       mThread = nullptr;
     } else {
@@ -319,16 +269,7 @@ TimerThread::Init()
       }
     }
 
-    {
-      MonitorAutoLock lock(mMonitor);
-      mInitialized = true;
-      mMonitor.NotifyAll();
-    }
-  } else {
-    MonitorAutoLock lock(mMonitor);
-    while (!mInitialized) {
-      mMonitor.Wait();
-    }
+    mInitialized = true;
   }
 
   if (!mThread) {
@@ -338,16 +279,14 @@ TimerThread::Init()
   return NS_OK;
 }
 
-nsresult
-TimerThread::Shutdown()
-{
+nsresult TimerThread::Shutdown() {
   MOZ_LOG(GetTimerLog(), LogLevel::Debug, ("TimerThread::Shutdown begin\n"));
 
   if (!mThread) {
     return NS_ERROR_NOT_INITIALIZED;
   }
 
-  nsTArray<nsTimerImpl*> timers;
+  nsTArray<RefPtr<nsTimerImpl>> timers;
   {
     // lock scope
     MonitorAutoLock lock(mMonitor);
@@ -366,18 +305,20 @@ TimerThread::Shutdown()
     // might potentially call some code reentering the same lock
     // that leads to unexpected behavior or deadlock.
     // See bug 422472.
-    timers.AppendElements(mTimers);
+    for (const UniquePtr<Entry>& entry : mTimers) {
+      timers.AppendElement(entry->Take());
+    }
+
     mTimers.Clear();
   }
 
-  uint32_t timersCount = timers.Length();
-  for (uint32_t i = 0; i < timersCount; i++) {
-    nsTimerImpl* timer = timers[i];
-    timer->Cancel();
-    ReleaseTimerInternal(timer);
+  for (const RefPtr<nsTimerImpl>& timer : timers) {
+    if (timer) {
+      timer->Cancel();
+    }
   }
 
-  mThread->Shutdown();    // wait for the thread to die
+  mThread->Shutdown();  // wait for the thread to die
 
   nsTimerEvent::Shutdown();
 
@@ -387,26 +328,23 @@ TimerThread::Shutdown()
 
 namespace {
 
-struct MicrosecondsToInterval
-{
+struct MicrosecondsToInterval {
   PRIntervalTime operator[](size_t aMs) const {
     return PR_MicrosecondsToInterval(aMs);
   }
 };
 
-struct IntervalComparator
-{
+struct IntervalComparator {
   int operator()(PRIntervalTime aInterval) const {
     return (0 < aInterval) ? -1 : 1;
   }
 };
 
-} // namespace
+}  // namespace
 
 NS_IMETHODIMP
-TimerThread::Run()
-{
-  PR_SetCurrentThreadName("Timer");
+TimerThread::Run() {
+  NS_SetCurrentThreadName("Timer");
 
   MonitorAutoLock lock(mMonitor);
 
@@ -420,13 +358,14 @@ TimerThread::Run()
   }
 
   size_t usIntervalResolution;
-  BinarySearchIf(MicrosecondsToInterval(), 0, usForPosInterval, IntervalComparator(), &usIntervalResolution);
+  BinarySearchIf(MicrosecondsToInterval(), 0, usForPosInterval,
+                 IntervalComparator(), &usIntervalResolution);
   MOZ_ASSERT(PR_MicrosecondsToInterval(usIntervalResolution - 1) == 0);
   MOZ_ASSERT(PR_MicrosecondsToInterval(usIntervalResolution) == 1);
 
   // Half of the amount of microseconds needed to get positive PRIntervalTime.
   // We use this to decide how to round our wait times later
-  int32_t halfMicrosecondsIntervalResolution = usIntervalResolution / 2;
+  mAllowedEarlyFiringMicroseconds = usIntervalResolution / 2;
   bool forceRunNextTimer = false;
 
   while (!mShutdown) {
@@ -445,26 +384,24 @@ TimerThread::Run()
     } else {
       waitFor = PR_INTERVAL_NO_TIMEOUT;
       TimeStamp now = TimeStamp::Now();
-      nsTimerImpl* timer = nullptr;
+
+      RemoveLeadingCanceledTimersInternal();
 
       if (!mTimers.IsEmpty()) {
-        timer = mTimers[0];
-
-        if (now >= timer->mTimeout || forceRunThisTimer) {
-    next:
+        if (now >= mTimers[0]->Value()->mTimeout || forceRunThisTimer) {
+        next:
           // NB: AddRef before the Release under RemoveTimerInternal to avoid
           // mRefCnt passing through zero, in case all other refs than the one
           // from mTimers have gone away (the last non-mTimers[i]-ref's Release
           // must be racing with us, blocked in gThread->RemoveTimer waiting
           // for TimerThread::mMonitor, under nsTimerImpl::Release.
 
-          RefPtr<nsTimerImpl> timerRef(timer);
-          RemoveTimerInternal(timer);
-          timer = nullptr;
+          RefPtr<nsTimerImpl> timerRef(mTimers[0]->Take());
+          RemoveFirstTimerInternal();
 
           MOZ_LOG(GetTimerLog(), LogLevel::Debug,
-                 ("Timer thread woke up %fms from when it was supposed to\n",
-                  fabs((now - timerRef->mTimeout).ToMilliseconds())));
+                  ("Timer thread woke up %fms from when it was supposed to\n",
+                   fabs((now - timerRef->mTimeout).ToMilliseconds())));
 
           // We are going to let the call to PostTimerEvent here handle the
           // release of the timer so that we don't end up releasing the timer
@@ -502,16 +439,16 @@ TimerThread::Run()
         }
       }
 
-      if (!mTimers.IsEmpty()) {
-        timer = mTimers[0];
+      RemoveLeadingCanceledTimersInternal();
 
-        TimeStamp timeout = timer->mTimeout;
+      if (!mTimers.IsEmpty()) {
+        TimeStamp timeout = mTimers[0]->Value()->mTimeout;
 
         // Don't wait at all (even for PR_INTERVAL_NO_WAIT) if the next timer
         // is due now or overdue.
         //
         // Note that we can only sleep for integer values of a certain
-        // resolution. We use halfMicrosecondsIntervalResolution, calculated
+        // resolution. We use mAllowedEarlyFiringMicroseconds, calculated
         // before, to do the optimal rounding (i.e., of how to decide what
         // interval is so small we should not wait at all).
         double microseconds = (timeout - now).ToMilliseconds() * 1000;
@@ -520,20 +457,19 @@ TimerThread::Run()
           // The mean value of sFractions must be 1 to ensure that
           // the average of a long sequence of timeouts converges to the
           // actual sum of their times.
-          static const float sFractions[] = {
-            0.0f, 0.25f, 0.5f, 0.75f, 1.0f, 1.75f, 2.75f
-          };
-          microseconds *=
-            sFractions[ChaosMode::randomUint32LessThan(ArrayLength(sFractions))];
+          static const float sFractions[] = {0.0f, 0.25f, 0.5f, 0.75f,
+                                             1.0f, 1.75f, 2.75f};
+          microseconds *= sFractions[ChaosMode::randomUint32LessThan(
+              ArrayLength(sFractions))];
           forceRunNextTimer = true;
         }
 
-        if (microseconds < halfMicrosecondsIntervalResolution) {
+        if (microseconds < mAllowedEarlyFiringMicroseconds) {
           forceRunNextTimer = false;
-          goto next; // round down; execute event now
+          goto next;  // round down; execute event now
         }
         waitFor = PR_MicrosecondsToInterval(
-          static_cast<uint32_t>(microseconds)); // Floor is accurate enough.
+            static_cast<uint32_t>(microseconds));  // Floor is accurate enough.
         if (waitFor == 0) {
           waitFor = 1;  // round up, wait the minimum time we can wait
         }
@@ -542,10 +478,10 @@ TimerThread::Run()
       if (MOZ_LOG_TEST(GetTimerLog(), LogLevel::Debug)) {
         if (waitFor == PR_INTERVAL_NO_TIMEOUT)
           MOZ_LOG(GetTimerLog(), LogLevel::Debug,
-                 ("waiting for PR_INTERVAL_NO_TIMEOUT\n"));
+                  ("waiting for PR_INTERVAL_NO_TIMEOUT\n"));
         else
           MOZ_LOG(GetTimerLog(), LogLevel::Debug,
-                 ("waiting for %u\n", PR_IntervalToMilliseconds(waitFor)));
+                  ("waiting for %u\n", PR_IntervalToMilliseconds(waitFor)));
       }
     }
 
@@ -561,23 +497,25 @@ TimerThread::Run()
   return NS_OK;
 }
 
-nsresult
-TimerThread::AddTimer(nsTimerImpl* aTimer)
-{
+nsresult TimerThread::AddTimer(nsTimerImpl* aTimer) {
   MonitorAutoLock lock(mMonitor);
 
   if (!aTimer->mEventTarget) {
     return NS_ERROR_NOT_INITIALIZED;
   }
 
+  nsresult rv = Init();
+  if (NS_FAILED(rv)) {
+    return rv;
+  }
+
   // Add the timer to our list.
-  int32_t i = AddTimerInternal(aTimer);
-  if (i < 0) {
+  if (!AddTimerInternal(aTimer)) {
     return NS_ERROR_OUT_OF_MEMORY;
   }
 
   // Awaken the timer thread.
-  if (mWaiting && i == 0) {
+  if (mWaiting && mTimers[0]->Value() == aTimer) {
     mNotified = true;
     mMonitor.Notify();
   }
@@ -585,9 +523,7 @@ TimerThread::AddTimer(nsTimerImpl* aTimer)
   return NS_OK;
 }
 
-nsresult
-TimerThread::RemoveTimer(nsTimerImpl* aTimer)
-{
+nsresult TimerThread::RemoveTimer(nsTimerImpl* aTimer) {
   MonitorAutoLock lock(mMonitor);
 
   // Remove the timer from our array.  Tell callers that aTimer was not found
@@ -606,25 +542,95 @@ TimerThread::RemoveTimer(nsTimerImpl* aTimer)
   return NS_OK;
 }
 
+TimeStamp TimerThread::FindNextFireTimeForCurrentThread(TimeStamp aDefault,
+                                                        uint32_t aSearchBound) {
+  MonitorAutoLock lock(mMonitor);
+  TimeStamp timeStamp = aDefault;
+  uint32_t index = 0;
+
+#ifdef DEBUG
+  TimeStamp firstTimeStamp;
+  Entry* initialFirstEntry = nullptr;
+  if (!mTimers.IsEmpty()) {
+    initialFirstEntry = mTimers[0].get();
+    firstTimeStamp = mTimers[0]->Timeout();
+  }
+#endif
+
+  auto end = mTimers.end();
+  while (end != mTimers.begin()) {
+    nsTimerImpl* timer = mTimers[0]->Value();
+    if (timer) {
+      if (timer->mTimeout > aDefault) {
+        timeStamp = aDefault;
+        break;
+      }
+
+      // Don't yield to timers created with the *_LOW_PRIORITY type.
+      if (!timer->IsLowPriority()) {
+        bool isOnCurrentThread = false;
+        nsresult rv =
+            timer->mEventTarget->IsOnCurrentThread(&isOnCurrentThread);
+        if (NS_SUCCEEDED(rv) && isOnCurrentThread) {
+          timeStamp = timer->mTimeout;
+          break;
+        }
+      }
+
+      if (++index > aSearchBound) {
+        // Track the currently highest timeout so that we can bail out when we
+        // reach the bound or when we find a timer for the current thread.
+        // This won't give accurate information if we stop before finding
+        // any timer for the current thread, but at least won't report too
+        // long idle period.
+        timeStamp = timer->mTimeout;
+        break;
+      }
+    }
+
+    std::pop_heap(mTimers.begin(), end, Entry::UniquePtrLessThan);
+    --end;
+  }
+
+  while (end != mTimers.end()) {
+    ++end;
+    std::push_heap(mTimers.begin(), end, Entry::UniquePtrLessThan);
+  }
+
+#ifdef DEBUG
+  if (!mTimers.IsEmpty()) {
+    if (firstTimeStamp != mTimers[0]->Timeout()) {
+      TimeStamp now = TimeStamp::Now();
+      printf_stderr(
+          "firstTimeStamp %f, mTimers[0]->Timeout() %f, "
+          "initialFirstTimer %p, current first %p\n",
+          (firstTimeStamp - now).ToMilliseconds(),
+          (mTimers[0]->Timeout() - now).ToMilliseconds(), initialFirstEntry,
+          mTimers[0].get());
+    }
+  }
+  MOZ_ASSERT_IF(!mTimers.IsEmpty(), firstTimeStamp == mTimers[0]->Timeout());
+#endif
+
+  return timeStamp;
+}
+
 // This function must be called from within a lock
-int32_t
-TimerThread::AddTimerInternal(nsTimerImpl* aTimer)
-{
+bool TimerThread::AddTimerInternal(nsTimerImpl* aTimer) {
   mMonitor.AssertCurrentThreadOwns();
   if (mShutdown) {
-    return -1;
+    return false;
   }
 
   TimeStamp now = TimeStamp::Now();
 
-  TimerAdditionComparator c(now, aTimer);
-  nsTimerImpl** insertSlot = mTimers.InsertElementSorted(aTimer, c);
-
-  if (!insertSlot) {
-    return -1;
+  UniquePtr<Entry>* entry = mTimers.AppendElement(
+      MakeUnique<Entry>(now, aTimer->mTimeout, aTimer), mozilla::fallible);
+  if (!entry) {
+    return false;
   }
 
-  NS_ADDREF(aTimer);
+  std::push_heap(mTimers.begin(), mTimers.end(), Entry::UniquePtrLessThan);
 
 #ifdef MOZ_TASK_TRACER
   // Caller of AddTimer is the parent task of its timer event, so we store the
@@ -632,34 +638,53 @@ TimerThread::AddTimerInternal(nsTimerImpl* aTimer)
   aTimer->GetTLSTraceInfo();
 #endif
 
-  return insertSlot - mTimers.Elements();
-}
-
-bool
-TimerThread::RemoveTimerInternal(nsTimerImpl* aTimer)
-{
-  mMonitor.AssertCurrentThreadOwns();
-  if (!mTimers.RemoveElement(aTimer)) {
-    return false;
-  }
-
-  ReleaseTimerInternal(aTimer);
   return true;
 }
 
-void
-TimerThread::ReleaseTimerInternal(nsTimerImpl* aTimer)
-{
-  if (!mShutdown) {
-    // copied to a local array before releasing in shutdown
-    mMonitor.AssertCurrentThreadOwns();
+bool TimerThread::RemoveTimerInternal(nsTimerImpl* aTimer) {
+  mMonitor.AssertCurrentThreadOwns();
+  if (!aTimer || !aTimer->mHolder) {
+    return false;
   }
-  NS_RELEASE(aTimer);
+  aTimer->mHolder->Forget(aTimer);
+  return true;
 }
 
-already_AddRefed<nsTimerImpl>
-TimerThread::PostTimerEvent(already_AddRefed<nsTimerImpl> aTimerRef)
-{
+void TimerThread::RemoveLeadingCanceledTimersInternal() {
+  mMonitor.AssertCurrentThreadOwns();
+
+  // Move all canceled timers from the front of the list to
+  // the back of the list using std::pop_heap().  We do this
+  // without actually removing them from the list so we can
+  // modify the nsTArray in a single bulk operation.
+  auto sortedEnd = mTimers.end();
+  while (sortedEnd != mTimers.begin() && !mTimers[0]->Value()) {
+    std::pop_heap(mTimers.begin(), sortedEnd, Entry::UniquePtrLessThan);
+    --sortedEnd;
+  }
+
+  // If there were no canceled timers then we are done.
+  if (sortedEnd == mTimers.end()) {
+    return;
+  }
+
+  // Finally, remove the canceled timers from the back of the
+  // nsTArray.  Note, since std::pop_heap() uses iterators
+  // we must convert to nsTArray indices and number of
+  // elements here.
+  mTimers.RemoveElementsAt(sortedEnd - mTimers.begin(),
+                           mTimers.end() - sortedEnd);
+}
+
+void TimerThread::RemoveFirstTimerInternal() {
+  mMonitor.AssertCurrentThreadOwns();
+  MOZ_ASSERT(!mTimers.IsEmpty());
+  std::pop_heap(mTimers.begin(), mTimers.end(), Entry::UniquePtrLessThan);
+  mTimers.RemoveElementAt(mTimers.Length() - 1);
+}
+
+already_AddRefed<nsTimerImpl> TimerThread::PostTimerEvent(
+    already_AddRefed<nsTimerImpl> aTimerRef) {
   mMonitor.AssertCurrentThreadOwns();
 
   RefPtr<nsTimerImpl> timer(aTimerRef);
@@ -713,33 +738,27 @@ TimerThread::PostTimerEvent(already_AddRefed<nsTimerImpl> aTimerRef)
   return nullptr;
 }
 
-void
-TimerThread::DoBeforeSleep()
-{
+void TimerThread::DoBeforeSleep() {
   // Mainthread
   MonitorAutoLock lock(mMonitor);
   mSleeping = true;
 }
 
 // Note: wake may be notified without preceding sleep notification
-void
-TimerThread::DoAfterSleep()
-{
+void TimerThread::DoAfterSleep() {
   // Mainthread
   MonitorAutoLock lock(mMonitor);
   mSleeping = false;
 
-  // Wake up the timer thread to re-process the array to ensure the sleep delay is correct,
-  // and fire any expired timers (perhaps quite a few)
+  // Wake up the timer thread to re-process the array to ensure the sleep delay
+  // is correct, and fire any expired timers (perhaps quite a few)
   mNotified = true;
   mMonitor.Notify();
 }
 
-
 NS_IMETHODIMP
 TimerThread::Observe(nsISupports* /* aSubject */, const char* aTopic,
-                     const char16_t* /* aData */)
-{
+                     const char16_t* /* aData */) {
   if (strcmp(aTopic, "sleep_notification") == 0 ||
       strcmp(aTopic, "suspend_process_notification") == 0) {
     DoBeforeSleep();
@@ -750,3 +769,7 @@ TimerThread::Observe(nsISupports* /* aSubject */, const char* aTopic,
 
   return NS_OK;
 }
+
+uint32_t TimerThread::AllowedEarlyFiringMicroseconds() const {
+  return mAllowedEarlyFiringMicroseconds;
+}
