@@ -25,18 +25,24 @@
 #include "nsIObserverService.h"
 #include "nsXULAppAPI.h"
 #include "mozilla/Services.h"
+#include "GeckoProfiler.h"
 
 #include <stdlib.h>
 
 #if defined(PROCESSMODEL_WINAPI)
-#include "prmem.h"
 #include "nsString.h"
 #include "nsLiteralString.h"
 #include "nsReadableUtils.h"
+#include "mozilla/UniquePtrExtensions.h"
 #else
 #ifdef XP_MACOSX
 #include <crt_externs.h>
 #include <spawn.h>
+#endif
+#ifdef XP_UNIX
+#ifndef XP_MACOSX
+#include "base/process_util.h"
+#endif
 #include <sys/wait.h>
 #include <sys/errno.h>
 #endif
@@ -49,46 +55,44 @@ using namespace mozilla;
 #ifdef XP_MACOSX
 cpu_type_t pref_cpu_types[2] = {
 #if defined(__i386__)
-  CPU_TYPE_X86,
+    CPU_TYPE_X86,
 #elif defined(__x86_64__)
-  CPU_TYPE_X86_64,
+    CPU_TYPE_X86_64,
 #elif defined(__ppc__)
-  CPU_TYPE_POWERPC,
+    CPU_TYPE_POWERPC,
 #endif
-  CPU_TYPE_ANY
-};
+    CPU_TYPE_ANY};
 #endif
 
 //-------------------------------------------------------------------//
 // nsIProcess implementation
 //-------------------------------------------------------------------//
-NS_IMPL_ISUPPORTS(nsProcess, nsIProcess,
-                  nsIObserver)
+NS_IMPL_ISUPPORTS(nsProcess, nsIProcess, nsIObserver)
 
-//Constructor
+// Constructor
 nsProcess::nsProcess()
-  : mThread(nullptr)
-  , mLock("nsProcess.mLock")
-  , mShutdown(false)
-  , mBlocking(false)
-  , mPid(-1)
-  , mObserver(nullptr)
-  , mWeakObserver(nullptr)
-  , mExitValue(-1)
-#if !defined(XP_MACOSX)
-  , mProcess(nullptr)
+    : mThread(nullptr),
+      mLock("nsProcess.mLock"),
+      mShutdown(false),
+      mBlocking(false),
+      mStartHidden(false),
+      mNoShell(false),
+      mPid(-1),
+      mObserver(nullptr),
+      mWeakObserver(nullptr),
+      mExitValue(-1)
+#if !defined(XP_UNIX)
+      ,
+      mProcess(nullptr)
 #endif
 {
 }
 
-//Destructor
-nsProcess::~nsProcess()
-{
-}
+// Destructor
+nsProcess::~nsProcess() {}
 
 NS_IMETHODIMP
-nsProcess::Init(nsIFile* aExecutable)
-{
+nsProcess::Init(nsIFile* aExecutable) {
   if (mExecutable) {
     return NS_ERROR_ALREADY_INITIALIZED;
   }
@@ -98,7 +102,7 @@ nsProcess::Init(nsIFile* aExecutable)
   }
   bool isFile;
 
-  //First make sure the file exists
+  // First make sure the file exists
   nsresult rv = aExecutable->IsFile(&isFile);
   if (NS_FAILED(rv)) {
     return rv;
@@ -107,9 +111,9 @@ nsProcess::Init(nsIFile* aExecutable)
     return NS_ERROR_FAILURE;
   }
 
-  //Store the nsIFile in mExecutable
+  // Store the nsIFile in mExecutable
   mExecutable = aExecutable;
-  //Get the path because it is needed by the NSPR process creation
+  // Get the path because it is needed by the NSPR process creation
 #ifdef XP_WIN
   rv = mExecutable->GetTarget(mTargetPath);
   if (NS_FAILED(rv) || mTargetPath.IsEmpty())
@@ -119,12 +123,10 @@ nsProcess::Init(nsIFile* aExecutable)
   return rv;
 }
 
-
 #if defined(XP_WIN)
-// Out param `aWideCmdLine` must be PR_Freed by the caller.
-static int
-assembleCmdLine(char* const* aArgv, wchar_t** aWideCmdLine, UINT aCodePage)
-{
+// Out param `aWideCmdLine` must be free()d by the caller.
+static int assembleCmdLine(char* const* aArgv, wchar_t** aWideCmdLine,
+                           UINT aCodePage) {
   char* const* arg;
   char* p;
   char* q;
@@ -146,11 +148,11 @@ assembleCmdLine(char* const* aArgv, wchar_t** aWideCmdLine, UINT aCodePage)
      * Finally, we need a space between arguments, and
      * a null byte at the end of command line.
      */
-    cmdLineSize += 2 * strlen(*arg)  /* \ and " need to be escaped */
-                   + 2               /* we quote every argument */
-                   + 1;              /* space in between, or final null */
+    cmdLineSize += 2 * strlen(*arg) /* \ and " need to be escaped */
+                   + 2              /* we quote every argument */
+                   + 1;             /* space in between, or final null */
   }
-  p = cmdLine = (char*)PR_MALLOC(cmdLineSize * sizeof(char));
+  p = cmdLine = (char*)malloc(cmdLineSize * sizeof(char));
   if (!p) {
     return -1;
   }
@@ -225,20 +227,24 @@ assembleCmdLine(char* const* aArgv, wchar_t** aWideCmdLine, UINT aCodePage)
 
   *p = '\0';
   int32_t numChars = MultiByteToWideChar(aCodePage, 0, cmdLine, -1, nullptr, 0);
-  *aWideCmdLine = (wchar_t*)PR_MALLOC(numChars * sizeof(wchar_t));
+  *aWideCmdLine = (wchar_t*)malloc(numChars * sizeof(wchar_t));
   MultiByteToWideChar(aCodePage, 0, cmdLine, -1, *aWideCmdLine, numChars);
-  PR_Free(cmdLine);
+  free(cmdLine);
   return 0;
 }
 #endif
 
-void
-nsProcess::Monitor(void* aArg)
-{
+void nsProcess::Monitor(void* aArg) {
   RefPtr<nsProcess> process = dont_AddRef(static_cast<nsProcess*>(aArg));
 
+#ifdef MOZ_GECKO_PROFILER
+  Maybe<AutoProfilerRegisterThread> registerThread;
   if (!process->mBlocking) {
-    PR_SetCurrentThreadName("RunProcess");
+    registerThread.emplace("RunProcess");
+  }
+#endif
+  if (!process->mBlocking) {
+    NS_SetCurrentThreadName("RunProcess");
   }
 
 #if defined(PROCESSMODEL_WINAPI)
@@ -263,7 +269,7 @@ nsProcess::Monitor(void* aArg)
     }
   }
 #else
-#ifdef XP_MACOSX
+#ifdef XP_UNIX
   int exitCode = -1;
   int status = 0;
   pid_t result;
@@ -274,7 +280,7 @@ nsProcess::Monitor(void* aArg)
     if (WIFEXITED(status)) {
       exitCode = WEXITSTATUS(status);
     } else if (WIFSIGNALED(status)) {
-      exitCode = 256; // match NSPR's signal exit status
+      exitCode = 256;  // match NSPR's signal exit status
     }
   }
 #else
@@ -287,7 +293,7 @@ nsProcess::Monitor(void* aArg)
   // Lock in case Kill or GetExitCode are called during this
   {
     MutexAutoLock lock(process->mLock);
-#if !defined(XP_MACOSX)
+#if !defined(XP_UNIX)
     process->mProcess = nullptr;
 #endif
     process->mExitValue = exitCode;
@@ -302,16 +308,14 @@ nsProcess::Monitor(void* aArg)
   if (NS_IsMainThread()) {
     process->ProcessComplete();
   } else {
-    NS_DispatchToMainThread(NewRunnableMethod(process, &nsProcess::ProcessComplete));
+    NS_DispatchToMainThread(NewRunnableMethod(
+        "nsProcess::ProcessComplete", process, &nsProcess::ProcessComplete));
   }
 }
 
-void
-nsProcess::ProcessComplete()
-{
+void nsProcess::ProcessComplete() {
   if (mThread) {
-    nsCOMPtr<nsIObserverService> os =
-      mozilla::services::GetObserverService();
+    nsCOMPtr<nsIObserverService> os = mozilla::services::GetObserverService();
     if (os) {
       os->RemoveObserver(this, "xpcom-shutdown");
     }
@@ -343,24 +347,21 @@ nsProcess::ProcessComplete()
 
 // XXXldb |aArgs| has the wrong const-ness
 NS_IMETHODIMP
-nsProcess::Run(bool aBlocking, const char** aArgs, uint32_t aCount)
-{
+nsProcess::Run(bool aBlocking, const char** aArgs, uint32_t aCount) {
   return CopyArgsAndRunProcess(aBlocking, aArgs, aCount, nullptr, false);
 }
 
 // XXXldb |aArgs| has the wrong const-ness
 NS_IMETHODIMP
-nsProcess::RunAsync(const char** aArgs, uint32_t aCount,
-                    nsIObserver* aObserver, bool aHoldWeak)
-{
+nsProcess::RunAsync(const char** aArgs, uint32_t aCount, nsIObserver* aObserver,
+                    bool aHoldWeak) {
   return CopyArgsAndRunProcess(false, aArgs, aCount, aObserver, aHoldWeak);
 }
 
-nsresult
-nsProcess::CopyArgsAndRunProcess(bool aBlocking, const char** aArgs,
-                                 uint32_t aCount, nsIObserver* aObserver,
-                                 bool aHoldWeak)
-{
+nsresult nsProcess::CopyArgsAndRunProcess(bool aBlocking, const char** aArgs,
+                                          uint32_t aCount,
+                                          nsIObserver* aObserver,
+                                          bool aHoldWeak) {
   // Add one to the aCount for the program name and one for null termination.
   char** my_argv = nullptr;
   my_argv = (char**)moz_xmalloc(sizeof(char*) * (aCount + 2));
@@ -385,24 +386,22 @@ nsProcess::CopyArgsAndRunProcess(bool aBlocking, const char** aArgs,
 
 // XXXldb |aArgs| has the wrong const-ness
 NS_IMETHODIMP
-nsProcess::Runw(bool aBlocking, const char16_t** aArgs, uint32_t aCount)
-{
+nsProcess::Runw(bool aBlocking, const char16_t** aArgs, uint32_t aCount) {
   return CopyArgsAndRunProcessw(aBlocking, aArgs, aCount, nullptr, false);
 }
 
 // XXXldb |aArgs| has the wrong const-ness
 NS_IMETHODIMP
 nsProcess::RunwAsync(const char16_t** aArgs, uint32_t aCount,
-                     nsIObserver* aObserver, bool aHoldWeak)
-{
+                     nsIObserver* aObserver, bool aHoldWeak) {
   return CopyArgsAndRunProcessw(false, aArgs, aCount, aObserver, aHoldWeak);
 }
 
-nsresult
-nsProcess::CopyArgsAndRunProcessw(bool aBlocking, const char16_t** aArgs,
-                                  uint32_t aCount, nsIObserver* aObserver,
-                                  bool aHoldWeak)
-{
+nsresult nsProcess::CopyArgsAndRunProcessw(bool aBlocking,
+                                           const char16_t** aArgs,
+                                           uint32_t aCount,
+                                           nsIObserver* aObserver,
+                                           bool aHoldWeak) {
   // Add one to the aCount for the program name and one for null termination.
   char** my_argv = nullptr;
   my_argv = (char**)moz_xmalloc(sizeof(char*) * (aCount + 2));
@@ -427,10 +426,9 @@ nsProcess::CopyArgsAndRunProcessw(bool aBlocking, const char16_t** aArgs,
   return rv;
 }
 
-nsresult
-nsProcess::RunProcess(bool aBlocking, char** aMyArgv, nsIObserver* aObserver,
-                      bool aHoldWeak, bool aArgsUTF8)
-{
+nsresult nsProcess::RunProcess(bool aBlocking, char** aMyArgv,
+                               nsIObserver* aObserver, bool aHoldWeak,
+                               bool aArgsUTF8) {
   NS_WARNING_ASSERTION(!XRE_IsContentProcess(),
                        "No launching of new processes in the content process");
 
@@ -457,46 +455,77 @@ nsProcess::RunProcess(bool aBlocking, char** aMyArgv, nsIObserver* aObserver,
 
 #if defined(PROCESSMODEL_WINAPI)
   BOOL retVal;
-  wchar_t* cmdLine = nullptr;
+  UniqueFreePtr<wchar_t> cmdLine;
 
   // |aMyArgv| is null-terminated and always starts with the program path. If
   // the second slot is non-null then arguments are being passed.
-  if (aMyArgv[1] && assembleCmdLine(aMyArgv + 1, &cmdLine,
-                                    aArgsUTF8 ? CP_UTF8 : CP_ACP) == -1) {
-    return NS_ERROR_FILE_EXECUTION_FAILED;
-  }
+  if (aMyArgv[1] || mNoShell) {
+    // Pass the executable path as argv[0] to the launched program when calling
+    // CreateProcess().
+    char** argv = mNoShell ? aMyArgv : aMyArgv + 1;
 
-  /* The SEE_MASK_NO_CONSOLE flag is important to prevent console windows
-   * from appearing. This makes behavior the same on all platforms. The flag
-   * will not have any effect on non-console applications.
-   */
+    wchar_t* assembledCmdLine = nullptr;
+    if (assembleCmdLine(argv, &assembledCmdLine,
+                        aArgsUTF8 ? CP_UTF8 : CP_ACP) == -1) {
+      return NS_ERROR_FILE_EXECUTION_FAILED;
+    }
+    cmdLine.reset(assembledCmdLine);
+  }
 
   // The program name in aMyArgv[0] is always UTF-8
   NS_ConvertUTF8toUTF16 wideFile(aMyArgv[0]);
 
-  SHELLEXECUTEINFOW sinfo;
-  memset(&sinfo, 0, sizeof(SHELLEXECUTEINFOW));
-  sinfo.cbSize = sizeof(SHELLEXECUTEINFOW);
-  sinfo.hwnd   = nullptr;
-  sinfo.lpFile = wideFile.get();
-  sinfo.nShow  = SW_SHOWNORMAL;
-  sinfo.fMask  = SEE_MASK_FLAG_DDEWAIT |
-                 SEE_MASK_NO_CONSOLE |
-                 SEE_MASK_NOCLOSEPROCESS;
+  if (mNoShell) {
+    STARTUPINFO startupInfo;
+    ZeroMemory(&startupInfo, sizeof(startupInfo));
+    startupInfo.cb = sizeof(startupInfo);
+    startupInfo.dwFlags = STARTF_USESHOWWINDOW;
+    startupInfo.wShowWindow = mStartHidden ? SW_HIDE : SW_SHOWNORMAL;
 
-  if (cmdLine) {
-    sinfo.lpParameters = cmdLine;
-  }
+    PROCESS_INFORMATION processInfo;
+    retVal = CreateProcess(/* lpApplicationName = */ wideFile.get(),
+                           /* lpCommandLine */ cmdLine.get(),
+                           /* lpProcessAttributes = */ NULL,
+                           /* lpThreadAttributes = */ NULL,
+                           /* bInheritHandles = */ FALSE,
+                           /* dwCreationFlags = */ 0,
+                           /* lpEnvironment = */ NULL,
+                           /* lpCurrentDirectory = */ NULL,
+                           /* lpStartupInfo = */ &startupInfo,
+                           /* lpProcessInformation */ &processInfo);
 
-  retVal = ShellExecuteExW(&sinfo);
-  if (!retVal) {
-    return NS_ERROR_FILE_EXECUTION_FAILED;
-  }
+    if (!retVal) {
+      return NS_ERROR_FILE_EXECUTION_FAILED;
+    }
 
-  mProcess = sinfo.hProcess;
+    CloseHandle(processInfo.hThread);
 
-  if (cmdLine) {
-    PR_Free(cmdLine);
+    mProcess = processInfo.hProcess;
+  } else {
+    SHELLEXECUTEINFOW sinfo;
+    memset(&sinfo, 0, sizeof(SHELLEXECUTEINFOW));
+    sinfo.cbSize = sizeof(SHELLEXECUTEINFOW);
+    sinfo.hwnd = nullptr;
+    sinfo.lpFile = wideFile.get();
+    sinfo.nShow = mStartHidden ? SW_HIDE : SW_SHOWNORMAL;
+
+    /* The SEE_MASK_NO_CONSOLE flag is important to prevent console windows
+     * from appearing. This makes behavior the same on all platforms. The flag
+     * will not have any effect on non-console applications.
+     */
+    sinfo.fMask =
+        SEE_MASK_FLAG_DDEWAIT | SEE_MASK_NO_CONSOLE | SEE_MASK_NOCLOSEPROCESS;
+
+    if (cmdLine) {
+      sinfo.lpParameters = cmdLine.get();
+    }
+
+    retVal = ShellExecuteExW(&sinfo);
+    if (!retVal) {
+      return NS_ERROR_FILE_EXECUTION_FAILED;
+    }
+
+    mProcess = sinfo.hProcess;
   }
 
   mPid = GetProcessId(mProcess);
@@ -528,13 +557,26 @@ nsProcess::RunProcess(bool aBlocking, char** aMyArgv, nsIObserver* aObserver,
   if (result != 0) {
     return NS_ERROR_FAILURE;
   }
+#elif defined(XP_UNIX)
+  base::LaunchOptions options;
+  std::vector<std::string> argvVec;
+  for (char** arg = aMyArgv; *arg != nullptr; ++arg) {
+    argvVec.push_back(*arg);
+  }
+  pid_t newPid;
+  if (base::LaunchApp(argvVec, options, &newPid)) {
+    static_assert(sizeof(pid_t) <= sizeof(int32_t),
+                  "mPid is large enough to hold a pid");
+    mPid = static_cast<int32_t>(newPid);
+  } else {
+    return NS_ERROR_FAILURE;
+  }
 #else
   mProcess = PR_CreateProcess(aMyArgv[0], aMyArgv, nullptr, nullptr);
   if (!mProcess) {
     return NS_ERROR_FAILURE;
   }
-  struct MYProcess
-  {
+  struct MYProcess {
     uint32_t pid;
   };
   MYProcess* ptrProc = (MYProcess*)mProcess;
@@ -549,17 +591,16 @@ nsProcess::RunProcess(bool aBlocking, char** aMyArgv, nsIObserver* aObserver,
       return NS_ERROR_FILE_EXECUTION_FAILED;
     }
   } else {
-    mThread = PR_CreateThread(PR_SYSTEM_THREAD, Monitor, this,
-                              PR_PRIORITY_NORMAL, PR_GLOBAL_THREAD,
-                              PR_JOINABLE_THREAD, 0);
+    mThread =
+        PR_CreateThread(PR_SYSTEM_THREAD, Monitor, this, PR_PRIORITY_NORMAL,
+                        PR_GLOBAL_THREAD, PR_JOINABLE_THREAD, 0);
     if (!mThread) {
       NS_RELEASE_THIS();
       return NS_ERROR_FAILURE;
     }
 
     // It isn't a failure if we just can't watch for shutdown
-    nsCOMPtr<nsIObserverService> os =
-      mozilla::services::GetObserverService();
+    nsCOMPtr<nsIObserverService> os = mozilla::services::GetObserverService();
     if (os) {
       os->AddObserver(this, "xpcom-shutdown", false);
     }
@@ -569,8 +610,7 @@ nsProcess::RunProcess(bool aBlocking, char** aMyArgv, nsIObserver* aObserver,
 }
 
 NS_IMETHODIMP
-nsProcess::GetIsRunning(bool* aIsRunning)
-{
+nsProcess::GetIsRunning(bool* aIsRunning) {
   if (mThread) {
     *aIsRunning = true;
   } else {
@@ -581,8 +621,31 @@ nsProcess::GetIsRunning(bool* aIsRunning)
 }
 
 NS_IMETHODIMP
-nsProcess::GetPid(uint32_t* aPid)
-{
+nsProcess::GetStartHidden(bool* aStartHidden) {
+  *aStartHidden = mStartHidden;
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsProcess::SetStartHidden(bool aStartHidden) {
+  mStartHidden = aStartHidden;
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsProcess::GetNoShell(bool* aNoShell) {
+  *aNoShell = mNoShell;
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsProcess::SetNoShell(bool aNoShell) {
+  mNoShell = aNoShell;
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsProcess::GetPid(uint32_t* aPid) {
   if (!mThread) {
     return NS_ERROR_FAILURE;
   }
@@ -594,8 +657,7 @@ nsProcess::GetPid(uint32_t* aPid)
 }
 
 NS_IMETHODIMP
-nsProcess::Kill()
-{
+nsProcess::Kill() {
   if (!mThread) {
     return NS_ERROR_FAILURE;
   }
@@ -606,7 +668,7 @@ nsProcess::Kill()
     if (TerminateProcess(mProcess, 0) == 0) {
       return NS_ERROR_FAILURE;
     }
-#elif defined(XP_MACOSX)
+#elif defined(XP_UNIX)
     if (kill(mPid, SIGKILL) != 0) {
       return NS_ERROR_FAILURE;
     }
@@ -630,8 +692,7 @@ nsProcess::Kill()
 }
 
 NS_IMETHODIMP
-nsProcess::GetExitValue(int32_t* aExitValue)
-{
+nsProcess::GetExitValue(int32_t* aExitValue) {
   MutexAutoLock lock(mLock);
 
   *aExitValue = mExitValue;
@@ -641,12 +702,10 @@ nsProcess::GetExitValue(int32_t* aExitValue)
 
 NS_IMETHODIMP
 nsProcess::Observe(nsISupports* aSubject, const char* aTopic,
-                   const char16_t* aData)
-{
+                   const char16_t* aData) {
   // Shutting down, drop all references
   if (mThread) {
-    nsCOMPtr<nsIObserverService> os =
-      mozilla::services::GetObserverService();
+    nsCOMPtr<nsIObserverService> os = mozilla::services::GetObserverService();
     if (os) {
       os->RemoveObserver(this, "xpcom-shutdown");
     }
